Package com.softlayer.api.service
Interface Brand.Service
- All Superinterfaces:
Maskable,ResultLimitable,Service
- Enclosing class:
- Brand
@ApiService("SoftLayer_Brand") public static interface Brand.Service extends Service
Every IBM Cloud Infrastructure customer account is associated to a brand.
IBM Cloud Infrastructure customers are unable to change their brand information in the portal or the API.
IBM Cloud Infrastructure customers are unable to change their brand information in the portal or the API.
- See Also:
- SoftLayer_Brand
-
Method Summary
Modifier and Type Method Description Brand.ServiceAsyncasAsync()Get an async version of this serviceAccountcreateCustomerAccount(Account account, Boolean bypassDuplicateAccountCheck)Create a new customer account record.BrandcreateObject(Brand templateObject)
createObject() allows the creation of a new brand.VoiddisableAccount(Long accountId)Disable an account associated with this Brand.AccountgetAccount()BooleangetAllowAccountCreationFlag()This flag indicates if creation of accounts is allowed.List<Account>getAllOwnedAccounts()All accounts owned by the brand.List<Subject>getAllTicketSubjects(Account account)(DEPRECATED) Use [[SoftLayer_Ticket_Subject::getAllObjects]] method.PartnergetBusinessPartner()Business Partner details for the brand.BooleangetBusinessPartnerFlag()Flag indicating if the brand is a business partner.CataloggetCatalog()The Product Catalog for the BrandList<Contact>getContactInformation()Retrieve the contact information for the brand such as the corporate or support contact.List<Contact>getContacts()The contacts for the brand.List<CustomerCountry>getCustomerCountryLocationRestrictions()This references relationship between brands, locations and countries associated with a user's account that are ineligible when ordering products.BrandgetDistributor()BooleangetDistributorChildFlag()StringgetDistributorFlag()List<Hardware>getHardware()An account's associated hardware objects.BooleangetHasAgentAdvancedSupportFlag()BooleangetHasAgentSupportFlag()StringgetMerchantName()Get the payment processor merchant name.BrandgetObject()List<Ticket>getOpenTickets()List<Account>getOwnedAccounts()Active accounts owned by the brand.LevelgetSecurityLevel()List<Group>getTicketGroups()List<Ticket>getTickets()StringgetToken(Long userId)(DEPRECATED) Use [[SoftLayer_User_Customer::getImpersonationToken]] method.List<Customer>getUsers()List<Guest>getVirtualGuests()An account's associated virtual guest objects.BooleanisIbmSlicBrand()Check if the brand is IBM SLIC top level brand or sub brand.BooleanisPlatformServicesBrand()Check if the alternate billing system of brand is Bluemix.VoidreactivateAccount(Long accountId)Reactivate an account associated with this Brand.voidsetMask(Brand.Mask mask)VoidverifyCanDisableAccount(Long accountId)Verify that an account may be disabled by a Brand Agent.VoidverifyCanReactivateAccount(Long accountId)Verify that an account may be reactivated by a Brand Agent.Brand.MaskwithMask()Use the existing mask on this service or create it if not presentBrand.MaskwithNewMask()Overwrite the existing mask on this service with a new one and return itMethods inherited from interface com.softlayer.api.ResultLimitable
getLastResponseTotalItemCount, getResultLimit, setResultLimit
-
Method Details
-
asAsync
Brand.ServiceAsync asAsync()Description copied from interface:ServiceGet an async version of this service -
withNewMask
Brand.Mask withNewMask()Description copied from interface:MaskableOverwrite the existing mask on this service with a new one and return it- Specified by:
withNewMaskin interfaceMaskable
-
withMask
Brand.Mask withMask()Description copied from interface:MaskableUse the existing mask on this service or create it if not present -
setMask
-
createCustomerAccount
Create a new customer account record. By default, the newly created account will be associated to a platform (PaaS) account. To skip the automatic creation and linking to a new platform account, set the bluemixLinkedFlag to false on the account template.- See Also:
- SoftLayer_Brand::createCustomerAccount
-
createObject
createObject() allows the creation of a new brand. This will also create an `account`
to serve as the owner of the brand.
In order to create a brand, a template object must be sent in with several required values.
### Input [[SoftLayer_Brand]]
- `name`
+ Name of brand
+ Required
+ Type: string
- `keyName`
+ Reference key name
+ Required
+ Type: string
- `longName`
+ More descriptive name of brand
+ Required
+ Type: string
- `account.firstName`
+ First Name of account contact
+ Required
+ Type: string
- `account.lastName`
+ Last Name of account contact
+ Required
+ Type: string
- `account.address1`
+ Street Address of company
+ Required
+ Type: string
- `account.address2`
+ Street Address of company
+ Optional
+ Type: string
- `account.city`
+ City of company
+ Required
+ Type: string
- `account.state`
+ State of company (if applicable)
+ Conditionally Required
+ Type: string
- `account.postalCode`
+ Postal Code of company
+ Required
+ Type: string
- `account.country`
+ Country of company
+ Required
+ Type: string
- `account.officePhone`
+ Office Phone number of Company
+ Required
+ Type: string
- `account.alternatePhone`
+ Alternate Phone number of Company
+ Optional
+ Type: string
- `account.companyName`
+ Name of company
+ Required
+ Type: string
- `account.email`
+ Email address of account contact
+ Required
+ Type: string
REST Example:
```
curl -X POST -d '{
"parameters":[{
"name": "Brand Corp",
"keyName": "BRAND_CORP",
"longName": "Brand Corporation",
"account": {
"firstName": "Gloria",
"lastName": "Brand",
"address1": "123 Drive",
"city": "Boston",
"state": "MA",
"postalCode": "02107",
"country": "US",
"companyName": "Brand Corp",
"officePhone": "857-111-1111",
"email": "[email protected]"
}
}]
}' https://api.softlayer.com/rest/v3.1/SoftLayer_Brand/createObject.json
```- See Also:
- SoftLayer_Brand::createObject
-
disableAccount
Disable an account associated with this Brand. Anything that would disqualify the account from being disabled will cause an exception to be raised.- See Also:
- SoftLayer_Brand::disableAccount
-
getAllTicketSubjects
(DEPRECATED) Use [[SoftLayer_Ticket_Subject::getAllObjects]] method.- See Also:
- SoftLayer_Brand::getAllTicketSubjects
-
getContactInformation
Retrieve the contact information for the brand such as the corporate or support contact. This will include the contact name, telephone number, fax number, email address, and mailing address of the contact.- See Also:
- SoftLayer_Brand::getContactInformation
-
getMerchantName
Get the payment processor merchant name.- See Also:
- SoftLayer_Brand::getMerchantName
-
getObject
- See Also:
- SoftLayer_Brand::getObject
-
getToken
(DEPRECATED) Use [[SoftLayer_User_Customer::getImpersonationToken]] method.- See Also:
- SoftLayer_Brand::getToken
-
isIbmSlicBrand
Check if the brand is IBM SLIC top level brand or sub brand.- See Also:
- SoftLayer_Brand::isIbmSlicBrand
-
isPlatformServicesBrand
Check if the alternate billing system of brand is Bluemix.- See Also:
- SoftLayer_Brand::isPlatformServicesBrand
-
reactivateAccount
Reactivate an account associated with this Brand. Anything that would disqualify the account from being reactivated will cause an exception to be raised.- See Also:
- SoftLayer_Brand::reactivateAccount
-
verifyCanDisableAccount
Verify that an account may be disabled by a Brand Agent. Anything that would disqualify the account from being disabled will cause an exception to be raised.- See Also:
- SoftLayer_Brand::verifyCanDisableAccount
-
verifyCanReactivateAccount
Verify that an account may be reactivated by a Brand Agent. Anything that would disqualify the account from being reactivated will cause an exception to be raised. -
getAccount
- See Also:
- SoftLayer_Brand::getAccount
-
getAllOwnedAccounts
All accounts owned by the brand.- See Also:
- SoftLayer_Brand::getAllOwnedAccounts
-
getAllowAccountCreationFlag
This flag indicates if creation of accounts is allowed. -
getBusinessPartner
Business Partner details for the brand. Country Enterprise Code, Channel, Segment, Reseller Level.- See Also:
- SoftLayer_Brand::getBusinessPartner
-
getBusinessPartnerFlag
Flag indicating if the brand is a business partner.- See Also:
- SoftLayer_Brand::getBusinessPartnerFlag
-
getCatalog
The Product Catalog for the Brand- See Also:
- SoftLayer_Brand::getCatalog
-
getContacts
The contacts for the brand.- See Also:
- SoftLayer_Brand::getContacts
-
getCustomerCountryLocationRestrictions
This references relationship between brands, locations and countries associated with a user's account that are ineligible when ordering products. For example, the India datacenter may not be available on this brand for customers that live in Great Britain. -
getDistributor
- See Also:
- SoftLayer_Brand::getDistributor
-
getDistributorChildFlag
- See Also:
- SoftLayer_Brand::getDistributorChildFlag
-
getDistributorFlag
- See Also:
- SoftLayer_Brand::getDistributorFlag
-
getHardware
An account's associated hardware objects.- See Also:
- SoftLayer_Brand::getHardware
-
getHasAgentAdvancedSupportFlag
-
getHasAgentSupportFlag
- See Also:
- SoftLayer_Brand::getHasAgentSupportFlag
-
getOpenTickets
- See Also:
- SoftLayer_Brand::getOpenTickets
-
getOwnedAccounts
Active accounts owned by the brand.- See Also:
- SoftLayer_Brand::getOwnedAccounts
-
getSecurityLevel
- See Also:
- SoftLayer_Brand::getSecurityLevel
-
getTicketGroups
- See Also:
- SoftLayer_Brand::getTicketGroups
-
getTickets
- See Also:
- SoftLayer_Brand::getTickets
-
getUsers
- See Also:
- SoftLayer_Brand::getUsers
-
getVirtualGuests
An account's associated virtual guest objects.- See Also:
- SoftLayer_Brand::getVirtualGuests
-