Package com.softlayer.api.service
Interface Brand.ServiceAsync
- All Superinterfaces:
Maskable,ResultLimitable,ServiceAsync
- Enclosing class:
- Brand
public static interface Brand.ServiceAsync extends ServiceAsync
-
Method Summary
Methods inherited from interface com.softlayer.api.ResultLimitable
getLastResponseTotalItemCount, getResultLimit, setResultLimit
-
Method Details
-
withNewMask
Brand.Mask withNewMask()Description copied from interface:MaskableOverwrite the existing mask on this service with a new one and return it- Specified by:
withNewMaskin interfaceMaskable
-
withMask
Brand.Mask withMask()Description copied from interface:MaskableUse the existing mask on this service or create it if not present -
setMask
-
createCustomerAccount
-
createCustomerAccount
Future<?> createCustomerAccount(Account account, Boolean bypassDuplicateAccountCheck, ResponseHandler<Account> callback) -
createObject
Async version ofBrand.Service.createObject(com.softlayer.api.service.Brand) -
createObject
-
disableAccount
Async version ofBrand.Service.disableAccount(java.lang.Long) -
disableAccount
-
getAllTicketSubjects
-
getAllTicketSubjects
-
getContactInformation
Async version ofBrand.Service.getContactInformation() -
getContactInformation
-
getMerchantName
Async version ofBrand.Service.getMerchantName() -
getMerchantName
-
getObject
Async version ofBrand.Service.getObject() -
getObject
-
getToken
Async version ofBrand.Service.getToken(java.lang.Long) -
getToken
-
isIbmSlicBrand
Async version ofBrand.Service.isIbmSlicBrand() -
isIbmSlicBrand
-
isPlatformServicesBrand
Async version ofBrand.Service.isPlatformServicesBrand() -
isPlatformServicesBrand
-
reactivateAccount
Async version ofBrand.Service.reactivateAccount(java.lang.Long) -
reactivateAccount
-
verifyCanDisableAccount
Async version ofBrand.Service.verifyCanDisableAccount(java.lang.Long) -
verifyCanDisableAccount
-
verifyCanReactivateAccount
Async version ofBrand.Service.verifyCanReactivateAccount(java.lang.Long) -
verifyCanReactivateAccount
-
getAccount
Async version ofBrand.Service.getAccount() -
getAccount
Async callback version ofBrand.Service.getAccount() -
getAllOwnedAccounts
Async version ofBrand.Service.getAllOwnedAccounts() -
getAllOwnedAccounts
Async callback version ofBrand.Service.getAllOwnedAccounts() -
getAllowAccountCreationFlag
Async version ofBrand.Service.getAllowAccountCreationFlag() -
getAllowAccountCreationFlag
Async callback version ofBrand.Service.getAllowAccountCreationFlag() -
getBusinessPartner
Async version ofBrand.Service.getBusinessPartner() -
getBusinessPartner
Async callback version ofBrand.Service.getBusinessPartner() -
getBusinessPartnerFlag
Async version ofBrand.Service.getBusinessPartnerFlag() -
getBusinessPartnerFlag
Async callback version ofBrand.Service.getBusinessPartnerFlag() -
getCatalog
Async version ofBrand.Service.getCatalog() -
getCatalog
Async callback version ofBrand.Service.getCatalog() -
getContacts
Async version ofBrand.Service.getContacts() -
getContacts
Async callback version ofBrand.Service.getContacts() -
getCustomerCountryLocationRestrictions
Future<List<CustomerCountry>> getCustomerCountryLocationRestrictions()Async version ofBrand.Service.getCustomerCountryLocationRestrictions() -
getCustomerCountryLocationRestrictions
Async callback version ofBrand.Service.getCustomerCountryLocationRestrictions() -
getDistributor
Async version ofBrand.Service.getDistributor() -
getDistributor
Async callback version ofBrand.Service.getDistributor() -
getDistributorChildFlag
Async version ofBrand.Service.getDistributorChildFlag() -
getDistributorChildFlag
Async callback version ofBrand.Service.getDistributorChildFlag() -
getDistributorFlag
Async version ofBrand.Service.getDistributorFlag() -
getDistributorFlag
Async callback version ofBrand.Service.getDistributorFlag() -
getHardware
Async version ofBrand.Service.getHardware() -
getHardware
Async callback version ofBrand.Service.getHardware() -
getHasAgentAdvancedSupportFlag
Async version ofBrand.Service.getHasAgentAdvancedSupportFlag() -
getHasAgentAdvancedSupportFlag
Async callback version ofBrand.Service.getHasAgentAdvancedSupportFlag() -
getHasAgentSupportFlag
Async version ofBrand.Service.getHasAgentSupportFlag() -
getHasAgentSupportFlag
Async callback version ofBrand.Service.getHasAgentSupportFlag() -
getOpenTickets
Async version ofBrand.Service.getOpenTickets() -
getOpenTickets
Async callback version ofBrand.Service.getOpenTickets() -
getOwnedAccounts
Async version ofBrand.Service.getOwnedAccounts() -
getOwnedAccounts
Async callback version ofBrand.Service.getOwnedAccounts() -
getSecurityLevel
Async version ofBrand.Service.getSecurityLevel() -
getSecurityLevel
Async callback version ofBrand.Service.getSecurityLevel() -
getTicketGroups
Async version ofBrand.Service.getTicketGroups() -
getTicketGroups
Async callback version ofBrand.Service.getTicketGroups() -
getTickets
Async version ofBrand.Service.getTickets() -
getTickets
Async callback version ofBrand.Service.getTickets() -
getUsers
Async version ofBrand.Service.getUsers() -
getUsers
Async callback version ofBrand.Service.getUsers() -
getVirtualGuests
Async version ofBrand.Service.getVirtualGuests() -
getVirtualGuests
Async callback version ofBrand.Service.getVirtualGuests()
-