Package com.softlayer.api.service
Class Location
java.lang.Object
com.softlayer.api.Type
com.softlayer.api.service.Entity
com.softlayer.api.service.Location
@ApiType("SoftLayer_Location") public class Location extends Entity
Every piece of hardware and network connection owned by SoftLayer is tracked physically by location and stored in the SoftLayer_Location data type. SoftLayer locations exist in parent/child relationships, a convenient way to track equipment from it's city, datacenter, server room, rack, then slot. Network backbones are tied to datacenters only, not to a room, rack, or slot.
- See Also:
- SoftLayer_Location
-
Nested Class Summary
Nested Classes Modifier and Type Class Description static classLocation.Maskstatic interfaceLocation.ServiceThe SoftLayer_Location API service queries SoftLayer's location tree to find locations for all softlayer resources including bare metal servers, virtual servers, storage repositories, datacenters, points of presence, network backbones, and many more.static interfaceLocation.ServiceAsync -
Field Summary
Fields Modifier and Type Field Description protected LongactivePresaleEventCountA count ofprotected List<Event>activePresaleEventsprotected LongbackboneDependentCountA count ofprotected List<Dependent>backboneDependentsprotected BooleanbnppCompliantFlagA flag indicating whether or not the datacenter/location is BNPP compliant.protected BooleaneuCompliantFlagA flag indicating whether or not the datacenter/location is EU compliant.protected LonggroupCountA count of a location can be a member of 1 or more groups.protected List<Group>groupsA location can be a member of 1 or more groups.protected LonghardwareFirewallCountA count ofprotected List<Hardware>hardwareFirewallsprotected LongidThe unique identifier of a specific location.protected booleanidSpecifiedprotected AddresslocationAddressA location's physical address.protected LonglocationAddressCountA count of a location's physical addresses.protected List<Address>locationAddressesA location's physical addresses.protected MemberlocationReservationMemberA location's Dedicated Rack memberprotected StatuslocationStatusThe current locations status.protected StringlongNameA longer location description.protected booleanlongNameSpecifiedprotected StringnameA short location description.protected booleannameSpecifiedprotected AttributenetworkConfigurationAttributeprotected LongonlinePptpVpnUserCountThe total number of users online using SoftLayer's PPTP VPN service for a location.protected LongonlineSslVpnUserCountThe total number of users online using SoftLayer's SSL VPN service for a location.protected StringpathStringprotected LongpriceGroupCountA count of a location can be a member of 1 or more Price Groups.protected List<Group>priceGroupsA location can be a member of 1 or more Price Groups.protected LongregionCountA count of a location can be a member of 1 or more regions.protected List<Region>regionsA location can be a member of 1 or more regions.protected LongstatusIdprotected booleanstatusIdSpecifiedprotected Timezonetimezoneprotected CrossReferencevdrGroupA location can be a member of 1 Bandwidth Pooling Group.Fields inherited from class com.softlayer.api.Type
unknownProperties -
Constructor Summary
Constructors Constructor Description Location() -
Method Summary
Methods inherited from class com.softlayer.api.Type
getUnknownProperties, setUnknownProperties
-
Field Details
-
activePresaleEvents
-
backboneDependents
-
bnppCompliantFlag
A flag indicating whether or not the datacenter/location is BNPP compliant. -
euCompliantFlag
A flag indicating whether or not the datacenter/location is EU compliant. -
groups
A location can be a member of 1 or more groups. This will show which groups to which a location belongs. -
hardwareFirewalls
-
locationAddress
A location's physical address. -
locationAddresses
A location's physical addresses. -
locationReservationMember
A location's Dedicated Rack member -
locationStatus
The current locations status. -
networkConfigurationAttribute
-
onlinePptpVpnUserCount
The total number of users online using SoftLayer's PPTP VPN service for a location. -
onlineSslVpnUserCount
The total number of users online using SoftLayer's SSL VPN service for a location. -
pathString
-
priceGroups
A location can be a member of 1 or more Price Groups. This will show which groups to which a location belongs. -
regions
A location can be a member of 1 or more regions. This will show which regions to which a location belongs. -
timezone
-
vdrGroup
A location can be a member of 1 Bandwidth Pooling Group. This will show which group to which a location belongs. -
id
The unique identifier of a specific location. -
idSpecified
protected boolean idSpecified -
longName
A longer location description. -
longNameSpecified
protected boolean longNameSpecified -
name
A short location description. -
nameSpecified
protected boolean nameSpecified -
statusId
-
statusIdSpecified
protected boolean statusIdSpecified -
activePresaleEventCount
A count of -
backboneDependentCount
A count of -
groupCount
A count of a location can be a member of 1 or more groups. This will show which groups to which a location belongs. -
hardwareFirewallCount
A count of -
locationAddressCount
A count of a location's physical addresses. -
priceGroupCount
A count of a location can be a member of 1 or more Price Groups. This will show which groups to which a location belongs. -
regionCount
A count of a location can be a member of 1 or more regions. This will show which regions to which a location belongs.
-
-
Constructor Details
-
Location
public Location()
-
-
Method Details
-
getActivePresaleEvents
-
getBackboneDependents
-
getBnppCompliantFlag
-
setBnppCompliantFlag
-
getEuCompliantFlag
-
setEuCompliantFlag
-
getGroups
-
getHardwareFirewalls
-
getLocationAddress
-
setLocationAddress
-
getLocationAddresses
-
getLocationReservationMember
-
setLocationReservationMember
-
getLocationStatus
-
setLocationStatus
-
getNetworkConfigurationAttribute
-
setNetworkConfigurationAttribute
-
getOnlinePptpVpnUserCount
-
setOnlinePptpVpnUserCount
-
getOnlineSslVpnUserCount
-
setOnlineSslVpnUserCount
-
getPathString
-
setPathString
-
getPriceGroups
-
getRegions
-
getTimezone
-
setTimezone
-
getVdrGroup
-
setVdrGroup
-
getId
-
setId
-
isIdSpecified
public boolean isIdSpecified() -
unsetId
public void unsetId() -
getLongName
-
setLongName
-
isLongNameSpecified
public boolean isLongNameSpecified() -
unsetLongName
public void unsetLongName() -
getName
-
setName
-
isNameSpecified
public boolean isNameSpecified() -
unsetName
public void unsetName() -
getStatusId
-
setStatusId
-
isStatusIdSpecified
public boolean isStatusIdSpecified() -
unsetStatusId
public void unsetStatusId() -
getActivePresaleEventCount
-
setActivePresaleEventCount
-
getBackboneDependentCount
-
setBackboneDependentCount
-
getGroupCount
-
setGroupCount
-
getHardwareFirewallCount
-
setHardwareFirewallCount
-
getLocationAddressCount
-
setLocationAddressCount
-
getPriceGroupCount
-
setPriceGroupCount
-
getRegionCount
-
setRegionCount
-
asService
-
service
-
service
-