Package com.softlayer.api.service
Class Notification
java.lang.Object
com.softlayer.api.Type
com.softlayer.api.service.Entity
com.softlayer.api.service.Notification
- Direct Known Subclasses:
Mobile
@ApiType("SoftLayer_Notification") public class Notification extends Entity
Details provided for the notification are basic. Details such as the related preferences, name and keyname for the notification can be retrieved. The keyname property for the notification can be used to refer to a notification when integrating into the SoftLayer Notification system. The name property can used more for display purposes.
- See Also:
- SoftLayer_Notification
-
Nested Class Summary
Nested Classes Modifier and Type Class Description static classNotification.Maskstatic interfaceNotification.ServiceSoftLayer Customers can use this service to view all of the available notifications that can be subscribed to.static interfaceNotification.ServiceAsync -
Field Summary
Fields Modifier and Type Field Description protected LongidUnique identifier for the notification.protected booleanidSpecifiedprotected StringkeyNameName that can be used by external systems to refer to a notification.protected booleankeyNameSpecifiedprotected StringnameFriendly name for the notification.protected booleannameSpecifiedprotected LongpreferenceCountA count of the preferences related to the notification.protected List<Preference>preferencesThe preferences related to the notification.protected LongrequiredPreferenceCountA count of the required preferences related to the notification.protected List<Preference>requiredPreferencesThe required preferences related to the notification.Fields inherited from class com.softlayer.api.Type
unknownProperties -
Constructor Summary
Constructors Constructor Description Notification() -
Method Summary
Modifier and Type Method Description Notification.ServiceasService(ApiClient client)LonggetId()StringgetKeyName()StringgetName()LonggetPreferenceCount()List<Preference>getPreferences()LonggetRequiredPreferenceCount()List<Preference>getRequiredPreferences()booleanisIdSpecified()booleanisKeyNameSpecified()booleanisNameSpecified()static Notification.Serviceservice(ApiClient client)static Notification.Serviceservice(ApiClient client, Long id)voidsetId(Long id)voidsetKeyName(String keyName)voidsetName(String name)voidsetPreferenceCount(Long preferenceCount)voidsetRequiredPreferenceCount(Long requiredPreferenceCount)voidunsetId()voidunsetKeyName()voidunsetName()Methods inherited from class com.softlayer.api.Type
getUnknownProperties, setUnknownProperties
-
Field Details
-
preferences
The preferences related to the notification. These are preferences are configurable and optional for subscribers to use. -
requiredPreferences
The required preferences related to the notification. While configurable, the subscriber does not have the option whether to use the preference. -
id
Unique identifier for the notification. -
idSpecified
protected boolean idSpecified -
keyName
Name that can be used by external systems to refer to a notification. -
keyNameSpecified
protected boolean keyNameSpecified -
name
Friendly name for the notification. -
nameSpecified
protected boolean nameSpecified -
preferenceCount
A count of the preferences related to the notification. These are preferences are configurable and optional for subscribers to use. -
requiredPreferenceCount
A count of the required preferences related to the notification. While configurable, the subscriber does not have the option whether to use the preference.
-
-
Constructor Details
-
Notification
public Notification()
-
-
Method Details
-
getPreferences
-
getRequiredPreferences
-
getId
-
setId
-
isIdSpecified
public boolean isIdSpecified() -
unsetId
public void unsetId() -
getKeyName
-
setKeyName
-
isKeyNameSpecified
public boolean isKeyNameSpecified() -
unsetKeyName
public void unsetKeyName() -
getName
-
setName
-
isNameSpecified
public boolean isNameSpecified() -
unsetName
public void unsetName() -
getPreferenceCount
-
setPreferenceCount
-
getRequiredPreferenceCount
-
setRequiredPreferenceCount
-
asService
-
service
-
service
-