Package com.softlayer.api.service
Class Search
java.lang.Object
com.softlayer.api.Type
com.softlayer.api.service.Entity
com.softlayer.api.service.Search
@ApiType("SoftLayer_Search") public class Search extends Entity
SoftLayer's account historical service allows users to access a broad overview of devices for that account and historical details concerning the overall function and performance of the devices on that account
- See Also:
- SoftLayer_Search
-
Nested Class Summary
Nested Classes Modifier and Type Class Description static classSearch.Maskstatic interfaceSearch.ServiceSoftLayer's account historical service allows users to access a broad overview of devices for that account and historical details concerning the overall function and performance of the devices on that accountstatic interfaceSearch.ServiceAsync -
Field Summary
-
Constructor Summary
Constructors Constructor Description Search() -
Method Summary
Modifier and Type Method Description static Search.Serviceservice(ApiClient client)