Package com.softlayer.api.service
Interface Survey.Service
- All Superinterfaces:
Maskable,ResultLimitable,Service
- Enclosing class:
- Survey
@ApiService("SoftLayer_Survey") public static interface Survey.Service extends Service
Every SoftLayer survey is defined in the SoftLayer_Survey service. Softlayer survey's have questions and answers from SoftLayer users.
- See Also:
- SoftLayer_Survey
-
Method Summary
Modifier and Type Method Description Survey.ServiceAsyncasAsync()Get an async version of this serviceSurveygetActiveSurveyByType(String type)Provides survey details for the given typeSurveygetObject()getObject retrieves the SoftLayer_Survey object whose ID number corresponds to the ID number of the init parameter passed to the SoftLayer_Survey service.List<Question>getQuestions()The questions for a survey.StatusgetStatus()The status of the surveyTypegetType()The type of surveyvoidsetMask(Survey.Mask mask)BooleantakeSurvey(List<Response> responses)Response to a SoftLayer survey's questions.Survey.MaskwithMask()Use the existing mask on this service or create it if not presentSurvey.MaskwithNewMask()Overwrite the existing mask on this service with a new one and return itMethods inherited from interface com.softlayer.api.ResultLimitable
getLastResponseTotalItemCount, getResultLimit, setResultLimit
-
Method Details
-
asAsync
Survey.ServiceAsync asAsync()Description copied from interface:ServiceGet an async version of this service -
withNewMask
Survey.Mask withNewMask()Description copied from interface:MaskableOverwrite the existing mask on this service with a new one and return it- Specified by:
withNewMaskin interfaceMaskable
-
withMask
Survey.Mask withMask()Description copied from interface:MaskableUse the existing mask on this service or create it if not present -
setMask
-
getActiveSurveyByType
Provides survey details for the given type- See Also:
- SoftLayer_Survey::getActiveSurveyByType
-
getObject
getObject retrieves the SoftLayer_Survey object whose ID number corresponds to the ID number of the init parameter passed to the SoftLayer_Survey service. You can only retrieve the survey that your portal user has taken.- See Also:
- SoftLayer_Survey::getObject
-
takeSurvey
Response to a SoftLayer survey's questions.- See Also:
- SoftLayer_Survey::takeSurvey
-
getQuestions
The questions for a survey.- See Also:
- SoftLayer_Survey::getQuestions
-
getStatus
The status of the survey- See Also:
- SoftLayer_Survey::getStatus
-
getType
The type of survey- See Also:
- SoftLayer_Survey::getType
-