Class Note
java.lang.Object
com.softlayer.api.Type
com.softlayer.api.service.Entity
com.softlayer.api.service.account.Note
@ApiType("SoftLayer_Account_Note") public class Note extends Entity
- See Also:
- SoftLayer_Account_Note
-
Nested Class Summary
Nested Classes Modifier and Type Class Description static classNote.Maskstatic interfaceNote.Servicestatic interfaceNote.ServiceAsync -
Field Summary
Fields Modifier and Type Field Description protected Accountaccountprotected LongaccountIdprotected booleanaccountIdSpecifiedprotected GregorianCalendarcreateDateprotected booleancreateDateSpecifiedprotected Customercustomerprotected Longidprotected booleanidSpecifiedprotected GregorianCalendarmodifyDateprotected booleanmodifyDateSpecifiedprotected Stringnoteprotected List<History>noteHistoryprotected LongnoteHistoryCountA count ofprotected booleannoteSpecifiedprotected LongnoteTypeIdprotected booleannoteTypeIdSpecifiedprotected LonguserIdprotected booleanuserIdSpecified -
Constructor Summary
Constructors Constructor Description Note() -
Method Summary
-
Field Details
-
account
-
customer
-
noteHistory
-
accountId
-
accountIdSpecified
protected boolean accountIdSpecified -
createDate
-
createDateSpecified
protected boolean createDateSpecified -
id
-
idSpecified
protected boolean idSpecified -
modifyDate
-
modifyDateSpecified
protected boolean modifyDateSpecified -
note
-
noteSpecified
protected boolean noteSpecified -
noteTypeId
-
noteTypeIdSpecified
protected boolean noteTypeIdSpecified -
userId
-
userIdSpecified
protected boolean userIdSpecified -
noteHistoryCount
A count of
-
-
Constructor Details
-
Note
public Note()
-
-
Method Details
-
getAccount
-
setAccount
-
getCustomer
-
setCustomer
-
getNoteHistory
-
getAccountId
-
setAccountId
-
isAccountIdSpecified
public boolean isAccountIdSpecified() -
unsetAccountId
public void unsetAccountId() -
getCreateDate
-
setCreateDate
-
isCreateDateSpecified
public boolean isCreateDateSpecified() -
unsetCreateDate
public void unsetCreateDate() -
getId
-
setId
-
isIdSpecified
public boolean isIdSpecified() -
unsetId
public void unsetId() -
getModifyDate
-
setModifyDate
-
isModifyDateSpecified
public boolean isModifyDateSpecified() -
unsetModifyDate
public void unsetModifyDate() -
getNote
-
setNote
-
isNoteSpecified
public boolean isNoteSpecified() -
unsetNote
public void unsetNote() -
getNoteTypeId
-
setNoteTypeId
-
isNoteTypeIdSpecified
public boolean isNoteTypeIdSpecified() -
unsetNoteTypeId
public void unsetNoteTypeId() -
getUserId
-
setUserId
-
isUserIdSpecified
public boolean isUserIdSpecified() -
unsetUserId
public void unsetUserId() -
getNoteHistoryCount
-
setNoteHistoryCount
-
asService
-
service
-
service
-