Class Password
java.lang.Object
com.softlayer.api.Type
com.softlayer.api.service.Entity
com.softlayer.api.service.account.Password
@ApiType("SoftLayer_Account_Password") public class Password extends Entity
The SoftLayer_Account_Password contains username, passwords and notes for services that may require for external applications such the Webcc interface for the EVault Storage service.
- See Also:
- SoftLayer_Account_Password
-
Nested Class Summary
Nested Classes Modifier and Type Class Description static classPassword.Maskstatic interfacePassword.ServiceAs a SoftLayer customer accumulates services they may accumulate usernames and passwords to those services.static interfacePassword.ServiceAsync -
Field Summary
Fields Modifier and Type Field Description protected Accountaccountprotected LongaccountIdThe SoftLayer customer account id that a username/password combination is associated with.protected booleanaccountIdSpecifiedprotected LongidA username/password combination's internal identifier.protected booleanidSpecifiedprotected StringnotesA simple description of a username/password combination.protected booleannotesSpecifiedprotected StringpasswordThe password portion of a username/password combination.protected booleanpasswordSpecifiedprotected TypetypeThe service that an account/password combination is tied to.protected LongtypeIdAn identifier relating to a username/password combinations's associated service.protected booleantypeIdSpecifiedprotected StringusernameThe username portion of a username/password combination.protected booleanusernameSpecified -
Constructor Summary
Constructors Constructor Description Password() -
Method Summary
Modifier and Type Method Description Password.ServiceasService(ApiClient client)AccountgetAccount()LonggetAccountId()LonggetId()StringgetNotes()StringgetPassword()TypegetType()LonggetTypeId()StringgetUsername()booleanisAccountIdSpecified()booleanisIdSpecified()booleanisNotesSpecified()booleanisPasswordSpecified()booleanisTypeIdSpecified()booleanisUsernameSpecified()static Password.Serviceservice(ApiClient client)static Password.Serviceservice(ApiClient client, Long id)voidsetAccount(Account account)voidsetAccountId(Long accountId)voidsetId(Long id)voidsetNotes(String notes)voidsetPassword(String password)voidsetType(Type type)voidsetTypeId(Long typeId)voidsetUsername(String username)voidunsetAccountId()voidunsetId()voidunsetNotes()voidunsetPassword()voidunsetTypeId()voidunsetUsername()
-
Field Details
-
account
-
type
The service that an account/password combination is tied to. -
accountId
The SoftLayer customer account id that a username/password combination is associated with. -
accountIdSpecified
protected boolean accountIdSpecified -
id
A username/password combination's internal identifier. -
idSpecified
protected boolean idSpecified -
notes
A simple description of a username/password combination. These notes don't affect portal functionality. -
notesSpecified
protected boolean notesSpecified -
password
The password portion of a username/password combination. -
passwordSpecified
protected boolean passwordSpecified -
typeId
An identifier relating to a username/password combinations's associated service. -
typeIdSpecified
protected boolean typeIdSpecified -
username
The username portion of a username/password combination. -
usernameSpecified
protected boolean usernameSpecified
-
-
Constructor Details
-
Password
public Password()
-
-
Method Details
-
getAccount
-
setAccount
-
getType
-
setType
-
getAccountId
-
setAccountId
-
isAccountIdSpecified
public boolean isAccountIdSpecified() -
unsetAccountId
public void unsetAccountId() -
getId
-
setId
-
isIdSpecified
public boolean isIdSpecified() -
unsetId
public void unsetId() -
getNotes
-
setNotes
-
isNotesSpecified
public boolean isNotesSpecified() -
unsetNotes
public void unsetNotes() -
getPassword
-
setPassword
-
isPasswordSpecified
public boolean isPasswordSpecified() -
unsetPassword
public void unsetPassword() -
getTypeId
-
setTypeId
-
isTypeIdSpecified
public boolean isTypeIdSpecified() -
unsetTypeId
public void unsetTypeId() -
getUsername
-
setUsername
-
isUsernameSpecified
public boolean isUsernameSpecified() -
unsetUsername
public void unsetUsername() -
asService
-
service
-
service
-