Class Attribute
java.lang.Object
com.softlayer.api.Type
com.softlayer.api.service.Entity
com.softlayer.api.service.account.authentication.Attribute
@ApiType("SoftLayer_Account_Authentication_Attribute") public class Attribute extends Entity
Account authentication has many different settings that can be set. This class allows the customer or employee to set these settigns.
-
Nested Class Summary
Nested Classes Modifier and Type Class Description static classAttribute.Maskstatic interfaceAttribute.Servicestatic interfaceAttribute.ServiceAsync -
Field Summary
Fields Modifier and Type Field Description protected AccountaccountThe SoftLayer customer account.protected LongaccountIdThe internal identifier of the SoftLayer customer account that is assigned an account authenction attribute.protected booleanaccountIdSpecifiedprotected SamlauthenticationRecordThe SoftLayer account authentication that has an attribute.protected LongidA SoftLayer account authenction attribute's internal identifier.protected booleanidSpecifiedprotected TypetypeThe type of attribute assigned to a SoftLayer account authentication.protected LongtypeIdThe internal identifier of the type of attribute that a SoftLayer account authenction attribute belongs to.protected booleantypeIdSpecifiedprotected StringvalueA SoftLayer account authenction attribute's value.protected booleanvalueSpecified -
Constructor Summary
Constructors Constructor Description Attribute() -
Method Summary
Modifier and Type Method Description Attribute.ServiceasService(ApiClient client)AccountgetAccount()LonggetAccountId()SamlgetAuthenticationRecord()LonggetId()TypegetType()LonggetTypeId()StringgetValue()booleanisAccountIdSpecified()booleanisIdSpecified()booleanisTypeIdSpecified()booleanisValueSpecified()static Attribute.Serviceservice(ApiClient client)static Attribute.Serviceservice(ApiClient client, Long id)voidsetAccount(Account account)voidsetAccountId(Long accountId)voidsetAuthenticationRecord(Saml authenticationRecord)voidsetId(Long id)voidsetType(Type type)voidsetTypeId(Long typeId)voidsetValue(String value)voidunsetAccountId()voidunsetId()voidunsetTypeId()voidunsetValue()
-
Field Details
-
account
The SoftLayer customer account. -
authenticationRecord
The SoftLayer account authentication that has an attribute. -
type
The type of attribute assigned to a SoftLayer account authentication. -
accountId
The internal identifier of the SoftLayer customer account that is assigned an account authenction attribute. -
accountIdSpecified
protected boolean accountIdSpecified -
id
A SoftLayer account authenction attribute's internal identifier. -
idSpecified
protected boolean idSpecified -
typeId
The internal identifier of the type of attribute that a SoftLayer account authenction attribute belongs to. -
typeIdSpecified
protected boolean typeIdSpecified -
value
A SoftLayer account authenction attribute's value. -
valueSpecified
protected boolean valueSpecified
-
-
Constructor Details
-
Attribute
public Attribute()
-
-
Method Details
-
getAccount
-
setAccount
-
getAuthenticationRecord
-
setAuthenticationRecord
-
getType
-
setType
-
getAccountId
-
setAccountId
-
isAccountIdSpecified
public boolean isAccountIdSpecified() -
unsetAccountId
public void unsetAccountId() -
getId
-
setId
-
isIdSpecified
public boolean isIdSpecified() -
unsetId
public void unsetId() -
getTypeId
-
setTypeId
-
isTypeIdSpecified
public boolean isTypeIdSpecified() -
unsetTypeId
public void unsetTypeId() -
getValue
-
setValue
-
isValueSpecified
public boolean isValueSpecified() -
unsetValue
public void unsetValue() -
asService
-
service
-
service
-