Interface Attribute.ServiceAsync
- All Superinterfaces:
Maskable,ResultLimitable,ServiceAsync
- Enclosing class:
- Attribute
public static interface Attribute.ServiceAsync extends ServiceAsync
-
Method Summary
Methods inherited from interface com.softlayer.api.ResultLimitable
getLastResponseTotalItemCount, getResultLimit, setResultLimit
-
Method Details
-
withNewMask
Attribute.Mask withNewMask()Description copied from interface:MaskableOverwrite the existing mask on this service with a new one and return it- Specified by:
withNewMaskin interfaceMaskable
-
withMask
Attribute.Mask withMask()Description copied from interface:MaskableUse the existing mask on this service or create it if not present -
setMask
-
getObject
Async version ofAttribute.Service.getObject() -
getObject
-
getAccount
Async version ofAttribute.Service.getAccount() -
getAccount
Async callback version ofAttribute.Service.getAccount() -
getAuthenticationRecord
Async version ofAttribute.Service.getAuthenticationRecord() -
getAuthenticationRecord
Async callback version ofAttribute.Service.getAuthenticationRecord() -
getType
Async version ofAttribute.Service.getType() -
getType
Async callback version ofAttribute.Service.getType()
-