Class ProjectCreationDetails
java.lang.Object
com.softlayer.api.Type
com.softlayer.api.service.Entity
com.softlayer.api.service.account.link.openstack.ProjectCreationDetails
@ApiType("SoftLayer_Account_Link_OpenStack_ProjectCreationDetails") public class ProjectCreationDetails extends Entity
OpenStack project creation details
-
Nested Class Summary
Nested Classes Modifier and Type Class Description static classProjectCreationDetails.Mask -
Field Summary
Fields Modifier and Type Field Description protected StringdomainIdId for the domain this project was added to.protected booleandomainIdSpecifiedprotected StringprojectIdId for this project.protected booleanprojectIdSpecifiedprotected StringprojectNameName for this project.protected booleanprojectNameSpecifiedprotected StringuserIdId for the user given the Project Admin role for this project.protected booleanuserIdSpecifiedprotected StringuserNameName for the user given the Project Admin role for this project.protected booleanuserNameSpecified -
Constructor Summary
Constructors Constructor Description ProjectCreationDetails() -
Method Summary
Modifier and Type Method Description StringgetDomainId()StringgetProjectId()StringgetProjectName()StringgetUserId()StringgetUserName()booleanisDomainIdSpecified()booleanisProjectIdSpecified()booleanisProjectNameSpecified()booleanisUserIdSpecified()booleanisUserNameSpecified()voidsetDomainId(String domainId)voidsetProjectId(String projectId)voidsetProjectName(String projectName)voidsetUserId(String userId)voidsetUserName(String userName)voidunsetDomainId()voidunsetProjectId()voidunsetProjectName()voidunsetUserId()voidunsetUserName()
-
Field Details
-
domainId
Id for the domain this project was added to. -
domainIdSpecified
protected boolean domainIdSpecified -
projectId
Id for this project. -
projectIdSpecified
protected boolean projectIdSpecified -
projectName
Name for this project. -
projectNameSpecified
protected boolean projectNameSpecified -
userId
Id for the user given the Project Admin role for this project. -
userIdSpecified
protected boolean userIdSpecified -
userName
Name for the user given the Project Admin role for this project. -
userNameSpecified
protected boolean userNameSpecified
-
-
Constructor Details
-
ProjectCreationDetails
public ProjectCreationDetails()
-
-
Method Details
-
getDomainId
-
setDomainId
-
isDomainIdSpecified
public boolean isDomainIdSpecified() -
unsetDomainId
public void unsetDomainId() -
getProjectId
-
setProjectId
-
isProjectIdSpecified
public boolean isProjectIdSpecified() -
unsetProjectId
public void unsetProjectId() -
getProjectName
-
setProjectName
-
isProjectNameSpecified
public boolean isProjectNameSpecified() -
unsetProjectName
public void unsetProjectName() -
getUserId
-
setUserId
-
isUserIdSpecified
public boolean isUserIdSpecified() -
unsetUserId
public void unsetUserId() -
getUserName
-
setUserName
-
isUserNameSpecified
public boolean isUserNameSpecified() -
unsetUserName
public void unsetUserName()
-