Interface Status.ServiceAsync
- All Superinterfaces:
Maskable,ResultLimitable,ServiceAsync
- Enclosing class:
- Status
public static interface Status.ServiceAsync extends ServiceAsync
-
Method Summary
Modifier and Type Method Description Future<List<Reading>>getNetworkStatus(String target)Async version ofStatus.Service.getNetworkStatus(java.lang.String)Future<?>getNetworkStatus(String target, ResponseHandler<List<Reading>> callback)voidsetMask(Status.Mask mask)Status.MaskwithMask()Use the existing mask on this service or create it if not presentStatus.MaskwithNewMask()Overwrite the existing mask on this service with a new one and return itMethods inherited from interface com.softlayer.api.ResultLimitable
getLastResponseTotalItemCount, getResultLimit, setResultLimit
-
Method Details
-
withNewMask
Status.Mask withNewMask()Description copied from interface:MaskableOverwrite the existing mask on this service with a new one and return it- Specified by:
withNewMaskin interfaceMaskable
-
withMask
Status.Mask withMask()Description copied from interface:MaskableUse the existing mask on this service or create it if not present -
setMask
-
getNetworkStatus
Async version ofStatus.Service.getNetworkStatus(java.lang.String) -
getNetworkStatus
-