Class Info
java.lang.Object
com.softlayer.api.Type
com.softlayer.api.service.Entity
com.softlayer.api.service.billing.Info
@ApiType("SoftLayer_Billing_Info") public class Info extends Entity
Every SoftLayer customer account has billing specific information which is kept in the SoftLayer_Billing_Info data type. This information is used by the SoftLayer accounting group when sending invoices and making billing inquiries.
- See Also:
- SoftLayer_Billing_Info
-
Nested Class Summary
Nested Classes Modifier and Type Class Description static classInfo.Maskstatic interfaceInfo.ServiceSoftLayer billing info contains company billing information such as the last date a payment was made and the last time any billing information was update.static interfaceInfo.ServiceAsync -
Field Summary
Fields Modifier and Type Field Description protected AccountaccountThe SoftLayer customer account associated with this billing information.protected LongaccountIdA SoftLayer account's identifier.protected booleanaccountIdSpecifiedprotected List<Ach>achInformationprotected LongachInformationCountA count ofprotected LonganniversaryDayOfMonthThe day of the month that a SoftLayer customer is billed.protected booleananniversaryDayOfMonthSpecifiedprotected StringcardAccountNumberThis value doesn't persist to this object.protected booleancardAccountNumberSpecifiedprotected LongcardExpirationMonththe expiration month of the credit card on fileprotected booleancardExpirationMonthSpecifiedprotected LongcardExpirationYearthe expiration year of the credit card on fileprotected booleancardExpirationYearSpecifiedprotected StringcardNicknameprotected booleancardNicknameSpecifiedprotected StringcardTypethe type of the credit card on fileprotected booleancardTypeSpecifiedprotected StringcardVerificationNumberThis value doesn't persist to this object.protected booleancardVerificationNumberSpecifiedprotected GregorianCalendarcreateDateThe date a customer's billing information was created.protected booleancreateDateSpecifiedprotected CurrencycurrencyCurrency to be used by this customer account.protected CyclecurrentBillingCycleInformation related to an account's current and previous billing cycles.protected LongidA SoftLayer customer's billing information identifier.protected booleanidSpecifiedprotected GregorianCalendarlastBillDateThe date on which an account was last billed.protected LonglastFourPaymentCardDigitsThe last four digits of the credit card currently on the account.protected booleanlastFourPaymentCardDigitsSpecifiedprotected GregorianCalendarlastPaymentDateThe date of the last payment received by SoftLayer from the account holder.protected booleanlastPaymentDateSpecifiedprotected GregorianCalendarmodifyDateThe date a customer's billing information was last modified.protected booleanmodifyDateSpecifiedprotected GregorianCalendarnextBillDateThe date on which an account will be billed next.protected LongpaymentTermsThe payment terms for an account.protected booleanpaymentTermsSpecifiedprotected LongpercentDiscountOnetimeThe percentage discount received on all one-time charges on a customer's monthly bill.protected booleanpercentDiscountOnetimeSpecifiedprotected LongpercentDiscountRecurringThe percentage discount received on all recurring charges on a customer's monthly bill.protected booleanpercentDiscountRecurringSpecifiedprotected LongsparePoolAmountThe total recurring fee amount for servers that are in the spare pool status.protected booleansparePoolAmountSpecifiedprotected StringtaxCertificateIdprotected booleantaxCertificateIdSpecifiedprotected StringvatIdprotected booleanvatIdSpecified -
Constructor Summary
Constructors Constructor Description Info() -
Method Summary
-
Field Details
-
account
The SoftLayer customer account associated with this billing information. -
achInformation
-
currency
Currency to be used by this customer account. -
currentBillingCycle
Information related to an account's current and previous billing cycles. -
lastBillDate
The date on which an account was last billed. -
nextBillDate
The date on which an account will be billed next. -
accountId
A SoftLayer account's identifier. -
accountIdSpecified
protected boolean accountIdSpecified -
anniversaryDayOfMonth
The day of the month that a SoftLayer customer is billed. -
anniversaryDayOfMonthSpecified
protected boolean anniversaryDayOfMonthSpecified -
cardAccountNumber
This value doesn't persist to this object. It's used as part of the account creation process only; -
cardAccountNumberSpecified
protected boolean cardAccountNumberSpecified -
cardExpirationMonth
the expiration month of the credit card on file -
cardExpirationMonthSpecified
protected boolean cardExpirationMonthSpecified -
cardExpirationYear
the expiration year of the credit card on file -
cardExpirationYearSpecified
protected boolean cardExpirationYearSpecified -
cardNickname
-
cardNicknameSpecified
protected boolean cardNicknameSpecified -
cardType
the type of the credit card on file -
cardTypeSpecified
protected boolean cardTypeSpecified -
cardVerificationNumber
This value doesn't persist to this object. It's used as part of the account creation process only. -
cardVerificationNumberSpecified
protected boolean cardVerificationNumberSpecified -
createDate
The date a customer's billing information was created. -
createDateSpecified
protected boolean createDateSpecified -
id
A SoftLayer customer's billing information identifier. -
idSpecified
protected boolean idSpecified -
lastFourPaymentCardDigits
The last four digits of the credit card currently on the account. This is the only portion of the card that we store. For Paypal customers, this value will be empty. -
lastFourPaymentCardDigitsSpecified
protected boolean lastFourPaymentCardDigitsSpecified -
lastPaymentDate
The date of the last payment received by SoftLayer from the account holder. -
lastPaymentDateSpecified
protected boolean lastPaymentDateSpecified -
modifyDate
The date a customer's billing information was last modified. -
modifyDateSpecified
protected boolean modifyDateSpecified -
paymentTerms
The payment terms for an account. -
paymentTermsSpecified
protected boolean paymentTermsSpecified -
percentDiscountOnetime
The percentage discount received on all one-time charges on a customer's monthly bill. -
percentDiscountOnetimeSpecified
protected boolean percentDiscountOnetimeSpecified -
percentDiscountRecurring
The percentage discount received on all recurring charges on a customer's monthly bill. -
percentDiscountRecurringSpecified
protected boolean percentDiscountRecurringSpecified -
sparePoolAmount
The total recurring fee amount for servers that are in the spare pool status. -
sparePoolAmountSpecified
protected boolean sparePoolAmountSpecified -
taxCertificateId
-
taxCertificateIdSpecified
protected boolean taxCertificateIdSpecified -
vatId
-
vatIdSpecified
protected boolean vatIdSpecified -
achInformationCount
A count of
-
-
Constructor Details
-
Info
public Info()
-
-
Method Details
-
getAccount
-
setAccount
-
getAchInformation
-
getCurrency
-
setCurrency
-
getCurrentBillingCycle
-
setCurrentBillingCycle
-
getLastBillDate
-
setLastBillDate
-
getNextBillDate
-
setNextBillDate
-
getAccountId
-
setAccountId
-
isAccountIdSpecified
public boolean isAccountIdSpecified() -
unsetAccountId
public void unsetAccountId() -
getAnniversaryDayOfMonth
-
setAnniversaryDayOfMonth
-
isAnniversaryDayOfMonthSpecified
public boolean isAnniversaryDayOfMonthSpecified() -
unsetAnniversaryDayOfMonth
public void unsetAnniversaryDayOfMonth() -
getCardAccountNumber
-
setCardAccountNumber
-
isCardAccountNumberSpecified
public boolean isCardAccountNumberSpecified() -
unsetCardAccountNumber
public void unsetCardAccountNumber() -
getCardExpirationMonth
-
setCardExpirationMonth
-
isCardExpirationMonthSpecified
public boolean isCardExpirationMonthSpecified() -
unsetCardExpirationMonth
public void unsetCardExpirationMonth() -
getCardExpirationYear
-
setCardExpirationYear
-
isCardExpirationYearSpecified
public boolean isCardExpirationYearSpecified() -
unsetCardExpirationYear
public void unsetCardExpirationYear() -
getCardNickname
-
setCardNickname
-
isCardNicknameSpecified
public boolean isCardNicknameSpecified() -
unsetCardNickname
public void unsetCardNickname() -
getCardType
-
setCardType
-
isCardTypeSpecified
public boolean isCardTypeSpecified() -
unsetCardType
public void unsetCardType() -
getCardVerificationNumber
-
setCardVerificationNumber
-
isCardVerificationNumberSpecified
public boolean isCardVerificationNumberSpecified() -
unsetCardVerificationNumber
public void unsetCardVerificationNumber() -
getCreateDate
-
setCreateDate
-
isCreateDateSpecified
public boolean isCreateDateSpecified() -
unsetCreateDate
public void unsetCreateDate() -
getId
-
setId
-
isIdSpecified
public boolean isIdSpecified() -
unsetId
public void unsetId() -
getLastFourPaymentCardDigits
-
setLastFourPaymentCardDigits
-
isLastFourPaymentCardDigitsSpecified
public boolean isLastFourPaymentCardDigitsSpecified() -
unsetLastFourPaymentCardDigits
public void unsetLastFourPaymentCardDigits() -
getLastPaymentDate
-
setLastPaymentDate
-
isLastPaymentDateSpecified
public boolean isLastPaymentDateSpecified() -
unsetLastPaymentDate
public void unsetLastPaymentDate() -
getModifyDate
-
setModifyDate
-
isModifyDateSpecified
public boolean isModifyDateSpecified() -
unsetModifyDate
public void unsetModifyDate() -
getPaymentTerms
-
setPaymentTerms
-
isPaymentTermsSpecified
public boolean isPaymentTermsSpecified() -
unsetPaymentTerms
public void unsetPaymentTerms() -
getPercentDiscountOnetime
-
setPercentDiscountOnetime
-
isPercentDiscountOnetimeSpecified
public boolean isPercentDiscountOnetimeSpecified() -
unsetPercentDiscountOnetime
public void unsetPercentDiscountOnetime() -
getPercentDiscountRecurring
-
setPercentDiscountRecurring
-
isPercentDiscountRecurringSpecified
public boolean isPercentDiscountRecurringSpecified() -
unsetPercentDiscountRecurring
public void unsetPercentDiscountRecurring() -
getSparePoolAmount
-
setSparePoolAmount
-
isSparePoolAmountSpecified
public boolean isSparePoolAmountSpecified() -
unsetSparePoolAmount
public void unsetSparePoolAmount() -
getTaxCertificateId
-
setTaxCertificateId
-
isTaxCertificateIdSpecified
public boolean isTaxCertificateIdSpecified() -
unsetTaxCertificateId
public void unsetTaxCertificateId() -
getVatId
-
setVatId
-
isVatIdSpecified
public boolean isVatIdSpecified() -
unsetVatId
public void unsetVatId() -
getAchInformationCount
-
setAchInformationCount
-
asService
-
service
-
service
-