Interface Info.ServiceAsync
- All Superinterfaces:
Maskable,ResultLimitable,ServiceAsync
- Enclosing class:
- Info
public static interface Info.ServiceAsync extends ServiceAsync
-
Method Summary
Methods inherited from interface com.softlayer.api.ResultLimitable
getLastResponseTotalItemCount, getResultLimit, setResultLimit
-
Method Details
-
withNewMask
Info.Mask withNewMask()Description copied from interface:MaskableOverwrite the existing mask on this service with a new one and return it- Specified by:
withNewMaskin interfaceMaskable
-
withMask
Info.Mask withMask()Description copied from interface:MaskableUse the existing mask on this service or create it if not present -
setMask
-
getObject
Async version ofInfo.Service.getObject() -
getObject
-
getAccount
Async version ofInfo.Service.getAccount() -
getAccount
Async callback version ofInfo.Service.getAccount() -
getAchInformation
Async version ofInfo.Service.getAchInformation() -
getAchInformation
Async callback version ofInfo.Service.getAchInformation() -
getCurrency
Async version ofInfo.Service.getCurrency() -
getCurrency
Async callback version ofInfo.Service.getCurrency() -
getCurrentBillingCycle
Async version ofInfo.Service.getCurrentBillingCycle() -
getCurrentBillingCycle
Async callback version ofInfo.Service.getCurrentBillingCycle() -
getLastBillDate
Future<GregorianCalendar> getLastBillDate()Async version ofInfo.Service.getLastBillDate() -
getLastBillDate
Async callback version ofInfo.Service.getLastBillDate() -
getNextBillDate
Future<GregorianCalendar> getNextBillDate()Async version ofInfo.Service.getNextBillDate() -
getNextBillDate
Async callback version ofInfo.Service.getNextBillDate()
-