Uses of Class
com.softlayer.api.service.billing.payment.processor.Method
| Package | Description |
|---|---|
| com.softlayer.api.service.billing.payment |
-
Uses of Method in com.softlayer.api.service.billing.payment
Fields in com.softlayer.api.service.billing.payment with type parameters of type Method Modifier and Type Field Description protected List<Method>Processor. paymentMethodsMethods in com.softlayer.api.service.billing.payment that return types with arguments of type Method Modifier and Type Method Description List<Method>Processor. getPaymentMethods()