Uses of Class
com.softlayer.api.service.Notification
-
Uses of Notification in com.softlayer.api.service
Methods in com.softlayer.api.service that return Notification Modifier and Type Method Description NotificationNotification.Service. getObject()Methods in com.softlayer.api.service that return types with arguments of type Notification Modifier and Type Method Description List<Notification>Notification.Service. getAllObjects()Use this method to retrieve all active notifications that can be subscribed to.Future<List<Notification>>Notification.ServiceAsync. getAllObjects()Async version ofNotification.Service.getAllObjects()Future<Notification>Notification.ServiceAsync. getObject()Async version ofNotification.Service.getObject()Method parameters in com.softlayer.api.service with type arguments of type Notification Modifier and Type Method Description Future<?>Notification.ServiceAsync. getAllObjects(ResponseHandler<List<Notification>> callback)Future<?>Notification.ServiceAsync. getObject(ResponseHandler<Notification> callback) -
Uses of Notification in com.softlayer.api.service.network
Fields in com.softlayer.api.service.network declared as Notification Modifier and Type Field Description protected NotificationStorage. usageNotificationThe usage notification for SL Storage services.Methods in com.softlayer.api.service.network that return Notification Modifier and Type Method Description NotificationStorage. getUsageNotification()NotificationStorage.Service. getUsageNotification()The usage notification for SL Storage services.Methods in com.softlayer.api.service.network that return types with arguments of type Notification Modifier and Type Method Description Future<Notification>Storage.ServiceAsync. getUsageNotification()Async version ofStorage.Service.getUsageNotification()Methods in com.softlayer.api.service.network with parameters of type Notification Modifier and Type Method Description voidStorage. setUsageNotification(Notification usageNotification)Method parameters in com.softlayer.api.service.network with type arguments of type Notification Modifier and Type Method Description Future<?>Storage.ServiceAsync. getUsageNotification(ResponseHandler<Notification> callback)Async callback version ofStorage.Service.getUsageNotification() -
Uses of Notification in com.softlayer.api.service.notification
Subclasses of Notification in com.softlayer.api.service.notification Modifier and Type Class Description classMobileThis is an extension of the SoftLayer_Notification class.Fields in com.softlayer.api.service.notification declared as Notification Modifier and Type Field Description protected NotificationSubscriber. notificationMethods in com.softlayer.api.service.notification that return Notification Modifier and Type Method Description NotificationSubscriber. getNotification()Methods in com.softlayer.api.service.notification with parameters of type Notification Modifier and Type Method Description voidSubscriber. setNotification(Notification notification) -
Uses of Notification in com.softlayer.api.service.notification.user
Fields in com.softlayer.api.service.notification.user declared as Notification Modifier and Type Field Description protected NotificationSubscriber. notificationNotification subscribed to.Methods in com.softlayer.api.service.notification.user that return Notification Modifier and Type Method Description NotificationSubscriber. getNotification()NotificationSubscriber.Service. getNotification()Notification subscribed to.Methods in com.softlayer.api.service.notification.user that return types with arguments of type Notification Modifier and Type Method Description Future<Notification>Subscriber.ServiceAsync. getNotification()Async version ofSubscriber.Service.getNotification()Methods in com.softlayer.api.service.notification.user with parameters of type Notification Modifier and Type Method Description voidSubscriber. setNotification(Notification notification)Method parameters in com.softlayer.api.service.notification.user with type arguments of type Notification Modifier and Type Method Description Future<?>Subscriber.ServiceAsync. getNotification(ResponseHandler<Notification> callback)Async callback version ofSubscriber.Service.getNotification() -
Uses of Notification in com.softlayer.api.service.user.customer
Fields in com.softlayer.api.service.user.customer with type parameters of type Notification Modifier and Type Field Description protected List<Notification>MobileDevice. availablePushNotificationSubscriptionsNotification subscriptions available to a mobile device.Methods in com.softlayer.api.service.user.customer that return types with arguments of type Notification Modifier and Type Method Description List<Notification>MobileDevice. getAvailablePushNotificationSubscriptions()List<Notification>MobileDevice.Service. getAvailablePushNotificationSubscriptions()Notification subscriptions available to a mobile device.Future<List<Notification>>MobileDevice.ServiceAsync. getAvailablePushNotificationSubscriptions()Async version ofMobileDevice.Service.getAvailablePushNotificationSubscriptions()Method parameters in com.softlayer.api.service.user.customer with type arguments of type Notification Modifier and Type Method Description Future<?>MobileDevice.ServiceAsync. getAvailablePushNotificationSubscriptions(ResponseHandler<List<Notification>> callback)Async callback version ofMobileDevice.Service.getAvailablePushNotificationSubscriptions()