Class Profile
java.lang.Object
com.softlayer.api.Type
com.softlayer.api.service.Entity
com.softlayer.api.service.configuration.template.section.Profile
@ApiType("SoftLayer_Configuration_Template_Section_Profile") public class Profile extends Entity
Some configuration templates let you create a unique configuration profiles.
For example, you can create multiple configuration profiles to monitor multiple hard drives with "CPU/Memory/Disk Monitoring Agent". SoftLayer_Configuration_Template_Section_Profile help you keep track of custom configuration profiles.
For example, you can create multiple configuration profiles to monitor multiple hard drives with "CPU/Memory/Disk Monitoring Agent". SoftLayer_Configuration_Template_Section_Profile help you keep track of custom configuration profiles.
-
Nested Class Summary
Nested Classes Modifier and Type Class Description static classProfile.Maskstatic interfaceProfile.ServiceSoftLayer_Configuration_Template_Section_Profile help you keep track of custom configuration profiles.static interfaceProfile.ServiceAsync -
Field Summary
Fields Modifier and Type Field Description protected LongagentIdInternal identifier of a monitoring agent this profile belongs to.protected booleanagentIdSpecifiedprotected SectionconfigurationSectionprotected GregorianCalendarcreateDateCreated dateprotected booleancreateDateSpecifiedprotected LongidInternal identifier of a configuration profile.protected booleanidSpecifiedprotected StringnameName of a configuration profileprotected booleannameSpecifiedprotected LongsectionIdInternal identifier of a configuration section that this profile belongs to.protected booleansectionIdSpecified -
Constructor Summary
Constructors Constructor Description Profile() -
Method Summary
Modifier and Type Method Description Profile.ServiceasService(ApiClient client)LonggetAgentId()SectiongetConfigurationSection()GregorianCalendargetCreateDate()LonggetId()StringgetName()LonggetSectionId()booleanisAgentIdSpecified()booleanisCreateDateSpecified()booleanisIdSpecified()booleanisNameSpecified()booleanisSectionIdSpecified()static Profile.Serviceservice(ApiClient client)static Profile.Serviceservice(ApiClient client, Long id)voidsetAgentId(Long agentId)voidsetConfigurationSection(Section configurationSection)voidsetCreateDate(GregorianCalendar createDate)voidsetId(Long id)voidsetName(String name)voidsetSectionId(Long sectionId)voidunsetAgentId()voidunsetCreateDate()voidunsetId()voidunsetName()voidunsetSectionId()
-
Field Details
-
configurationSection
-
agentId
Internal identifier of a monitoring agent this profile belongs to. -
agentIdSpecified
protected boolean agentIdSpecified -
createDate
Created date -
createDateSpecified
protected boolean createDateSpecified -
id
Internal identifier of a configuration profile. -
idSpecified
protected boolean idSpecified -
name
Name of a configuration profile -
nameSpecified
protected boolean nameSpecified -
sectionId
Internal identifier of a configuration section that this profile belongs to. -
sectionIdSpecified
protected boolean sectionIdSpecified
-
-
Constructor Details
-
Profile
public Profile()
-
-
Method Details
-
getConfigurationSection
-
setConfigurationSection
-
getAgentId
-
setAgentId
-
isAgentIdSpecified
public boolean isAgentIdSpecified() -
unsetAgentId
public void unsetAgentId() -
getCreateDate
-
setCreateDate
-
isCreateDateSpecified
public boolean isCreateDateSpecified() -
unsetCreateDate
public void unsetCreateDate() -
getId
-
setId
-
isIdSpecified
public boolean isIdSpecified() -
unsetId
public void unsetId() -
getName
-
setName
-
isNameSpecified
public boolean isNameSpecified() -
unsetName
public void unsetName() -
getSectionId
-
setSectionId
-
isSectionIdSpecified
public boolean isSectionIdSpecified() -
unsetSectionId
public void unsetSectionId() -
asService
-
service
-
service
-