-
-
Class Summary
| Class |
Description |
| Attribute |
Configuration section attribute class contains supplementary information for a configuration section.
|
| Attribute.Mask |
|
| Definition |
Configuration definition gives you details of the value that you're setting.
|
| Definition.Mask |
|
| Profile |
Some configuration templates let you create a unique configuration profiles.
|
| Profile.Mask |
|
| Reference |
The SoftLayer_Configuration_Template_Section_Reference data type contains information of a configuration section and its associated configuration template.
|
| Reference.Mask |
|
| Type |
The SoftLayer_Configuration_Template_Section_Type data type contains information of a configuration section type.
|
| Type.Mask |
|