Class Message
java.lang.Object
com.softlayer.api.Type
com.softlayer.api.service.Entity
com.softlayer.api.service.container.Message
@ApiType("SoftLayer_Container_Message") public class Message extends Entity
- See Also:
- SoftLayer_Container_Message
-
Nested Class Summary
Nested Classes Modifier and Type Class Description static classMessage.Mask -
Field Summary
Fields Modifier and Type Field Description protected Stringmessageprotected booleanmessageSpecifiedprotected Stringtypeprotected booleantypeSpecified -
Constructor Summary
Constructors Constructor Description Message() -
Method Summary
Modifier and Type Method Description StringgetMessage()StringgetType()booleanisMessageSpecified()booleanisTypeSpecified()voidsetMessage(String message)voidsetType(String type)voidunsetMessage()voidunsetType()
-
Field Details
-
message
-
messageSpecified
protected boolean messageSpecified -
type
-
typeSpecified
protected boolean typeSpecified
-
-
Constructor Details
-
Message
public Message()
-
-
Method Details
-
getMessage
-
setMessage
-
isMessageSpecified
public boolean isMessageSpecified() -
unsetMessage
public void unsetMessage() -
getType
-
setType
-
isTypeSpecified
public boolean isTypeSpecified() -
unsetType
public void unsetType()
-