-
Class Summary
| Class |
Description |
| Account |
The SoftLayer_Container_Authentication_Response_Account data type contains account information for responses from the getPortalLogin API.
|
| Account.Mask |
|
| AccountIdMissing |
The SoftLayer_Container_Authentication_Response_AccountIdMissing data type contains information for specific responses from the getPortalLogin API.
|
| AccountIdMissing.Mask |
|
| Common |
The SoftLayer_Container_Authentication_Response_Common data type contains common information for responses from the getPortalLogin API.
|
| Common.Mask |
|
| IpAddressRestrictionCheckNeeded |
The SoftLayer_Container_Authentication_Response_IpAddressRestrictionCheckNeeded data type indicates that the caller (IAM presumably) needs to do an IP address check of the logging-in user against the restricted IP list kept in BSS.
|
| IpAddressRestrictionCheckNeeded.Mask |
|
| LoginFailed |
The SoftLayer_Container_Authentication_Response_LOGIN_FAILED data type contains information for specific responses from the getPortalLogin API.
|
| LoginFailed.Mask |
|
| Success |
The SoftLayer_Container_Authentication_Response_SUCCESS data type contains information for specific responses from the getPortalLogin API.
|
| Success.Mask |
|
| z2FactorAuthenticationNeeded |
The SoftLayer_Container_Authentication_Response_2FactorAuthenticationNeeded data type contains information for specific responses from the getPortalLogin API.
|
| z2FactorAuthenticationNeeded.Mask |
|