Uses of Class
com.softlayer.api.service.container.graph.Plot
| Package | Description |
|---|---|
| com.softlayer.api.service.container |
-
Uses of Plot in com.softlayer.api.service.container
Fields in com.softlayer.api.service.container with type parameters of type Plot Modifier and Type Field Description protected List<Plot>Graph. plotsA collection of graph plots.Methods in com.softlayer.api.service.container that return types with arguments of type Plot Modifier and Type Method Description List<Plot>Graph. getPlots()