Class Usage
java.lang.Object
com.softlayer.api.Type
com.softlayer.api.service.Entity
com.softlayer.api.service.container.network.bandwidth.version1.Usage
@ApiType("SoftLayer_Container_Network_Bandwidth_Version1_Usage") public class Usage extends Entity
SoftLayer_Container_Network_Bandwidth_Version1_Usage models an hourly bandwidth record.
-
Nested Class Summary
Nested Classes Modifier and Type Class Description static classUsage.Mask -
Field Summary
Fields Modifier and Type Field Description protected BigDecimalincomingAmountThe amount of incoming bandwidth that a server has used within the hour of the recordedDate.protected booleanincomingAmountSpecifiedprotected BigDecimaloutgoingAmountThe amount of outgoing bandwidth that a server has used within the hour of the recordedDate.protected booleanoutgoingAmountSpecifiedprotected GregorianCalendarrecordedDateThe date and time that the bandwidth was used by a piece of hardwareprotected booleanrecordedDateSpecified -
Constructor Summary
Constructors Constructor Description Usage() -
Method Summary
Modifier and Type Method Description BigDecimalgetIncomingAmount()BigDecimalgetOutgoingAmount()GregorianCalendargetRecordedDate()booleanisIncomingAmountSpecified()booleanisOutgoingAmountSpecified()booleanisRecordedDateSpecified()voidsetIncomingAmount(BigDecimal incomingAmount)voidsetOutgoingAmount(BigDecimal outgoingAmount)voidsetRecordedDate(GregorianCalendar recordedDate)voidunsetIncomingAmount()voidunsetOutgoingAmount()voidunsetRecordedDate()
-
Field Details
-
incomingAmount
The amount of incoming bandwidth that a server has used within the hour of the recordedDate. -
incomingAmountSpecified
protected boolean incomingAmountSpecified -
outgoingAmount
The amount of outgoing bandwidth that a server has used within the hour of the recordedDate. -
outgoingAmountSpecified
protected boolean outgoingAmountSpecified -
recordedDate
The date and time that the bandwidth was used by a piece of hardware -
recordedDateSpecified
protected boolean recordedDateSpecified
-
-
Constructor Details
-
Usage
public Usage()
-
-
Method Details
-
getIncomingAmount
-
setIncomingAmount
-
isIncomingAmountSpecified
public boolean isIncomingAmountSpecified() -
unsetIncomingAmount
public void unsetIncomingAmount() -
getOutgoingAmount
-
setOutgoingAmount
-
isOutgoingAmountSpecified
public boolean isOutgoingAmountSpecified() -
unsetOutgoingAmount
public void unsetOutgoingAmount() -
getRecordedDate
-
setRecordedDate
-
isRecordedDateSpecified
public boolean isRecordedDateSpecified() -
unsetRecordedDate
public void unsetRecordedDate()
-