Class Host
java.lang.Object
com.softlayer.api.Type
com.softlayer.api.service.Entity
com.softlayer.api.service.container.network.storage.Host
@ApiType("SoftLayer_Container_Network_Storage_Host") public class Host extends Entity
The SoftLayer_Container_Network_Storage_Host will contain the reference id field for the object associated with the host. The host object type will also be returned.
- See Also:
- SoftLayer_Container_Network_Storage_Host
-
Nested Class Summary
Nested Classes Modifier and Type Class Description static classHost.Mask -
Field Summary
Fields Modifier and Type Field Description protected LongidReference id field for object associated with host.protected booleanidSpecifiedprotected StringobjectTypeType for the object associated with hostprotected booleanobjectTypeSpecified -
Constructor Summary
Constructors Constructor Description Host() -
Method Summary
Modifier and Type Method Description LonggetId()StringgetObjectType()booleanisIdSpecified()booleanisObjectTypeSpecified()voidsetId(Long id)voidsetObjectType(String objectType)voidunsetId()voidunsetObjectType()
-
Field Details
-
id
Reference id field for object associated with host. -
idSpecified
protected boolean idSpecified -
objectType
Type for the object associated with host -
objectTypeSpecified
protected boolean objectTypeSpecified
-
-
Constructor Details
-
Host
public Host()
-
-
Method Details
-
getId
-
setId
-
isIdSpecified
public boolean isIdSpecified() -
unsetId
public void unsetId() -
getObjectType
-
setObjectType
-
isObjectTypeSpecified
public boolean isObjectTypeSpecified() -
unsetObjectType
public void unsetObjectType()
-