java.lang.Object
com.softlayer.api.Type
com.softlayer.api.service.Entity
com.softlayer.api.service.container.product.Order
Direct Known Subclasses:
AsAService, AsAService, Binding, Certificate, Cloud, Cluster, Controller, Dedicated, DedicatedHost, Delivery, Enterprise, External, Firewall, Global, Hub, Image, Interconnect, Ipsec, Iscsi, License, LoadBalancer, Modification, MultiConfiguration, Nas, NewCustomerSetup, Object, OrderService, Package, PerformanceStorage, Plugin, Registration, Replication, Request, Request, Reseller, ReservedCapacity, Server, SnapshotSpace, SnapshotSpace, Subnet, Support, Upgrade, Vault, Virtual, Vlan

@ApiType("SoftLayer_Container_Product_Order")
public class Order
extends Entity
This is the datatype that needs to be populated and sent to SoftLayer_Product_Order::placeOrder. This datatype has everything required to place an order with SoftLayer.
See Also:
SoftLayer_Container_Product_Order