Uses of Class
com.softlayer.api.service.container.product.Order
-
Uses of Order in com.softlayer.api.service
Methods in com.softlayer.api.service that return Order Modifier and Type Method Description OrderHardware.Service. generateOrderTemplate(Hardware templateObject)
Obtain an [[SoftLayer_Container_Product_Order_Hardware_Server (type)|order container]] that can be sent to [[SoftLayer_Product_Order/verifyOrder|verifyOrder]] or [[SoftLayer_Product_Order/placeOrder|placeOrder]].Methods in com.softlayer.api.service that return types with arguments of type Order Modifier and Type Method Description Future<Order>Hardware.ServiceAsync. generateOrderTemplate(Hardware templateObject)Method parameters in com.softlayer.api.service with type arguments of type Order Modifier and Type Method Description Future<?>Hardware.ServiceAsync. generateOrderTemplate(Hardware templateObject, ResponseHandler<Order> callback) -
Uses of Order in com.softlayer.api.service.billing
Methods in com.softlayer.api.service.billing that return Order Modifier and Type Method Description OrderOrder.Service. getRecalculatedOrderContainer(String message, Boolean ignoreDiscountsFlag)Generate an [[SoftLayer_Container_Product_Order|order container]] from a billing order.Methods in com.softlayer.api.service.billing that return types with arguments of type Order Modifier and Type Method Description Future<Order>Order.ServiceAsync. getRecalculatedOrderContainer(String message, Boolean ignoreDiscountsFlag)Method parameters in com.softlayer.api.service.billing with type arguments of type Order Modifier and Type Method Description Future<?>Order.ServiceAsync. getRecalculatedOrderContainer(String message, Boolean ignoreDiscountsFlag, ResponseHandler<Order> callback) -
Uses of Order in com.softlayer.api.service.billing.order
Methods in com.softlayer.api.service.billing.order that return Order Modifier and Type Method Description OrderCart.Service. getRecalculatedOrderContainer(Order orderData, Boolean orderBeingPlacedFlag)This method allows the customer to retrieve a saved cart and put it in a format that's suitable to be sent to SoftLayer_Billing_Order_Cart::createCart to create a new cart or to SoftLayer_Billing_Order_Cart::updateCart to update an existing cart.OrderQuote.Service. getRecalculatedOrderContainer(Order userOrderData, Boolean orderBeingPlacedFlag)Generate an [[SoftLayer_Container_Product_Order|order container]] from the previously-created quote.OrderQuote.Service. placeQuote(Order orderData)Use this method for placing server quotes and additional services quotes.OrderQuote.Service. verifyOrder(Order orderData)Use this method for placing server orders and additional services orders.Methods in com.softlayer.api.service.billing.order that return types with arguments of type Order Modifier and Type Method Description Future<Order>Cart.ServiceAsync. getRecalculatedOrderContainer(Order orderData, Boolean orderBeingPlacedFlag)Future<Order>Quote.ServiceAsync. getRecalculatedOrderContainer(Order userOrderData, Boolean orderBeingPlacedFlag)Future<Order>Quote.ServiceAsync. placeQuote(Order orderData)Future<Order>Quote.ServiceAsync. verifyOrder(Order orderData)Methods in com.softlayer.api.service.billing.order with parameters of type Order Modifier and Type Method Description LongCart.Service. createCart(Order orderData)When creating a new cart, the order data is sent through SoftLayer_Product_Order::verifyOrder to make sure that the cart contains valid data.Future<Long>Cart.ServiceAsync. createCart(Order orderData)Future<?>Cart.ServiceAsync. createCart(Order orderData, ResponseHandler<Long> callback)OrderCart.Service. getRecalculatedOrderContainer(Order orderData, Boolean orderBeingPlacedFlag)This method allows the customer to retrieve a saved cart and put it in a format that's suitable to be sent to SoftLayer_Billing_Order_Cart::createCart to create a new cart or to SoftLayer_Billing_Order_Cart::updateCart to update an existing cart.Future<Order>Cart.ServiceAsync. getRecalculatedOrderContainer(Order orderData, Boolean orderBeingPlacedFlag)Future<?>Cart.ServiceAsync. getRecalculatedOrderContainer(Order orderData, Boolean orderBeingPlacedFlag, ResponseHandler<Order> callback)OrderQuote.Service. getRecalculatedOrderContainer(Order userOrderData, Boolean orderBeingPlacedFlag)Generate an [[SoftLayer_Container_Product_Order|order container]] from the previously-created quote.Future<Order>Quote.ServiceAsync. getRecalculatedOrderContainer(Order userOrderData, Boolean orderBeingPlacedFlag)Future<?>Quote.ServiceAsync. getRecalculatedOrderContainer(Order userOrderData, Boolean orderBeingPlacedFlag, ResponseHandler<Order> callback)ReceiptQuote.Service. placeOrder(Order orderData)Use this method for placing server orders and additional services orders.Future<Receipt>Quote.ServiceAsync. placeOrder(Order orderData)Future<?>Quote.ServiceAsync. placeOrder(Order orderData, ResponseHandler<Receipt> callback)OrderQuote.Service. placeQuote(Order orderData)Use this method for placing server quotes and additional services quotes.Future<Order>Quote.ServiceAsync. placeQuote(Order orderData)Future<?>Quote.ServiceAsync. placeQuote(Order orderData, ResponseHandler<Order> callback)LongCart.Service. updateCart(Order orderData)Like SoftLayer_Billing_Order_Cart::createCart, the order data will be sent through SoftLayer_Product_Order::verifyOrder to make sure that the updated cart information is valid.Future<Long>Cart.ServiceAsync. updateCart(Order orderData)Future<?>Cart.ServiceAsync. updateCart(Order orderData, ResponseHandler<Long> callback)OrderQuote.Service. verifyOrder(Order orderData)Use this method for placing server orders and additional services orders.Future<Order>Quote.ServiceAsync. verifyOrder(Order orderData)Future<?>Quote.ServiceAsync. verifyOrder(Order orderData, ResponseHandler<Order> callback)Method parameters in com.softlayer.api.service.billing.order with type arguments of type Order Modifier and Type Method Description Future<?>Cart.ServiceAsync. getRecalculatedOrderContainer(Order orderData, Boolean orderBeingPlacedFlag, ResponseHandler<Order> callback)Future<?>Quote.ServiceAsync. getRecalculatedOrderContainer(Order userOrderData, Boolean orderBeingPlacedFlag, ResponseHandler<Order> callback)Future<?>Quote.ServiceAsync. placeQuote(Order orderData, ResponseHandler<Order> callback)Future<?>Quote.ServiceAsync. verifyOrder(Order orderData, ResponseHandler<Order> callback) -
Uses of Order in com.softlayer.api.service.container.product
Fields in com.softlayer.api.service.container.product with type parameters of type Order Modifier and Type Field Description protected List<Order>Order. orderContainersOrders may contain an array of configurations.Methods in com.softlayer.api.service.container.product that return types with arguments of type Order Modifier and Type Method Description List<Order>Order. getOrderContainers() -
Uses of Order in com.softlayer.api.service.container.product.order
Subclasses of Order in com.softlayer.api.service.container.product.order Modifier and Type Class Description classMultiConfigurationThis is a datatype used with multi-configuration deployments.classNewCustomerSetupThis is the datatype that needs to be populated and sent to SoftLayer_Product_Order::placeOrder when linking a Bluemix account to a newly created SoftLayer account.classOrderServiceThis is the datatype that needs to be populated and sent to SoftLayer_Product_Order::placeOrder.classSupportWhen ordering paid support this datatype needs to be populated and sent to SoftLayer_Product_Order::placeOrder.Fields in com.softlayer.api.service.container.product.order declared as Order Modifier and Type Field Description protected OrderReceipt. orderDetailsThis is a copy of the order container (SoftLayer_Container_Product_Order) which holds all the data related to an order.Fields in com.softlayer.api.service.container.product.order with type parameters of type Order Modifier and Type Field Description protected List<Order>Network. publicVlansThe list of public [[SoftLayer_Container_Product_Order_Network_Vlan|vlans]] available for ordering.protected List<Order>Network. subnetsThe list of private [[SoftLayer_Container_Product_Order_Network_Subnet|subnets]] available for ordering with a description of their available IP space.Methods in com.softlayer.api.service.container.product.order that return Order Modifier and Type Method Description OrderReceipt. getOrderDetails()Methods in com.softlayer.api.service.container.product.order that return types with arguments of type Order Modifier and Type Method Description List<Order>Network. getPublicVlans()List<Order>Network. getSubnets()Methods in com.softlayer.api.service.container.product.order with parameters of type Order Modifier and Type Method Description voidReceipt. setOrderDetails(Order orderDetails) -
Uses of Order in com.softlayer.api.service.container.product.order.account.media.data.transfer
Subclasses of Order in com.softlayer.api.service.container.product.order.account.media.data.transfer Modifier and Type Class Description classRequestThis datatype is to be used for data transfer requests. -
Uses of Order in com.softlayer.api.service.container.product.order.dns.domain
Subclasses of Order in com.softlayer.api.service.container.product.order.dns.domain Modifier and Type Class Description classRegistrationThis is the datatype that needs to be populated and sent to SoftLayer_Product_Order::placeOrder.classResellerThis is the datatype that needs to be populated and sent to SoftLayer_Product_Order::placeOrder. -
Uses of Order in com.softlayer.api.service.container.product.order.gateway.appliance
Subclasses of Order in com.softlayer.api.service.container.product.order.gateway.appliance Modifier and Type Class Description classClusterThis is the datatype that needs to be populated and sent to SoftLayer_Product_Order::placeOrder.classUpgradeThis is the datatype that needs to be populated and sent to SoftLayer_Product_Order::placeOrder. -
Uses of Order in com.softlayer.api.service.container.product.order.hardware
Subclasses of Order in com.softlayer.api.service.container.product.order.hardware Modifier and Type Class Description classServerThis is the datatype that needs to be populated and sent to SoftLayer_Product_Order::placeOrder. -
Uses of Order in com.softlayer.api.service.container.product.order.hardware.security
Subclasses of Order in com.softlayer.api.service.container.product.order.hardware.security Modifier and Type Class Description classModuleThis is the datatype that needs to be populated and sent to SoftLayer_Product_Order::placeOrder. -
Uses of Order in com.softlayer.api.service.container.product.order.hardware.server
Subclasses of Order in com.softlayer.api.service.container.product.order.hardware.server Modifier and Type Class Description classColocationThis is the datatype that needs to be populated and sent to SoftLayer_Product_Order::placeOrder.classUpgradeThis is the datatype that needs to be populated and sent to SoftLayer_Product_Order::placeOrder.classVpc -
Uses of Order in com.softlayer.api.service.container.product.order.hardware.server.gateway
Subclasses of Order in com.softlayer.api.service.container.product.order.hardware.server.gateway Modifier and Type Class Description classApplianceThis is the datatype that needs to be populated and sent to SoftLayer_Product_Order::placeOrder. -
Uses of Order in com.softlayer.api.service.container.product.order.monitoring
Subclasses of Order in com.softlayer.api.service.container.product.order.monitoring Modifier and Type Class Description classPackageThis is the datatype that needs to be populated and sent to SoftLayer_Product_Order::placeOrder. -
Uses of Order in com.softlayer.api.service.container.product.order.multiconfiguration
Subclasses of Order in com.softlayer.api.service.container.product.order.multiconfiguration Modifier and Type Class Description classTornado -
Uses of Order in com.softlayer.api.service.container.product.order.network
Subclasses of Order in com.softlayer.api.service.container.product.order.network Modifier and Type Class Description classInterconnectThis is the datatype that needs to be populated and sent to SoftLayer_Product_Order::placeOrder when purchasing a Network Interconnect.classLoadBalancerThis is the default container type for network load balancer orders.classPerformanceStorageThis is the base data type for Performance storage order containers.classSubnetThis is the datatype that needs to be populated and sent to SoftLayer_Product_Order::placeOrder.classVlanThis is the datatype that needs to be populated and sent to SoftLayer_Product_Order::placeOrder.Fields in com.softlayer.api.service.container.product.order.network with type parameters of type Order Modifier and Type Field Description protected List<Order>Vlans. privateVlansThe collection of private vlans available during ordering.protected List<Order>Vlans. publicVlansThe collection of public vlans available during ordering.protected List<Order>Vlan. subnetsThe collection of subnets associated with this vlan.Methods in com.softlayer.api.service.container.product.order.network that return types with arguments of type Order Modifier and Type Method Description List<Order>Vlans. getPrivateVlans()List<Order>Vlans. getPublicVlans()List<Order>Vlan. getSubnets() -
Uses of Order in com.softlayer.api.service.container.product.order.network.application.delivery
Subclasses of Order in com.softlayer.api.service.container.product.order.network.application.delivery Modifier and Type Class Description classControllerThis is the datatype that needs to be populated and sent to SoftLayer_Product_Order::placeOrder. -
Uses of Order in com.softlayer.api.service.container.product.order.network.interconnect
Subclasses of Order in com.softlayer.api.service.container.product.order.network.interconnect Modifier and Type Class Description classUpgradeThis is the datatype that needs to be populated and sent to SoftLayer_Product_Order::placeOrder. -
Uses of Order in com.softlayer.api.service.container.product.order.network.loadbalancer
Subclasses of Order in com.softlayer.api.service.container.product.order.network.loadbalancer Modifier and Type Class Description classAsAServiceThis is the datatype that needs to be populated and sent to SoftLayer_Product_Order::placeOrder.classGlobalThe global load balancer service has been deprecated and is no longer available. -
Uses of Order in com.softlayer.api.service.container.product.order.network.message
Subclasses of Order in com.softlayer.api.service.container.product.order.network.message Modifier and Type Class Description classDeliveryThis is the datatype that needs to be populated and sent to SoftLayer_Product_Order::placeOrder. -
Uses of Order in com.softlayer.api.service.container.product.order.network.performancestorage
Subclasses of Order in com.softlayer.api.service.container.product.order.network.performancestorage Modifier and Type Class Description classIscsiThis is the datatype that needs to be populated and sent to SoftLayer_Product_Order::placeOrder.classNfsThis is the datatype that needs to be populated and sent to SoftLayer_Product_Order::placeOrder. -
Uses of Order in com.softlayer.api.service.container.product.order.network.protection
Subclasses of Order in com.softlayer.api.service.container.product.order.network.protection Modifier and Type Class Description classFirewallThis is the datatype that needs to be populated and sent to SoftLayer_Product_Order::placeOrder. -
Uses of Order in com.softlayer.api.service.container.product.order.network.protection.firewall
Subclasses of Order in com.softlayer.api.service.container.product.order.network.protection.firewall Modifier and Type Class Description classDedicatedThis is the datatype that needs to be populated and sent to SoftLayer_Product_Order::placeOrder. -
Uses of Order in com.softlayer.api.service.container.product.order.network.protection.firewall.dedicated
Subclasses of Order in com.softlayer.api.service.container.product.order.network.protection.firewall.dedicated Modifier and Type Class Description classUpgradeThis is the datatype that needs to be populated and sent to SoftLayer_Product_Order::placeOrder. -
Uses of Order in com.softlayer.api.service.container.product.order.network.storage
Subclasses of Order in com.softlayer.api.service.container.product.order.network.storage Modifier and Type Class Description classAsAServiceThis is the datatype that needs to be populated and sent to SoftLayer_Product_Order::placeOrder.classEnterpriseThis is the datatype that needs to be populated and sent to SoftLayer_Product_Order::placeOrder.classHubThis datatype is to be used for object storage orders.classIscsiThis is the datatype that needs to be populated and sent to SoftLayer_Product_Order::placeOrder.classModificationThe SoftLayer_Container_Product_Order_Network_Storage_Modification datatype has everything required to place a modification to an existing StorageLayer account with SoftLayer.classNasThis is the datatype that needs to be populated and sent to SoftLayer_Product_Order::placeOrder when placing network attached storage orders.classObjectThis datatype is to be used for ordering object storage products using the object_storage [[SoftLayer_Product_Item_Category|category]]. -
Uses of Order in com.softlayer.api.service.container.product.order.network.storage.asaservice
Subclasses of Order in com.softlayer.api.service.container.product.order.network.storage.asaservice Modifier and Type Class Description classUpgradeThis is the datatype that needs to be populated and sent to SoftLayer_Product_Order::placeOrder. -
Uses of Order in com.softlayer.api.service.container.product.order.network.storage.backup.evault
Subclasses of Order in com.softlayer.api.service.container.product.order.network.storage.backup.evault Modifier and Type Class Description classPluginThis is the datatype that needs to be populated and sent to SoftLayer_Product_Order::placeOrder.classVaultThis is the datatype that needs to be populated and sent to SoftLayer_Product_Order::placeOrder. -
Uses of Order in com.softlayer.api.service.container.product.order.network.storage.enterprise
Subclasses of Order in com.softlayer.api.service.container.product.order.network.storage.enterprise Modifier and Type Class Description classSnapshotSpaceThis is the datatype that needs to be populated and sent to SoftLayer_Product_Order::placeOrder. -
Uses of Order in com.softlayer.api.service.container.product.order.network.storage.enterprise.snapshotspace
Subclasses of Order in com.softlayer.api.service.container.product.order.network.storage.enterprise.snapshotspace Modifier and Type Class Description classUpgradeThis is the datatype that needs to be populated and sent to SoftLayer_Product_Order::placeOrder. -
Uses of Order in com.softlayer.api.service.container.product.order.network.storage.iscsi
Subclasses of Order in com.softlayer.api.service.container.product.order.network.storage.iscsi Modifier and Type Class Description classReplicationThis is the datatype that needs to be populated and sent to SoftLayer_Product_Order::placeOrder.classSnapshotSpaceThis is the datatype that needs to be populated and sent to SoftLayer_Product_Order::placeOrder. -
Uses of Order in com.softlayer.api.service.container.product.order.network.storage.massdatamigration
Subclasses of Order in com.softlayer.api.service.container.product.order.network.storage.massdatamigration Modifier and Type Class Description classRequestThis datatype is to be used for mass data migration requests. -
Uses of Order in com.softlayer.api.service.container.product.order.network.tunnel
Subclasses of Order in com.softlayer.api.service.container.product.order.network.tunnel Modifier and Type Class Description classIpsecThis is the datatype that needs to be populated and sent to SoftLayer_Product_Order::placeOrder. -
Uses of Order in com.softlayer.api.service.container.product.order.priv
Subclasses of Order in com.softlayer.api.service.container.product.order.priv Modifier and Type Class Description classCloudThis is the datatype that needs to be populated and sent to SoftLayer_Product_Order::placeOrder. -
Uses of Order in com.softlayer.api.service.container.product.order.security
Subclasses of Order in com.softlayer.api.service.container.product.order.security Modifier and Type Class Description classCertificateThis is the datatype that needs to be populated and sent to SoftLayer_Product_Order::placeOrder. -
Uses of Order in com.softlayer.api.service.container.product.order.service
Subclasses of Order in com.softlayer.api.service.container.product.order.service Modifier and Type Class Description classExternalThis is the datatype that needs to be populated and sent to SoftLayer_Product_Order::placeOrder. -
Uses of Order in com.softlayer.api.service.container.product.order.software
Subclasses of Order in com.softlayer.api.service.container.product.order.software Modifier and Type Class Description classLicenseThis is the datatype that needs to be populated and sent to SoftLayer_Product_Order::placeOrder. -
Uses of Order in com.softlayer.api.service.container.product.order.software.component
Subclasses of Order in com.softlayer.api.service.container.product.order.software.component Modifier and Type Class Description classVirtualThis is the datatype that needs to be populated and sent to SoftLayer_Product_Order::placeOrder. -
Uses of Order in com.softlayer.api.service.container.product.order.user.customer.external
Subclasses of Order in com.softlayer.api.service.container.product.order.user.customer.external Modifier and Type Class Description classBindingThis container type is used for placing orders for external authentication, such as phone-based authentication. -
Uses of Order in com.softlayer.api.service.container.product.order.virtual
Subclasses of Order in com.softlayer.api.service.container.product.order.virtual Modifier and Type Class Description classDedicatedHostThis is the default container type for Dedicated Virtual Host orders.classGuestThis is the datatype that needs to be populated and sent to SoftLayer_Product_Order::placeOrder.classReservedCapacityThis is the default container type for Reserved Capacity orders. -
Uses of Order in com.softlayer.api.service.container.product.order.virtual.disk
Subclasses of Order in com.softlayer.api.service.container.product.order.virtual.disk Modifier and Type Class Description classImageThis is the datatype that needs to be populated and sent to SoftLayer_Product_Order::placeOrder. -
Uses of Order in com.softlayer.api.service.container.product.order.virtual.guest
Subclasses of Order in com.softlayer.api.service.container.product.order.virtual.guest Modifier and Type Class Description classUpgradeThis is the datatype that needs to be populated and sent to SoftLayer_Product_Order::placeOrder.classVpc -
Uses of Order in com.softlayer.api.service.container.product.order.virtual.guest.vpc
Subclasses of Order in com.softlayer.api.service.container.product.order.virtual.guest.vpc Modifier and Type Class Description classUpgrade -
Uses of Order in com.softlayer.api.service.product
Methods in com.softlayer.api.service.product that return Order Modifier and Type Method Description OrderOrder.Service. getResellerOrder(Order orderContainer)When the account is on an external reseller brand, this service will provide a SoftLayer_Product_Order with the the pricing adjusted by the external reseller.OrderOrder.Service. processExternalPaymentAuthorization(String token, String payerId)This method simply finalizes an authorization from PayPal.OrderOrder.Service. verifyOrder(Order orderData)This service is used to verify that an order meets all the necessary requirements to purchase a server, virtual server or service from SoftLayer.Methods in com.softlayer.api.service.product that return types with arguments of type Order Modifier and Type Method Description Future<Order>Order.ServiceAsync. getResellerOrder(Order orderContainer)Future<Order>Order.ServiceAsync. processExternalPaymentAuthorization(String token, String payerId)Future<Order>Order.ServiceAsync. verifyOrder(Order orderData)Methods in com.softlayer.api.service.product with parameters of type Order Modifier and Type Method Description OrderOrder.Service. getResellerOrder(Order orderContainer)When the account is on an external reseller brand, this service will provide a SoftLayer_Product_Order with the the pricing adjusted by the external reseller.Future<Order>Order.ServiceAsync. getResellerOrder(Order orderContainer)Future<?>Order.ServiceAsync. getResellerOrder(Order orderContainer, ResponseHandler<Order> callback)VlansOrder.Service. getVlans(Long locationId, Long packageId, String selectedItems, List<Long> vlanIds, List<Long> subnetIds, Long accountId, Order orderContainer, Boolean hardwareFirewallOrderedFlag)Return collections of public and private VLANs that are available during ordering.Future<Vlans>Order.ServiceAsync. getVlans(Long locationId, Long packageId, String selectedItems, List<Long> vlanIds, List<Long> subnetIds, Long accountId, Order orderContainer, Boolean hardwareFirewallOrderedFlag)Future<?>Order.ServiceAsync. getVlans(Long locationId, Long packageId, String selectedItems, List<Long> vlanIds, List<Long> subnetIds, Long accountId, Order orderContainer, Boolean hardwareFirewallOrderedFlag, ResponseHandler<Vlans> callback)ReceiptOrder.Service. placeOrder(Order orderData, Boolean saveAsQuote)
Use this method to place bare metal server, virtual server and additional service orders with SoftLayer.Future<Receipt>Order.ServiceAsync. placeOrder(Order orderData, Boolean saveAsQuote)Future<?>Order.ServiceAsync. placeOrder(Order orderData, Boolean saveAsQuote, ResponseHandler<Receipt> callback)ReceiptOrder.Service. placeQuote(Order orderData)Use this method for placing server quotes and additional services quotes.Future<Receipt>Order.ServiceAsync. placeQuote(Order orderData)Future<?>Order.ServiceAsync. placeQuote(Order orderData, ResponseHandler<Receipt> callback)OrderOrder.Service. verifyOrder(Order orderData)This service is used to verify that an order meets all the necessary requirements to purchase a server, virtual server or service from SoftLayer.Future<Order>Order.ServiceAsync. verifyOrder(Order orderData)Future<?>Order.ServiceAsync. verifyOrder(Order orderData, ResponseHandler<Order> callback)Method parameters in com.softlayer.api.service.product with type arguments of type Order Modifier and Type Method Description Future<?>Order.ServiceAsync. getResellerOrder(Order orderContainer, ResponseHandler<Order> callback)Future<?>Order.ServiceAsync. processExternalPaymentAuthorization(String token, String payerId, ResponseHandler<Order> callback)Future<?>Order.ServiceAsync. verifyOrder(Order orderData, ResponseHandler<Order> callback) -
Uses of Order in com.softlayer.api.service.virtual
Methods in com.softlayer.api.service.virtual that return Order Modifier and Type Method Description OrderGuest.Service. generateOrderTemplate(Guest templateObject)
Obtain an [[SoftLayer_Container_Product_Order_Virtual_Guest (type)|order container]] that can be sent to [[SoftLayer_Product_Order/verifyOrder|verifyOrder]] or [[SoftLayer_Product_Order/placeOrder|placeOrder]].OrderGuest.Service. getOrderTemplate(String billingType, List<Price> orderPrices)Obtain an order container that is ready to be sent to the [[SoftLayer_Product_Order#placeOrder|SoftLayer_Product_Order::placeOrder]] method.Methods in com.softlayer.api.service.virtual that return types with arguments of type Order Modifier and Type Method Description Future<Order>Guest.ServiceAsync. generateOrderTemplate(Guest templateObject)Future<Order>Guest.ServiceAsync. getOrderTemplate(String billingType, List<Price> orderPrices)Method parameters in com.softlayer.api.service.virtual with type arguments of type Order Modifier and Type Method Description Future<?>Guest.ServiceAsync. generateOrderTemplate(Guest templateObject, ResponseHandler<Order> callback)Future<?>Guest.ServiceAsync. getOrderTemplate(String billingType, List<Price> orderPrices, ResponseHandler<Order> callback) -
Uses of Order in com.softlayer.api.service.workload.citrix.workspace.order
Fields in com.softlayer.api.service.workload.citrix.workspace.order with type parameters of type Order Modifier and Type Field Description protected List<Order>Container. orderContainersThere should be one child orderContainer for each component ordered.Methods in com.softlayer.api.service.workload.citrix.workspace.order that return types with arguments of type Order Modifier and Type Method Description List<Order>Container. getOrderContainers()