Class SensorReadingsWithGraphs
java.lang.Object
com.softlayer.api.Type
com.softlayer.api.service.Entity
com.softlayer.api.service.container.remotemanagement.SensorReadingsWithGraphs
@ApiType("SoftLayer_Container_RemoteManagement_SensorReadingsWithGraphs") public class SensorReadingsWithGraphs extends Entity
The SoftLayer_Container_RemoteManagement_SensorReadingsWithGraphs contains the raw data retrieved from a server's remote management card. Along with the raw data, two sets of graphs will be returned. One set of graphs is used to display, using thermometer graphs, the temperatures (cpu(s) and system) retrieved from the management card. The other set is used to display speed for each of the server's fans.
-
Nested Class Summary
Nested Classes Modifier and Type Class Description static classSensorReadingsWithGraphs.Mask -
Field Summary
Fields Modifier and Type Field Description protected List<SensorReading>rawDataThe raw data returned from the server's remote management card.protected booleanrawDataSpecifiedprotected List<SensorSpeed>speedGraphsThe graph(s) to display the server's fan speeds.protected booleanspeedGraphsSpecifiedprotected List<SensorTemperature>temperatureGraphsThe graph(s) to display the server's cpu(s) and system temperatures.protected booleantemperatureGraphsSpecified -
Constructor Summary
Constructors Constructor Description SensorReadingsWithGraphs() -
Method Summary
Modifier and Type Method Description List<SensorReading>getRawData()List<SensorSpeed>getSpeedGraphs()List<SensorTemperature>getTemperatureGraphs()booleanisRawDataSpecified()booleanisSpeedGraphsSpecified()booleanisTemperatureGraphsSpecified()voidunsetRawData()voidunsetSpeedGraphs()voidunsetTemperatureGraphs()
-
Field Details
-
rawData
The raw data returned from the server's remote management card. -
rawDataSpecified
protected boolean rawDataSpecified -
speedGraphs
The graph(s) to display the server's fan speeds. -
speedGraphsSpecified
protected boolean speedGraphsSpecified -
temperatureGraphs
The graph(s) to display the server's cpu(s) and system temperatures. -
temperatureGraphsSpecified
protected boolean temperatureGraphsSpecified
-
-
Constructor Details
-
SensorReadingsWithGraphs
public SensorReadingsWithGraphs()
-
-
Method Details
-
getRawData
-
isRawDataSpecified
public boolean isRawDataSpecified() -
unsetRawData
public void unsetRawData() -
getSpeedGraphs
-
isSpeedGraphsSpecified
public boolean isSpeedGraphsSpecified() -
unsetSpeedGraphs
public void unsetSpeedGraphs() -
getTemperatureGraphs
-
isTemperatureGraphsSpecified
public boolean isTemperatureGraphsSpecified() -
unsetTemperatureGraphs
public void unsetTemperatureGraphs()
-