Class Token
java.lang.Object
com.softlayer.api.Type
com.softlayer.api.service.Entity
com.softlayer.api.service.container.user.authentication.Token
@ApiType("SoftLayer_Container_User_Authentication_Token") public class Token extends Entity
Container class used to hold user authentication token
-
Nested Class Summary
Nested Classes Modifier and Type Class Description static classToken.Mask -
Field Summary
Fields Modifier and Type Field Description protected Stringhashhash that gets populated for user authenticationprotected booleanhashSpecifiedprotected Customeruserthe user authenticated objectprotected LonguserIdthe id of the user to authenticateprotected booleanuserIdSpecifiedprotected booleanuserSpecified -
Constructor Summary
Constructors Constructor Description Token() -
Method Summary
Modifier and Type Method Description StringgetHash()CustomergetUser()LonggetUserId()booleanisHashSpecified()booleanisUserIdSpecified()booleanisUserSpecified()voidsetHash(String hash)voidsetUser(Customer user)voidsetUserId(Long userId)voidunsetHash()voidunsetUser()voidunsetUserId()
-
Field Details
-
hash
hash that gets populated for user authentication -
hashSpecified
protected boolean hashSpecified -
user
the user authenticated object -
userSpecified
protected boolean userSpecified -
userId
the id of the user to authenticate -
userIdSpecified
protected boolean userIdSpecified
-
-
Constructor Details
-
Token
public Token()
-
-
Method Details
-
getHash
-
setHash
-
isHashSpecified
public boolean isHashSpecified() -
unsetHash
public void unsetHash() -
getUser
-
setUser
-
isUserSpecified
public boolean isUserSpecified() -
unsetUser
public void unsetUser() -
getUserId
-
setUserId
-
isUserIdSpecified
public boolean isUserIdSpecified() -
unsetUserId
public void unsetUserId()
-