Class Phone
java.lang.Object
com.softlayer.api.Type
com.softlayer.api.service.Entity
com.softlayer.api.service.container.user.data.Phone
@ApiType("SoftLayer_Container_User_Data_Phone") public class Phone extends Entity
This container holds user's phone information.
- See Also:
- SoftLayer_Container_User_Data_Phone
-
Nested Class Summary
Nested Classes Modifier and Type Class Description static classPhone.Mask -
Field Summary
Fields Modifier and Type Field Description protected LongcountryCodeCountry code number for the phone number Default: 1 (United States & Canada +1)protected booleancountryCodeSpecifiedprotected StringextensionPhone extension code.protected booleanextensionSpecifiedprotected StringphonePhone number can be a mobile phone number, desk phone number, or some other option.protected booleanphoneSpecifiedprotected StringphoneTypeType of phone number such as "primary", "office" or "home"protected booleanphoneTypeSpecifiedFields inherited from class com.softlayer.api.Type
unknownProperties -
Constructor Summary
Constructors Constructor Description Phone() -
Method Summary
Modifier and Type Method Description LonggetCountryCode()StringgetExtension()StringgetPhone()StringgetPhoneType()booleanisCountryCodeSpecified()booleanisExtensionSpecified()booleanisPhoneSpecified()booleanisPhoneTypeSpecified()voidsetCountryCode(Long countryCode)voidsetExtension(String extension)voidsetPhone(String phone)voidsetPhoneType(String phoneType)voidunsetCountryCode()voidunsetExtension()voidunsetPhone()voidunsetPhoneType()Methods inherited from class com.softlayer.api.Type
getUnknownProperties, setUnknownProperties
-
Field Details
-
countryCode
Country code number for the phone number Default: 1 (United States & Canada +1) -
countryCodeSpecified
protected boolean countryCodeSpecified -
extension
Phone extension code. It can be digits, commas, *, and # are allowed. -
extensionSpecified
protected boolean extensionSpecified -
phone
Phone number can be a mobile phone number, desk phone number, or some other option. The phone number format must match the format selected in the country code. -
phoneSpecified
protected boolean phoneSpecified -
phoneType
Type of phone number such as "primary", "office" or "home" -
phoneTypeSpecified
protected boolean phoneTypeSpecified
-
-
Constructor Details
-
Phone
public Phone()
-
-
Method Details
-
getCountryCode
-
setCountryCode
-
isCountryCodeSpecified
public boolean isCountryCodeSpecified() -
unsetCountryCode
public void unsetCountryCode() -
getExtension
-
setExtension
-
isExtensionSpecified
public boolean isExtensionSpecified() -
unsetExtension
public void unsetExtension() -
getPhone
-
setPhone
-
isPhoneSpecified
public boolean isPhoneSpecified() -
unsetPhone
public void unsetPhone() -
getPhoneType
-
setPhoneType
-
isPhoneTypeSpecified
public boolean isPhoneTypeSpecified() -
unsetPhoneType
public void unsetPhoneType()
-