Uses of Class
com.softlayer.api.service.container.user.data.Phone
| Package | Description |
|---|---|
| com.softlayer.api.service.user.customer.external.binding |
-
Uses of Phone in com.softlayer.api.service.user.customer.external.binding
Methods in com.softlayer.api.service.user.customer.external.binding that return types with arguments of type Phone Modifier and Type Method Description List<Phone>Phone.Service. getPhoneData()Future<List<Phone>>Phone.ServiceAsync. getPhoneData()Async version ofPhone.Service.getPhoneData()Methods in com.softlayer.api.service.user.customer.external.binding with parameters of type Phone Modifier and Type Method Description StringPhone.Service. requestPhoneValidation(Phone phoneData)Initiates a phone validation requests and returns a unique token.Future<String>Phone.ServiceAsync. requestPhoneValidation(Phone phoneData)Future<?>Phone.ServiceAsync. requestPhoneValidation(Phone phoneData, ResponseHandler<String> callback)Method parameters in com.softlayer.api.service.user.customer.external.binding with type arguments of type Phone Modifier and Type Method Description Future<?>Phone.ServiceAsync. getPhoneData(ResponseHandler<List<Phone>> callback)BooleanPhone.Service. updatePhone(List<Phone> phoneData)Phone external binding supports a primary and a backup phone number.Future<Boolean>Phone.ServiceAsync. updatePhone(List<Phone> phoneData)Future<?>Phone.ServiceAsync. updatePhone(List<Phone> phoneData, ResponseHandler<Boolean> callback)