Package com.softlayer.api.service.dns
Class Message
java.lang.Object
com.softlayer.api.Type
com.softlayer.api.service.Entity
com.softlayer.api.service.dns.Message
@ApiType("SoftLayer_Dns_Message") public class Message extends Entity
The SoftLayer_Dns_Message data type contains information for a single message generated by the SoftLayer DNS system. SoftLayer_Dns_Messages are typically created during the secondary DNS transfer process.
- See Also:
- SoftLayer_Dns_Message
-
Nested Class Summary
Nested Classes Modifier and Type Class Description static classMessage.Mask -
Field Summary
Fields Modifier and Type Field Description protected GregorianCalendarcreateDateThe date the message was created.protected booleancreateDateSpecifiedprotected DomaindomainThe domain that is associated with a message.protected LongidThe internal identifier for a DNS message.protected booleanidSpecifiedprotected StringmessageThe message text.protected booleanmessageSpecifiedprotected StringpriorityThe priority level for a DNS message.protected booleanprioritySpecifiedprotected ResourceRecordresourceRecordThe resource record that is associated with a message.protected SecondarysecondaryThe secondary DNS record that a message belongs to. -
Constructor Summary
Constructors Constructor Description Message() -
Method Summary
Modifier and Type Method Description GregorianCalendargetCreateDate()DomaingetDomain()LonggetId()StringgetMessage()StringgetPriority()ResourceRecordgetResourceRecord()SecondarygetSecondary()booleanisCreateDateSpecified()booleanisIdSpecified()booleanisMessageSpecified()booleanisPrioritySpecified()voidsetCreateDate(GregorianCalendar createDate)voidsetDomain(Domain domain)voidsetId(Long id)voidsetMessage(String message)voidsetPriority(String priority)voidsetResourceRecord(ResourceRecord resourceRecord)voidsetSecondary(Secondary secondary)voidunsetCreateDate()voidunsetId()voidunsetMessage()voidunsetPriority()
-
Field Details
-
domain
The domain that is associated with a message. -
resourceRecord
The resource record that is associated with a message. -
secondary
The secondary DNS record that a message belongs to. -
createDate
The date the message was created. -
createDateSpecified
protected boolean createDateSpecified -
id
The internal identifier for a DNS message. -
idSpecified
protected boolean idSpecified -
message
The message text. -
messageSpecified
protected boolean messageSpecified -
priority
The priority level for a DNS message. The possible levels are 'notice' and 'error'. -
prioritySpecified
protected boolean prioritySpecified
-
-
Constructor Details
-
Message
public Message()
-
-
Method Details
-
getDomain
-
setDomain
-
getResourceRecord
-
setResourceRecord
-
getSecondary
-
setSecondary
-
getCreateDate
-
setCreateDate
-
isCreateDateSpecified
public boolean isCreateDateSpecified() -
unsetCreateDate
public void unsetCreateDate() -
getId
-
setId
-
isIdSpecified
public boolean isIdSpecified() -
unsetId
public void unsetId() -
getMessage
-
setMessage
-
isMessageSpecified
public boolean isMessageSpecified() -
unsetMessage
public void unsetMessage() -
getPriority
-
setPriority
-
isPrioritySpecified
public boolean isPrioritySpecified() -
unsetPriority
public void unsetPriority()
-