Package com.softlayer.api.service.event
Class Log
java.lang.Object
com.softlayer.api.Type
com.softlayer.api.service.Entity
com.softlayer.api.service.event.Log
@ApiType("SoftLayer_Event_Log") public class Log extends Entity
The SoftLayer_Event_Log data type contains an event detail occurred upon various SoftLayer resources.
- See Also:
- SoftLayer_Event_Log
-
Nested Class Summary
Nested Classes Modifier and Type Class Description static classLog.Maskstatic interfaceLog.ServiceEvent Log service lets you find interesting events related to various SoftLayer products and services such as hardware, virtual server or DNS.static interfaceLog.ServiceAsync -
Field Summary
Fields Modifier and Type Field Description protected LongaccountIdAccount id with which the event is associatedprotected booleanaccountIdSpecifiedprotected GregorianCalendareventCreateDateEvent creation date in millisecond precisionprotected booleaneventCreateDateSpecifiedprotected StringeventNameEvent name such as "reboot", "cancel", "update host" and so on.protected booleaneventNameSpecifiedprotected StringipAddressThe remote IP Address that made the requestprotected booleanipAddressSpecifiedprotected StringlabelLabel or description of the event objectprotected booleanlabelSpecifiedprotected StringmetaDataMeta data for an event in JSON stringprotected booleanmetaDataSpecifiedprotected LongobjectIdEvent object idprotected booleanobjectIdSpecifiedprotected StringobjectNameEvent object name such as "server", "dns" and so on.protected booleanobjectNameSpecifiedprotected StringopenIdConnectUserNameOpenIdConnectUserName of the customer who initiated the eventprotected booleanopenIdConnectUserNameSpecifiedprotected EntityresourceA resource object that is associated with the eventprotected booleanresourceSpecifiedprotected StringtraceIdA unique trace id.protected booleantraceIdSpecifiedprotected Customeruserprotected LonguserIdId of customer who initiated the eventprotected booleanuserIdSpecifiedprotected StringusernameCustomer username who initiated the eventprotected booleanusernameSpecifiedprotected StringuserTypeType of user that triggered the event.protected booleanuserTypeSpecifiedFields inherited from class com.softlayer.api.Type
unknownProperties -
Constructor Summary
Constructors Constructor Description Log() -
Method Summary
Methods inherited from class com.softlayer.api.Type
getUnknownProperties, setUnknownProperties
-
Field Details
-
user
-
accountId
Account id with which the event is associated -
accountIdSpecified
protected boolean accountIdSpecified -
eventCreateDate
Event creation date in millisecond precision -
eventCreateDateSpecified
protected boolean eventCreateDateSpecified -
eventName
Event name such as "reboot", "cancel", "update host" and so on. -
eventNameSpecified
protected boolean eventNameSpecified -
ipAddress
The remote IP Address that made the request -
ipAddressSpecified
protected boolean ipAddressSpecified -
label
Label or description of the event object -
labelSpecified
protected boolean labelSpecified -
metaData
Meta data for an event in JSON string -
metaDataSpecified
protected boolean metaDataSpecified -
objectId
Event object id -
objectIdSpecified
protected boolean objectIdSpecified -
objectName
Event object name such as "server", "dns" and so on. -
objectNameSpecified
protected boolean objectNameSpecified -
openIdConnectUserName
OpenIdConnectUserName of the customer who initiated the event -
openIdConnectUserNameSpecified
protected boolean openIdConnectUserNameSpecified -
resource
A resource object that is associated with the event -
resourceSpecified
protected boolean resourceSpecified -
traceId
A unique trace id. Multiple event can be grouped by a trace id. -
traceIdSpecified
protected boolean traceIdSpecified -
userId
Id of customer who initiated the event -
userIdSpecified
protected boolean userIdSpecified -
userType
Type of user that triggered the event. User type can be CUSTOMER, EMPLOYEE or SYSTEM. -
userTypeSpecified
protected boolean userTypeSpecified -
username
Customer username who initiated the event -
usernameSpecified
protected boolean usernameSpecified
-
-
Constructor Details
-
Log
public Log()
-
-
Method Details
-
getUser
-
setUser
-
getAccountId
-
setAccountId
-
isAccountIdSpecified
public boolean isAccountIdSpecified() -
unsetAccountId
public void unsetAccountId() -
getEventCreateDate
-
setEventCreateDate
-
isEventCreateDateSpecified
public boolean isEventCreateDateSpecified() -
unsetEventCreateDate
public void unsetEventCreateDate() -
getEventName
-
setEventName
-
isEventNameSpecified
public boolean isEventNameSpecified() -
unsetEventName
public void unsetEventName() -
getIpAddress
-
setIpAddress
-
isIpAddressSpecified
public boolean isIpAddressSpecified() -
unsetIpAddress
public void unsetIpAddress() -
getLabel
-
setLabel
-
isLabelSpecified
public boolean isLabelSpecified() -
unsetLabel
public void unsetLabel() -
getMetaData
-
setMetaData
-
isMetaDataSpecified
public boolean isMetaDataSpecified() -
unsetMetaData
public void unsetMetaData() -
getObjectId
-
setObjectId
-
isObjectIdSpecified
public boolean isObjectIdSpecified() -
unsetObjectId
public void unsetObjectId() -
getObjectName
-
setObjectName
-
isObjectNameSpecified
public boolean isObjectNameSpecified() -
unsetObjectName
public void unsetObjectName() -
getOpenIdConnectUserName
-
setOpenIdConnectUserName
-
isOpenIdConnectUserNameSpecified
public boolean isOpenIdConnectUserNameSpecified() -
unsetOpenIdConnectUserName
public void unsetOpenIdConnectUserName() -
getResource
-
setResource
-
isResourceSpecified
public boolean isResourceSpecified() -
unsetResource
public void unsetResource() -
getTraceId
-
setTraceId
-
isTraceIdSpecified
public boolean isTraceIdSpecified() -
unsetTraceId
public void unsetTraceId() -
getUserId
-
setUserId
-
isUserIdSpecified
public boolean isUserIdSpecified() -
unsetUserId
public void unsetUserId() -
getUserType
-
setUserType
-
isUserTypeSpecified
public boolean isUserTypeSpecified() -
unsetUserType
public void unsetUserType() -
getUsername
-
setUsername
-
isUsernameSpecified
public boolean isUsernameSpecified() -
unsetUsername
public void unsetUsername() -
service
-