Package com.softlayer.api.service.event
Interface Log.Service
- All Superinterfaces:
Maskable,ResultLimitable,Service
- Enclosing class:
- Log
@ApiService("SoftLayer_Event_Log") public static interface Log.Service extends Service
Event Log service lets you find interesting events related to various SoftLayer products and services such as hardware, virtual server or DNS.
- See Also:
- SoftLayer_Event_Log
-
Method Summary
Modifier and Type Method Description Log.ServiceAsyncasAsync()Get an async version of this serviceList<String>getAllEventNames(String objectName)This all indexed event names.List<String>getAllEventObjectNames()This all indexed event object names.List<Log>getAllObjects()List<String>getAllUserTypes()CustomergetUser()voidsetMask(Log.Mask mask)Log.MaskwithMask()Use the existing mask on this service or create it if not presentLog.MaskwithNewMask()Overwrite the existing mask on this service with a new one and return itMethods inherited from interface com.softlayer.api.ResultLimitable
getLastResponseTotalItemCount, getResultLimit, setResultLimit
-
Method Details
-
asAsync
Log.ServiceAsync asAsync()Description copied from interface:ServiceGet an async version of this service -
withNewMask
Log.Mask withNewMask()Description copied from interface:MaskableOverwrite the existing mask on this service with a new one and return it- Specified by:
withNewMaskin interfaceMaskable
-
withMask
Log.Mask withMask()Description copied from interface:MaskableUse the existing mask on this service or create it if not present -
setMask
-
getAllEventNames
This all indexed event names.- See Also:
- SoftLayer_Event_Log::getAllEventNames
-
getAllEventObjectNames
This all indexed event object names. -
getAllObjects
- See Also:
- SoftLayer_Event_Log::getAllObjects
-
getAllUserTypes
- See Also:
- SoftLayer_Event_Log::getAllUserTypes
-
getUser
- See Also:
- SoftLayer_Event_Log::getUser
-