Class Attribute
java.lang.Object
com.softlayer.api.Type
com.softlayer.api.service.Entity
com.softlayer.api.service.hardware.Attribute
- Direct Known Subclasses:
UserData
@ApiType("SoftLayer_Hardware_Attribute") public class Attribute extends Entity
The SoftLayer_Hardware_Attribute type contains general information for a hardware attribute. Hardware attributes can be assigned to specific hardware objects to describe relatively arbitrary information.
- See Also:
- SoftLayer_Hardware_Attribute
-
Nested Class Summary
Nested Classes Modifier and Type Class Description static classAttribute.Mask -
Field Summary
Fields Modifier and Type Field Description protected TypehardwareAttributeTypeThe type of hardware attribute that this represents.protected LonghardwareAttributeTypeIdThe unique identifier of a hardware attribute's type.protected booleanhardwareAttributeTypeIdSpecifiedprotected LongidA hardware attribute's unique identifier.protected booleanidSpecifiedprotected StringvalueA hardware attribute's value.protected booleanvalueSpecifiedFields inherited from class com.softlayer.api.Type
unknownProperties -
Constructor Summary
Constructors Constructor Description Attribute() -
Method Summary
Modifier and Type Method Description TypegetHardwareAttributeType()LonggetHardwareAttributeTypeId()LonggetId()StringgetValue()booleanisHardwareAttributeTypeIdSpecified()booleanisIdSpecified()booleanisValueSpecified()voidsetHardwareAttributeType(Type hardwareAttributeType)voidsetHardwareAttributeTypeId(Long hardwareAttributeTypeId)voidsetId(Long id)voidsetValue(String value)voidunsetHardwareAttributeTypeId()voidunsetId()voidunsetValue()Methods inherited from class com.softlayer.api.Type
getUnknownProperties, setUnknownProperties
-
Field Details
-
hardwareAttributeType
The type of hardware attribute that this represents. -
hardwareAttributeTypeId
The unique identifier of a hardware attribute's type. -
hardwareAttributeTypeIdSpecified
protected boolean hardwareAttributeTypeIdSpecified -
id
A hardware attribute's unique identifier. -
idSpecified
protected boolean idSpecified -
value
A hardware attribute's value. -
valueSpecified
protected boolean valueSpecified
-
-
Constructor Details
-
Attribute
public Attribute()
-
-
Method Details
-
getHardwareAttributeType
-
setHardwareAttributeType
-
getHardwareAttributeTypeId
-
setHardwareAttributeTypeId
-
isHardwareAttributeTypeIdSpecified
public boolean isHardwareAttributeTypeIdSpecified() -
unsetHardwareAttributeTypeId
public void unsetHardwareAttributeTypeId() -
getId
-
setId
-
isIdSpecified
public boolean isIdSpecified() -
unsetId
public void unsetId() -
getValue
-
setValue
-
isValueSpecified
public boolean isValueSpecified() -
unsetValue
public void unsetValue()
-