Class Chassis
java.lang.Object
com.softlayer.api.Type
com.softlayer.api.service.Entity
com.softlayer.api.service.hardware.Chassis
@ApiType("SoftLayer_Hardware_Chassis") public class Chassis extends Entity
Every piece of hardware in SoftLayer's datacenters, including customer servers, are housed in one of many hardware chassis. The SoftLayer_Hardware_Chassis data type defines these chassis.
- See Also:
- SoftLayer_Hardware_Chassis
-
Nested Class Summary
Nested Classes Modifier and Type Class Description static classChassis.Mask -
Field Summary
Fields Modifier and Type Field Description protected StringbackplaneCapacityprotected StringbayCapacityprotected StringdriveCapacityprotected StringdriveControllerCapacityprotected LongformFactorIdA hardware form factor internal identifier.protected booleanformFactorIdSpecifiedprotected StringgpuCapacityprotected FunctionhardwareFunctionA hardware's function.protected LongidA hardware chassis' internal identifier.protected booleanidSpecifiedprotected StringmanufacturerA hardware chassis' manufacturer.protected booleanmanufacturerSpecifiedprotected StringmoduleCapacityprotected StringnameA hardware chassis' name.protected booleannameSpecifiedprotected StringpowerCapacityprotected Stringu2Capacityprotected LongunitSizeThe physical size of a hardware chassis.protected booleanunitSizeSpecifiedprotected StringversionA hardware chassis' revision number.protected booleanversionSpecified -
Constructor Summary
Constructors Constructor Description Chassis() -
Method Summary
-
Field Details
-
backplaneCapacity
-
bayCapacity
-
driveCapacity
-
driveControllerCapacity
-
gpuCapacity
-
hardwareFunction
A hardware's function. -
moduleCapacity
-
powerCapacity
-
u2Capacity
-
formFactorId
A hardware form factor internal identifier. -
formFactorIdSpecified
protected boolean formFactorIdSpecified -
id
A hardware chassis' internal identifier. -
idSpecified
protected boolean idSpecified -
manufacturer
A hardware chassis' manufacturer. -
manufacturerSpecified
protected boolean manufacturerSpecified -
name
A hardware chassis' name. -
nameSpecified
protected boolean nameSpecified -
unitSize
The physical size of a hardware chassis. Currently this relates to the 'U' size of a chassis buy default. -
unitSizeSpecified
protected boolean unitSizeSpecified -
version
A hardware chassis' revision number. -
versionSpecified
protected boolean versionSpecified
-
-
Constructor Details
-
Chassis
public Chassis()
-
-
Method Details
-
getBackplaneCapacity
-
setBackplaneCapacity
-
getBayCapacity
-
setBayCapacity
-
getDriveCapacity
-
setDriveCapacity
-
getDriveControllerCapacity
-
setDriveControllerCapacity
-
getGpuCapacity
-
setGpuCapacity
-
getHardwareFunction
-
setHardwareFunction
-
getModuleCapacity
-
setModuleCapacity
-
getPowerCapacity
-
setPowerCapacity
-
getU2Capacity
-
setU2Capacity
-
getFormFactorId
-
setFormFactorId
-
isFormFactorIdSpecified
public boolean isFormFactorIdSpecified() -
unsetFormFactorId
public void unsetFormFactorId() -
getId
-
setId
-
isIdSpecified
public boolean isIdSpecified() -
unsetId
public void unsetId() -
getManufacturer
-
setManufacturer
-
isManufacturerSpecified
public boolean isManufacturerSpecified() -
unsetManufacturer
public void unsetManufacturer() -
getName
-
setName
-
isNameSpecified
public boolean isNameSpecified() -
unsetName
public void unsetName() -
getUnitSize
-
setUnitSize
-
isUnitSizeSpecified
public boolean isUnitSizeSpecified() -
unsetUnitSize
public void unsetUnitSize() -
getVersion
-
setVersion
-
isVersionSpecified
public boolean isVersionSpecified() -
unsetVersion
public void unsetVersion()
-