Class Component
java.lang.Object
com.softlayer.api.Type
com.softlayer.api.service.Entity
com.softlayer.api.service.hardware.Component
- Direct Known Subclasses:
DriveController,HardDrive,Motherboard,NetworkCard,Processor,Ram,RemoteManagement,SecurityDevice
@ApiType("SoftLayer_Hardware_Component") public class Component extends Entity
The SoftLayer_Hardware_Component data type abstracts information related to a hardware component.
- See Also:
- SoftLayer_Hardware_Component
-
Nested Class Summary
Nested Classes Modifier and Type Class Description static classComponent.Mask -
Field Summary
Fields Modifier and Type Field Description protected BigDecimalcapacityA component's capacity.protected List<Component>childrenA components sub components.protected LongchildrenCountA count of a components sub components.protected StringcomponentRevisionA component's Revision.protected LongdownlinkHardwareComponentCountA count ofprotected List<Component>downlinkHardwareComponentsprotected HardwarehardwareThe hardware object that this component belongs to.protected ModelhardwareComponentModelThe general group of component models.protected LonghardwareComponentModelIdThe internal identifier of a hardware component's component model.protected booleanhardwareComponentModelIdSpecifiedprotected TypehardwareComponentTypeA components type.protected LonghardwareIdThe internal identifier of the hardware that a hardware component resides inside.protected booleanhardwareIdSpecifiedprotected LongidA hardware component's internal identifier.protected booleanidSpecifiedprotected BooleanisChildModuleprotected LonglogicalVolumeStorageGroupCountA count of returns the associated logic volume storage groups for the hardware component.protected List<Group>logicalVolumeStorageGroupsReturns the associated logic volume storage groups for the hardware component.protected Stringm2SataSlotCapacityA component's M.2 SATA capacity.protected GregorianCalendarmodifyDateThe date that a hardware component was last modified.protected booleanmodifyDateSpecifiedprotected LongmoduleComponentCountA count of the module's hardware componentsprotected List<Component>moduleComponentsThe module's hardware componentsprotected LongmoduleCountA count ofprotected LongmoduleHardwareComponentCountA count of the module's hardware componentsprotected List<Component>moduleHardwareComponentsThe module's hardware componentsprotected LongmoduleNetworkComponentCountA count of the module's network componentsprotected List<Component>moduleNetworkComponentsThe module's network componentsprotected List<Component>modulesprotected StringnameThe name of this component as referenced by the operating system.protected booleannameSpecifiedprotected LongnetworkComponentCountA count of the components local ethernet and remote management interfacesprotected List<Component>networkComponentsThe components local ethernet and remote management interfacesprotected AccountownerThe account this component belongs to.protected ComponentparentA components parent.protected ComponentparentModuleprotected AttributeprefixAttributeprotected StringraidModeA RAID controllers RAID mode.protected RevisionrevisionThe component revision designation.protected StringserialNumberThe component serial number.protected booleanserialNumberSpecifiedprotected ProviderserviceProviderprotected LongserviceProviderIdA hardware's internal identification number at its service providerprotected booleanserviceProviderIdSpecifiedprotected LonguplinkHardwareComponentCountA count ofprotected List<Component>uplinkHardwareComponents -
Constructor Summary
Constructors Constructor Description Component() -
Method Summary
-
Field Details
-
capacity
A component's capacity. -
children
A components sub components. Devices that are usually integrated or in some way attached to a component. -
componentRevision
A component's Revision. -
downlinkHardwareComponents
-
hardware
The hardware object that this component belongs to. -
hardwareComponentModel
The general group of component models. -
hardwareComponentType
A components type. -
isChildModule
-
logicalVolumeStorageGroups
Returns the associated logic volume storage groups for the hardware component. -
m2SataSlotCapacity
A component's M.2 SATA capacity. -
moduleComponents
The module's hardware components -
moduleHardwareComponents
The module's hardware components -
moduleNetworkComponents
The module's network components -
modules
-
networkComponents
The components local ethernet and remote management interfaces -
owner
The account this component belongs to. -
parent
A components parent. Devices that are usually integrated or in some way attached to a component. -
parentModule
-
prefixAttribute
-
raidMode
A RAID controllers RAID mode. -
revision
The component revision designation. -
serviceProvider
-
uplinkHardwareComponents
-
hardwareComponentModelId
The internal identifier of a hardware component's component model. -
hardwareComponentModelIdSpecified
protected boolean hardwareComponentModelIdSpecified -
hardwareId
The internal identifier of the hardware that a hardware component resides inside. -
hardwareIdSpecified
protected boolean hardwareIdSpecified -
id
A hardware component's internal identifier. -
idSpecified
protected boolean idSpecified -
modifyDate
The date that a hardware component was last modified. -
modifyDateSpecified
protected boolean modifyDateSpecified -
name
The name of this component as referenced by the operating system. -
nameSpecified
protected boolean nameSpecified -
serialNumber
The component serial number. -
serialNumberSpecified
protected boolean serialNumberSpecified -
serviceProviderId
A hardware's internal identification number at its service provider -
serviceProviderIdSpecified
protected boolean serviceProviderIdSpecified -
childrenCount
A count of a components sub components. Devices that are usually integrated or in some way attached to a component. -
downlinkHardwareComponentCount
A count of -
logicalVolumeStorageGroupCount
A count of returns the associated logic volume storage groups for the hardware component. -
moduleComponentCount
A count of the module's hardware components -
moduleCount
A count of -
moduleHardwareComponentCount
A count of the module's hardware components -
moduleNetworkComponentCount
A count of the module's network components -
networkComponentCount
A count of the components local ethernet and remote management interfaces -
uplinkHardwareComponentCount
A count of
-
-
Constructor Details
-
Component
public Component()
-
-
Method Details
-
getCapacity
-
setCapacity
-
getChildren
-
getComponentRevision
-
setComponentRevision
-
getDownlinkHardwareComponents
-
getHardware
-
setHardware
-
getHardwareComponentModel
-
setHardwareComponentModel
-
getHardwareComponentType
-
setHardwareComponentType
-
getIsChildModule
-
setIsChildModule
-
getLogicalVolumeStorageGroups
-
getM2SataSlotCapacity
-
setM2SataSlotCapacity
-
getModuleComponents
-
getModuleHardwareComponents
-
getModuleNetworkComponents
-
getModules
-
getNetworkComponents
-
getOwner
-
setOwner
-
getParent
-
setParent
-
getParentModule
-
setParentModule
-
getPrefixAttribute
-
setPrefixAttribute
-
getRaidMode
-
setRaidMode
-
getRevision
-
setRevision
-
getServiceProvider
-
setServiceProvider
-
getUplinkHardwareComponents
-
getHardwareComponentModelId
-
setHardwareComponentModelId
-
isHardwareComponentModelIdSpecified
public boolean isHardwareComponentModelIdSpecified() -
unsetHardwareComponentModelId
public void unsetHardwareComponentModelId() -
getHardwareId
-
setHardwareId
-
isHardwareIdSpecified
public boolean isHardwareIdSpecified() -
unsetHardwareId
public void unsetHardwareId() -
getId
-
setId
-
isIdSpecified
public boolean isIdSpecified() -
unsetId
public void unsetId() -
getModifyDate
-
setModifyDate
-
isModifyDateSpecified
public boolean isModifyDateSpecified() -
unsetModifyDate
public void unsetModifyDate() -
getName
-
setName
-
isNameSpecified
public boolean isNameSpecified() -
unsetName
public void unsetName() -
getSerialNumber
-
setSerialNumber
-
isSerialNumberSpecified
public boolean isSerialNumberSpecified() -
unsetSerialNumber
public void unsetSerialNumber() -
getServiceProviderId
-
setServiceProviderId
-
isServiceProviderIdSpecified
public boolean isServiceProviderIdSpecified() -
unsetServiceProviderId
public void unsetServiceProviderId() -
getChildrenCount
-
setChildrenCount
-
getDownlinkHardwareComponentCount
-
setDownlinkHardwareComponentCount
-
getLogicalVolumeStorageGroupCount
-
setLogicalVolumeStorageGroupCount
-
getModuleComponentCount
-
setModuleComponentCount
-
getModuleCount
-
setModuleCount
-
getModuleHardwareComponentCount
-
setModuleHardwareComponentCount
-
getModuleNetworkComponentCount
-
setModuleNetworkComponentCount
-
getNetworkComponentCount
-
setNetworkComponentCount
-
getUplinkHardwareComponentCount
-
setUplinkHardwareComponentCount
-