Class Group
java.lang.Object
com.softlayer.api.Type
com.softlayer.api.service.Entity
com.softlayer.api.service.hardware.Group
@ApiType("SoftLayer_Hardware_Group") public class Group extends Entity
- See Also:
- SoftLayer_Hardware_Group
-
Nested Class Summary
Nested Classes Modifier and Type Class Description static classGroup.Mask -
Field Summary
Fields Modifier and Type Field Description protected Stringdomainprotected booleandomainSpecifiedprotected LongdownlinkServerCountA count of all servers attached to a network hardware.protected List<Hardware>downlinkServersAll servers attached to a network hardware.protected LongdownlinkVirtualGuestCountA count of all virtual guests attached to a network hardware.protected List<Guest>downlinkVirtualGuestsAll virtual guests attached to a network hardware.protected List<Hardware>downstreamNetworkHardwareAll network hardware downstream from this hardware.protected LongdownstreamNetworkHardwareCountA count of all network hardware downstream from this hardware.protected LongdownstreamNetworkHardwareWithIncidentCountA count of all network hardware with monitoring warnings or errors downstream from this hardware.protected List<Hardware>downstreamNetworkHardwareWithIncidentsAll network hardware with monitoring warnings or errors downstream from this hardware.protected ChassishardwareChassisThe chassis that a piece of hardware is housed in.protected Stringhostnameprotected booleanhostnameSpecifiedprotected Longidprotected booleanidSpecifiedprotected List<Hardware>networkMonitorAttachedDownHardwareAll servers attached downstream to a hardware that have failed monitoringprotected LongnetworkMonitorAttachedDownHardwareCountA count of all servers attached downstream to a hardware that have failed monitoringprotected LongnetworkMonitorAttachedDownVirtualGuestCountA count of virtual guests that are attached downstream to a hardware that have failed monitoringprotected List<Guest>networkMonitorAttachedDownVirtualGuestsVirtual guests that are attached downstream to a hardware that have failed monitoringprotected StringnetworkStatusThe value of a hardware's network status attribute. -
Constructor Summary
Constructors Constructor Description Group() -
Method Summary
-
Field Details
-
downlinkServers
All servers attached to a network hardware. -
downlinkVirtualGuests
All virtual guests attached to a network hardware. -
downstreamNetworkHardware
All network hardware downstream from this hardware. -
downstreamNetworkHardwareWithIncidents
All network hardware with monitoring warnings or errors downstream from this hardware. -
hardwareChassis
The chassis that a piece of hardware is housed in. -
networkMonitorAttachedDownHardware
All servers attached downstream to a hardware that have failed monitoring -
networkMonitorAttachedDownVirtualGuests
Virtual guests that are attached downstream to a hardware that have failed monitoring -
networkStatus
The value of a hardware's network status attribute. -
domain
-
domainSpecified
protected boolean domainSpecified -
hostname
-
hostnameSpecified
protected boolean hostnameSpecified -
id
-
idSpecified
protected boolean idSpecified -
downlinkServerCount
A count of all servers attached to a network hardware. -
downlinkVirtualGuestCount
A count of all virtual guests attached to a network hardware. -
downstreamNetworkHardwareCount
A count of all network hardware downstream from this hardware. -
downstreamNetworkHardwareWithIncidentCount
A count of all network hardware with monitoring warnings or errors downstream from this hardware. -
networkMonitorAttachedDownHardwareCount
A count of all servers attached downstream to a hardware that have failed monitoring -
networkMonitorAttachedDownVirtualGuestCount
A count of virtual guests that are attached downstream to a hardware that have failed monitoring
-
-
Constructor Details
-
Group
public Group()
-
-
Method Details
-
getDownlinkServers
-
getDownlinkVirtualGuests
-
getDownstreamNetworkHardware
-
getDownstreamNetworkHardwareWithIncidents
-
getHardwareChassis
-
setHardwareChassis
-
getNetworkMonitorAttachedDownHardware
-
getNetworkMonitorAttachedDownVirtualGuests
-
getNetworkStatus
-
setNetworkStatus
-
getDomain
-
setDomain
-
isDomainSpecified
public boolean isDomainSpecified() -
unsetDomain
public void unsetDomain() -
getHostname
-
setHostname
-
isHostnameSpecified
public boolean isHostnameSpecified() -
unsetHostname
public void unsetHostname() -
getId
-
setId
-
isIdSpecified
public boolean isIdSpecified() -
unsetId
public void unsetId() -
getDownlinkServerCount
-
setDownlinkServerCount
-
getDownlinkVirtualGuestCount
-
setDownlinkVirtualGuestCount
-
getDownstreamNetworkHardwareCount
-
setDownstreamNetworkHardwareCount
-
getDownstreamNetworkHardwareWithIncidentCount
-
setDownstreamNetworkHardwareWithIncidentCount
public void setDownstreamNetworkHardwareWithIncidentCount(Long downstreamNetworkHardwareWithIncidentCount) -
getNetworkMonitorAttachedDownHardwareCount
-
setNetworkMonitorAttachedDownHardwareCount
public void setNetworkMonitorAttachedDownHardwareCount(Long networkMonitorAttachedDownHardwareCount) -
getNetworkMonitorAttachedDownVirtualGuestCount
-
setNetworkMonitorAttachedDownVirtualGuestCount
public void setNetworkMonitorAttachedDownVirtualGuestCount(Long networkMonitorAttachedDownVirtualGuestCount)
-