Class Router
java.lang.Object
com.softlayer.api.Type
com.softlayer.api.service.Entity
com.softlayer.api.service.Hardware
com.softlayer.api.service.hardware.Switch
com.softlayer.api.service.hardware.Router
@ApiType("SoftLayer_Hardware_Router") public class Router extends Switch
The SoftLayer_Hardware_Router data type contains general information relating to a single SoftLayer router.
- See Also:
- SoftLayer_Hardware_Router
-
Nested Class Summary
Nested Classes Modifier and Type Class Description static classRouter.Maskstatic interfaceRouter.ServiceThis service provides access to the device responsible for routing a particular SoftLayer Router.static interfaceRouter.ServiceAsync -
Field Summary
Fields Modifier and Type Field Description protected LongboundSubnetCountA count of associated subnets for a router object.protected List<Subnet>boundSubnetsAssociated subnets for a router object.protected BooleanlocalDiskStorageCapabilityFlagA flag indicating that a VLAN on the router can be assigned to a host that has local disk functionality.protected BooleansanStorageCapabilityFlagA flag indicating that a VLAN on the router can be assigned to a host that has SAN disk functionality.Fields inherited from class com.softlayer.api.service.Hardware
account, accountId, accountIdSpecified, activeComponentCount, activeComponents, activeNetworkMonitorIncident, activeNetworkMonitorIncidentCount, allowedHost, allowedNetworkStorage, allowedNetworkStorageCount, allowedNetworkStorageReplicaCount, allowedNetworkStorageReplicas, allPowerComponentCount, allPowerComponents, antivirusSpywareSoftwareComponent, attributeCount, attributes, averageDailyPublicBandwidthUsage, backendNetworkComponentCount, backendNetworkComponents, backendRouterCount, backendRouters, bandwidthAllocation, bandwidthAllotmentDetail, bareMetalInstanceFlag, bareMetalInstanceFlagSpecified, benchmarkCertificationCount, benchmarkCertifications, billingItem, billingItemFlag, blockCancelBecauseDisconnectedFlag, businessContinuanceInsuranceFlag, childrenHardware, childrenHardwareCount, componentCount, components, continuousDataProtectionSoftwareComponent, currentBillableBandwidthUsage, datacenter, datacenterName, daysInSparePool, domain, domainSpecified, downlinkHardware, downlinkHardwareCount, downlinkNetworkHardware, downlinkNetworkHardwareCount, downlinkServerCount, downlinkServers, downlinkVirtualGuestCount, downlinkVirtualGuests, downstreamHardwareBindingCount, downstreamHardwareBindings, downstreamNetworkHardware, downstreamNetworkHardwareCount, downstreamNetworkHardwareWithIncidentCount, downstreamNetworkHardwareWithIncidents, downstreamServerCount, downstreamServers, downstreamVirtualGuestCount, downstreamVirtualGuests, driveControllerCount, driveControllers, evaultNetworkStorage, evaultNetworkStorageCount, firewallServiceComponent, fixedConfigurationPreset, frontendNetworkComponentCount, frontendNetworkComponents, frontendRouterCount, frontendRouters, fullyQualifiedDomainName, fullyQualifiedDomainNameSpecified, globalIdentifier, hardDriveCount, hardDrives, hardwareChassis, hardwareFunction, hardwareFunctionDescription, hardwareStatus, hardwareStatusId, hardwareStatusIdSpecified, hasTrustedPlatformModuleBillingItemFlag, hostIpsSoftwareComponent, hostname, hostnameSpecified, hourlyBillingFlag, id, idSpecified, inboundBandwidthUsage, inboundPublicBandwidthUsage, lastTransaction, latestNetworkMonitorIncident, location, locationPathString, lockboxNetworkStorage, managedResourceFlag, manufacturerSerialNumber, manufacturerSerialNumberSpecified, memory, memoryCapacity, memoryCount, metricTrackingObject, moduleCount, modules, monitoringServiceComponent, motherboard, networkCardCount, networkCards, networkComponentCount, networkComponents, networkGatewayMember, networkGatewayMemberFlag, networkManagementIpAddress, networkMonitorAttachedDownHardware, networkMonitorAttachedDownHardwareCount, networkMonitorAttachedDownVirtualGuestCount, networkMonitorAttachedDownVirtualGuests, networkMonitorCount, networkMonitorIncidentCount, networkMonitorIncidents, networkMonitors, networkStatus, networkStatusAttribute, networkStorage, networkStorageCount, networkVlanCount, networkVlans, nextBillingCycleBandwidthAllocation, notes, notesHistory, notesHistoryCount, notesSpecified, nvRamCapacity, nvRamComponentModelCount, nvRamComponentModels, operatingSystem, operatingSystemReferenceCode, outboundBandwidthUsage, outboundPublicBandwidthUsage, parentBay, parentHardware, pointOfPresenceLocation, postInstallScriptUri, postInstallScriptUriSpecified, powerComponentCount, powerComponents, powerSupply, powerSupplyCount, primaryBackendIpAddress, primaryBackendNetworkComponent, primaryIpAddress, primaryNetworkComponent, privateNetworkOnlyFlag, processorCoreAmount, processorCount, processorPhysicalCoreAmount, processors, provisionDate, provisionDateSpecified, rack, raidControllerCount, raidControllers, recentEventCount, recentEvents, remoteManagementAccountCount, remoteManagementAccounts, remoteManagementComponent, resourceConfigurationCount, resourceConfigurations, resourceGroupCount, resourceGroupMemberReferenceCount, resourceGroupMemberReferences, resourceGroupRoleCount, resourceGroupRoles, resourceGroups, routerCount, routers, scaleAssetCount, scaleAssets, securityScanRequestCount, securityScanRequests, serialNumber, serialNumberSpecified, serverRoom, serviceProvider, serviceProviderId, serviceProviderIdSpecified, serviceProviderResourceId, serviceProviderResourceIdSpecified, softwareComponentCount, softwareComponents, sparePoolBillingItem, sshKeyCount, sshKeys, storageGroupCount, storageGroups, storageNetworkComponentCount, storageNetworkComponents, tagReferenceCount, tagReferences, topLevelLocation, upgradeRequest, uplinkHardware, uplinkNetworkComponentCount, uplinkNetworkComponents, userData, userDataCount, virtualChassis, virtualChassisSiblingCount, virtualChassisSiblings, virtualHost, virtualizationPlatform, virtualLicenseCount, virtualLicenses, virtualRack, virtualRackId, virtualRackName -
Constructor Summary
Constructors Constructor Description Router() -
Method Summary
Modifier and Type Method Description Router.ServiceasService(ApiClient client)LonggetBoundSubnetCount()List<Subnet>getBoundSubnets()BooleangetLocalDiskStorageCapabilityFlag()BooleangetSanStorageCapabilityFlag()static Router.Serviceservice(ApiClient client)static Router.Serviceservice(ApiClient client, Long id)static Router.Serviceservice(ApiClient client, String globalIdentifier)voidsetBoundSubnetCount(Long boundSubnetCount)voidsetLocalDiskStorageCapabilityFlag(Boolean localDiskStorageCapabilityFlag)voidsetSanStorageCapabilityFlag(Boolean sanStorageCapabilityFlag)Methods inherited from class com.softlayer.api.service.Hardware
getAccount, getAccountId, getActiveComponentCount, getActiveComponents, getActiveNetworkMonitorIncident, getActiveNetworkMonitorIncidentCount, getAllowedHost, getAllowedNetworkStorage, getAllowedNetworkStorageCount, getAllowedNetworkStorageReplicaCount, getAllowedNetworkStorageReplicas, getAllPowerComponentCount, getAllPowerComponents, getAntivirusSpywareSoftwareComponent, getAttributeCount, getAttributes, getAverageDailyPublicBandwidthUsage, getBackendNetworkComponentCount, getBackendNetworkComponents, getBackendRouterCount, getBackendRouters, getBandwidthAllocation, getBandwidthAllotmentDetail, getBareMetalInstanceFlag, getBenchmarkCertificationCount, getBenchmarkCertifications, getBillingItem, getBillingItemFlag, getBlockCancelBecauseDisconnectedFlag, getBusinessContinuanceInsuranceFlag, getChildrenHardware, getChildrenHardwareCount, getComponentCount, getComponents, getContinuousDataProtectionSoftwareComponent, getCurrentBillableBandwidthUsage, getDatacenter, getDatacenterName, getDaysInSparePool, getDomain, getDownlinkHardware, getDownlinkHardwareCount, getDownlinkNetworkHardware, getDownlinkNetworkHardwareCount, getDownlinkServerCount, getDownlinkServers, getDownlinkVirtualGuestCount, getDownlinkVirtualGuests, getDownstreamHardwareBindingCount, getDownstreamHardwareBindings, getDownstreamNetworkHardware, getDownstreamNetworkHardwareCount, getDownstreamNetworkHardwareWithIncidentCount, getDownstreamNetworkHardwareWithIncidents, getDownstreamServerCount, getDownstreamServers, getDownstreamVirtualGuestCount, getDownstreamVirtualGuests, getDriveControllerCount, getDriveControllers, getEvaultNetworkStorage, getEvaultNetworkStorageCount, getFirewallServiceComponent, getFixedConfigurationPreset, getFrontendNetworkComponentCount, getFrontendNetworkComponents, getFrontendRouterCount, getFrontendRouters, getFullyQualifiedDomainName, getGlobalIdentifier, getHardDriveCount, getHardDrives, getHardwareChassis, getHardwareFunction, getHardwareFunctionDescription, getHardwareStatus, getHardwareStatusId, getHasTrustedPlatformModuleBillingItemFlag, getHostIpsSoftwareComponent, getHostname, getHourlyBillingFlag, getId, getInboundBandwidthUsage, getInboundPublicBandwidthUsage, getLastTransaction, getLatestNetworkMonitorIncident, getLocation, getLocationPathString, getLockboxNetworkStorage, getManagedResourceFlag, getManufacturerSerialNumber, getMemory, getMemoryCapacity, getMemoryCount, getMetricTrackingObject, getModuleCount, getModules, getMonitoringServiceComponent, getMotherboard, getNetworkCardCount, getNetworkCards, getNetworkComponentCount, getNetworkComponents, getNetworkGatewayMember, getNetworkGatewayMemberFlag, getNetworkManagementIpAddress, getNetworkMonitorAttachedDownHardware, getNetworkMonitorAttachedDownHardwareCount, getNetworkMonitorAttachedDownVirtualGuestCount, getNetworkMonitorAttachedDownVirtualGuests, getNetworkMonitorCount, getNetworkMonitorIncidentCount, getNetworkMonitorIncidents, getNetworkMonitors, getNetworkStatus, getNetworkStatusAttribute, getNetworkStorage, getNetworkStorageCount, getNetworkVlanCount, getNetworkVlans, getNextBillingCycleBandwidthAllocation, getNotes, getNotesHistory, getNotesHistoryCount, getNvRamCapacity, getNvRamComponentModelCount, getNvRamComponentModels, getOperatingSystem, getOperatingSystemReferenceCode, getOutboundBandwidthUsage, getOutboundPublicBandwidthUsage, getParentBay, getParentHardware, getPointOfPresenceLocation, getPostInstallScriptUri, getPowerComponentCount, getPowerComponents, getPowerSupply, getPowerSupplyCount, getPrimaryBackendIpAddress, getPrimaryBackendNetworkComponent, getPrimaryIpAddress, getPrimaryNetworkComponent, getPrivateNetworkOnlyFlag, getProcessorCoreAmount, getProcessorCount, getProcessorPhysicalCoreAmount, getProcessors, getProvisionDate, getRack, getRaidControllerCount, getRaidControllers, getRecentEventCount, getRecentEvents, getRemoteManagementAccountCount, getRemoteManagementAccounts, getRemoteManagementComponent, getResourceConfigurationCount, getResourceConfigurations, getResourceGroupCount, getResourceGroupMemberReferenceCount, getResourceGroupMemberReferences, getResourceGroupRoleCount, getResourceGroupRoles, getResourceGroups, getRouterCount, getRouters, getScaleAssetCount, getScaleAssets, getSecurityScanRequestCount, getSecurityScanRequests, getSerialNumber, getServerRoom, getServiceProvider, getServiceProviderId, getServiceProviderResourceId, getSoftwareComponentCount, getSoftwareComponents, getSparePoolBillingItem, getSshKeyCount, getSshKeys, getStorageGroupCount, getStorageGroups, getStorageNetworkComponentCount, getStorageNetworkComponents, getTagReferenceCount, getTagReferences, getTopLevelLocation, getUpgradeRequest, getUplinkHardware, getUplinkNetworkComponentCount, getUplinkNetworkComponents, getUserData, getUserDataCount, getVirtualChassis, getVirtualChassisSiblingCount, getVirtualChassisSiblings, getVirtualHost, getVirtualizationPlatform, getVirtualLicenseCount, getVirtualLicenses, getVirtualRack, getVirtualRackId, getVirtualRackName, isAccountIdSpecified, isBareMetalInstanceFlagSpecified, isDomainSpecified, isFullyQualifiedDomainNameSpecified, isHardwareStatusIdSpecified, isHostnameSpecified, isIdSpecified, isManufacturerSerialNumberSpecified, isNotesSpecified, isPostInstallScriptUriSpecified, isProvisionDateSpecified, isSerialNumberSpecified, isServiceProviderIdSpecified, isServiceProviderResourceIdSpecified, setAccount, setAccountId, setActiveComponentCount, setActiveNetworkMonitorIncidentCount, setAllowedHost, setAllowedNetworkStorageCount, setAllowedNetworkStorageReplicaCount, setAllPowerComponentCount, setAntivirusSpywareSoftwareComponent, setAttributeCount, setAverageDailyPublicBandwidthUsage, setBackendNetworkComponentCount, setBackendRouterCount, setBandwidthAllocation, setBandwidthAllotmentDetail, setBareMetalInstanceFlag, setBenchmarkCertificationCount, setBillingItem, setBillingItemFlag, setBlockCancelBecauseDisconnectedFlag, setBusinessContinuanceInsuranceFlag, setChildrenHardwareCount, setComponentCount, setContinuousDataProtectionSoftwareComponent, setCurrentBillableBandwidthUsage, setDatacenter, setDatacenterName, setDaysInSparePool, setDomain, setDownlinkHardwareCount, setDownlinkNetworkHardwareCount, setDownlinkServerCount, setDownlinkVirtualGuestCount, setDownstreamHardwareBindingCount, setDownstreamNetworkHardwareCount, setDownstreamNetworkHardwareWithIncidentCount, setDownstreamServerCount, setDownstreamVirtualGuestCount, setDriveControllerCount, setEvaultNetworkStorageCount, setFirewallServiceComponent, setFixedConfigurationPreset, setFrontendNetworkComponentCount, setFrontendRouterCount, setFullyQualifiedDomainName, setGlobalIdentifier, setHardDriveCount, setHardwareChassis, setHardwareFunction, setHardwareFunctionDescription, setHardwareStatus, setHardwareStatusId, setHasTrustedPlatformModuleBillingItemFlag, setHostIpsSoftwareComponent, setHostname, setHourlyBillingFlag, setId, setInboundBandwidthUsage, setInboundPublicBandwidthUsage, setLastTransaction, setLatestNetworkMonitorIncident, setLocation, setLocationPathString, setLockboxNetworkStorage, setManagedResourceFlag, setManufacturerSerialNumber, setMemoryCapacity, setMemoryCount, setMetricTrackingObject, setModuleCount, setMonitoringServiceComponent, setMotherboard, setNetworkCardCount, setNetworkComponentCount, setNetworkGatewayMember, setNetworkGatewayMemberFlag, setNetworkManagementIpAddress, setNetworkMonitorAttachedDownHardwareCount, setNetworkMonitorAttachedDownVirtualGuestCount, setNetworkMonitorCount, setNetworkMonitorIncidentCount, setNetworkStatus, setNetworkStatusAttribute, setNetworkStorageCount, setNetworkVlanCount, setNextBillingCycleBandwidthAllocation, setNotes, setNotesHistoryCount, setNvRamCapacity, setNvRamComponentModelCount, setOperatingSystem, setOperatingSystemReferenceCode, setOutboundBandwidthUsage, setOutboundPublicBandwidthUsage, setParentBay, setParentHardware, setPointOfPresenceLocation, setPostInstallScriptUri, setPowerComponentCount, setPowerSupplyCount, setPrimaryBackendIpAddress, setPrimaryBackendNetworkComponent, setPrimaryIpAddress, setPrimaryNetworkComponent, setPrivateNetworkOnlyFlag, setProcessorCoreAmount, setProcessorCount, setProcessorPhysicalCoreAmount, setProvisionDate, setRack, setRaidControllerCount, setRecentEventCount, setRemoteManagementAccountCount, setRemoteManagementComponent, setResourceConfigurationCount, setResourceGroupCount, setResourceGroupMemberReferenceCount, setResourceGroupRoleCount, setRouterCount, setScaleAssetCount, setSecurityScanRequestCount, setSerialNumber, setServerRoom, setServiceProvider, setServiceProviderId, setServiceProviderResourceId, setSoftwareComponentCount, setSparePoolBillingItem, setSshKeyCount, setStorageGroupCount, setStorageNetworkComponentCount, setTagReferenceCount, setTopLevelLocation, setUpgradeRequest, setUplinkHardware, setUplinkNetworkComponentCount, setUserDataCount, setVirtualChassis, setVirtualChassisSiblingCount, setVirtualHost, setVirtualizationPlatform, setVirtualLicenseCount, setVirtualRack, setVirtualRackId, setVirtualRackName, unsetAccountId, unsetBareMetalInstanceFlag, unsetDomain, unsetFullyQualifiedDomainName, unsetHardwareStatusId, unsetHostname, unsetId, unsetManufacturerSerialNumber, unsetNotes, unsetPostInstallScriptUri, unsetProvisionDate, unsetSerialNumber, unsetServiceProviderId, unsetServiceProviderResourceId
-
Field Details
-
boundSubnets
Associated subnets for a router object. -
localDiskStorageCapabilityFlag
A flag indicating that a VLAN on the router can be assigned to a host that has local disk functionality. -
sanStorageCapabilityFlag
A flag indicating that a VLAN on the router can be assigned to a host that has SAN disk functionality. -
boundSubnetCount
A count of associated subnets for a router object.
-
-
Constructor Details
-
Router
public Router()
-
-
Method Details