Class Certification
java.lang.Object
com.softlayer.api.Type
com.softlayer.api.service.Entity
com.softlayer.api.service.hardware.benchmark.Certification
@ApiType("SoftLayer_Hardware_Benchmark_Certification") public class Certification extends Entity
The SoftLayer_Hardware_Benchmark_Certification data type contains general information relating to a single SoftLayer hardware benchmark certification document.
-
Nested Class Summary
Nested Classes Modifier and Type Class Description static classCertification.Maskstatic interfaceCertification.ServiceThis certification is used to indicate the date, time and validity of the benchmark certification process.static interfaceCertification.ServiceAsync -
Field Summary
Fields Modifier and Type Field Description protected AccountaccountInformation regarding a benchmark certification result's associated SoftLayer customer account.protected LongaccountIdThe internal identifier of the SoftLayer customer account associated with a benchmark certification result.protected booleanaccountIdSpecifiedprotected GregorianCalendarcreateDateThe date that a benchmark certification result was generated.protected booleancreateDateSpecifiedprotected HardwarehardwareInformation regarding the piece of hardware on which a benchmark certification test was performed.protected LonghardwareIdA benchmark certification results's associated hardware's internal identification number.protected booleanhardwareIdSpecified -
Constructor Summary
Constructors Constructor Description Certification() -
Method Summary
Modifier and Type Method Description AccountgetAccount()LonggetAccountId()GregorianCalendargetCreateDate()HardwaregetHardware()LonggetHardwareId()booleanisAccountIdSpecified()booleanisCreateDateSpecified()booleanisHardwareIdSpecified()static Certification.Serviceservice(ApiClient client)voidsetAccount(Account account)voidsetAccountId(Long accountId)voidsetCreateDate(GregorianCalendar createDate)voidsetHardware(Hardware hardware)voidsetHardwareId(Long hardwareId)voidunsetAccountId()voidunsetCreateDate()voidunsetHardwareId()
-
Field Details
-
account
Information regarding a benchmark certification result's associated SoftLayer customer account. -
hardware
Information regarding the piece of hardware on which a benchmark certification test was performed. -
accountId
The internal identifier of the SoftLayer customer account associated with a benchmark certification result. -
accountIdSpecified
protected boolean accountIdSpecified -
createDate
The date that a benchmark certification result was generated. -
createDateSpecified
protected boolean createDateSpecified -
hardwareId
A benchmark certification results's associated hardware's internal identification number. -
hardwareIdSpecified
protected boolean hardwareIdSpecified
-
-
Constructor Details
-
Certification
public Certification()
-
-
Method Details
-
getAccount
-
setAccount
-
getHardware
-
setHardware
-
getAccountId
-
setAccountId
-
isAccountIdSpecified
public boolean isAccountIdSpecified() -
unsetAccountId
public void unsetAccountId() -
getCreateDate
-
setCreateDate
-
isCreateDateSpecified
public boolean isCreateDateSpecified() -
unsetCreateDate
public void unsetCreateDate() -
getHardwareId
-
setHardwareId
-
isHardwareIdSpecified
public boolean isHardwareIdSpecified() -
unsetHardwareId
public void unsetHardwareId() -
service
-