Uses of Class
com.softlayer.api.service.hardware.Note
| Package | Description |
|---|---|
| com.softlayer.api.service |
-
Uses of Note in com.softlayer.api.service
Fields in com.softlayer.api.service with type parameters of type Note Modifier and Type Field Description protected List<Note>Hardware. notesHistoryMethods in com.softlayer.api.service that return types with arguments of type Note Modifier and Type Method Description List<Note>Hardware. getNotesHistory()List<Note>Hardware.Service. getNotesHistory()Future<List<Note>>Hardware.ServiceAsync. getNotesHistory()Async version ofHardware.Service.getNotesHistory()Method parameters in com.softlayer.api.service with type arguments of type Note Modifier and Type Method Description Future<?>Hardware.ServiceAsync. getNotesHistory(ResponseHandler<List<Note>> callback)Async callback version ofHardware.Service.getNotesHistory()