Class Locator
java.lang.Object
com.softlayer.api.Type
com.softlayer.api.service.Entity
com.softlayer.api.service.hardware.component.Locator
@ApiType("SoftLayer_Hardware_Component_Locator") public class Locator extends Entity
SoftLayer public API to determine the availability of generic hardware component models at data centers
- See Also:
- SoftLayer_Hardware_Component_Locator
-
Nested Class Summary
Nested Classes Modifier and Type Class Description static classLocator.Maskstatic interfaceLocator.ServiceSoftLayer public API to determine the availability of generic hardware component models at data centersstatic interfaceLocator.ServiceAsync -
Field Summary
-
Constructor Summary
Constructors Constructor Description Locator() -
Method Summary
Modifier and Type Method Description static Locator.Serviceservice(ApiClient client)