Class Attribute
java.lang.Object
com.softlayer.api.Type
com.softlayer.api.service.Entity
com.softlayer.api.service.hardware.component.model.Attribute
@ApiType("SoftLayer_Hardware_Component_Model_Attribute") public class Attribute extends Entity
The SoftLayer_Hardware_Component__Model_Attribute data type contains general information relating to a single hardware setting or attribute for a component model.
-
Nested Class Summary
Nested Classes Modifier and Type Class Description static classAttribute.Mask -
Field Summary
Fields Modifier and Type Field Description protected LongattributeTypeIdA hardware component model attribute's associated [[SoftLayer_Hardware_Component_Model_Attribute_Type|type]] Id.protected booleanattributeTypeIdSpecifiedprotected ModelhardwareComponentprotected TypehardwareComponentAttributeTypeprotected LonghardwareComponentModelIdA hardware component model attribute's associated [[SoftLayer_Hardware_Component_Model|hardware component model]] Id.protected booleanhardwareComponentModelIdSpecifiedprotected StringvalueA hardware component model attribute's value.protected booleanvalueSpecified -
Constructor Summary
Constructors Constructor Description Attribute() -
Method Summary
Modifier and Type Method Description LonggetAttributeTypeId()ModelgetHardwareComponent()TypegetHardwareComponentAttributeType()LonggetHardwareComponentModelId()StringgetValue()booleanisAttributeTypeIdSpecified()booleanisHardwareComponentModelIdSpecified()booleanisValueSpecified()voidsetAttributeTypeId(Long attributeTypeId)voidsetHardwareComponent(Model hardwareComponent)voidsetHardwareComponentAttributeType(Type hardwareComponentAttributeType)voidsetHardwareComponentModelId(Long hardwareComponentModelId)voidsetValue(String value)voidunsetAttributeTypeId()voidunsetHardwareComponentModelId()voidunsetValue()
-
Field Details
-
hardwareComponent
-
hardwareComponentAttributeType
-
attributeTypeId
A hardware component model attribute's associated [[SoftLayer_Hardware_Component_Model_Attribute_Type|type]] Id. -
attributeTypeIdSpecified
protected boolean attributeTypeIdSpecified -
hardwareComponentModelId
A hardware component model attribute's associated [[SoftLayer_Hardware_Component_Model|hardware component model]] Id. -
hardwareComponentModelIdSpecified
protected boolean hardwareComponentModelIdSpecified -
value
A hardware component model attribute's value. A value can have many different values depending on the attributes [[SoftLayer_Hardware_Component_Model_Attribute_Type|type]]. -
valueSpecified
protected boolean valueSpecified
-
-
Constructor Details
-
Attribute
public Attribute()
-
-
Method Details
-
getHardwareComponent
-
setHardwareComponent
-
getHardwareComponentAttributeType
-
setHardwareComponentAttributeType
-
getAttributeTypeId
-
setAttributeTypeId
-
isAttributeTypeIdSpecified
public boolean isAttributeTypeIdSpecified() -
unsetAttributeTypeId
public void unsetAttributeTypeId() -
getHardwareComponentModelId
-
setHardwareComponentModelId
-
isHardwareComponentModelIdSpecified
public boolean isHardwareComponentModelIdSpecified() -
unsetHardwareComponentModelId
public void unsetHardwareComponentModelId() -
getValue
-
setValue
-
isValueSpecified
public boolean isValueSpecified() -
unsetValue
public void unsetValue()
-