Package com.softlayer.api.service.layout
Class Item
java.lang.Object
com.softlayer.api.Type
com.softlayer.api.service.Entity
com.softlayer.api.service.layout.Item
@ApiType("SoftLayer_Layout_Item") public class Item extends Entity
The SoftLayer_Layout_Item contains definitions for default layout items
- See Also:
- SoftLayer_Layout_Item
-
Nested Class Summary
Nested Classes Modifier and Type Class Description static classItem.Maskstatic interfaceItem.ServiceLayout items are used in the customization of the Portal 4 customer experience.static interfaceItem.ServiceAsync -
Field Summary
Fields Modifier and Type Field Description protected LongidThe internal identifier of a layout itemprotected booleanidSpecifiedprotected StringkeynameThe unique key name of the layout item, used primarily for programmatic purposesprotected booleankeynameSpecifiedprotected LonglayoutItemPreferenceCountA count of the layout preferences assigned to this layout itemprotected List<Preference>layoutItemPreferencesThe layout preferences assigned to this layout itemprotected TypelayoutItemTypeThe type of the layout item objectprotected LonglayoutItemTypeIdThe internal identifier of the related [[SoftLayer_Layout_Item_Type]]protected booleanlayoutItemTypeIdSpecifiedprotected StringnameThe friendly name of the layout itemprotected booleannameSpecifiedFields inherited from class com.softlayer.api.Type
unknownProperties -
Constructor Summary
Constructors Constructor Description Item() -
Method Summary
Modifier and Type Method Description Item.ServiceasService(ApiClient client)LonggetId()StringgetKeyname()LonggetLayoutItemPreferenceCount()List<Preference>getLayoutItemPreferences()TypegetLayoutItemType()LonggetLayoutItemTypeId()StringgetName()booleanisIdSpecified()booleanisKeynameSpecified()booleanisLayoutItemTypeIdSpecified()booleanisNameSpecified()static Item.Serviceservice(ApiClient client)static Item.Serviceservice(ApiClient client, Long id)voidsetId(Long id)voidsetKeyname(String keyname)voidsetLayoutItemPreferenceCount(Long layoutItemPreferenceCount)voidsetLayoutItemType(Type layoutItemType)voidsetLayoutItemTypeId(Long layoutItemTypeId)voidsetName(String name)voidunsetId()voidunsetKeyname()voidunsetLayoutItemTypeId()voidunsetName()Methods inherited from class com.softlayer.api.Type
getUnknownProperties, setUnknownProperties
-
Field Details
-
layoutItemPreferences
The layout preferences assigned to this layout item -
layoutItemType
The type of the layout item object -
id
The internal identifier of a layout item -
idSpecified
protected boolean idSpecified -
keyname
The unique key name of the layout item, used primarily for programmatic purposes -
keynameSpecified
protected boolean keynameSpecified -
layoutItemTypeId
The internal identifier of the related [[SoftLayer_Layout_Item_Type]] -
layoutItemTypeIdSpecified
protected boolean layoutItemTypeIdSpecified -
name
The friendly name of the layout item -
nameSpecified
protected boolean nameSpecified -
layoutItemPreferenceCount
A count of the layout preferences assigned to this layout item
-
-
Constructor Details
-
Item
public Item()
-
-
Method Details
-
getLayoutItemPreferences
-
getLayoutItemType
-
setLayoutItemType
-
getId
-
setId
-
isIdSpecified
public boolean isIdSpecified() -
unsetId
public void unsetId() -
getKeyname
-
setKeyname
-
isKeynameSpecified
public boolean isKeynameSpecified() -
unsetKeyname
public void unsetKeyname() -
getLayoutItemTypeId
-
setLayoutItemTypeId
-
isLayoutItemTypeIdSpecified
public boolean isLayoutItemTypeIdSpecified() -
unsetLayoutItemTypeId
public void unsetLayoutItemTypeId() -
getName
-
setName
-
isNameSpecified
public boolean isNameSpecified() -
unsetName
public void unsetName() -
getLayoutItemPreferenceCount
-
setLayoutItemPreferenceCount
-
asService
-
service
-
service
-