Package com.softlayer.api.service.layout
Class Profile
java.lang.Object
com.softlayer.api.Type
com.softlayer.api.service.Entity
com.softlayer.api.service.layout.Profile
- Direct Known Subclasses:
Customer
@ApiType("SoftLayer_Layout_Profile") public class Profile extends Entity
The SoftLayer_Layout_Profile contains the definition of the layout profile
- See Also:
- SoftLayer_Layout_Profile
-
Nested Class Summary
Nested Classes Modifier and Type Class Description static classProfile.Maskstatic interfaceProfile.ServiceLayout profiles are the primary object used to tie customized portal experiences to the [[SoftLayer_User_Customer|user account]].static interfaceProfile.ServiceAsync -
Field Summary
Fields Modifier and Type Field Description protected LongactiveFlagActive status of the layout profileprotected booleanactiveFlagSpecifiedprotected GregorianCalendarcreateDateTimestamp of when the layout profile was createdprotected booleancreateDateSpecifiedprotected LongidThe internal identifier of a layout profileprotected booleanidSpecifiedprotected LonglayoutContainerCountA count ofprotected List<Container>layoutContainersprotected LonglayoutPreferenceCountA count ofprotected List<Preference>layoutPreferencesprotected GregorianCalendarmodifyDateTimestamp of when the layout profile was last updatedprotected booleanmodifyDateSpecifiedprotected StringnameThe friendly name of the layout profileprotected booleannameSpecifiedprotected LonguserRecordIdThe [[SoftLayer_User_Customer]] owning this layout profileprotected booleanuserRecordIdSpecified -
Constructor Summary
Constructors Constructor Description Profile() -
Method Summary
-
Field Details
-
layoutContainers
-
layoutPreferences
-
activeFlag
Active status of the layout profile -
activeFlagSpecified
protected boolean activeFlagSpecified -
createDate
Timestamp of when the layout profile was created -
createDateSpecified
protected boolean createDateSpecified -
id
The internal identifier of a layout profile -
idSpecified
protected boolean idSpecified -
modifyDate
Timestamp of when the layout profile was last updated -
modifyDateSpecified
protected boolean modifyDateSpecified -
name
The friendly name of the layout profile -
nameSpecified
protected boolean nameSpecified -
userRecordId
The [[SoftLayer_User_Customer]] owning this layout profile -
userRecordIdSpecified
protected boolean userRecordIdSpecified -
layoutContainerCount
A count of -
layoutPreferenceCount
A count of
-
-
Constructor Details
-
Profile
public Profile()
-
-
Method Details
-
getLayoutContainers
-
getLayoutPreferences
-
getActiveFlag
-
setActiveFlag
-
isActiveFlagSpecified
public boolean isActiveFlagSpecified() -
unsetActiveFlag
public void unsetActiveFlag() -
getCreateDate
-
setCreateDate
-
isCreateDateSpecified
public boolean isCreateDateSpecified() -
unsetCreateDate
public void unsetCreateDate() -
getId
-
setId
-
isIdSpecified
public boolean isIdSpecified() -
unsetId
public void unsetId() -
getModifyDate
-
setModifyDate
-
isModifyDateSpecified
public boolean isModifyDateSpecified() -
unsetModifyDate
public void unsetModifyDate() -
getName
-
setName
-
isNameSpecified
public boolean isNameSpecified() -
unsetName
public void unsetName() -
getUserRecordId
-
setUserRecordId
-
isUserRecordIdSpecified
public boolean isUserRecordIdSpecified() -
unsetUserRecordId
public void unsetUserRecordId() -
getLayoutContainerCount
-
setLayoutContainerCount
-
getLayoutPreferenceCount
-
setLayoutPreferenceCount
-
asService
-
service
-
service
-