Class Containers
java.lang.Object
com.softlayer.api.Type
com.softlayer.api.service.Entity
com.softlayer.api.service.layout.profile.Containers
@ApiType("SoftLayer_Layout_Profile_Containers") public class Containers extends Entity
- See Also:
- SoftLayer_Layout_Profile_Containers
-
Nested Class Summary
Nested Classes Modifier and Type Class Description static classContainers.Maskstatic interfaceContainers.Servicestatic interfaceContainers.ServiceAsync -
Field Summary
Fields Modifier and Type Field Description protected GregorianCalendarcreateDateTimestamp of when the reference was createdprotected booleancreateDateSpecifiedprotected LongidThe internal identifier of the container referenceprotected booleanidSpecifiedprotected LonglayoutContainerIdThe id of the referenced [[SoftLayer_Layout_Container]]protected booleanlayoutContainerIdSpecifiedprotected ContainerlayoutContainerTypeThe container to be containedprotected ProfilelayoutProfileThe profile containing this containerprotected LonglayoutProfileIdThe id of the referenced [[SoftLayer_Layout_Profile]]protected booleanlayoutProfileIdSpecifiedprotected GregorianCalendarmodifyDateTimestamp of when the reference was last updatedprotected booleanmodifyDateSpecified -
Constructor Summary
Constructors Constructor Description Containers() -
Method Summary
-
Field Details
-
layoutContainerType
The container to be contained -
layoutProfile
The profile containing this container -
createDate
Timestamp of when the reference was created -
createDateSpecified
protected boolean createDateSpecified -
id
The internal identifier of the container reference -
idSpecified
protected boolean idSpecified -
layoutContainerId
The id of the referenced [[SoftLayer_Layout_Container]] -
layoutContainerIdSpecified
protected boolean layoutContainerIdSpecified -
layoutProfileId
The id of the referenced [[SoftLayer_Layout_Profile]] -
layoutProfileIdSpecified
protected boolean layoutProfileIdSpecified -
modifyDate
Timestamp of when the reference was last updated -
modifyDateSpecified
protected boolean modifyDateSpecified
-
-
Constructor Details
-
Containers
public Containers()
-
-
Method Details
-
getLayoutContainerType
-
setLayoutContainerType
-
getLayoutProfile
-
setLayoutProfile
-
getCreateDate
-
setCreateDate
-
isCreateDateSpecified
public boolean isCreateDateSpecified() -
unsetCreateDate
public void unsetCreateDate() -
getId
-
setId
-
isIdSpecified
public boolean isIdSpecified() -
unsetId
public void unsetId() -
getLayoutContainerId
-
setLayoutContainerId
-
isLayoutContainerIdSpecified
public boolean isLayoutContainerIdSpecified() -
unsetLayoutContainerId
public void unsetLayoutContainerId() -
getLayoutProfileId
-
setLayoutProfileId
-
isLayoutProfileIdSpecified
public boolean isLayoutProfileIdSpecified() -
unsetLayoutProfileId
public void unsetLayoutProfileId() -
getModifyDate
-
setModifyDate
-
isModifyDateSpecified
public boolean isModifyDateSpecified() -
unsetModifyDate
public void unsetModifyDate() -
asService
-
service
-
service
-