Interface Customer.Service
- All Superinterfaces:
Maskable,Profile.Service,ResultLimitable,Service
- Enclosing class:
- Customer
@ApiService("SoftLayer_Layout_Profile_Customer") public static interface Customer.Service extends Profile.Service
- See Also:
- SoftLayer_Layout_Profile_Customer
-
Method Summary
Modifier and Type Method Description Customer.ServiceAsyncasAsync()Get an async version of this serviceCustomergetObjectForCustomer()CustomergetUserRecord()voidsetMask(Customer.Mask mask)Customer.MaskwithMask()Use the existing mask on this service or create it if not presentCustomer.MaskwithNewMask()Overwrite the existing mask on this service with a new one and return itMethods inherited from interface com.softlayer.api.service.layout.Profile.Service
createObject, deleteObject, editObject, getLayoutContainers, getLayoutPreferences, getObject, modifyPreference, modifyPreferences, setMaskMethods inherited from interface com.softlayer.api.ResultLimitable
getLastResponseTotalItemCount, getResultLimit, setResultLimit
-
Method Details
-
asAsync
Customer.ServiceAsync asAsync()Description copied from interface:ServiceGet an async version of this service- Specified by:
asAsyncin interfaceProfile.Service- Specified by:
asAsyncin interfaceService
-
withNewMask
Customer.Mask withNewMask()Description copied from interface:MaskableOverwrite the existing mask on this service with a new one and return it- Specified by:
withNewMaskin interfaceMaskable- Specified by:
withNewMaskin interfaceProfile.Service
-
withMask
Customer.Mask withMask()Description copied from interface:MaskableUse the existing mask on this service or create it if not present- Specified by:
withMaskin interfaceMaskable- Specified by:
withMaskin interfaceProfile.Service
-
setMask
-
getObjectForCustomer
-
getUserRecord
-