Interface Customer.ServiceAsync
- All Superinterfaces:
Maskable,Profile.ServiceAsync,ResultLimitable,ServiceAsync
- Enclosing class:
- Customer
public static interface Customer.ServiceAsync extends Profile.ServiceAsync
-
Method Summary
Modifier and Type Method Description Future<Customer>getObjectForCustomer()Async version ofCustomer.Service.getObjectForCustomer()Future<?>getObjectForCustomer(ResponseHandler<Customer> callback)Future<Customer>getUserRecord()Async version ofCustomer.Service.getUserRecord()Future<?>getUserRecord(ResponseHandler<Customer> callback)Async callback version ofCustomer.Service.getUserRecord()voidsetMask(Customer.Mask mask)Customer.MaskwithMask()Use the existing mask on this service or create it if not presentCustomer.MaskwithNewMask()Overwrite the existing mask on this service with a new one and return itMethods inherited from interface com.softlayer.api.service.layout.Profile.ServiceAsync
createObject, createObject, deleteObject, deleteObject, editObject, editObject, getLayoutContainers, getLayoutContainers, getLayoutPreferences, getLayoutPreferences, getObject, getObject, modifyPreference, modifyPreference, modifyPreferences, modifyPreferences, setMaskMethods inherited from interface com.softlayer.api.ResultLimitable
getLastResponseTotalItemCount, getResultLimit, setResultLimit
-
Method Details
-
withNewMask
Customer.Mask withNewMask()Description copied from interface:MaskableOverwrite the existing mask on this service with a new one and return it- Specified by:
withNewMaskin interfaceMaskable- Specified by:
withNewMaskin interfaceProfile.ServiceAsync
-
withMask
Customer.Mask withMask()Description copied from interface:MaskableUse the existing mask on this service or create it if not present- Specified by:
withMaskin interfaceMaskable- Specified by:
withMaskin interfaceProfile.ServiceAsync
-
setMask
-
getObjectForCustomer
Async version ofCustomer.Service.getObjectForCustomer() -
getObjectForCustomer
-
getUserRecord
Async version ofCustomer.Service.getUserRecord() -
getUserRecord
Async callback version ofCustomer.Service.getUserRecord()
-