Uses of Class
com.softlayer.api.service.layout.profile.Containers
| Package | Description |
|---|---|
| com.softlayer.api.service.layout.profile |
-
Uses of Containers in com.softlayer.api.service.layout.profile
Methods in com.softlayer.api.service.layout.profile that return Containers Modifier and Type Method Description ContainersContainers.Service. getObject()Methods in com.softlayer.api.service.layout.profile that return types with arguments of type Containers Modifier and Type Method Description Future<Containers>Containers.ServiceAsync. getObject()Async version ofContainers.Service.getObject()Methods in com.softlayer.api.service.layout.profile with parameters of type Containers Modifier and Type Method Description BooleanContainers.Service. createObject(Containers templateObject)Future<Boolean>Containers.ServiceAsync. createObject(Containers templateObject)Future<?>Containers.ServiceAsync. createObject(Containers templateObject, ResponseHandler<Boolean> callback)BooleanContainers.Service. editObject(Containers templateObject)Future<Boolean>Containers.ServiceAsync. editObject(Containers templateObject)Future<?>Containers.ServiceAsync. editObject(Containers templateObject, ResponseHandler<Boolean> callback)Method parameters in com.softlayer.api.service.layout.profile with type arguments of type Containers Modifier and Type Method Description Future<?>Containers.ServiceAsync. getObject(ResponseHandler<Containers> callback)