Package com.softlayer.api.service.locale
Interface Timezone.ServiceAsync
- All Superinterfaces:
Maskable,ResultLimitable,ServiceAsync
- Enclosing class:
- Timezone
public static interface Timezone.ServiceAsync extends ServiceAsync
-
Method Summary
Modifier and Type Method Description Future<List<Timezone>>getAllObjects()Async version ofTimezone.Service.getAllObjects()Future<?>getAllObjects(ResponseHandler<List<Timezone>> callback)Future<Timezone>getObject()Async version ofTimezone.Service.getObject()Future<?>getObject(ResponseHandler<Timezone> callback)voidsetMask(Timezone.Mask mask)Timezone.MaskwithMask()Use the existing mask on this service or create it if not presentTimezone.MaskwithNewMask()Overwrite the existing mask on this service with a new one and return itMethods inherited from interface com.softlayer.api.ResultLimitable
getLastResponseTotalItemCount, getResultLimit, setResultLimit
-
Method Details
-
withNewMask
Timezone.Mask withNewMask()Description copied from interface:MaskableOverwrite the existing mask on this service with a new one and return it- Specified by:
withNewMaskin interfaceMaskable
-
withMask
Timezone.Mask withMask()Description copied from interface:MaskableUse the existing mask on this service or create it if not present -
setMask
-
getAllObjects
Async version ofTimezone.Service.getAllObjects() -
getAllObjects
-
getObject
Async version ofTimezone.Service.getObject() -
getObject
-