Class Datacenter
java.lang.Object
com.softlayer.api.Type
com.softlayer.api.service.Entity
com.softlayer.api.service.Location
com.softlayer.api.service.location.Datacenter
@ApiType("SoftLayer_Location_Datacenter") public class Datacenter extends Location
SoftLayer_Location_Datacenter extends the [[SoftLayer_Location]] data type to include datacenter-specific properties.
- See Also:
- SoftLayer_Location_Datacenter
-
Nested Class Summary
Nested Classes Modifier and Type Class Description static classDatacenter.Maskstatic interfaceDatacenter.ServiceSoftLayer_Location_Datacenter exposes functionality to access datacenter-specific portions of SoftLayer's backend network.static interfaceDatacenter.ServiceAsync -
Field Summary
Fields Modifier and Type Field Description protected LongactiveItemPresaleEventCountA count ofprotected List<Event>activeItemPresaleEventsprotected LongbackendHardwareRouterCountA count ofprotected List<Hardware>backendHardwareRoutersprotected LongboundSubnetCountA count of subnets which are directly bound to one or more routers in a given datacenter, and currently allow routing.protected List<Subnet>boundSubnetsSubnets which are directly bound to one or more routers in a given datacenter, and currently allow routing.protected LongbrandCountryRestrictionCountA count of this references relationship between brands, locations and countries associated with a user's account that are ineligible when ordering products.protected List<CustomerCountry>brandCountryRestrictionsThis references relationship between brands, locations and countries associated with a user's account that are ineligible when ordering products.protected LongfrontendHardwareRouterCountA count ofprotected List<Hardware>frontendHardwareRoutersprotected LonghardwareRouterCountA count ofprotected List<Hardware>hardwareRoutersprotected LongpresaleEventCountA count ofprotected List<Event>presaleEventsprotected RegionalregionalGroupThe regional group this datacenter belongs to.protected RegistryregionalInternetRegistryprotected LongroutableBoundSubnetCountA count of retrieve all subnets that are eligible to be routed; those which the account has permission to associate with a vlan.protected List<Subnet>routableBoundSubnetsRetrieve all subnets that are eligible to be routed; those which the account has permission to associate with a vlan.Fields inherited from class com.softlayer.api.service.Location
activePresaleEventCount, activePresaleEvents, backboneDependentCount, backboneDependents, bnppCompliantFlag, euCompliantFlag, groupCount, groups, hardwareFirewallCount, hardwareFirewalls, id, idSpecified, locationAddress, locationAddressCount, locationAddresses, locationReservationMember, locationStatus, longName, longNameSpecified, name, nameSpecified, networkConfigurationAttribute, onlinePptpVpnUserCount, onlineSslVpnUserCount, pathString, priceGroupCount, priceGroups, regionCount, regions, statusId, statusIdSpecified, timezone, vdrGroup -
Constructor Summary
Constructors Constructor Description Datacenter() -
Method Summary
Methods inherited from class com.softlayer.api.service.Location
getActivePresaleEventCount, getActivePresaleEvents, getBackboneDependentCount, getBackboneDependents, getBnppCompliantFlag, getEuCompliantFlag, getGroupCount, getGroups, getHardwareFirewallCount, getHardwareFirewalls, getId, getLocationAddress, getLocationAddressCount, getLocationAddresses, getLocationReservationMember, getLocationStatus, getLongName, getName, getNetworkConfigurationAttribute, getOnlinePptpVpnUserCount, getOnlineSslVpnUserCount, getPathString, getPriceGroupCount, getPriceGroups, getRegionCount, getRegions, getStatusId, getTimezone, getVdrGroup, isIdSpecified, isLongNameSpecified, isNameSpecified, isStatusIdSpecified, setActivePresaleEventCount, setBackboneDependentCount, setBnppCompliantFlag, setEuCompliantFlag, setGroupCount, setHardwareFirewallCount, setId, setLocationAddress, setLocationAddressCount, setLocationReservationMember, setLocationStatus, setLongName, setName, setNetworkConfigurationAttribute, setOnlinePptpVpnUserCount, setOnlineSslVpnUserCount, setPathString, setPriceGroupCount, setRegionCount, setStatusId, setTimezone, setVdrGroup, unsetId, unsetLongName, unsetName, unsetStatusId
-
Field Details
-
activeItemPresaleEvents
-
backendHardwareRouters
-
boundSubnets
Subnets which are directly bound to one or more routers in a given datacenter, and currently allow routing. -
brandCountryRestrictions
This references relationship between brands, locations and countries associated with a user's account that are ineligible when ordering products. For example, the India datacenter may not be available on this brand for customers that live in Great Britain. -
frontendHardwareRouters
-
hardwareRouters
-
presaleEvents
-
regionalGroup
The regional group this datacenter belongs to. -
regionalInternetRegistry
-
routableBoundSubnets
Retrieve all subnets that are eligible to be routed; those which the account has permission to associate with a vlan. -
activeItemPresaleEventCount
A count of -
backendHardwareRouterCount
A count of -
boundSubnetCount
A count of subnets which are directly bound to one or more routers in a given datacenter, and currently allow routing. -
brandCountryRestrictionCount
A count of this references relationship between brands, locations and countries associated with a user's account that are ineligible when ordering products. For example, the India datacenter may not be available on this brand for customers that live in Great Britain. -
frontendHardwareRouterCount
A count of -
hardwareRouterCount
A count of -
presaleEventCount
A count of -
routableBoundSubnetCount
A count of retrieve all subnets that are eligible to be routed; those which the account has permission to associate with a vlan.
-
-
Constructor Details
-
Datacenter
public Datacenter()
-
-
Method Details
-
getActiveItemPresaleEvents
-
getBackendHardwareRouters
-
getBoundSubnets
-
getBrandCountryRestrictions
-
getFrontendHardwareRouters
-
getHardwareRouters
-
getPresaleEvents
-
getRegionalGroup
-
setRegionalGroup
-
getRegionalInternetRegistry
-
setRegionalInternetRegistry
-
getRoutableBoundSubnets
-
getActiveItemPresaleEventCount
-
setActiveItemPresaleEventCount
-
getBackendHardwareRouterCount
-
setBackendHardwareRouterCount
-
getBoundSubnetCount
-
setBoundSubnetCount
-
getBrandCountryRestrictionCount
-
setBrandCountryRestrictionCount
-
getFrontendHardwareRouterCount
-
setFrontendHardwareRouterCount
-
getHardwareRouterCount
-
setHardwareRouterCount
-
getPresaleEventCount
-
setPresaleEventCount
-
getRoutableBoundSubnetCount
-
setRoutableBoundSubnetCount
-
asService
-
service
-
service
-