Class Group
java.lang.Object
com.softlayer.api.Type
com.softlayer.api.service.Entity
com.softlayer.api.service.location.Group
@ApiType("SoftLayer_Location_Group") public class Group extends Entity
- See Also:
- SoftLayer_Location_Group
-
Nested Class Summary
Nested Classes Modifier and Type Class Description static classGroup.Maskstatic interfaceGroup.Servicestatic interfaceGroup.ServiceAsync -
Field Summary
Fields Modifier and Type Field Description protected Stringdescriptionprotected booleandescriptionSpecifiedprotected Longidprotected booleanidSpecifiedprotected LonglocationCountA count of the locations in a group.protected TypelocationGroupTypeThe type for this location group.protected LonglocationGroupTypeIdprotected booleanlocationGroupTypeIdSpecifiedprotected List<Location>locationsThe locations in a group.protected Stringnameprotected booleannameSpecifiedprotected LongsecurityLevelIdprotected booleansecurityLevelIdSpecified -
Constructor Summary
Constructors Constructor Description Group() -
Method Summary
Modifier and Type Method Description Group.ServiceasService(ApiClient client)StringgetDescription()LonggetId()LonggetLocationCount()TypegetLocationGroupType()LonggetLocationGroupTypeId()List<Location>getLocations()StringgetName()LonggetSecurityLevelId()booleanisDescriptionSpecified()booleanisIdSpecified()booleanisLocationGroupTypeIdSpecified()booleanisNameSpecified()booleanisSecurityLevelIdSpecified()static Group.Serviceservice(ApiClient client)static Group.Serviceservice(ApiClient client, Long id)voidsetDescription(String description)voidsetId(Long id)voidsetLocationCount(Long locationCount)voidsetLocationGroupType(Type locationGroupType)voidsetLocationGroupTypeId(Long locationGroupTypeId)voidsetName(String name)voidsetSecurityLevelId(Long securityLevelId)voidunsetDescription()voidunsetId()voidunsetLocationGroupTypeId()voidunsetName()voidunsetSecurityLevelId()
-
Field Details
-
locationGroupType
The type for this location group. -
locations
The locations in a group. -
description
-
descriptionSpecified
protected boolean descriptionSpecified -
id
-
idSpecified
protected boolean idSpecified -
locationGroupTypeId
-
locationGroupTypeIdSpecified
protected boolean locationGroupTypeIdSpecified -
name
-
nameSpecified
protected boolean nameSpecified -
securityLevelId
-
securityLevelIdSpecified
protected boolean securityLevelIdSpecified -
locationCount
A count of the locations in a group.
-
-
Constructor Details
-
Group
public Group()
-
-
Method Details
-
getLocationGroupType
-
setLocationGroupType
-
getLocations
-
getDescription
-
setDescription
-
isDescriptionSpecified
public boolean isDescriptionSpecified() -
unsetDescription
public void unsetDescription() -
getId
-
setId
-
isIdSpecified
public boolean isIdSpecified() -
unsetId
public void unsetId() -
getLocationGroupTypeId
-
setLocationGroupTypeId
-
isLocationGroupTypeIdSpecified
public boolean isLocationGroupTypeIdSpecified() -
unsetLocationGroupTypeId
public void unsetLocationGroupTypeId() -
getName
-
setName
-
isNameSpecified
public boolean isNameSpecified() -
unsetName
public void unsetName() -
getSecurityLevelId
-
setSecurityLevelId
-
isSecurityLevelIdSpecified
public boolean isSecurityLevelIdSpecified() -
unsetSecurityLevelId
public void unsetSecurityLevelId() -
getLocationCount
-
setLocationCount
-
asService
-
service
-
service
-