Interface Group.Service
- All Superinterfaces:
Maskable,ResultLimitable,Service
- All Known Subinterfaces:
Pricing.Service,Regional.Service
- Enclosing class:
- Group
@ApiService("SoftLayer_Location_Group") public static interface Group.Service extends Service
- See Also:
- SoftLayer_Location_Group
-
Method Summary
Modifier and Type Method Description Group.ServiceAsyncasAsync()Get an async version of this serviceList<Group>getAllObjects()TypegetLocationGroupType()The type for this location group.List<Location>getLocations()The locations in a group.GroupgetObject()voidsetMask(Group.Mask mask)Group.MaskwithMask()Use the existing mask on this service or create it if not presentGroup.MaskwithNewMask()Overwrite the existing mask on this service with a new one and return itMethods inherited from interface com.softlayer.api.ResultLimitable
getLastResponseTotalItemCount, getResultLimit, setResultLimit
-
Method Details
-
asAsync
Group.ServiceAsync asAsync()Description copied from interface:ServiceGet an async version of this service -
withNewMask
Group.Mask withNewMask()Description copied from interface:MaskableOverwrite the existing mask on this service with a new one and return it- Specified by:
withNewMaskin interfaceMaskable
-
withMask
Group.Mask withMask()Description copied from interface:MaskableUse the existing mask on this service or create it if not present -
setMask
-
getAllObjects
- See Also:
- SoftLayer_Location_Group::getAllObjects
-
getObject
- See Also:
- SoftLayer_Location_Group::getObject
-
getLocationGroupType
The type for this location group. -
getLocations
The locations in a group.- See Also:
- SoftLayer_Location_Group::getLocations
-