Interface Group.ServiceAsync
- All Superinterfaces:
Maskable,ResultLimitable,ServiceAsync
- All Known Subinterfaces:
Pricing.ServiceAsync,Regional.ServiceAsync
- Enclosing class:
- Group
public static interface Group.ServiceAsync extends ServiceAsync
-
Method Summary
Modifier and Type Method Description Future<List<Group>>getAllObjects()Async version ofGroup.Service.getAllObjects()Future<?>getAllObjects(ResponseHandler<List<Group>> callback)Future<Type>getLocationGroupType()Async version ofGroup.Service.getLocationGroupType()Future<?>getLocationGroupType(ResponseHandler<Type> callback)Async callback version ofGroup.Service.getLocationGroupType()Future<List<Location>>getLocations()Async version ofGroup.Service.getLocations()Future<?>getLocations(ResponseHandler<List<Location>> callback)Async callback version ofGroup.Service.getLocations()Future<Group>getObject()Async version ofGroup.Service.getObject()Future<?>getObject(ResponseHandler<Group> callback)voidsetMask(Group.Mask mask)Group.MaskwithMask()Use the existing mask on this service or create it if not presentGroup.MaskwithNewMask()Overwrite the existing mask on this service with a new one and return itMethods inherited from interface com.softlayer.api.ResultLimitable
getLastResponseTotalItemCount, getResultLimit, setResultLimit
-
Method Details
-
withNewMask
Group.Mask withNewMask()Description copied from interface:MaskableOverwrite the existing mask on this service with a new one and return it- Specified by:
withNewMaskin interfaceMaskable
-
withMask
Group.Mask withMask()Description copied from interface:MaskableUse the existing mask on this service or create it if not present -
setMask
-
getAllObjects
Async version ofGroup.Service.getAllObjects() -
getAllObjects
-
getObject
Async version ofGroup.Service.getObject() -
getObject
-
getLocationGroupType
Async version ofGroup.Service.getLocationGroupType() -
getLocationGroupType
Async callback version ofGroup.Service.getLocationGroupType() -
getLocations
Async version ofGroup.Service.getLocations() -
getLocations
Async callback version ofGroup.Service.getLocations()
-