Class Backbone


@ApiType("SoftLayer_Network_Backbone")
public class Backbone
extends Entity
A SoftLayer_Network_Backbone represents a single backbone connection from SoftLayer to the public Internet, from the Internet to the SoftLayer private network, or a link that connects the private networks between SoftLayer's datacenters. The SoftLayer_Network_Backbone data type is a collection of data associated with one of those connections.
See Also:
SoftLayer_Network_Backbone
  • Field Details

    • health

      @ApiProperty protected String health
      A backbone's status.
    • location

      @ApiProperty protected Location location
      Which of the SoftLayer datacenters a backbone is connected to.
    • networkComponent

      @ApiProperty protected Component networkComponent
      A backbone's primary network component.
    • capacity

      @ApiProperty(canBeNullOrNotSet=true) protected Long capacity
      The numeric portion of the bandwidth capacity of a SoftLayer backbone. For instance, if a backbone is rated at "1 GigE" capacity then the capacity property of the backbone is 1.
    • capacitySpecified

      protected boolean capacitySpecified
    • capacityUnits

      @ApiProperty(canBeNullOrNotSet=true) protected String capacityUnits
      The unit portion of the bandwidth capacity of a SoftLayer backbone. For instance, if a backbone is rated at "10 G" capacity then the capacityUnits property of the backbone is "G".
    • capacityUnitsSpecified

      protected boolean capacityUnitsSpecified
    • id

      @ApiProperty(canBeNullOrNotSet=true) protected Long id
      A backbone's internal identifier.
    • idSpecified

      protected boolean idSpecified
    • name

      @ApiProperty(canBeNullOrNotSet=true) protected String name
      A backbone's name. This is usually the name of the backbone's network provider followed by a number in case SoftLayer uses more than one backbone from a provider. Backbone provider numbers start with the number one and increment from there.
    • nameSpecified

      protected boolean nameSpecified
    • networkComponentId

      @ApiProperty(canBeNullOrNotSet=true) protected Long networkComponentId
      The internal identifier of the network component that backbone is connected to.
    • networkComponentIdSpecified

      protected boolean networkComponentIdSpecified
    • type

      @ApiProperty(canBeNullOrNotSet=true) protected String type
      Whether a SoftLayer backbone connects to the public Internet, to the private network, or connecting the private networks of SoftLayer's datacenters. Type is either the string "public", "private", or "private-interconnect".
    • typeSpecified

      protected boolean typeSpecified
  • Constructor Details

    • Backbone

      public Backbone()
  • Method Details

    • getHealth

      public String getHealth()
    • setHealth

      public void setHealth​(String health)
    • getLocation

      public Location getLocation()
    • setLocation

      public void setLocation​(Location location)
    • getNetworkComponent

      public Component getNetworkComponent()
    • setNetworkComponent

      public void setNetworkComponent​(Component networkComponent)
    • getCapacity

      public Long getCapacity()
    • setCapacity

      public void setCapacity​(Long capacity)
    • isCapacitySpecified

      public boolean isCapacitySpecified()
    • unsetCapacity

      public void unsetCapacity()
    • getCapacityUnits

      public String getCapacityUnits()
    • setCapacityUnits

      public void setCapacityUnits​(String capacityUnits)
    • isCapacityUnitsSpecified

      public boolean isCapacityUnitsSpecified()
    • unsetCapacityUnits

      public void unsetCapacityUnits()
    • getId

      public Long getId()
    • setId

      public void setId​(Long id)
    • isIdSpecified

      public boolean isIdSpecified()
    • unsetId

      public void unsetId()
    • getName

      public String getName()
    • setName

      public void setName​(String name)
    • isNameSpecified

      public boolean isNameSpecified()
    • unsetName

      public void unsetName()
    • getNetworkComponentId

      public Long getNetworkComponentId()
    • setNetworkComponentId

      public void setNetworkComponentId​(Long networkComponentId)
    • isNetworkComponentIdSpecified

      public boolean isNetworkComponentIdSpecified()
    • unsetNetworkComponentId

      public void unsetNetworkComponentId()
    • getType

      public String getType()
    • setType

      public void setType​(String type)
    • isTypeSpecified

      public boolean isTypeSpecified()
    • unsetType

      public void unsetType()
    • asService

      public Backbone.Service asService​(ApiClient client)
    • service

      public static Backbone.Service service​(ApiClient client)
    • service

      public static Backbone.Service service​(ApiClient client, Long id)