Interface Gateway.Service
- All Superinterfaces:
Maskable,ResultLimitable,Service
- Enclosing class:
- Gateway
@ApiService("SoftLayer_Network_Gateway") public static interface Gateway.Service extends Service
A network gateway is a set of members which have a configurable set of VLANs trunked through them. This is helpful for creating proxies. Each network gateway can have a configurable set of hardware and VLANs within the same pod routed to it. Gateways can be bypassed or unbypassed either as a whole or for specific VLANs. They are also provided gateway VLANs for management that are never bypassed. Members cannot be simply removed once attached to a gateway, they must be reclaimed.
- See Also:
- SoftLayer_Network_Gateway
-
Method Summary
Modifier and Type Method Description Gateway.ServiceAsyncasAsync()Get an async version of this serviceVoidbypassAllVlans()Start the asynchronous process to bypass all VLANs.VoidbypassVlans(List<Vlan> vlans)Start the asynchronous process to bypass the provided VLANs.BooleanchangeGatewayVersion(Long versionId, Boolean rollbackVersion)Used to create a transaction to upgrade or rollback the vSRX version for Juniper gateway.BooleancheckAccountWhiteList(Long accountId, String category)GatewaycreateObject(Gateway templateObject)Create and return a new gateway.BooleaneditObject(Gateway templateObject)Edit this gateway.AccountgetAccount()The account for this gateway.List<Long>getAllowedOsPriceIds(Long memberId)Used to get a list of OS prices (ids) which are allowed for the Gateway.StringgetCapacity()Returns the Gbps capacity of the gateway object
List<Vlan>getInsideVlans()All VLANs trunked to this gateway.StringgetManufacturer(Boolean checkSameOs, Boolean checkOsReloadMember)Returns manufacturer name for a given gateway object.BooleangetMemberGatewayImagesMatch()Returns true if no mismatch is found, gateway is not Juniper vSRX or SA gateway
List<Member>getMembers()The members for this gateway.FirewallgetNetworkFirewall()The firewall associated with this gateway, if any.BooleangetNetworkFirewallFlag()Whether or not there is a firewall associated with this gateway.GatewaygetObject()List<Vlan>getPossibleInsideVlans()Get all VLANs that can become inside VLANs on this gateway.IpAddressgetPrivateIpAddress()The private gateway IP address.VlangetPrivateVlan()The private VLAN for accessing this gateway.IpAddressgetPublicIpAddress()The public gateway IP address.IpAddressgetPublicIpv6Address()The public gateway IPv6 address.VlangetPublicVlan()The public VLAN for accessing this gateway.StringgetRollbackSupport()Returns the following statuses SUPPORTED - rollback is supported and perform automatically UNSUPPORTED - rollback is not supported MANUAL - rollback can be performed but
StatusgetStatus()The current status of the gateway.List<Price>getUpgradeItemPrices()Retrieve a list of upgradable items available for network gateways.BooleanisAccountWhiteListed(String category)BooleanisLicenseServerAllowed(String licenseKeyName)BooleanisRollbackAllowed()Returns true if rollback is allowed.BooleanrebuildvSRXHACluster()Rebuild a vSRX gateway with HA cluster by destroying existing vSRX and installing new vSRX on both gateway servers, then creating HA cluster between 2 vSRX.BooleansetGatewayPassword(String password)Returns true if password change is successful, false if not successful
voidsetMask(Gateway.Mask mask)VoidunbypassAllVlans()Start the asynchronous process to unbypass all VLANs.VoidunbypassVlans(List<Vlan> vlans)Start the asynchronous process to unbypass the provided VLANs.Gateway.MaskwithMask()Use the existing mask on this service or create it if not presentGateway.MaskwithNewMask()Overwrite the existing mask on this service with a new one and return itMethods inherited from interface com.softlayer.api.ResultLimitable
getLastResponseTotalItemCount, getResultLimit, setResultLimit
-
Method Details
-
asAsync
Gateway.ServiceAsync asAsync()Description copied from interface:ServiceGet an async version of this service -
withNewMask
Gateway.Mask withNewMask()Description copied from interface:MaskableOverwrite the existing mask on this service with a new one and return it- Specified by:
withNewMaskin interfaceMaskable
-
withMask
Gateway.Mask withMask()Description copied from interface:MaskableUse the existing mask on this service or create it if not present -
setMask
-
bypassAllVlans
Start the asynchronous process to bypass all VLANs. Any VLANs that are already bypassed will be ignored. The status field can be checked for progress. -
bypassVlans
Start the asynchronous process to bypass the provided VLANs. The VLANs must already be attached. Any VLANs that are already bypassed will be ignored. The status field can be checked for progress.- See Also:
- SoftLayer_Network_Gateway::bypassVlans
-
changeGatewayVersion
@ApiMethod(instanceRequired=true) Boolean changeGatewayVersion(Long versionId, Boolean rollbackVersion)Used to create a transaction to upgrade or rollback the vSRX version for Juniper gateway.
-
checkAccountWhiteList
-
createObject
Create and return a new gateway. This object can be created with any number of members or VLANs, but they all must be in the same pod. By creating a gateway with members and/or VLANs attached, it is the equivalent of individually calling their createObject methods except this will start a single asynchronous process to setup the gateway. The status of this process can be checked using the status field.- See Also:
- SoftLayer_Network_Gateway::createObject
-
editObject
Edit this gateway. Currently, the only value that can be edited is the name.- See Also:
- SoftLayer_Network_Gateway::editObject
-
getAllowedOsPriceIds
Used to get a list of OS prices (ids) which are allowed for the Gateway.
-
getCapacity
Returns the Gbps capacity of the gateway object
- See Also:
- SoftLayer_Network_Gateway::getCapacity
-
getManufacturer
@ApiMethod(instanceRequired=true) String getManufacturer(Boolean checkSameOs, Boolean checkOsReloadMember)Returns manufacturer name for a given gateway object.
-
getMemberGatewayImagesMatch
Returns true if no mismatch is found, gateway is not Juniper vSRX or SA gateway
-
getObject
- See Also:
- SoftLayer_Network_Gateway::getObject
-
getPossibleInsideVlans
Get all VLANs that can become inside VLANs on this gateway. This means the VLAN must not already be an inside VLAN, on the same router as this gateway, not a gateway transit VLAN, and not firewalled. -
getRollbackSupport
Returns the following statuses SUPPORTED - rollback is supported and perform automatically UNSUPPORTED - rollback is not supported MANUAL - rollback can be performed but
-
getUpgradeItemPrices
Retrieve a list of upgradable items available for network gateways. -
isAccountWhiteListed
-
isLicenseServerAllowed
-
isRollbackAllowed
Returns true if rollback is allowed.
-
rebuildvSRXHACluster
Rebuild a vSRX gateway with HA cluster by destroying existing vSRX and installing new vSRX on both gateway servers, then creating HA cluster between 2 vSRX. This is a destructive process which will remove existing vSRX configuration and stop all gateway capabilities. vSRX will need to be re-configured after this operation.
-
setGatewayPassword
Returns true if password change is successful, false if not successful
-
unbypassAllVlans
Start the asynchronous process to unbypass all VLANs. Any VLANs that are already unbypassed will be ignored. The status field can be checked for progress. -
unbypassVlans
Start the asynchronous process to unbypass the provided VLANs. The VLANs must already be attached. Any VLANs that are already unbypassed will be ignored. The status field can be checked for progress.- See Also:
- SoftLayer_Network_Gateway::unbypassVlans
-
getAccount
The account for this gateway.- See Also:
- SoftLayer_Network_Gateway::getAccount
-
getInsideVlans
All VLANs trunked to this gateway. -
getMembers
The members for this gateway.- See Also:
- SoftLayer_Network_Gateway::getMembers
-
getNetworkFirewall
The firewall associated with this gateway, if any. -
getNetworkFirewallFlag
Whether or not there is a firewall associated with this gateway. -
getPrivateIpAddress
The private gateway IP address. -
getPrivateVlan
The private VLAN for accessing this gateway. -
getPublicIpAddress
The public gateway IP address. -
getPublicIpv6Address
The public gateway IPv6 address. -
getPublicVlan
The public VLAN for accessing this gateway.- See Also:
- SoftLayer_Network_Gateway::getPublicVlan
-
getStatus
The current status of the gateway.- See Also:
- SoftLayer_Network_Gateway::getStatus
-