Interface Monitor.ServiceAsync
- All Superinterfaces:
Maskable,ResultLimitable,ServiceAsync
- Enclosing class:
- Monitor
public static interface Monitor.ServiceAsync extends ServiceAsync
-
Method Summary
Modifier and Type Method Description Future<List<IpAddress>>getIpAddressesByHardware(Hardware hardware, String partialIpAddress)Future<?>getIpAddressesByHardware(Hardware hardware, String partialIpAddress, ResponseHandler<List<IpAddress>> callback)Future<List<IpAddress>>getIpAddressesByVirtualGuest(Guest guest, String partialIpAddress)Future<?>getIpAddressesByVirtualGuest(Guest guest, String partialIpAddress, ResponseHandler<List<IpAddress>> callback)voidsetMask(Monitor.Mask mask)Monitor.MaskwithMask()Use the existing mask on this service or create it if not presentMonitor.MaskwithNewMask()Overwrite the existing mask on this service with a new one and return itMethods inherited from interface com.softlayer.api.ResultLimitable
getLastResponseTotalItemCount, getResultLimit, setResultLimit
-
Method Details
-
withNewMask
Monitor.Mask withNewMask()Description copied from interface:MaskableOverwrite the existing mask on this service with a new one and return it- Specified by:
withNewMaskin interfaceMaskable
-
withMask
Monitor.Mask withMask()Description copied from interface:MaskableUse the existing mask on this service or create it if not present -
setMask
-
getIpAddressesByHardware
-
getIpAddressesByHardware
-
getIpAddressesByVirtualGuest
-
getIpAddressesByVirtualGuest
-