Class Pod
java.lang.Object
com.softlayer.api.Type
com.softlayer.api.service.Entity
com.softlayer.api.service.network.Pod
@ApiType("SoftLayer_Network_Pod") public class Pod extends Entity
SoftLayer_Network_Pod refers to a portion of a data center that share a Backend Customer Router (BCR) and usually a front-end counterpart known as a Frontend Customer Router (FCR). A Pod primarily denotes a logical location within the network and the physical aspects that support networks. This is in contrast to representing a specific physical location.
A ``Pod`` is identified by a ``name``, which is unique. A Pod name follows the format 'dddnn.podii', where 'ddd' is a data center code, 'nn' is the data center number, 'pod' is a literal string and 'ii' is a two digit, left-zero- padded number which corresponds to a Backend Customer Router (BCR) of the desired data center. Examples:
A ``Pod`` is identified by a ``name``, which is unique. A Pod name follows the format 'dddnn.podii', where 'ddd' is a data center code, 'nn' is the data center number, 'pod' is a literal string and 'ii' is a two digit, left-zero- padded number which corresponds to a Backend Customer Router (BCR) of the desired data center. Examples:
- dal09.pod01 = Dallas 9, Pod 1 (ie. bcr01)
- sjc01.pod04 = San Jose 1, Pod 4 (ie. bcr04)
- ams01.pod01 = Amsterdam 1, Pod 1 (ie. bcr01)
- See Also:
- SoftLayer_Network_Pod
-
Nested Class Summary
Nested Classes Modifier and Type Class Description static classPod.Maskstatic interfacePod.ServiceSoftLayer_Network_Pod refers to a portion of a data center that share a Backend Customer Router (BCR) and usually a front-end counterpart known as a Frontend Customer Router (FCR).static interfacePod.ServiceAsync -
Field Summary
Fields Modifier and Type Field Description protected LongbackendRouterIdIdentifier for this Pod's Backend Customer Router (BCR)protected booleanbackendRouterIdSpecifiedprotected StringbackendRouterNameHost name of Pod's Backend Customer Router (BCR), e.g.protected booleanbackendRouterNameSpecifiedprotected List<String>capabilitiesProperty providing a means to filter Pods based on available capabitilies.protected booleancapabilitiesSpecifiedprotected LongdatacenterIdIdentifier for the Data Center the Pod resides withinprotected booleandatacenterIdSpecifiedprotected StringdatacenterLongNameLong form name of the data center in which this Pod resides, e.g.protected booleandatacenterLongNameSpecifiedprotected StringdatacenterNameName of data center in which this Pod resides, e.g.protected booleandatacenterNameSpecifiedprotected LongfrontendRouterId(optional) Identifier for this Pod's Frontend Customer Router (FCR)protected booleanfrontendRouterIdSpecifiedprotected StringfrontendRouterName(optional) Host name of Pod's Frontend Customer Router (FCR), e.g.protected booleanfrontendRouterNameSpecifiedprotected StringnameThe unique name of the Pod.protected booleannameSpecified -
Constructor Summary
Constructors Constructor Description Pod() -
Method Summary
-
Field Details
-
backendRouterId
Identifier for this Pod's Backend Customer Router (BCR) -
backendRouterIdSpecified
protected boolean backendRouterIdSpecified -
backendRouterName
Host name of Pod's Backend Customer Router (BCR), e.g. bcr01a.dal09 -
backendRouterNameSpecified
protected boolean backendRouterNameSpecified -
capabilities
Property providing a means to filter Pods based on available capabitilies. See [[SoftLayer_Network_Pod/getAllObjects]] to filter for Pods with specific capabilities. See [[SoftLayer_Network_Pod/getCapabilities]] to retrieve capabilities of a specific Pod. -
capabilitiesSpecified
protected boolean capabilitiesSpecified -
datacenterId
Identifier for the Data Center the Pod resides within -
datacenterIdSpecified
protected boolean datacenterIdSpecified -
datacenterLongName
Long form name of the data center in which this Pod resides, e.g. Dallas 9 -
datacenterLongNameSpecified
protected boolean datacenterLongNameSpecified -
datacenterName
Name of data center in which this Pod resides, e.g. dal09 -
datacenterNameSpecified
protected boolean datacenterNameSpecified -
frontendRouterId
(optional) Identifier for this Pod's Frontend Customer Router (FCR) -
frontendRouterIdSpecified
protected boolean frontendRouterIdSpecified -
frontendRouterName
(optional) Host name of Pod's Frontend Customer Router (FCR), e.g. fcr01a.dal09 -
frontendRouterNameSpecified
protected boolean frontendRouterNameSpecified -
name
The unique name of the Pod. See [[SoftLayer_Network_Pod (type)]] for details of the name's construction. -
nameSpecified
protected boolean nameSpecified
-
-
Constructor Details
-
Pod
public Pod()
-
-
Method Details
-
getBackendRouterId
-
setBackendRouterId
-
isBackendRouterIdSpecified
public boolean isBackendRouterIdSpecified() -
unsetBackendRouterId
public void unsetBackendRouterId() -
getBackendRouterName
-
setBackendRouterName
-
isBackendRouterNameSpecified
public boolean isBackendRouterNameSpecified() -
unsetBackendRouterName
public void unsetBackendRouterName() -
getCapabilities
-
isCapabilitiesSpecified
public boolean isCapabilitiesSpecified() -
unsetCapabilities
public void unsetCapabilities() -
getDatacenterId
-
setDatacenterId
-
isDatacenterIdSpecified
public boolean isDatacenterIdSpecified() -
unsetDatacenterId
public void unsetDatacenterId() -
getDatacenterLongName
-
setDatacenterLongName
-
isDatacenterLongNameSpecified
public boolean isDatacenterLongNameSpecified() -
unsetDatacenterLongName
public void unsetDatacenterLongName() -
getDatacenterName
-
setDatacenterName
-
isDatacenterNameSpecified
public boolean isDatacenterNameSpecified() -
unsetDatacenterName
public void unsetDatacenterName() -
getFrontendRouterId
-
setFrontendRouterId
-
isFrontendRouterIdSpecified
public boolean isFrontendRouterIdSpecified() -
unsetFrontendRouterId
public void unsetFrontendRouterId() -
getFrontendRouterName
-
setFrontendRouterName
-
isFrontendRouterNameSpecified
public boolean isFrontendRouterNameSpecified() -
unsetFrontendRouterName
public void unsetFrontendRouterName() -
getName
-
setName
-
isNameSpecified
public boolean isNameSpecified() -
unsetName
public void unsetName() -
service
-