Interface Pod.ServiceAsync
- All Superinterfaces:
Maskable,ResultLimitable,ServiceAsync
- Enclosing class:
- Pod
public static interface Pod.ServiceAsync extends ServiceAsync
-
Method Summary
Modifier and Type Method Description Future<List<Pod>>getAllObjects()Async version ofPod.Service.getAllObjects()Future<?>getAllObjects(ResponseHandler<List<Pod>> callback)Future<List<String>>getCapabilities()Async version ofPod.Service.getCapabilities()Future<?>getCapabilities(ResponseHandler<List<String>> callback)Future<Pod>getObject()Async version ofPod.Service.getObject()Future<?>getObject(ResponseHandler<Pod> callback)Future<List<String>>listCapabilities()Async version ofPod.Service.listCapabilities()Future<?>listCapabilities(ResponseHandler<List<String>> callback)voidsetMask(Pod.Mask mask)Pod.MaskwithMask()Use the existing mask on this service or create it if not presentPod.MaskwithNewMask()Overwrite the existing mask on this service with a new one and return itMethods inherited from interface com.softlayer.api.ResultLimitable
getLastResponseTotalItemCount, getResultLimit, setResultLimit
-
Method Details
-
withNewMask
Pod.Mask withNewMask()Description copied from interface:MaskableOverwrite the existing mask on this service with a new one and return it- Specified by:
withNewMaskin interfaceMaskable
-
withMask
Pod.Mask withMask()Description copied from interface:MaskableUse the existing mask on this service or create it if not present -
setMask
-
getAllObjects
Async version ofPod.Service.getAllObjects() -
getAllObjects
-
getCapabilities
Async version ofPod.Service.getCapabilities() -
getCapabilities
-
getObject
Async version ofPod.Service.getObject() -
getObject
-
listCapabilities
Async version ofPod.Service.listCapabilities() -
listCapabilities
-