Class Subnet
java.lang.Object
com.softlayer.api.Type
com.softlayer.api.service.Entity
com.softlayer.api.service.network.Subnet
@ApiType("SoftLayer_Network_Subnet") public class Subnet extends Entity
The SoftLayer_Network_Subnet data type contains general information relating to a single SoftLayer subnet. Personal information in this type such as names, addresses, and phone numbers are assigned to the account only and not to users belonging to the account.
- See Also:
- SoftLayer_Network_Subnet
-
Nested Class Summary
Nested Classes Modifier and Type Class Description static classSubnet.Maskstatic interfaceSubnet.ServiceEvery SoftLayer ip address is associated with a subnet which is defined in the SoftLayer_Network_Subnet service.static interfaceSubnet.ServiceAsync -
Field Summary
Fields Modifier and Type Field Description protected Accountaccountprotected RegistrationactiveRegistrationIf present, the active registration for this subnet.protected TransactionactiveSwipTransactionDEPRECATEDprotected TransactionactiveTransactionThe billing item for a subnet.protected StringaddressSpaceIdentifier which distinguishes what classification of addresses the subnet represents.protected HostallowedHostThe SoftLayer_Network_Storage_Allowed_Host information to connect this Subnet to Network Storage supporting access control lists.protected List<Storage>allowedNetworkStorageThe SoftLayer_Network_Storage objects that this SoftLayer_Hardware has access to.protected LongallowedNetworkStorageCountA count of the SoftLayer_Network_Storage objects that this SoftLayer_Hardware has access to.protected LongallowedNetworkStorageReplicaCountA count of the SoftLayer_Network_Storage objects whose Replica that this SoftLayer_Hardware has access to.protected List<Storage>allowedNetworkStorageReplicasThe SoftLayer_Network_Storage objects whose Replica that this SoftLayer_Hardware has access to.protected ItembillingItemThe billing item for a subnet.protected LongboundDescendantCountA count ofprotected List<Subnet>boundDescendantsprotected LongboundRouterCountA count ofprotected BooleanboundRouterFlagWhether or not this subnet is associated with a router.protected List<Hardware>boundRoutersprotected StringbroadcastAddressThe last IP address in a subnet is the subnet's broadcast address.protected booleanbroadcastAddressSpecifiedprotected List<Subnet>childrenprotected LongchildrenCountA count ofprotected LongcidrA subnet's Classless Inter-Domain Routing prefix.protected booleancidrSpecifiedprotected DatacenterdatacenterThe data center this subnet may be routed within.protected LongdescendantCountA count ofprotected List<Subnet>descendantsprotected StringdisplayLabelprotected IpAddressendPointIpAddressA static routed ip addressprotected StringgatewayA subnet's gateway address.protected booleangatewaySpecifiedprotected GlobalglobalIpRecordprotected List<Hardware>hardwareThe hardware using IP addresses on this subnet.protected LonghardwareCountA count of the hardware using IP addresses on this subnet.protected LongidA subnet's internal identifier.protected booleanidSpecifiedprotected LongipAddressCountA count of all the ip addresses associated with a subnet.protected List<IpAddress>ipAddressesAll the ip addresses associated with a subnet.protected BooleanisCustomerOwnedprotected booleanisCustomerOwnedSpecifiedprotected BooleanisCustomerRoutableprotected booleanisCustomerRoutableSpecifiedprotected GregorianCalendarmodifyDateThe last time this subnet was last modifiedprotected booleanmodifyDateSpecifiedprotected StringnetmaskA bitmask in dotted-quad format that is used to separate a subnet's network address from it's host addresses.protected booleannetmaskSpecifiedprotected FirewallnetworkComponentFirewallThe upstream network component firewall.protected StringnetworkIdentifierA subnet's network identifier.protected booleannetworkIdentifierSpecifiedprotected LongnetworkProtectionAddressCountA count ofprotected List<Address>networkProtectionAddressesprotected LongnetworkTunnelContextCountA count of iPSec network tunnels that have access to a private subnet.protected List<Context>networkTunnelContextsIPSec network tunnels that have access to a private subnet.protected VlannetworkVlanThe VLAN object that a subnet is associated with.protected LongnetworkVlanIdA subnet's associated VLAN's internal identifier.protected booleannetworkVlanIdSpecifiedprotected StringnoteThis is the note field.protected booleannoteSpecifiedprotected StringpodNameThe pod in which this subnet resides.protected LongprotectedIpAddressCountA count ofprotected List<IpAddress>protectedIpAddressesprotected RegistryregionalInternetRegistryprotected LongregistrationCountA count of all registrations that have been created for this subnet.protected List<Registration>registrationsAll registrations that have been created for this subnet.protected DomainreverseDomainThe reverse DNS domain associated with this subnet.protected StringroleKeyNameAn identifier of the role the subnet is within.protected StringroleNameThe name of the role the subnet is within.protected StringroutingTypeKeyNameThe identifier for the type of route then subnet is currently configured for.protected StringroutingTypeNameThe name for the type of route then subnet is currently configured for.protected StringsortOrderUsed to sort subnets and group subnets of similar type together for use on customer facing portals.protected booleansortOrderSpecifiedprotected StringsubnetTypeA subnet type can be any of the following:
* PRIMARY
* ADDITIONAL_PRIMARY
* SECONDARY_ON_VLAN
* STATIC_IP_ROUTED
* PRIMARY_6
* SUBNET_ON_VLAN
* STATIC_IP_ROUTED_6
* GLOBAL_IP
A "PRIMARY" subnet is the primary network bound to a VLAN within the softlayer network.protected booleansubnetTypeSpecifiedprotected List<Transaction>swipTransactionDEPRECATEDprotected LongswipTransactionCountA count of dEPRECATEDprotected LongtagReferenceCountA count of references to all tags for this subnet.protected List<Reference>tagReferencesReferences to all tags for this subnet.protected BigDecimaltotalIpAddressesThe number of IP addresses contained within this subnet.protected booleantotalIpAddressesSpecifiedprotected LongunboundDescendantCountA count ofprotected List<Subnet>unboundDescendantsprotected BigDecimalusableIpAddressCountThe number of IP addresses that can be addressed within this subnet.protected booleanusableIpAddressCountSpecifiedprotected LongutilizedIpAddressCountProvides the total number of utilized IP addresses on this subnet.protected LongversionThis is the Internet Protocol version.protected booleanversionSpecifiedprotected LongvirtualGuestCountA count of the Virtual Servers using IP addresses on this subnet.protected List<Guest>virtualGuestsThe Virtual Servers using IP addresses on this subnet. -
Constructor Summary
Constructors Constructor Description Subnet() -
Method Summary
-
Field Details
-
account
-
activeRegistration
If present, the active registration for this subnet. -
activeSwipTransaction
DEPRECATED -
activeTransaction
The billing item for a subnet. -
addressSpace
Identifier which distinguishes what classification of addresses the subnet represents. -
allowedHost
The SoftLayer_Network_Storage_Allowed_Host information to connect this Subnet to Network Storage supporting access control lists. -
allowedNetworkStorage
The SoftLayer_Network_Storage objects that this SoftLayer_Hardware has access to. -
allowedNetworkStorageReplicas
The SoftLayer_Network_Storage objects whose Replica that this SoftLayer_Hardware has access to. -
billingItem
The billing item for a subnet. -
boundDescendants
-
boundRouterFlag
Whether or not this subnet is associated with a router. Subnets that are not associated with a router cannot be routed. -
boundRouters
-
children
-
datacenter
The data center this subnet may be routed within. -
descendants
-
displayLabel
-
endPointIpAddress
A static routed ip address -
globalIpRecord
-
hardware
The hardware using IP addresses on this subnet. -
ipAddresses
All the ip addresses associated with a subnet. -
networkComponentFirewall
The upstream network component firewall. -
networkProtectionAddresses
-
networkTunnelContexts
IPSec network tunnels that have access to a private subnet. -
networkVlan
The VLAN object that a subnet is associated with. -
podName
The pod in which this subnet resides. -
protectedIpAddresses
-
regionalInternetRegistry
-
registrations
All registrations that have been created for this subnet. -
reverseDomain
The reverse DNS domain associated with this subnet. -
roleKeyName
An identifier of the role the subnet is within. Roles dictate how a subnet may be used. -
roleName
The name of the role the subnet is within. Roles dictate how a subnet may be used. -
routingTypeKeyName
The identifier for the type of route then subnet is currently configured for. -
routingTypeName
The name for the type of route then subnet is currently configured for. -
swipTransaction
DEPRECATED -
tagReferences
References to all tags for this subnet. -
unboundDescendants
-
utilizedIpAddressCount
Provides the total number of utilized IP addresses on this subnet. The primary consumer of IP addresses are compute resources, which can consume more than one address. This value is only supported for primary subnet types. -
virtualGuests
The Virtual Servers using IP addresses on this subnet. -
broadcastAddress
The last IP address in a subnet is the subnet's broadcast address. This is an IP address that will broadcast network requests to the entire subnet and may not be assigned to a network interface. -
broadcastAddressSpecified
protected boolean broadcastAddressSpecified -
cidr
A subnet's Classless Inter-Domain Routing prefix. This is a number between 0 and 32 signifying the number of bits in a subnet's netmask. These bits separate a subnet's network address from it's host addresses. It performs the same function as the ''netmask'' property, but is represented as an integer. -
cidrSpecified
protected boolean cidrSpecified -
gateway
A subnet's gateway address. This is an IP address that belongs to the router on the subnet and may not be assigned to a network interface. -
gatewaySpecified
protected boolean gatewaySpecified -
id
A subnet's internal identifier. -
idSpecified
protected boolean idSpecified -
isCustomerOwned
-
isCustomerOwnedSpecified
protected boolean isCustomerOwnedSpecified -
isCustomerRoutable
-
isCustomerRoutableSpecified
protected boolean isCustomerRoutableSpecified -
modifyDate
The last time this subnet was last modified -
modifyDateSpecified
protected boolean modifyDateSpecified -
netmask
A bitmask in dotted-quad format that is used to separate a subnet's network address from it's host addresses. This performs the same function as the ''cidr'' property, but is expressed in a string format. -
netmaskSpecified
protected boolean netmaskSpecified -
networkIdentifier
A subnet's network identifier. This is the first IP address of a subnet and may not be assigned to a network interface. -
networkIdentifierSpecified
protected boolean networkIdentifierSpecified -
networkVlanId
A subnet's associated VLAN's internal identifier. -
networkVlanIdSpecified
protected boolean networkVlanIdSpecified -
note
This is the note field. -
noteSpecified
protected boolean noteSpecified -
sortOrder
Used to sort subnets and group subnets of similar type together for use on customer facing portals. -
sortOrderSpecified
protected boolean sortOrderSpecified -
subnetType
A subnet type can be any of the following:
* PRIMARY
* ADDITIONAL_PRIMARY
* SECONDARY_ON_VLAN
* STATIC_IP_ROUTED
* PRIMARY_6
* SUBNET_ON_VLAN
* STATIC_IP_ROUTED_6
* GLOBAL_IP
A "PRIMARY" subnet is the primary network bound to a VLAN within the softlayer network. An "ADDITIONAL_PRIMARY" subnet is bound to a network VLAN to augment the pool of available primary IP addresses that may be assigned to a server. A "SECONDARY_ON_VLAN" subnet is a secondary portable subnet whose IP addresses are managed by the end user. "STATIC_IP_ROUTED" subnets are subnets that are statically routed to a single endpoint IP address. A "PRIMARY_6" subnet is the primary IPv6 network bound to a VLAN. A "SUBNET_ON_VLAN" subnet is the secondary portable IPv6 subnet whose IP addresses are managed by the end user. A "STATIC_IP_ROUTED_6" subnet is statically routed to a single IPv6 endpoint IP address. A "GLOBAL_IP" subnet is a subnet that is routable to a single endpoint IP address. The "GLOBAL_IP" type is used for both IPv4 and IPv6 subnets. -
subnetTypeSpecified
protected boolean subnetTypeSpecified -
totalIpAddresses
The number of IP addresses contained within this subnet. -
totalIpAddressesSpecified
protected boolean totalIpAddressesSpecified -
usableIpAddressCount
The number of IP addresses that can be addressed within this subnet. For IPv4 subnets with a CIDR value of at most 30, a discount of 3 is taken from the total number of IP addresses for the subnet's unusable network, gateway and broadcast IP addresses. For IPv6 subnets with a CIDR value of at most 126, a discount of 2 is taken for the subnet's network and gateway IP addresses. -
usableIpAddressCountSpecified
protected boolean usableIpAddressCountSpecified -
version
This is the Internet Protocol version. Current values may be either 4 or 6. -
versionSpecified
protected boolean versionSpecified -
allowedNetworkStorageCount
A count of the SoftLayer_Network_Storage objects that this SoftLayer_Hardware has access to. -
allowedNetworkStorageReplicaCount
A count of the SoftLayer_Network_Storage objects whose Replica that this SoftLayer_Hardware has access to. -
boundDescendantCount
A count of -
boundRouterCount
A count of -
childrenCount
A count of -
descendantCount
A count of -
hardwareCount
A count of the hardware using IP addresses on this subnet. -
ipAddressCount
A count of all the ip addresses associated with a subnet. -
networkProtectionAddressCount
A count of -
networkTunnelContextCount
A count of iPSec network tunnels that have access to a private subnet. -
protectedIpAddressCount
A count of -
registrationCount
A count of all registrations that have been created for this subnet. -
swipTransactionCount
A count of dEPRECATED -
tagReferenceCount
A count of references to all tags for this subnet. -
unboundDescendantCount
A count of -
virtualGuestCount
A count of the Virtual Servers using IP addresses on this subnet.
-
-
Constructor Details
-
Subnet
public Subnet()
-
-
Method Details
-
getAccount
-
setAccount
-
getActiveRegistration
-
setActiveRegistration
-
getActiveSwipTransaction
-
setActiveSwipTransaction
-
getActiveTransaction
-
setActiveTransaction
-
getAddressSpace
-
setAddressSpace
-
getAllowedHost
-
setAllowedHost
-
getAllowedNetworkStorage
-
getAllowedNetworkStorageReplicas
-
getBillingItem
-
setBillingItem
-
getBoundDescendants
-
getBoundRouterFlag
-
setBoundRouterFlag
-
getBoundRouters
-
getChildren
-
getDatacenter
-
setDatacenter
-
getDescendants
-
getDisplayLabel
-
setDisplayLabel
-
getEndPointIpAddress
-
setEndPointIpAddress
-
getGlobalIpRecord
-
setGlobalIpRecord
-
getHardware
-
getIpAddresses
-
getNetworkComponentFirewall
-
setNetworkComponentFirewall
-
getNetworkProtectionAddresses
-
getNetworkTunnelContexts
-
getNetworkVlan
-
setNetworkVlan
-
getPodName
-
setPodName
-
getProtectedIpAddresses
-
getRegionalInternetRegistry
-
setRegionalInternetRegistry
-
getRegistrations
-
getReverseDomain
-
setReverseDomain
-
getRoleKeyName
-
setRoleKeyName
-
getRoleName
-
setRoleName
-
getRoutingTypeKeyName
-
setRoutingTypeKeyName
-
getRoutingTypeName
-
setRoutingTypeName
-
getSwipTransaction
-
getTagReferences
-
getUnboundDescendants
-
getUtilizedIpAddressCount
-
setUtilizedIpAddressCount
-
getVirtualGuests
-
getBroadcastAddress
-
setBroadcastAddress
-
isBroadcastAddressSpecified
public boolean isBroadcastAddressSpecified() -
unsetBroadcastAddress
public void unsetBroadcastAddress() -
getCidr
-
setCidr
-
isCidrSpecified
public boolean isCidrSpecified() -
unsetCidr
public void unsetCidr() -
getGateway
-
setGateway
-
isGatewaySpecified
public boolean isGatewaySpecified() -
unsetGateway
public void unsetGateway() -
getId
-
setId
-
isIdSpecified
public boolean isIdSpecified() -
unsetId
public void unsetId() -
getIsCustomerOwned
-
setIsCustomerOwned
-
isIsCustomerOwnedSpecified
public boolean isIsCustomerOwnedSpecified() -
unsetIsCustomerOwned
public void unsetIsCustomerOwned() -
getIsCustomerRoutable
-
setIsCustomerRoutable
-
isIsCustomerRoutableSpecified
public boolean isIsCustomerRoutableSpecified() -
unsetIsCustomerRoutable
public void unsetIsCustomerRoutable() -
getModifyDate
-
setModifyDate
-
isModifyDateSpecified
public boolean isModifyDateSpecified() -
unsetModifyDate
public void unsetModifyDate() -
getNetmask
-
setNetmask
-
isNetmaskSpecified
public boolean isNetmaskSpecified() -
unsetNetmask
public void unsetNetmask() -
getNetworkIdentifier
-
setNetworkIdentifier
-
isNetworkIdentifierSpecified
public boolean isNetworkIdentifierSpecified() -
unsetNetworkIdentifier
public void unsetNetworkIdentifier() -
getNetworkVlanId
-
setNetworkVlanId
-
isNetworkVlanIdSpecified
public boolean isNetworkVlanIdSpecified() -
unsetNetworkVlanId
public void unsetNetworkVlanId() -
getNote
-
setNote
-
isNoteSpecified
public boolean isNoteSpecified() -
unsetNote
public void unsetNote() -
getSortOrder
-
setSortOrder
-
isSortOrderSpecified
public boolean isSortOrderSpecified() -
unsetSortOrder
public void unsetSortOrder() -
getSubnetType
-
setSubnetType
-
isSubnetTypeSpecified
public boolean isSubnetTypeSpecified() -
unsetSubnetType
public void unsetSubnetType() -
getTotalIpAddresses
-
setTotalIpAddresses
-
isTotalIpAddressesSpecified
public boolean isTotalIpAddressesSpecified() -
unsetTotalIpAddresses
public void unsetTotalIpAddresses() -
getUsableIpAddressCount
-
setUsableIpAddressCount
-
isUsableIpAddressCountSpecified
public boolean isUsableIpAddressCountSpecified() -
unsetUsableIpAddressCount
public void unsetUsableIpAddressCount() -
getVersion
-
setVersion
-
isVersionSpecified
public boolean isVersionSpecified() -
unsetVersion
public void unsetVersion() -
getAllowedNetworkStorageCount
-
setAllowedNetworkStorageCount
-
getAllowedNetworkStorageReplicaCount
-
setAllowedNetworkStorageReplicaCount
-
getBoundDescendantCount
-
setBoundDescendantCount
-
getBoundRouterCount
-
setBoundRouterCount
-
getChildrenCount
-
setChildrenCount
-
getDescendantCount
-
setDescendantCount
-
getHardwareCount
-
setHardwareCount
-
getIpAddressCount
-
setIpAddressCount
-
getNetworkProtectionAddressCount
-
setNetworkProtectionAddressCount
-
getNetworkTunnelContextCount
-
setNetworkTunnelContextCount
-
getProtectedIpAddressCount
-
setProtectedIpAddressCount
-
getRegistrationCount
-
setRegistrationCount
-
getSwipTransactionCount
-
setSwipTransactionCount
-
getTagReferenceCount
-
setTagReferenceCount
-
getUnboundDescendantCount
-
setUnboundDescendantCount
-
getVirtualGuestCount
-
setVirtualGuestCount
-
asService
-
service
-
service
-