Interface Vlan.Service
- All Superinterfaces:
Maskable,ResultLimitable,Service
- Enclosing class:
- Vlan
@ApiService("SoftLayer_Network_Vlan") public static interface Vlan.Service extends Service
Virtual LANs are an integral part of SoftLayer' s public and private networks. A VLAN is a networking concept in which network interfaces on different routers, switches, and servers act as if they're on the same local network broadcast domain. This kind of network segmentation helps keep SoftLayer customers' networks separate from each other and provides a convenient mechanism for routing new IP subnets to servers. They also enable easy IP address sharing and swapping between servers on the same VLAN. SoftLayer servers are provisioned on private VLANs per router on the public and private networks.
The SoftLayer_Network_Vlan service controls these VLANs and provides relationships between VLANs, subnets, IP addresses, and network components.
The SoftLayer_Network_Vlan service controls these VLANs and provides relationships between VLANs, subnets, IP addresses, and network components.
- See Also:
- SoftLayer_Network_Vlan
-
Method Summary
Modifier and Type Method Description Vlan.ServiceAsyncasAsync()Get an async version of this serviceBooleaneditObject(Vlan templateObject)Edit a VLAN's propertiesAccountgetAccount()The SoftLayer customer account associated with a VLAN.List<Subnet>getAdditionalPrimarySubnets()A VLAN's additional primary subnets.GatewaygetAttachedNetworkGateway()The gateway this VLAN is inside of.BooleangetAttachedNetworkGatewayFlag()Whether or not this VLAN is inside a gateway.VlangetAttachedNetworkGatewayVlan()The inside VLAN record if this VLAN is inside a network gateway.ItemgetBillingItem()The billing item for a network vlan.List<String>getCancelFailureReasons()Get a set of reasons why this VLAN may not be cancelled.LonggetDedicatedFirewallFlag()A flag indicating that a network vlan is on a Hardware Firewall (Dedicated).RoutergetExtensionRouter()The extension router that a VLAN is associated with.List<Firewall>getFirewallGuestNetworkComponents()A firewalled Vlan's network components.List<Interface>getFirewallInterfaces()A firewalled vlan's inbound/outbound interfaces.List<Firewall>getFirewallNetworkComponents()A firewalled Vlan's network components.List<IpAddress>getFirewallProtectableIpAddresses()Get the IP addresses associated with this server that are protectable by a network component firewall.List<Subnet>getFirewallProtectableSubnets()Get the subnets associated with this server that are protectable by a network component firewall.List<Rule>getFirewallRules()The currently running rule set of a firewalled VLAN.List<Component>getGuestNetworkComponents()The networking components that are connected to a VLAN.List<Hardware>getHardware()All of the hardware that exists on a VLAN.BooleangetHighAvailabilityFirewallFlag()BooleangetLocalDiskStorageCapabilityFlag()A flag indicating that a vlan can be assigned to a host that has local disk functionality.NetworkgetNetwork()The network in which this VLAN resides.List<Component>getNetworkComponents()The networking components that are connected to a VLAN.List<Trunk>getNetworkComponentTrunks()The network components that are connected to this VLAN through a trunk.StringgetNetworkSpace()Identifier to denote whether a VLAN is used for public or private connectivity.FirewallgetNetworkVlanFirewall()The Hardware Firewall (Dedicated) for a network vlan.VlangetObject()getObject retrieves the SoftLayer_Network_Vlan object whose ID number corresponds to the ID number of the init parameter passed to the SoftLayer_Network_Vlan service.RoutergetPrimaryRouter()The primary router that a VLAN is associated with.SubnetgetPrimarySubnet()A VLAN's primary subnet.List<Subnet>getPrimarySubnets()SubnetgetPrimarySubnetVersion6()A VLAN's primary IPv6 subnet.List<Gateway>getPrivateNetworkGateways()The gateways this VLAN is the private VLAN of.VlangetPrivateVlan()Retrieve a VLAN's associated private network VLAN.VlangetPrivateVlanByIpAddress(String ipAddress)
*** DEPRECATED ***
Retrieve the private network VLAN associated with an IP address.List<IpAddress>getProtectedIpAddresses()List<Gateway>getPublicNetworkGateways()The gateways this VLAN is the public VLAN of.VlangetPublicVlanByFqdn(String fqdn)Retrieve the VLAN that belongs to a server's public network interface, as described by a server's fully-qualified domain name.List<Domain>getReverseDomainRecords()Retrieve all reverse DNS records associated with the subnets assigned to a VLAN.BooleangetSanStorageCapabilityFlag()A flag indicating that a vlan can be assigned to a host that has SAN disk functionality.List<Vlan>getScaleVlans()Collection of scale VLANs this VLAN applies to.HardwaregetSecondaryRouter()The secondary router that a VLAN is associated with.List<Subnet>getSecondarySubnets()The subnets that exist as secondary interfaces on a VLANList<Subnet>getSubnets()All of the subnets that exist as VLAN interfaces.List<Reference>getTagReferences()References to all tags for this VLAN.LonggetTotalPrimaryIpAddressCount()The number of primary IP addresses in a VLAN.TypegetType()The type of this VLAN.List<Guest>getVirtualGuests()All of the Virtual Servers that are connected to a VLAN.VlangetVlanForIpAddress(String ipAddress)Retrieve the VLAN associated with an IP address via the IP's associated subnet.voidsetMask(Vlan.Mask mask)BooleansetTags(String tags)Tag a VLAN by passing in one or more tags separated by a comma.VoidupdateFirewallIntraVlanCommunication(Boolean enabled)The '''getSensorData''' method updates a VLAN's firewall to allow or disallow intra-VLAN communication.Vlanupgrade()Convert the VLAN this operation is executed against to a paid resource.Vlan.MaskwithMask()Use the existing mask on this service or create it if not presentVlan.MaskwithNewMask()Overwrite the existing mask on this service with a new one and return itMethods inherited from interface com.softlayer.api.ResultLimitable
getLastResponseTotalItemCount, getResultLimit, setResultLimit
-
Method Details
-
asAsync
Vlan.ServiceAsync asAsync()Description copied from interface:ServiceGet an async version of this service -
withNewMask
Vlan.Mask withNewMask()Description copied from interface:MaskableOverwrite the existing mask on this service with a new one and return it- Specified by:
withNewMaskin interfaceMaskable
-
withMask
Vlan.Mask withMask()Description copied from interface:MaskableUse the existing mask on this service or create it if not present -
setMask
-
editObject
Edit a VLAN's properties- See Also:
- SoftLayer_Network_Vlan::editObject
-
getCancelFailureReasons
Get a set of reasons why this VLAN may not be cancelled. If the result is empty, this VLAN may be cancelled. -
getFirewallProtectableIpAddresses
Get the IP addresses associated with this server that are protectable by a network component firewall. Note, this may not return all values for IPv6 subnets for this VLAN. Please use getFirewallProtectableSubnets to get all protectable subnets. -
getFirewallProtectableSubnets
Get the subnets associated with this server that are protectable by a network component firewall. -
getObject
getObject retrieves the SoftLayer_Network_Vlan object whose ID number corresponds to the ID number of the init parameter passed to the SoftLayer_Network_Vlan service. You can only retrieve VLANs that are associated with your SoftLayer customer account.- See Also:
- SoftLayer_Network_Vlan::getObject
-
getPrivateVlan
Retrieve a VLAN's associated private network VLAN. getPrivateVlan gathers it's information by retrieving the private VLAN of a VLAN's primary hardware object.- See Also:
- SoftLayer_Network_Vlan::getPrivateVlan
-
getPrivateVlanByIpAddress
*** DEPRECATED ***
Retrieve the private network VLAN associated with an IP address. -
getPublicVlanByFqdn
Retrieve the VLAN that belongs to a server's public network interface, as described by a server's fully-qualified domain name. A server's ''FQDN'' is it's hostname, followed by a period then it's domain name. -
getReverseDomainRecords
Retrieve all reverse DNS records associated with the subnets assigned to a VLAN. -
getVlanForIpAddress
Retrieve the VLAN associated with an IP address via the IP's associated subnet. -
setTags
Tag a VLAN by passing in one or more tags separated by a comma. Tag references are cleared out every time this method is called. If your VLAN is already tagged you will need to pass the current tags along with any new ones. To remove all tag references pass an empty string. To remove one or more tags omit them from the tag list.- See Also:
- SoftLayer_Network_Vlan::setTags
-
updateFirewallIntraVlanCommunication
The '''getSensorData''' method updates a VLAN's firewall to allow or disallow intra-VLAN communication. -
upgrade
Convert the VLAN this operation is executed against to a paid resource. This can be done for any Automatic VLAN. This operation can only be executed on an Automatic VLAN, and will transition it to being a Premium VLAN. The VLAN will then provide the benefits of a Premium VLAN. A Premium VLAN will remain on the account until cancelled. This operation cannot be undone! Once a VLAN becomes Premium, it can only be removed through cancellation, which will result in it being reclaimed.
This operation is a convenience for utilizing the SoftLayer_Product_Order.placeOrder operation. It will place an order to upgrade the VLAN it is executed against. It will take a few moments for the order to be processed and the upgrade to complete. Note that the order is placed in such a way that any account state which prevents automatic order approval will prevent the order from being placed. Thus, if no error is received, the order was placed and approved, and the VLAN will be upgraded shortly.- See Also:
- SoftLayer_Network_Vlan::upgrade
-
getAccount
The SoftLayer customer account associated with a VLAN.- See Also:
- SoftLayer_Network_Vlan::getAccount
-
getAdditionalPrimarySubnets
A VLAN's additional primary subnets. These are used to extend the number of servers attached to the VLAN by adding more ip addresses to the primary IP address pool. -
getAttachedNetworkGateway
The gateway this VLAN is inside of. -
getAttachedNetworkGatewayFlag
Whether or not this VLAN is inside a gateway. -
getAttachedNetworkGatewayVlan
The inside VLAN record if this VLAN is inside a network gateway. -
getBillingItem
The billing item for a network vlan.- See Also:
- SoftLayer_Network_Vlan::getBillingItem
-
getDedicatedFirewallFlag
A flag indicating that a network vlan is on a Hardware Firewall (Dedicated). -
getExtensionRouter
The extension router that a VLAN is associated with. -
getFirewallGuestNetworkComponents
A firewalled Vlan's network components. -
getFirewallInterfaces
A firewalled vlan's inbound/outbound interfaces. -
getFirewallNetworkComponents
A firewalled Vlan's network components. -
getFirewallRules
The currently running rule set of a firewalled VLAN.- See Also:
- SoftLayer_Network_Vlan::getFirewallRules
-
getGuestNetworkComponents
The networking components that are connected to a VLAN. -
getHardware
All of the hardware that exists on a VLAN. Hardware is associated with a VLAN by its networking components.- See Also:
- SoftLayer_Network_Vlan::getHardware
-
getHighAvailabilityFirewallFlag
-
getLocalDiskStorageCapabilityFlag
A flag indicating that a vlan can be assigned to a host that has local disk functionality. -
getNetwork
The network in which this VLAN resides.- See Also:
- SoftLayer_Network_Vlan::getNetwork
-
getNetworkComponentTrunks
The network components that are connected to this VLAN through a trunk. -
getNetworkComponents
The networking components that are connected to a VLAN. -
getNetworkSpace
Identifier to denote whether a VLAN is used for public or private connectivity.- See Also:
- SoftLayer_Network_Vlan::getNetworkSpace
-
getNetworkVlanFirewall
The Hardware Firewall (Dedicated) for a network vlan. -
getPrimaryRouter
The primary router that a VLAN is associated with. Every SoftLayer VLAN is connected to more than one router for greater network redundancy.- See Also:
- SoftLayer_Network_Vlan::getPrimaryRouter
-
getPrimarySubnet
A VLAN's primary subnet. Each VLAN has at least one subnet, usually the subnet that is assigned to a server or new IP address block when it's purchased.- See Also:
- SoftLayer_Network_Vlan::getPrimarySubnet
-
getPrimarySubnetVersion6
A VLAN's primary IPv6 subnet. Some VLAN's may not have a primary IPv6 subnet. -
getPrimarySubnets
-
getPrivateNetworkGateways
The gateways this VLAN is the private VLAN of. -
getProtectedIpAddresses
-
getPublicNetworkGateways
The gateways this VLAN is the public VLAN of. -
getSanStorageCapabilityFlag
A flag indicating that a vlan can be assigned to a host that has SAN disk functionality. -
getScaleVlans
Collection of scale VLANs this VLAN applies to.- See Also:
- SoftLayer_Network_Vlan::getScaleVlans
-
getSecondaryRouter
The secondary router that a VLAN is associated with. Every SoftLayer VLAN is connected to more than one router for greater network redundancy. -
getSecondarySubnets
The subnets that exist as secondary interfaces on a VLAN -
getSubnets
All of the subnets that exist as VLAN interfaces.- See Also:
- SoftLayer_Network_Vlan::getSubnets
-
getTagReferences
References to all tags for this VLAN.- See Also:
- SoftLayer_Network_Vlan::getTagReferences
-
getTotalPrimaryIpAddressCount
The number of primary IP addresses in a VLAN. -
getType
The type of this VLAN.- See Also:
- SoftLayer_Network_Vlan::getType
-
getVirtualGuests
All of the Virtual Servers that are connected to a VLAN.- See Also:
- SoftLayer_Network_Vlan::getVirtualGuests
-