Class Usage
java.lang.Object
com.softlayer.api.Type
com.softlayer.api.service.Entity
com.softlayer.api.service.network.bandwidth.Usage
@ApiType("SoftLayer_Network_Bandwidth_Usage") public class Usage extends Entity
The SoftLayer_Network_Bandwidth_Usage data type contains specific information relating to bandwidth utilization at a specific point in time on a given network interface.
- See Also:
- SoftLayer_Network_Bandwidth_Usage
-
Nested Class Summary
Nested Classes Modifier and Type Class Description static classUsage.Mask -
Field Summary
Fields Modifier and Type Field Description protected BigDecimalamountInIncoming bandwidth utilization.protected booleanamountInSpecifiedprotected BigDecimalamountOutOutgoing bandwidth utilization.protected booleanamountOutSpecifiedprotected BigDecimalbandwidthUsageDetailTypeIdID of the bandwidth usage detail type for this record.protected booleanbandwidthUsageDetailTypeIdSpecifiedprotected ObjecttrackingObjectThe tracking object this bandwidth usage record describes.protected TypetypeIn and out bandwidth utilization for a specified time stamp. -
Constructor Summary
Constructors Constructor Description Usage() -
Method Summary
Modifier and Type Method Description BigDecimalgetAmountIn()BigDecimalgetAmountOut()BigDecimalgetBandwidthUsageDetailTypeId()ObjectgetTrackingObject()TypegetType()booleanisAmountInSpecified()booleanisAmountOutSpecified()booleanisBandwidthUsageDetailTypeIdSpecified()voidsetAmountIn(BigDecimal amountIn)voidsetAmountOut(BigDecimal amountOut)voidsetBandwidthUsageDetailTypeId(BigDecimal bandwidthUsageDetailTypeId)voidsetTrackingObject(Object trackingObject)voidsetType(Type type)voidunsetAmountIn()voidunsetAmountOut()voidunsetBandwidthUsageDetailTypeId()
-
Field Details
-
trackingObject
The tracking object this bandwidth usage record describes. -
type
In and out bandwidth utilization for a specified time stamp. -
amountIn
Incoming bandwidth utilization. -
amountInSpecified
protected boolean amountInSpecified -
amountOut
Outgoing bandwidth utilization. -
amountOutSpecified
protected boolean amountOutSpecified -
bandwidthUsageDetailTypeId
ID of the bandwidth usage detail type for this record. -
bandwidthUsageDetailTypeIdSpecified
protected boolean bandwidthUsageDetailTypeIdSpecified
-
-
Constructor Details
-
Usage
public Usage()
-
-
Method Details
-
getTrackingObject
-
setTrackingObject
-
getType
-
setType
-
getAmountIn
-
setAmountIn
-
isAmountInSpecified
public boolean isAmountInSpecified() -
unsetAmountIn
public void unsetAmountIn() -
getAmountOut
-
setAmountOut
-
isAmountOutSpecified
public boolean isAmountOutSpecified() -
unsetAmountOut
public void unsetAmountOut() -
getBandwidthUsageDetailTypeId
-
setBandwidthUsageDetailTypeId
-
isBandwidthUsageDetailTypeIdSpecified
public boolean isBandwidthUsageDetailTypeIdSpecified() -
unsetBandwidthUsageDetailTypeId
public void unsetBandwidthUsageDetailTypeId()
-