Class Interface
java.lang.Object
com.softlayer.api.Type
com.softlayer.api.service.Entity
com.softlayer.api.service.network.bandwidth.version1.Interface
@ApiType("SoftLayer_Network_Bandwidth_Version1_Interface") public class Interface extends Entity
[DEPRECATED] All bandwidth tracking is maintained through the switch that the bandwidth is used through. All bandwidth is stored in a "pod" repository. An interface links the hardware switch with the pod repository identification number. This is only relevant to bandwidth data. It is not common to use this.
-
Nested Class Summary
Nested Classes Modifier and Type Class Description static classInterface.Mask -
Field Summary
Fields Modifier and Type Field Description protected Hosthost[DEPRECATED] The host for an interface.protected LonghostIdA interface's host.protected booleanhostIdSpecifiedprotected ComponentnetworkComponent[DEPRECATED] The switch for an interface.protected LongnetworkComponentIdThe network component for this interface.protected booleannetworkComponentIdSpecified -
Constructor Summary
Constructors Constructor Description Interface() -
Method Summary
Modifier and Type Method Description HostgetHost()LonggetHostId()ComponentgetNetworkComponent()LonggetNetworkComponentId()booleanisHostIdSpecified()booleanisNetworkComponentIdSpecified()voidsetHost(Host host)voidsetHostId(Long hostId)voidsetNetworkComponent(Component networkComponent)voidsetNetworkComponentId(Long networkComponentId)voidunsetHostId()voidunsetNetworkComponentId()
-
Field Details
-
host
[DEPRECATED] The host for an interface. This is not to be confused with SoftLayer Hardware -
networkComponent
[DEPRECATED] The switch for an interface. -
hostId
A interface's host. The host stores the pod number for the bandwidth data. -
hostIdSpecified
protected boolean hostIdSpecified -
networkComponentId
The network component for this interface. -
networkComponentIdSpecified
protected boolean networkComponentIdSpecified
-
-
Constructor Details
-
Interface
public Interface()
-
-
Method Details
-
getHost
-
setHost
-
getNetworkComponent
-
setNetworkComponent
-
getHostId
-
setHostId
-
isHostIdSpecified
public boolean isHostIdSpecified() -
unsetHostId
public void unsetHostId() -
getNetworkComponentId
-
setNetworkComponentId
-
isNetworkComponentIdSpecified
public boolean isNetworkComponentIdSpecified() -
unsetNetworkComponentId
public void unsetNetworkComponentId()
-