Uses of Class
com.softlayer.api.service.network.bandwidth.version1.Interface
| Package | Description |
|---|---|
| com.softlayer.api.service.network |
-
Uses of Interface in com.softlayer.api.service.network
Fields in com.softlayer.api.service.network declared as Interface Modifier and Type Field Description protected InterfaceComponent. componentInterface[DEPRECATED] A hardware switch's interface to the bandwidth pod.Methods in com.softlayer.api.service.network that return Interface Modifier and Type Method Description InterfaceComponent. getComponentInterface()InterfaceComponent.Service. getComponentInterface()[DEPRECATED] A hardware switch's interface to the bandwidth pod.Methods in com.softlayer.api.service.network that return types with arguments of type Interface Modifier and Type Method Description Future<Interface>Component.ServiceAsync. getComponentInterface()Async version ofComponent.Service.getComponentInterface()Methods in com.softlayer.api.service.network with parameters of type Interface Modifier and Type Method Description voidComponent. setComponentInterface(Interface componentInterface)Method parameters in com.softlayer.api.service.network with type arguments of type Interface Modifier and Type Method Description Future<?>Component.ServiceAsync. getComponentInterface(ResponseHandler<Interface> callback)Async callback version ofComponent.Service.getComponentInterface()