Uses of Class
com.softlayer.api.service.network.Component
-
Uses of Component in com.softlayer.api.service
Fields in com.softlayer.api.service declared as Component Modifier and Type Field Description protected ComponentHardware. primaryBackendNetworkComponentInformation regarding the hardware's primary back-end network component.protected ComponentHardware. primaryNetworkComponentInformation regarding the hardware's primary public network component.protected ComponentHardware. remoteManagementComponentA hardware's associated remote management component.Fields in com.softlayer.api.service with type parameters of type Component Modifier and Type Field Description protected List<Component>Hardware. backendNetworkComponentsA piece of hardware's back-end or private network components.protected List<Component>Hardware. frontendNetworkComponentsA piece of hardware's front-end or public network components.protected List<Component>Hardware. networkComponentsReturns a hardware's network components.protected List<Component>Hardware. storageNetworkComponentsA piece of hardware's private storage network components.protected List<Component>Hardware. uplinkNetworkComponentsInformation regarding the network component that is one level higher than a piece of hardware on the network infrastructure.Methods in com.softlayer.api.service that return Component Modifier and Type Method Description ComponentHardware. getPrimaryBackendNetworkComponent()ComponentHardware.Service. getPrimaryBackendNetworkComponent()Information regarding the hardware's primary back-end network component.ComponentHardware. getPrimaryNetworkComponent()ComponentHardware.Service. getPrimaryNetworkComponent()Information regarding the hardware's primary public network component.ComponentHardware. getRemoteManagementComponent()ComponentHardware.Service. getRemoteManagementComponent()A hardware's associated remote management component.Methods in com.softlayer.api.service with parameters of type Component Modifier and Type Method Description voidHardware. setPrimaryBackendNetworkComponent(Component primaryBackendNetworkComponent)voidHardware. setPrimaryNetworkComponent(Component primaryNetworkComponent)voidHardware. setRemoteManagementComponent(Component remoteManagementComponent) -
Uses of Component in com.softlayer.api.service.container.hardware.server
Fields in com.softlayer.api.service.container.hardware.server with type parameters of type Component Modifier and Type Field Description protected List<Component>Details. networkComponentsThe network components that belong to a piece of hardware.Methods in com.softlayer.api.service.container.hardware.server that return types with arguments of type Component Modifier and Type Method Description List<Component>Details. getNetworkComponents() -
Uses of Component in com.softlayer.api.service.hardware
Fields in com.softlayer.api.service.hardware with type parameters of type Component Modifier and Type Field Description protected List<Component>Component. networkComponentsThe components local ethernet and remote management interfacesMethods in com.softlayer.api.service.hardware that return Component Modifier and Type Method Description ComponentServer.Service. getManagementNetworkComponent()Retrieve the remote management network component attached with this server.ComponentServer.Service. getPrivateNetworkComponent()Retrieve the private network component attached with this server.ComponentServer.Service. getPublicNetworkComponent()Retrieve a SoftLayer server's public network component.Methods in com.softlayer.api.service.hardware that return types with arguments of type Component Modifier and Type Method Description Future<Component>Server.ServiceAsync. getManagementNetworkComponent()Async version ofServer.Service.getManagementNetworkComponent()List<Component>Component. getNetworkComponents()Future<Component>Server.ServiceAsync. getPrivateNetworkComponent()Async version ofServer.Service.getPrivateNetworkComponent()Future<Component>Server.ServiceAsync. getPublicNetworkComponent()Async version ofServer.Service.getPublicNetworkComponent()Method parameters in com.softlayer.api.service.hardware with type arguments of type Component Modifier and Type Method Description Future<?>Server.ServiceAsync. getManagementNetworkComponent(ResponseHandler<Component> callback)Future<?>Server.ServiceAsync. getPrivateNetworkComponent(ResponseHandler<Component> callback)Future<?>Server.ServiceAsync. getPublicNetworkComponent(ResponseHandler<Component> callback) -
Uses of Component in com.softlayer.api.service.hardware.component
Fields in com.softlayer.api.service.hardware.component declared as Component Modifier and Type Field Description protected ComponentRemoteManagement. networkComponentA network component data type.Methods in com.softlayer.api.service.hardware.component that return Component Modifier and Type Method Description ComponentRemoteManagement. getNetworkComponent()Methods in com.softlayer.api.service.hardware.component with parameters of type Component Modifier and Type Method Description voidRemoteManagement. setNetworkComponent(Component networkComponent) -
Uses of Component in com.softlayer.api.service.hardware.component.remotemanagement
Fields in com.softlayer.api.service.hardware.component.remotemanagement declared as Component Modifier and Type Field Description protected ComponentUser. networkComponentMethods in com.softlayer.api.service.hardware.component.remotemanagement that return Component Modifier and Type Method Description ComponentUser. getNetworkComponent()Methods in com.softlayer.api.service.hardware.component.remotemanagement with parameters of type Component Modifier and Type Method Description voidUser. setNetworkComponent(Component networkComponent) -
Uses of Component in com.softlayer.api.service.hardware.component.remotemanagement.command
Fields in com.softlayer.api.service.hardware.component.remotemanagement.command declared as Component Modifier and Type Field Description protected ComponentRequest. networkComponentA hardware's network components.Methods in com.softlayer.api.service.hardware.component.remotemanagement.command that return Component Modifier and Type Method Description ComponentRequest. getNetworkComponent()Methods in com.softlayer.api.service.hardware.component.remotemanagement.command with parameters of type Component Modifier and Type Method Description voidRequest. setNetworkComponent(Component networkComponent) -
Uses of Component in com.softlayer.api.service.network
Fields in com.softlayer.api.service.network declared as Component Modifier and Type Field Description protected ComponentComponent. downlinkComponentThe network component linking this object to a child deviceprotected ComponentBackbone. networkComponentA backbone's primary network component.protected ComponentComponent. uplinkComponentThe network component linking this object to parentFields in com.softlayer.api.service.network with type parameters of type Component Modifier and Type Field Description protected List<Component>Vlan. networkComponentsThe networking components that are connected to a VLAN.Methods in com.softlayer.api.service.network that return Component Modifier and Type Method Description ComponentComponent. getDownlinkComponent()ComponentComponent.Service. getDownlinkComponent()The network component linking this object to a child deviceComponentBackbone. getNetworkComponent()ComponentBackbone.Service. getNetworkComponent()A backbone's primary network component.ComponentComponent.Service. getObject()ComponentComponent. getUplinkComponent()ComponentComponent.Service. getUplinkComponent()The network component linking this object to parentMethods in com.softlayer.api.service.network that return types with arguments of type Component Modifier and Type Method Description Future<Component>Component.ServiceAsync. getDownlinkComponent()Async version ofComponent.Service.getDownlinkComponent()Future<Component>Backbone.ServiceAsync. getNetworkComponent()Async version ofBackbone.Service.getNetworkComponent()List<Component>Vlan. getNetworkComponents()List<Component>Vlan.Service. getNetworkComponents()The networking components that are connected to a VLAN.Future<List<Component>>Vlan.ServiceAsync. getNetworkComponents()Async version ofVlan.Service.getNetworkComponents()Future<Component>Component.ServiceAsync. getObject()Async version ofComponent.Service.getObject()Future<Component>Component.ServiceAsync. getUplinkComponent()Async version ofComponent.Service.getUplinkComponent()Methods in com.softlayer.api.service.network with parameters of type Component Modifier and Type Method Description voidComponent. setDownlinkComponent(Component downlinkComponent)voidBackbone. setNetworkComponent(Component networkComponent)voidComponent. setUplinkComponent(Component uplinkComponent)Method parameters in com.softlayer.api.service.network with type arguments of type Component Modifier and Type Method Description Future<?>Component.ServiceAsync. getDownlinkComponent(ResponseHandler<Component> callback)Async callback version ofComponent.Service.getDownlinkComponent()Future<?>Backbone.ServiceAsync. getNetworkComponent(ResponseHandler<Component> callback)Async callback version ofBackbone.Service.getNetworkComponent()Future<?>Vlan.ServiceAsync. getNetworkComponents(ResponseHandler<List<Component>> callback)Async callback version ofVlan.Service.getNetworkComponents()Future<?>Component.ServiceAsync. getObject(ResponseHandler<Component> callback)Future<?>Component.ServiceAsync. getUplinkComponent(ResponseHandler<Component> callback)Async callback version ofComponent.Service.getUplinkComponent() -
Uses of Component in com.softlayer.api.service.network.bandwidth.version1
Fields in com.softlayer.api.service.network.bandwidth.version1 declared as Component Modifier and Type Field Description protected ComponentInterface. networkComponent[DEPRECATED] The switch for an interface.Methods in com.softlayer.api.service.network.bandwidth.version1 that return Component Modifier and Type Method Description ComponentInterface. getNetworkComponent()Methods in com.softlayer.api.service.network.bandwidth.version1 with parameters of type Component Modifier and Type Method Description voidInterface. setNetworkComponent(Component networkComponent) -
Uses of Component in com.softlayer.api.service.network.component
Subclasses of Component in com.softlayer.api.service.network.component Modifier and Type Class Description classRemoteManagementThe SoftLayer_Network_Component_RemoteManagement data type contains general information relating to a single SoftLayer remote management network component.Fields in com.softlayer.api.service.network.component declared as Component Modifier and Type Field Description protected ComponentFirewall. networkComponentThe network component of the switch interface that this network component firewall belongs to.protected ComponentIpAddress. networkComponentThe network component associated with this object's IP address.Fields in com.softlayer.api.service.network.component with type parameters of type Component Modifier and Type Field Description protected List<Component>Group. networkComponentsA network component group's associated network components.Methods in com.softlayer.api.service.network.component that return Component Modifier and Type Method Description ComponentFirewall. getNetworkComponent()ComponentFirewall.Service. getNetworkComponent()The network component of the switch interface that this network component firewall belongs to.ComponentIpAddress. getNetworkComponent()Methods in com.softlayer.api.service.network.component that return types with arguments of type Component Modifier and Type Method Description Future<Component>Firewall.ServiceAsync. getNetworkComponent()Async version ofFirewall.Service.getNetworkComponent()List<Component>Group. getNetworkComponents()Methods in com.softlayer.api.service.network.component with parameters of type Component Modifier and Type Method Description voidFirewall. setNetworkComponent(Component networkComponent)voidIpAddress. setNetworkComponent(Component networkComponent)Method parameters in com.softlayer.api.service.network.component with type arguments of type Component Modifier and Type Method Description Future<?>Firewall.ServiceAsync. getNetworkComponent(ResponseHandler<Component> callback)Async callback version ofFirewall.Service.getNetworkComponent() -
Uses of Component in com.softlayer.api.service.network.component.network.vlan
Fields in com.softlayer.api.service.network.component.network.vlan declared as Component Modifier and Type Field Description protected ComponentTrunk. networkComponentThe network component that the VLAN is being trunked to.Methods in com.softlayer.api.service.network.component.network.vlan that return Component Modifier and Type Method Description ComponentTrunk. getNetworkComponent()Methods in com.softlayer.api.service.network.component.network.vlan with parameters of type Component Modifier and Type Method Description voidTrunk. setNetworkComponent(Component networkComponent) -
Uses of Component in com.softlayer.api.service.network.component.uplink
Fields in com.softlayer.api.service.network.component.uplink declared as Component Modifier and Type Field Description protected ComponentHardware. networkComponentThe [[SoftLayer_Network_Component|Network Component]] that a uplink connection belongs to..Methods in com.softlayer.api.service.network.component.uplink that return Component Modifier and Type Method Description ComponentHardware. getNetworkComponent()Methods in com.softlayer.api.service.network.component.uplink with parameters of type Component Modifier and Type Method Description voidHardware. setNetworkComponent(Component networkComponent) -
Uses of Component in com.softlayer.api.service.network.subnet
Fields in com.softlayer.api.service.network.subnet declared as Component Modifier and Type Field Description protected ComponentIpAddress. networkComponentA network component that is statically routed to an IP address.protected ComponentIpAddress. remoteManagementNetworkComponentAn IPMI-based management network component of the IP address.Methods in com.softlayer.api.service.network.subnet that return Component Modifier and Type Method Description ComponentIpAddress. getNetworkComponent()ComponentIpAddress.Service. getNetworkComponent()A network component that is statically routed to an IP address.ComponentIpAddress. getRemoteManagementNetworkComponent()ComponentIpAddress.Service. getRemoteManagementNetworkComponent()An IPMI-based management network component of the IP address.Methods in com.softlayer.api.service.network.subnet that return types with arguments of type Component Modifier and Type Method Description Future<Component>IpAddress.ServiceAsync. getNetworkComponent()Async version ofIpAddress.Service.getNetworkComponent()Future<Component>IpAddress.ServiceAsync. getRemoteManagementNetworkComponent()Async version ofIpAddress.Service.getRemoteManagementNetworkComponent()Methods in com.softlayer.api.service.network.subnet with parameters of type Component Modifier and Type Method Description voidIpAddress. setNetworkComponent(Component networkComponent)voidIpAddress. setRemoteManagementNetworkComponent(Component remoteManagementNetworkComponent)Method parameters in com.softlayer.api.service.network.subnet with type arguments of type Component Modifier and Type Method Description Future<?>IpAddress.ServiceAsync. getNetworkComponent(ResponseHandler<Component> callback)Async callback version ofIpAddress.Service.getNetworkComponent()Future<?>IpAddress.ServiceAsync. getRemoteManagementNetworkComponent(ResponseHandler<Component> callback)Async callback version ofIpAddress.Service.getRemoteManagementNetworkComponent()