Uses of Class
com.softlayer.api.service.network.Pod
| Package | Description |
|---|---|
| com.softlayer.api.service.network |
-
Uses of Pod in com.softlayer.api.service.network
Methods in com.softlayer.api.service.network that return Pod Modifier and Type Method Description PodPod.Service. getObject()Set the initialization parameter to the ``name`` of the Pod to retrieve.Methods in com.softlayer.api.service.network that return types with arguments of type Pod Modifier and Type Method Description List<Pod>Pod.Service. getAllObjects()Filtering is supported for ``datacenterName`` and ``capabilities``.Future<List<Pod>>Pod.ServiceAsync. getAllObjects()Async version ofPod.Service.getAllObjects()Future<Pod>Pod.ServiceAsync. getObject()Async version ofPod.Service.getObject()Method parameters in com.softlayer.api.service.network with type arguments of type Pod Modifier and Type Method Description Future<?>Pod.ServiceAsync. getAllObjects(ResponseHandler<List<Pod>> callback)Future<?>Pod.ServiceAsync. getObject(ResponseHandler<Pod> callback)