Uses of Class
com.softlayer.api.service.network.SecurityGroup
-
Uses of SecurityGroup in com.softlayer.api.service
Fields in com.softlayer.api.service with type parameters of type SecurityGroup Modifier and Type Field Description protected List<SecurityGroup>Account. securityGroupsThe security groups belonging to this account.Methods in com.softlayer.api.service that return types with arguments of type SecurityGroup Modifier and Type Method Description List<SecurityGroup>Account. getSecurityGroups()List<SecurityGroup>Account.Service. getSecurityGroups()The security groups belonging to this account.Future<List<SecurityGroup>>Account.ServiceAsync. getSecurityGroups()Async version ofAccount.Service.getSecurityGroups()Method parameters in com.softlayer.api.service with type arguments of type SecurityGroup Modifier and Type Method Description Future<?>Account.ServiceAsync. getSecurityGroups(ResponseHandler<List<SecurityGroup>> callback)Async callback version ofAccount.Service.getSecurityGroups() -
Uses of SecurityGroup in com.softlayer.api.service.network
Methods in com.softlayer.api.service.network that return SecurityGroup Modifier and Type Method Description SecurityGroupSecurityGroup.Service. createObject(SecurityGroup templateObject)Create a new security group.SecurityGroupSecurityGroup.Service. getObject()Methods in com.softlayer.api.service.network that return types with arguments of type SecurityGroup Modifier and Type Method Description Future<SecurityGroup>SecurityGroup.ServiceAsync. createObject(SecurityGroup templateObject)List<SecurityGroup>SecurityGroup.Service. createObjects(List<SecurityGroup> templateObjects)Create new security groups.Future<List<SecurityGroup>>SecurityGroup.ServiceAsync. createObjects(List<SecurityGroup> templateObjects)List<SecurityGroup>SecurityGroup.Service. getAllObjects()Future<List<SecurityGroup>>SecurityGroup.ServiceAsync. getAllObjects()Async version ofSecurityGroup.Service.getAllObjects()Future<SecurityGroup>SecurityGroup.ServiceAsync. getObject()Async version ofSecurityGroup.Service.getObject()Methods in com.softlayer.api.service.network with parameters of type SecurityGroup Modifier and Type Method Description SecurityGroupSecurityGroup.Service. createObject(SecurityGroup templateObject)Create a new security group.Future<SecurityGroup>SecurityGroup.ServiceAsync. createObject(SecurityGroup templateObject)Future<?>SecurityGroup.ServiceAsync. createObject(SecurityGroup templateObject, ResponseHandler<SecurityGroup> callback)BooleanSecurityGroup.Service. editObject(SecurityGroup templateObject)Edit a security group.Future<Boolean>SecurityGroup.ServiceAsync. editObject(SecurityGroup templateObject)Future<?>SecurityGroup.ServiceAsync. editObject(SecurityGroup templateObject, ResponseHandler<Boolean> callback)Method parameters in com.softlayer.api.service.network with type arguments of type SecurityGroup Modifier and Type Method Description Future<?>SecurityGroup.ServiceAsync. createObject(SecurityGroup templateObject, ResponseHandler<SecurityGroup> callback)List<SecurityGroup>SecurityGroup.Service. createObjects(List<SecurityGroup> templateObjects)Create new security groups.Future<List<SecurityGroup>>SecurityGroup.ServiceAsync. createObjects(List<SecurityGroup> templateObjects)Future<?>SecurityGroup.ServiceAsync. createObjects(List<SecurityGroup> templateObjects, ResponseHandler<List<SecurityGroup>> callback)Future<?>SecurityGroup.ServiceAsync. createObjects(List<SecurityGroup> templateObjects, ResponseHandler<List<SecurityGroup>> callback)BooleanSecurityGroup.Service. deleteObjects(List<SecurityGroup> templateObjects)Delete security groups for an account.Future<Boolean>SecurityGroup.ServiceAsync. deleteObjects(List<SecurityGroup> templateObjects)Future<?>SecurityGroup.ServiceAsync. deleteObjects(List<SecurityGroup> templateObjects, ResponseHandler<Boolean> callback)BooleanSecurityGroup.Service. editObjects(List<SecurityGroup> templateObjects)Edit security groups.Future<Boolean>SecurityGroup.ServiceAsync. editObjects(List<SecurityGroup> templateObjects)Future<?>SecurityGroup.ServiceAsync. editObjects(List<SecurityGroup> templateObjects, ResponseHandler<Boolean> callback)Future<?>SecurityGroup.ServiceAsync. getAllObjects(ResponseHandler<List<SecurityGroup>> callback)Future<?>SecurityGroup.ServiceAsync. getObject(ResponseHandler<SecurityGroup> callback) -
Uses of SecurityGroup in com.softlayer.api.service.network.securitygroup
Fields in com.softlayer.api.service.network.securitygroup declared as SecurityGroup Modifier and Type Field Description protected SecurityGroupRule. remoteGroupThe remote security group allowed as part of this rule.protected SecurityGroupOrderBinding. securityGroupThe security group associated with the orderprotected SecurityGroupRule. securityGroupThe security group of this rule.Methods in com.softlayer.api.service.network.securitygroup that return SecurityGroup Modifier and Type Method Description SecurityGroupRule. getRemoteGroup()SecurityGroupOrderBinding. getSecurityGroup()SecurityGroupRule. getSecurityGroup()Methods in com.softlayer.api.service.network.securitygroup with parameters of type SecurityGroup Modifier and Type Method Description voidRule. setRemoteGroup(SecurityGroup remoteGroup)voidOrderBinding. setSecurityGroup(SecurityGroup securityGroup)voidRule. setSecurityGroup(SecurityGroup securityGroup) -
Uses of SecurityGroup in com.softlayer.api.service.virtual.network.securitygroup
Fields in com.softlayer.api.service.virtual.network.securitygroup declared as SecurityGroup Modifier and Type Field Description protected SecurityGroupNetworkComponentBinding. securityGroupMethods in com.softlayer.api.service.virtual.network.securitygroup that return SecurityGroup Modifier and Type Method Description SecurityGroupNetworkComponentBinding. getSecurityGroup()Methods in com.softlayer.api.service.virtual.network.securitygroup with parameters of type SecurityGroup Modifier and Type Method Description voidNetworkComponentBinding. setSecurityGroup(SecurityGroup securityGroup)