Uses of Class
com.softlayer.api.service.network.Subnet
-
Uses of Subnet in com.softlayer.api.service
Fields in com.softlayer.api.service with type parameters of type Subnet Modifier and Type Field Description protected List<Subnet>Account. privateSubnetsAll private subnets associated with an account.protected List<Subnet>Account. publicSubnetsAll public network subnets associated with an account.protected List<Subnet>Account. subnetsAll network subnets associated with an account.Methods in com.softlayer.api.service that return types with arguments of type Subnet Modifier and Type Method Description List<Subnet>Account. getPrivateSubnets()List<Subnet>Account.Service. getPrivateSubnets()All private subnets associated with an account.Future<List<Subnet>>Account.ServiceAsync. getPrivateSubnets()Async version ofAccount.Service.getPrivateSubnets()List<Subnet>Account. getPublicSubnets()List<Subnet>Account.Service. getPublicSubnets()All public network subnets associated with an account.Future<List<Subnet>>Account.ServiceAsync. getPublicSubnets()Async version ofAccount.Service.getPublicSubnets()List<Subnet>Account. getSubnets()List<Subnet>Account.Service. getSubnets()All network subnets associated with an account.Future<List<Subnet>>Account.ServiceAsync. getSubnets()Async version ofAccount.Service.getSubnets()Method parameters in com.softlayer.api.service with type arguments of type Subnet Modifier and Type Method Description Future<?>Account.ServiceAsync. getPrivateSubnets(ResponseHandler<List<Subnet>> callback)Async callback version ofAccount.Service.getPrivateSubnets()Future<?>Account.ServiceAsync. getPublicSubnets(ResponseHandler<List<Subnet>> callback)Async callback version ofAccount.Service.getPublicSubnets()Future<?>Account.ServiceAsync. getSubnets(ResponseHandler<List<Subnet>> callback)Async callback version ofAccount.Service.getSubnets() -
Uses of Subnet in com.softlayer.api.service.billing.item.network
Fields in com.softlayer.api.service.billing.item.network declared as Subnet Modifier and Type Field Description protected SubnetSubnet. resourceThe resource for a subnet-related billing item.Methods in com.softlayer.api.service.billing.item.network that return Subnet Modifier and Type Method Description SubnetSubnet. getResource()Methods in com.softlayer.api.service.billing.item.network with parameters of type Subnet Modifier and Type Method Description voidSubnet. setResource(Subnet resource) -
Uses of Subnet in com.softlayer.api.service.container.product.order.network.loadbalancer
Fields in com.softlayer.api.service.container.product.order.network.loadbalancer with type parameters of type Subnet Modifier and Type Field Description protected List<Subnet>AsAService. publicSubnetsSpecify the public subnet where this load balancer will be provisioned when useSystemPublicIpPool is false.protected List<Subnet>AsAService. subnetsThe [[SoftLayer_Network_Subnet]]s where this Load Balancer will be provisioned.Methods in com.softlayer.api.service.container.product.order.network.loadbalancer that return types with arguments of type Subnet Modifier and Type Method Description List<Subnet>AsAService. getPublicSubnets()List<Subnet>AsAService. getSubnets() -
Uses of Subnet in com.softlayer.api.service.hardware
Fields in com.softlayer.api.service.hardware with type parameters of type Subnet Modifier and Type Field Description protected List<Subnet>Router. boundSubnetsAssociated subnets for a router object.Methods in com.softlayer.api.service.hardware that return types with arguments of type Subnet Modifier and Type Method Description List<Subnet>Router. getBoundSubnets()List<Subnet>Router.Service. getBoundSubnets()Associated subnets for a router object.Future<List<Subnet>>Router.ServiceAsync. getBoundSubnets()Async version ofRouter.Service.getBoundSubnets()List<Subnet>Server.Service. getFirewallProtectableSubnets()Get the subnets associated with this server that are protectable by a network component firewall.Future<List<Subnet>>Server.ServiceAsync. getFirewallProtectableSubnets()Async version ofServer.Service.getFirewallProtectableSubnets()Method parameters in com.softlayer.api.service.hardware with type arguments of type Subnet Modifier and Type Method Description Future<?>Router.ServiceAsync. getBoundSubnets(ResponseHandler<List<Subnet>> callback)Async callback version ofRouter.Service.getBoundSubnets()Future<?>Server.ServiceAsync. getFirewallProtectableSubnets(ResponseHandler<List<Subnet>> callback) -
Uses of Subnet in com.softlayer.api.service.location
Fields in com.softlayer.api.service.location with type parameters of type Subnet Modifier and Type Field Description protected List<Subnet>Datacenter. boundSubnetsSubnets which are directly bound to one or more routers in a given datacenter, and currently allow routing.protected List<Subnet>Datacenter. routableBoundSubnetsRetrieve all subnets that are eligible to be routed; those which the account has permission to associate with a vlan.Methods in com.softlayer.api.service.location that return types with arguments of type Subnet Modifier and Type Method Description List<Subnet>Datacenter. getBoundSubnets()List<Subnet>Datacenter.Service. getBoundSubnets()Subnets which are directly bound to one or more routers in a given datacenter, and currently allow routing.Future<List<Subnet>>Datacenter.ServiceAsync. getBoundSubnets()Async version ofDatacenter.Service.getBoundSubnets()List<Subnet>Datacenter. getRoutableBoundSubnets()List<Subnet>Datacenter.Service. getRoutableBoundSubnets()Retrieve all subnets that are eligible to be routed; those which the account has permission to associate with a vlan.Future<List<Subnet>>Datacenter.ServiceAsync. getRoutableBoundSubnets()Async version ofDatacenter.Service.getRoutableBoundSubnets()Method parameters in com.softlayer.api.service.location with type arguments of type Subnet Modifier and Type Method Description Future<?>Datacenter.ServiceAsync. getBoundSubnets(ResponseHandler<List<Subnet>> callback)Async callback version ofDatacenter.Service.getBoundSubnets()Future<?>Datacenter.ServiceAsync. getRoutableBoundSubnets(ResponseHandler<List<Subnet>> callback)Async callback version ofDatacenter.Service.getRoutableBoundSubnets() -
Uses of Subnet in com.softlayer.api.service.network
Fields in com.softlayer.api.service.network declared as Subnet Modifier and Type Field Description protected SubnetComponent. primarySubnetThe subnet of the primary IP address assigned to this network component.protected SubnetVlan. primarySubnetA VLAN's primary subnet.protected SubnetVlan. primarySubnetVersion6A VLAN's primary IPv6 subnet.Fields in com.softlayer.api.service.network with type parameters of type Subnet Modifier and Type Field Description protected List<Subnet>Vlan. additionalPrimarySubnetsA VLAN's additional primary subnets.protected List<Subnet>Storage. allowedReplicationSubnetsThe SoftLayer_Network_Subnet objects which are allowed access to this storage volume's Replicant.protected List<Subnet>Storage. allowedSubnetsThe SoftLayer_Network_Subnet objects which are allowed access to this storage volume.protected List<Subnet>Subnet. boundDescendantsprotected List<Subnet>Subnet. childrenprotected List<Subnet>Subnet. descendantsprotected List<Subnet>Vlan. primarySubnetsprotected List<Subnet>Vlan. secondarySubnetsThe subnets that exist as secondary interfaces on a VLANprotected List<Subnet>Component. subnetsA network component's subnets.protected List<Subnet>Vlan. subnetsAll of the subnets that exist as VLAN interfaces.protected List<Subnet>Subnet. unboundDescendantsMethods in com.softlayer.api.service.network that return Subnet Modifier and Type Method Description SubnetSubnet.Service. getObject()getObject retrieves the SoftLayer_Network_Subnet object whose ID number corresponds to the ID number of the init parameter passed to the SoftLayer_Network_Subnet service.SubnetComponent. getPrimarySubnet()SubnetComponent.Service. getPrimarySubnet()The subnet of the primary IP address assigned to this network component.SubnetVlan. getPrimarySubnet()SubnetVlan.Service. getPrimarySubnet()A VLAN's primary subnet.SubnetVlan. getPrimarySubnetVersion6()SubnetVlan.Service. getPrimarySubnetVersion6()A VLAN's primary IPv6 subnet.SubnetSubnet.Service. getSubnetForIpAddress(String ipAddress)Retrieve the subnet associated with an IP address.Methods in com.softlayer.api.service.network with parameters of type Subnet Modifier and Type Method Description BooleanStorage.Service. allowAccessFromSubnet(Subnet subnetObjectTemplate)This method is used to modify the access control list for this Storage volume.Future<Boolean>Storage.ServiceAsync. allowAccessFromSubnet(Subnet subnetObjectTemplate)Future<?>Storage.ServiceAsync. allowAccessFromSubnet(Subnet subnetObjectTemplate, ResponseHandler<Boolean> callback)BooleanStorage.Service. allowAccessToReplicantFromSubnet(Subnet subnetObjectTemplate)This method is used to modify the access control list for this Storage replicant volume.Future<Boolean>Storage.ServiceAsync. allowAccessToReplicantFromSubnet(Subnet subnetObjectTemplate)Future<?>Storage.ServiceAsync. allowAccessToReplicantFromSubnet(Subnet subnetObjectTemplate, ResponseHandler<Boolean> callback)BooleanStorage.Service. removeAccessFromSubnet(Subnet subnetObjectTemplate)Future<Boolean>Storage.ServiceAsync. removeAccessFromSubnet(Subnet subnetObjectTemplate)Future<?>Storage.ServiceAsync. removeAccessFromSubnet(Subnet subnetObjectTemplate, ResponseHandler<Boolean> callback)BooleanStorage.Service. removeAccessToReplicantFromSubnet(Subnet subnetObjectTemplate)Future<Boolean>Storage.ServiceAsync. removeAccessToReplicantFromSubnet(Subnet subnetObjectTemplate)Future<?>Storage.ServiceAsync. removeAccessToReplicantFromSubnet(Subnet subnetObjectTemplate, ResponseHandler<Boolean> callback)voidComponent. setPrimarySubnet(Subnet primarySubnet)voidVlan. setPrimarySubnet(Subnet primarySubnet)voidVlan. setPrimarySubnetVersion6(Subnet primarySubnetVersion6) -
Uses of Subnet in com.softlayer.api.service.network.application.delivery
Fields in com.softlayer.api.service.network.application.delivery with type parameters of type Subnet Modifier and Type Field Description protected List<Subnet>Controller. subnetsA network application controller's subnets.Methods in com.softlayer.api.service.network.application.delivery that return types with arguments of type Subnet Modifier and Type Method Description List<Subnet>Controller. getSubnets()List<Subnet>Controller.Service. getSubnets()A network application controller's subnets.Future<List<Subnet>>Controller.ServiceAsync. getSubnets()Async version ofController.Service.getSubnets()Method parameters in com.softlayer.api.service.network.application.delivery with type arguments of type Subnet Modifier and Type Method Description Future<?>Controller.ServiceAsync. getSubnets(ResponseHandler<List<Subnet>> callback)Async callback version ofController.Service.getSubnets() -
Uses of Subnet in com.softlayer.api.service.network.component
Fields in com.softlayer.api.service.network.component with type parameters of type Subnet Modifier and Type Field Description protected List<Subnet>Firewall. applyServerRuleSubnetsThe additional subnets linked to this network component firewall, that inherit rules from the host that the context slot is attached to.protected List<Subnet>Firewall. subnetsThe additional subnets linked to this network component firewall.Methods in com.softlayer.api.service.network.component that return types with arguments of type Subnet Modifier and Type Method Description List<Subnet>Firewall. getApplyServerRuleSubnets()List<Subnet>Firewall.Service. getApplyServerRuleSubnets()The additional subnets linked to this network component firewall, that inherit rules from the host that the context slot is attached to.Future<List<Subnet>>Firewall.ServiceAsync. getApplyServerRuleSubnets()Async version ofFirewall.Service.getApplyServerRuleSubnets()List<Subnet>Firewall. getSubnets()List<Subnet>Firewall.Service. getSubnets()The additional subnets linked to this network component firewall.Future<List<Subnet>>Firewall.ServiceAsync. getSubnets()Async version ofFirewall.Service.getSubnets()Method parameters in com.softlayer.api.service.network.component with type arguments of type Subnet Modifier and Type Method Description Future<?>Firewall.ServiceAsync. getApplyServerRuleSubnets(ResponseHandler<List<Subnet>> callback)Async callback version ofFirewall.Service.getApplyServerRuleSubnets()Future<?>Firewall.ServiceAsync. getSubnets(ResponseHandler<List<Subnet>> callback)Async callback version ofFirewall.Service.getSubnets() -
Uses of Subnet in com.softlayer.api.service.network.component.firewall
Fields in com.softlayer.api.service.network.component.firewall declared as Subnet Modifier and Type Field Description protected SubnetSubnets. subnetThe subnet that this link binds to the network component firewall.Methods in com.softlayer.api.service.network.component.firewall that return Subnet Modifier and Type Method Description SubnetSubnets. getSubnet()Methods in com.softlayer.api.service.network.component.firewall with parameters of type Subnet Modifier and Type Method Description voidSubnets. setSubnet(Subnet subnet) -
Uses of Subnet in com.softlayer.api.service.network.protection
Fields in com.softlayer.api.service.network.protection declared as Subnet Modifier and Type Field Description protected SubnetAddress. subnetMethods in com.softlayer.api.service.network.protection that return Subnet Modifier and Type Method Description SubnetAddress. getSubnet()Methods in com.softlayer.api.service.network.protection with parameters of type Subnet Modifier and Type Method Description voidAddress. setSubnet(Subnet subnet) -
Uses of Subnet in com.softlayer.api.service.network.service.vpn
Fields in com.softlayer.api.service.network.service.vpn declared as Subnet Modifier and Type Field Description protected SubnetOverrides. subnetSubnet components accessible by a SoftLayer VPN portal user.Methods in com.softlayer.api.service.network.service.vpn that return Subnet Modifier and Type Method Description SubnetOverrides. getSubnet()SubnetOverrides.Service. getSubnet()Subnet components accessible by a SoftLayer VPN portal user.Methods in com.softlayer.api.service.network.service.vpn that return types with arguments of type Subnet Modifier and Type Method Description Future<Subnet>Overrides.ServiceAsync. getSubnet()Async version ofOverrides.Service.getSubnet()Methods in com.softlayer.api.service.network.service.vpn with parameters of type Subnet Modifier and Type Method Description voidOverrides. setSubnet(Subnet subnet)Method parameters in com.softlayer.api.service.network.service.vpn with type arguments of type Subnet Modifier and Type Method Description Future<?>Overrides.ServiceAsync. getSubnet(ResponseHandler<Subnet> callback)Async callback version ofOverrides.Service.getSubnet() -
Uses of Subnet in com.softlayer.api.service.network.storage.allowed
Fields in com.softlayer.api.service.network.storage.allowed with type parameters of type Subnet Modifier and Type Field Description protected List<Subnet>Host. subnetsInAclThe SoftLayer_Network_Subnet records assigned to the ACL for this allowed host.Methods in com.softlayer.api.service.network.storage.allowed that return types with arguments of type Subnet Modifier and Type Method Description List<Subnet>Host. getSubnetsInAcl()List<Subnet>Host.Service. getSubnetsInAcl()The SoftLayer_Network_Subnet records assigned to the ACL for this allowed host.Future<List<Subnet>>Host.ServiceAsync. getSubnetsInAcl()Async version ofHost.Service.getSubnetsInAcl()Method parameters in com.softlayer.api.service.network.storage.allowed with type arguments of type Subnet Modifier and Type Method Description Future<?>Host.ServiceAsync. getSubnetsInAcl(ResponseHandler<List<Subnet>> callback)Async callback version ofHost.Service.getSubnetsInAcl() -
Uses of Subnet in com.softlayer.api.service.network.storage.allowed.host
Fields in com.softlayer.api.service.network.storage.allowed.host declared as Subnet Modifier and Type Field Description protected SubnetSubnet. resourceThe SoftLayer_Network_Subnet object which this SoftLayer_Network_Storage_Allowed_Host is referencing.Methods in com.softlayer.api.service.network.storage.allowed.host that return Subnet Modifier and Type Method Description SubnetSubnet. getResource()SubnetSubnet.Service. getResource()The SoftLayer_Network_Subnet object which this SoftLayer_Network_Storage_Allowed_Host is referencing.Methods in com.softlayer.api.service.network.storage.allowed.host that return types with arguments of type Subnet Modifier and Type Method Description Future<Subnet>Subnet.ServiceAsync. getResource()Async version ofSubnet.Service.getResource()Methods in com.softlayer.api.service.network.storage.allowed.host with parameters of type Subnet Modifier and Type Method Description voidSubnet. setResource(Subnet resource)Method parameters in com.softlayer.api.service.network.storage.allowed.host with type arguments of type Subnet Modifier and Type Method Description Future<?>Subnet.ServiceAsync. getResource(ResponseHandler<Subnet> callback)Async callback version ofSubnet.Service.getResource() -
Uses of Subnet in com.softlayer.api.service.network.subnet
Fields in com.softlayer.api.service.network.subnet declared as Subnet Modifier and Type Field Description protected SubnetIpAddress. subnetAn IP address' associated subnet.protected SubnetRegistration. subnetThe subnet that this registration pertains to.Fields in com.softlayer.api.service.network.subnet with type parameters of type Subnet Modifier and Type Field Description protected List<Subnet>IpAddress. endpointSubnetsAll the subnets routed to an IP address.Methods in com.softlayer.api.service.network.subnet that return Subnet Modifier and Type Method Description SubnetIpAddress. getSubnet()SubnetIpAddress.Service. getSubnet()An IP address' associated subnet.SubnetRegistration. getSubnet()SubnetRegistration.Service. getSubnet()The subnet that this registration pertains to.Methods in com.softlayer.api.service.network.subnet that return types with arguments of type Subnet Modifier and Type Method Description List<Subnet>IpAddress. getEndpointSubnets()List<Subnet>IpAddress.Service. getEndpointSubnets()All the subnets routed to an IP address.Future<List<Subnet>>IpAddress.ServiceAsync. getEndpointSubnets()Async version ofIpAddress.Service.getEndpointSubnets()Future<Subnet>IpAddress.ServiceAsync. getSubnet()Async version ofIpAddress.Service.getSubnet()Future<Subnet>Registration.ServiceAsync. getSubnet()Async version ofRegistration.Service.getSubnet()Methods in com.softlayer.api.service.network.subnet with parameters of type Subnet Modifier and Type Method Description voidIpAddress. setSubnet(Subnet subnet)voidRegistration. setSubnet(Subnet subnet)Method parameters in com.softlayer.api.service.network.subnet with type arguments of type Subnet Modifier and Type Method Description Future<?>IpAddress.ServiceAsync. getEndpointSubnets(ResponseHandler<List<Subnet>> callback)Async callback version ofIpAddress.Service.getEndpointSubnets()Future<?>IpAddress.ServiceAsync. getSubnet(ResponseHandler<Subnet> callback)Async callback version ofIpAddress.Service.getSubnet()Future<?>Registration.ServiceAsync. getSubnet(ResponseHandler<Subnet> callback)Async callback version ofRegistration.Service.getSubnet() -
Uses of Subnet in com.softlayer.api.service.network.subnet.swip
Fields in com.softlayer.api.service.network.subnet.swip declared as Subnet Modifier and Type Field Description protected SubnetTransaction. subnetThe subnet that this SWIP transaction was created for.Methods in com.softlayer.api.service.network.subnet.swip that return Subnet Modifier and Type Method Description SubnetTransaction. getSubnet()SubnetTransaction.Service. getSubnet()The subnet that this SWIP transaction was created for.Methods in com.softlayer.api.service.network.subnet.swip that return types with arguments of type Subnet Modifier and Type Method Description Future<Subnet>Transaction.ServiceAsync. getSubnet()Async version ofTransaction.Service.getSubnet()Methods in com.softlayer.api.service.network.subnet.swip with parameters of type Subnet Modifier and Type Method Description voidTransaction. setSubnet(Subnet subnet)Method parameters in com.softlayer.api.service.network.subnet.swip with type arguments of type Subnet Modifier and Type Method Description Future<?>Transaction.ServiceAsync. getSubnet(ResponseHandler<Subnet> callback)Async callback version ofTransaction.Service.getSubnet() -
Uses of Subnet in com.softlayer.api.service.network.tunnel.module
Fields in com.softlayer.api.service.network.tunnel.module with type parameters of type Subnet Modifier and Type Field Description protected List<Subnet>Context. allAvailableServiceSubnetsSubnets that provide access to SoftLayer services such as the management portal and the SoftLayer API.protected List<Subnet>Context. internalSubnetsPrivate subnets that can be accessed through the network tunnel.protected List<Subnet>Context. serviceSubnetsService subnets that can be access through the network tunnel.protected List<Subnet>Context. staticRouteSubnetsSubnets used for a network tunnel's address translations.Methods in com.softlayer.api.service.network.tunnel.module that return types with arguments of type Subnet Modifier and Type Method Description List<Subnet>Context. getAllAvailableServiceSubnets()List<Subnet>Context.Service. getAllAvailableServiceSubnets()Subnets that provide access to SoftLayer services such as the management portal and the SoftLayer API.Future<List<Subnet>>Context.ServiceAsync. getAllAvailableServiceSubnets()Async version ofContext.Service.getAllAvailableServiceSubnets()List<Subnet>Context. getInternalSubnets()List<Subnet>Context.Service. getInternalSubnets()Private subnets that can be accessed through the network tunnel.Future<List<Subnet>>Context.ServiceAsync. getInternalSubnets()Async version ofContext.Service.getInternalSubnets()List<Subnet>Context. getServiceSubnets()List<Subnet>Context.Service. getServiceSubnets()Service subnets that can be access through the network tunnel.Future<List<Subnet>>Context.ServiceAsync. getServiceSubnets()Async version ofContext.Service.getServiceSubnets()List<Subnet>Context. getStaticRouteSubnets()List<Subnet>Context.Service. getStaticRouteSubnets()Subnets used for a network tunnel's address translations.Future<List<Subnet>>Context.ServiceAsync. getStaticRouteSubnets()Async version ofContext.Service.getStaticRouteSubnets()Method parameters in com.softlayer.api.service.network.tunnel.module with type arguments of type Subnet Modifier and Type Method Description Future<?>Context.ServiceAsync. getAllAvailableServiceSubnets(ResponseHandler<List<Subnet>> callback)Async callback version ofContext.Service.getAllAvailableServiceSubnets()Future<?>Context.ServiceAsync. getInternalSubnets(ResponseHandler<List<Subnet>> callback)Async callback version ofContext.Service.getInternalSubnets()Future<?>Context.ServiceAsync. getServiceSubnets(ResponseHandler<List<Subnet>> callback)Async callback version ofContext.Service.getServiceSubnets()Future<?>Context.ServiceAsync. getStaticRouteSubnets(ResponseHandler<List<Subnet>> callback)Async callback version ofContext.Service.getStaticRouteSubnets() -
Uses of Subnet in com.softlayer.api.service.resource.group.member.network
Fields in com.softlayer.api.service.resource.group.member.network declared as Subnet Modifier and Type Field Description protected SubnetSubnet. resourceA resource group member's associated network subnet.Methods in com.softlayer.api.service.resource.group.member.network that return Subnet Modifier and Type Method Description SubnetSubnet. getResource()Methods in com.softlayer.api.service.resource.group.member.network with parameters of type Subnet Modifier and Type Method Description voidSubnet. setResource(Subnet resource) -
Uses of Subnet in com.softlayer.api.service.software
Fields in com.softlayer.api.service.software declared as Subnet Modifier and Type Field Description protected SubnetVirtualLicense. subnetThe subnet this Virtual License's IP address belongs to.Methods in com.softlayer.api.service.software that return Subnet Modifier and Type Method Description SubnetVirtualLicense. getSubnet()SubnetVirtualLicense.Service. getSubnet()The subnet this Virtual License's IP address belongs to.Methods in com.softlayer.api.service.software that return types with arguments of type Subnet Modifier and Type Method Description Future<Subnet>VirtualLicense.ServiceAsync. getSubnet()Async version ofVirtualLicense.Service.getSubnet()Methods in com.softlayer.api.service.software with parameters of type Subnet Modifier and Type Method Description voidVirtualLicense. setSubnet(Subnet subnet)Method parameters in com.softlayer.api.service.software with type arguments of type Subnet Modifier and Type Method Description Future<?>VirtualLicense.ServiceAsync. getSubnet(ResponseHandler<Subnet> callback)Async callback version ofVirtualLicense.Service.getSubnet() -
Uses of Subnet in com.softlayer.api.service.virtual
Methods in com.softlayer.api.service.virtual that return types with arguments of type Subnet Modifier and Type Method Description List<Subnet>Guest.Service. getFirewallProtectableSubnets()Get the subnets associated with this CloudLayer computing instance that are protectable by a network component firewall.Future<List<Subnet>>Guest.ServiceAsync. getFirewallProtectableSubnets()Async version ofGuest.Service.getFirewallProtectableSubnets()Method parameters in com.softlayer.api.service.virtual with type arguments of type Subnet Modifier and Type Method Description Future<?>Guest.ServiceAsync. getFirewallProtectableSubnets(ResponseHandler<List<Subnet>> callback) -
Uses of Subnet in com.softlayer.api.service.virtual.guest.network
Fields in com.softlayer.api.service.virtual.guest.network declared as Subnet Modifier and Type Field Description protected SubnetComponent. primarySubnetA network component's subnet for its primary IP addressFields in com.softlayer.api.service.virtual.guest.network with type parameters of type Subnet Modifier and Type Field Description protected List<Subnet>Component. subnetsA network component's subnets.Methods in com.softlayer.api.service.virtual.guest.network that return Subnet Modifier and Type Method Description SubnetComponent. getPrimarySubnet()SubnetComponent.Service. getPrimarySubnet()A network component's subnet for its primary IP addressMethods in com.softlayer.api.service.virtual.guest.network that return types with arguments of type Subnet Modifier and Type Method Description Future<Subnet>Component.ServiceAsync. getPrimarySubnet()Async version ofComponent.Service.getPrimarySubnet()List<Subnet>Component. getSubnets()List<Subnet>Component.Service. getSubnets()A network component's subnets.Future<List<Subnet>>Component.ServiceAsync. getSubnets()Async version ofComponent.Service.getSubnets()Methods in com.softlayer.api.service.virtual.guest.network with parameters of type Subnet Modifier and Type Method Description voidComponent. setPrimarySubnet(Subnet primarySubnet)Method parameters in com.softlayer.api.service.virtual.guest.network with type arguments of type Subnet Modifier and Type Method Description Future<?>Component.ServiceAsync. getPrimarySubnet(ResponseHandler<Subnet> callback)Async callback version ofComponent.Service.getPrimarySubnet()Future<?>Component.ServiceAsync. getSubnets(ResponseHandler<List<Subnet>> callback)Async callback version ofComponent.Service.getSubnets()