Class Firewall
java.lang.Object
com.softlayer.api.Type
com.softlayer.api.service.Entity
com.softlayer.api.service.network.component.Firewall
@ApiType("SoftLayer_Network_Component_Firewall") public class Firewall extends Entity
The SoftLayer_Network_Component_Firewall data type contains general information relating to a single SoftLayer network component firewall. This is the object which ties the running rules to a specific downstream server. Use the [[SoftLayer Network Firewall Template]] service to pull SoftLayer recommended rule set templates. Use the [[SoftLayer Network Firewall Update Request]] service to submit a firewall update request.
- See Also:
- SoftLayer_Network_Component_Firewall
-
Nested Class Summary
Nested Classes Modifier and Type Class Description static classFirewall.Maskstatic interfaceFirewall.ServiceThe SoftLayer_Network_Component_Firewall service accesses general information relating to a single SoftLayer network component firewall.static interfaceFirewall.ServiceAsync -
Field Summary
Fields Modifier and Type Field Description protected LongapplyServerRuleSubnetCountA count of the additional subnets linked to this network component firewall, that inherit rules from the host that the context slot is attached to.protected List<Subnet>applyServerRuleSubnetsThe additional subnets linked to this network component firewall, that inherit rules from the host that the context slot is attached to.protected ItembillingItemThe billing item for a Hardware Firewall (Dedicated).protected ComponentguestNetworkComponentThe network component of the guest virtual server that this network component firewall belongs to.protected LongguestNetworkComponentIdUnique ID for the network component of the switch interface that this network component firewall is attached to.protected booleanguestNetworkComponentIdSpecifiedprotected LongidUnique ID for the network component firewall.protected booleanidSpecifiedprotected ComponentnetworkComponentThe network component of the switch interface that this network component firewall belongs to.protected LongnetworkComponentIdUnique ID for the network component of the switch interface that this network component firewall is attached to.protected booleannetworkComponentIdSpecifiedprotected List<Request>networkFirewallUpdateRequestThe update requests made for this firewall.protected LongnetworkFirewallUpdateRequestCountA count of the update requests made for this firewall.protected LongruleCountA count of the currently running rule set of this network component firewall.protected List<Rule>rulesThe currently running rule set of this network component firewall.protected StringstatusCurrent status of the network component firewall.protected booleanstatusSpecifiedprotected LongsubnetCountA count of the additional subnets linked to this network component firewall.protected List<Subnet>subnetsThe additional subnets linked to this network component firewall. -
Constructor Summary
Constructors Constructor Description Firewall() -
Method Summary
-
Field Details
-
applyServerRuleSubnets
The additional subnets linked to this network component firewall, that inherit rules from the host that the context slot is attached to. -
billingItem
The billing item for a Hardware Firewall (Dedicated). -
guestNetworkComponent
The network component of the guest virtual server that this network component firewall belongs to. -
networkComponent
The network component of the switch interface that this network component firewall belongs to. -
networkFirewallUpdateRequest
The update requests made for this firewall. -
rules
The currently running rule set of this network component firewall. -
subnets
The additional subnets linked to this network component firewall. -
guestNetworkComponentId
Unique ID for the network component of the switch interface that this network component firewall is attached to. -
guestNetworkComponentIdSpecified
protected boolean guestNetworkComponentIdSpecified -
id
Unique ID for the network component firewall. -
idSpecified
protected boolean idSpecified -
networkComponentId
Unique ID for the network component of the switch interface that this network component firewall is attached to. -
networkComponentIdSpecified
protected boolean networkComponentIdSpecified -
status
Current status of the network component firewall. -
statusSpecified
protected boolean statusSpecified -
applyServerRuleSubnetCount
A count of the additional subnets linked to this network component firewall, that inherit rules from the host that the context slot is attached to. -
networkFirewallUpdateRequestCount
A count of the update requests made for this firewall. -
ruleCount
A count of the currently running rule set of this network component firewall. -
subnetCount
A count of the additional subnets linked to this network component firewall.
-
-
Constructor Details
-
Firewall
public Firewall()
-
-
Method Details
-
getApplyServerRuleSubnets
-
getBillingItem
-
setBillingItem
-
getGuestNetworkComponent
-
setGuestNetworkComponent
-
getNetworkComponent
-
setNetworkComponent
-
getNetworkFirewallUpdateRequest
-
getRules
-
getSubnets
-
getGuestNetworkComponentId
-
setGuestNetworkComponentId
-
isGuestNetworkComponentIdSpecified
public boolean isGuestNetworkComponentIdSpecified() -
unsetGuestNetworkComponentId
public void unsetGuestNetworkComponentId() -
getId
-
setId
-
isIdSpecified
public boolean isIdSpecified() -
unsetId
public void unsetId() -
getNetworkComponentId
-
setNetworkComponentId
-
isNetworkComponentIdSpecified
public boolean isNetworkComponentIdSpecified() -
unsetNetworkComponentId
public void unsetNetworkComponentId() -
getStatus
-
setStatus
-
isStatusSpecified
public boolean isStatusSpecified() -
unsetStatus
public void unsetStatus() -
getApplyServerRuleSubnetCount
-
setApplyServerRuleSubnetCount
-
getNetworkFirewallUpdateRequestCount
-
setNetworkFirewallUpdateRequestCount
-
getRuleCount
-
setRuleCount
-
getSubnetCount
-
setSubnetCount
-
asService
-
service
-
service
-