Class IpAddress
java.lang.Object
com.softlayer.api.Type
com.softlayer.api.service.Entity
com.softlayer.api.service.network.component.IpAddress
@ApiType("SoftLayer_Network_Component_IpAddress") public class IpAddress extends Entity
The SoftLayer_Network_Component_IpAddress data type contains general information relating to the binding of a single network component to a single SoftLayer IP address.
- See Also:
- SoftLayer_Network_Component_IpAddress
-
Nested Class Summary
Nested Classes Modifier and Type Class Description static classIpAddress.Mask -
Field Summary
Fields Modifier and Type Field Description protected IpAddressipAddressThe IP address associated with this object's network component.protected ComponentnetworkComponentThe network component associated with this object's IP address. -
Constructor Summary
Constructors Constructor Description IpAddress() -
Method Summary
Modifier and Type Method Description IpAddressgetIpAddress()ComponentgetNetworkComponent()voidsetIpAddress(IpAddress ipAddress)voidsetNetworkComponent(Component networkComponent)
-
Field Details
-
ipAddress
The IP address associated with this object's network component. -
networkComponent
The network component associated with this object's IP address.
-
-
Constructor Details
-
IpAddress
public IpAddress()
-
-
Method Details