Class Rule
java.lang.Object
com.softlayer.api.Type
com.softlayer.api.service.Entity
com.softlayer.api.service.network.component.firewall.Rule
@ApiType("SoftLayer_Network_Component_Firewall_Rule") public class Rule extends Entity
A SoftLayer_Network_Component_Firewall_Rule object type represents a currently running firewall rule and contains relative information. Use the [[SoftLayer Network Firewall Update Request]] service to submit a firewall update request. Use the [[SoftLayer Network Firewall Template]] service to pull SoftLayer recommended rule set templates.
-
Nested Class Summary
Nested Classes Modifier and Type Class Description static classRule.Mask -
Field Summary
Fields Modifier and Type Field Description protected StringactionThe action that the rule is to take [permit or deny].protected booleanactionSpecifiedprotected StringdestinationIpAddressThe destination IP address considered for determining rule application.protected booleandestinationIpAddressSpecifiedprotected LongdestinationIpCidrThe CIDR is used for determining rule application.protected booleandestinationIpCidrSpecifiedprotected StringdestinationIpSubnetMaskThe destination IP subnet mask considered for determining rule application.protected booleandestinationIpSubnetMaskSpecifiedprotected LongdestinationPortRangeEndThe ending (upper end of range) destination port considered for determining rule application.protected booleandestinationPortRangeEndSpecifiedprotected LongdestinationPortRangeStartThe starting (lower end of range) destination port considered for determining rule application.protected booleandestinationPortRangeStartSpecifiedprotected LongidThe rule's internal identifier.protected booleanidSpecifiedprotected FirewallnetworkComponentFirewallThe network component firewall that this rule belongs to.protected StringnotesThe notes field for the rule.protected booleannotesSpecifiedprotected LongorderValueThe numeric value describing the order in which the rule should be applied.protected booleanorderValueSpecifiedprotected StringprotocolThe protocol considered for determining rule application.protected booleanprotocolSpecifiedprotected StringsourceIpAddressThe source IP address considered for determining rule application.protected booleansourceIpAddressSpecifiedprotected LongsourceIpCidrThe CIDR is used for determining rule application.protected booleansourceIpCidrSpecifiedprotected StringsourceIpSubnetMaskThe source IP subnet mask considered for determining rule application.protected booleansourceIpSubnetMaskSpecifiedprotected StringstatusCurrent status of the network component firewall.protected booleanstatusSpecifiedprotected LongversionWhether this rule is an IPv4 rule or an IPv6 rule.protected booleanversionSpecifiedFields inherited from class com.softlayer.api.Type
unknownProperties -
Constructor Summary
Constructors Constructor Description Rule() -
Method Summary
Methods inherited from class com.softlayer.api.Type
getUnknownProperties, setUnknownProperties
-
Field Details
-
networkComponentFirewall
The network component firewall that this rule belongs to. -
action
The action that the rule is to take [permit or deny]. -
actionSpecified
protected boolean actionSpecified -
destinationIpAddress
The destination IP address considered for determining rule application. -
destinationIpAddressSpecified
protected boolean destinationIpAddressSpecified -
destinationIpCidr
The CIDR is used for determining rule application. This value will -
destinationIpCidrSpecified
protected boolean destinationIpCidrSpecified -
destinationIpSubnetMask
The destination IP subnet mask considered for determining rule application. -
destinationIpSubnetMaskSpecified
protected boolean destinationIpSubnetMaskSpecified -
destinationPortRangeEnd
The ending (upper end of range) destination port considered for determining rule application. -
destinationPortRangeEndSpecified
protected boolean destinationPortRangeEndSpecified -
destinationPortRangeStart
The starting (lower end of range) destination port considered for determining rule application. -
destinationPortRangeStartSpecified
protected boolean destinationPortRangeStartSpecified -
id
The rule's internal identifier. -
idSpecified
protected boolean idSpecified -
notes
The notes field for the rule. -
notesSpecified
protected boolean notesSpecified -
orderValue
The numeric value describing the order in which the rule should be applied. -
orderValueSpecified
protected boolean orderValueSpecified -
protocol
The protocol considered for determining rule application. -
protocolSpecified
protected boolean protocolSpecified -
sourceIpAddress
The source IP address considered for determining rule application. -
sourceIpAddressSpecified
protected boolean sourceIpAddressSpecified -
sourceIpCidr
The CIDR is used for determining rule application. This value will -
sourceIpCidrSpecified
protected boolean sourceIpCidrSpecified -
sourceIpSubnetMask
The source IP subnet mask considered for determining rule application. -
sourceIpSubnetMaskSpecified
protected boolean sourceIpSubnetMaskSpecified -
status
Current status of the network component firewall. -
statusSpecified
protected boolean statusSpecified -
version
Whether this rule is an IPv4 rule or an IPv6 rule. If -
versionSpecified
protected boolean versionSpecified
-
-
Constructor Details
-
Rule
public Rule()
-
-
Method Details
-
getNetworkComponentFirewall
-
setNetworkComponentFirewall
-
getAction
-
setAction
-
isActionSpecified
public boolean isActionSpecified() -
unsetAction
public void unsetAction() -
getDestinationIpAddress
-
setDestinationIpAddress
-
isDestinationIpAddressSpecified
public boolean isDestinationIpAddressSpecified() -
unsetDestinationIpAddress
public void unsetDestinationIpAddress() -
getDestinationIpCidr
-
setDestinationIpCidr
-
isDestinationIpCidrSpecified
public boolean isDestinationIpCidrSpecified() -
unsetDestinationIpCidr
public void unsetDestinationIpCidr() -
getDestinationIpSubnetMask
-
setDestinationIpSubnetMask
-
isDestinationIpSubnetMaskSpecified
public boolean isDestinationIpSubnetMaskSpecified() -
unsetDestinationIpSubnetMask
public void unsetDestinationIpSubnetMask() -
getDestinationPortRangeEnd
-
setDestinationPortRangeEnd
-
isDestinationPortRangeEndSpecified
public boolean isDestinationPortRangeEndSpecified() -
unsetDestinationPortRangeEnd
public void unsetDestinationPortRangeEnd() -
getDestinationPortRangeStart
-
setDestinationPortRangeStart
-
isDestinationPortRangeStartSpecified
public boolean isDestinationPortRangeStartSpecified() -
unsetDestinationPortRangeStart
public void unsetDestinationPortRangeStart() -
getId
-
setId
-
isIdSpecified
public boolean isIdSpecified() -
unsetId
public void unsetId() -
getNotes
-
setNotes
-
isNotesSpecified
public boolean isNotesSpecified() -
unsetNotes
public void unsetNotes() -
getOrderValue
-
setOrderValue
-
isOrderValueSpecified
public boolean isOrderValueSpecified() -
unsetOrderValue
public void unsetOrderValue() -
getProtocol
-
setProtocol
-
isProtocolSpecified
public boolean isProtocolSpecified() -
unsetProtocol
public void unsetProtocol() -
getSourceIpAddress
-
setSourceIpAddress
-
isSourceIpAddressSpecified
public boolean isSourceIpAddressSpecified() -
unsetSourceIpAddress
public void unsetSourceIpAddress() -
getSourceIpCidr
-
setSourceIpCidr
-
isSourceIpCidrSpecified
public boolean isSourceIpCidrSpecified() -
unsetSourceIpCidr
public void unsetSourceIpCidr() -
getSourceIpSubnetMask
-
setSourceIpSubnetMask
-
isSourceIpSubnetMaskSpecified
public boolean isSourceIpSubnetMaskSpecified() -
unsetSourceIpSubnetMask
public void unsetSourceIpSubnetMask() -
getStatus
-
setStatus
-
isStatusSpecified
public boolean isStatusSpecified() -
unsetStatus
public void unsetStatus() -
getVersion
-
setVersion
-
isVersionSpecified
public boolean isVersionSpecified() -
unsetVersion
public void unsetVersion()
-