-
Interface Summary
| Interface |
Description |
| Firewall.Service |
The SoftLayer_Network_Component_Firewall service accesses general information relating to a single SoftLayer network component firewall.
|
| Firewall.ServiceAsync |
|
-
Class Summary
| Class |
Description |
| Firewall |
The SoftLayer_Network_Component_Firewall data type contains general information relating to a single SoftLayer network component firewall.
|
| Firewall.Mask |
|
| Group |
|
| Group.Mask |
|
| IpAddress |
The SoftLayer_Network_Component_IpAddress data type contains general information relating to the binding of a single network component to a single SoftLayer IP address.
|
| IpAddress.Mask |
|
| RemoteManagement |
The SoftLayer_Network_Component_RemoteManagement data type contains general information relating to a single SoftLayer remote management network component.
|
| RemoteManagement.Mask |
|