Interface Subnet.ServiceAsync
- All Superinterfaces:
Maskable,ResultLimitable,ServiceAsync
- Enclosing class:
- Subnet
public static interface Subnet.ServiceAsync extends ServiceAsync
-
Method Summary
Modifier and Type Method Description Future<Subnet>createObject(Subnet templateObject)Future<?>createObject(Subnet templateObject, ResponseHandler<Subnet> callback)Future<List<IpAddress>>getIpAddresses()Async version ofSubnet.Service.getIpAddresses()Future<?>getIpAddresses(ResponseHandler<List<IpAddress>> callback)Async callback version ofSubnet.Service.getIpAddresses()Future<Subnet>getObject()Async version ofSubnet.Service.getObject()Future<?>getObject(ResponseHandler<Subnet> callback)voidsetMask(Subnet.Mask mask)Subnet.MaskwithMask()Use the existing mask on this service or create it if not presentSubnet.MaskwithNewMask()Overwrite the existing mask on this service with a new one and return itMethods inherited from interface com.softlayer.api.ResultLimitable
getLastResponseTotalItemCount, getResultLimit, setResultLimit
-
Method Details
-
withNewMask
Subnet.Mask withNewMask()Description copied from interface:MaskableOverwrite the existing mask on this service with a new one and return it- Specified by:
withNewMaskin interfaceMaskable
-
withMask
Subnet.Mask withMask()Description copied from interface:MaskableUse the existing mask on this service or create it if not present -
setMask
-
createObject
-
createObject
-
getObject
Async version ofSubnet.Service.getObject() -
getObject
-
getIpAddresses
Async version ofSubnet.Service.getIpAddresses() -
getIpAddresses
Async callback version ofSubnet.Service.getIpAddresses()
-