Class Location
java.lang.Object
com.softlayer.api.Type
com.softlayer.api.service.Entity
com.softlayer.api.service.network.directlink.Location
@ApiType("SoftLayer_Network_DirectLink_Location") public class Location extends Entity
The SoftLayer_Network_DirectLink_Location presents a structure containing attributes of a Direct Link location, and its related object SoftLayer location.
- See Also:
- SoftLayer_Network_DirectLink_Location
-
Nested Class Summary
Nested Classes Modifier and Type Class Description static classLocation.Maskstatic interfaceLocation.ServiceThe SoftLayer_Network_DirectLink_Location service allows users to create, update, delete, get details of a Direct Link location and retrieve all existing details.static interfaceLocation.ServiceAsync -
Field Summary
Fields Modifier and Type Field Description protected StringbuildingColocationOwnerThe Direct Link specific location owner for POP/DC facilities.protected booleanbuildingColocationOwnerSpecifiedprotected LongidThe unique identifier of a Direct Link location.protected booleanidSpecifiedprotected BooleanisRedundantXcrSpecifies if The Direct Link specific location has Redundancy:secondary XCR availability.protected booleanisRedundantXcrSpecifiedprotected LocationlocationThe location of Direct Link facility.protected LonglocationIdThe Direct Link specific location ie.protected booleanlocationIdSpecifiedprotected StringmarketGeographyThe Direct Link Market location used in Direct Link Order.protected booleanmarketGeographySpecifiedprotected ProviderproviderThe Id of Direct Link provider.protected ServiceTypeserviceTypeThe Id of Direct Link service type. -
Constructor Summary
Constructors Constructor Description Location() -
Method Summary
-
Field Details
-
location
The location of Direct Link facility. -
provider
The Id of Direct Link provider. -
serviceType
The Id of Direct Link service type. -
buildingColocationOwner
The Direct Link specific location owner for POP/DC facilities. Like Equinix, Pacnet, Verizon etc. -
buildingColocationOwnerSpecified
protected boolean buildingColocationOwnerSpecified -
id
The unique identifier of a Direct Link location. -
idSpecified
protected boolean idSpecified -
isRedundantXcr
Specifies if The Direct Link specific location has Redundancy:secondary XCR availability. -
isRedundantXcrSpecified
protected boolean isRedundantXcrSpecified -
locationId
The Direct Link specific location ie. Data Center & Network POP facility. Refer to location object Like Dallas in US, London in England etc. -
locationIdSpecified
protected boolean locationIdSpecified -
marketGeography
The Direct Link Market location used in Direct Link Order. Like Europe, North America, Asia pacific etc. -
marketGeographySpecified
protected boolean marketGeographySpecified
-
-
Constructor Details
-
Location
public Location()
-
-
Method Details
-
getLocation
-
setLocation
-
getProvider
-
setProvider
-
getServiceType
-
setServiceType
-
getBuildingColocationOwner
-
setBuildingColocationOwner
-
isBuildingColocationOwnerSpecified
public boolean isBuildingColocationOwnerSpecified() -
unsetBuildingColocationOwner
public void unsetBuildingColocationOwner() -
getId
-
setId
-
isIdSpecified
public boolean isIdSpecified() -
unsetId
public void unsetId() -
getIsRedundantXcr
-
setIsRedundantXcr
-
isIsRedundantXcrSpecified
public boolean isIsRedundantXcrSpecified() -
unsetIsRedundantXcr
public void unsetIsRedundantXcr() -
getLocationId
-
setLocationId
-
isLocationIdSpecified
public boolean isLocationIdSpecified() -
unsetLocationId
public void unsetLocationId() -
getMarketGeography
-
setMarketGeography
-
isMarketGeographySpecified
public boolean isMarketGeographySpecified() -
unsetMarketGeography
public void unsetMarketGeography() -
asService
-
service
-
service
-