Interface Location.ServiceAsync
- All Superinterfaces:
Maskable,ResultLimitable,ServiceAsync
- Enclosing class:
- Location
public static interface Location.ServiceAsync extends ServiceAsync
-
Method Summary
Methods inherited from interface com.softlayer.api.ResultLimitable
getLastResponseTotalItemCount, getResultLimit, setResultLimit
-
Method Details
-
withNewMask
Location.Mask withNewMask()Description copied from interface:MaskableOverwrite the existing mask on this service with a new one and return it- Specified by:
withNewMaskin interfaceMaskable
-
withMask
Location.Mask withMask()Description copied from interface:MaskableUse the existing mask on this service or create it if not present -
setMask
-
getAllObjects
Async version ofLocation.Service.getAllObjects() -
getAllObjects
-
getObject
Async version ofLocation.Service.getObject() -
getObject
-
getLocation
Async version ofLocation.Service.getLocation() -
getLocation
Async callback version ofLocation.Service.getLocation() -
getProvider
Async version ofLocation.Service.getProvider() -
getProvider
Async callback version ofLocation.Service.getProvider() -
getServiceType
Future<ServiceType> getServiceType()Async version ofLocation.Service.getServiceType() -
getServiceType
Async callback version ofLocation.Service.getServiceType()
-