-
Interface Summary
| Interface |
Description |
| Location.Service |
The SoftLayer_Network_DirectLink_Location service allows users to create, update, delete, get details of a Direct Link location and retrieve all existing details.
|
| Location.ServiceAsync |
|
| Provider.Service |
The SoftLayer_Network_DirectLink_Provider service allows users to create, update, delete, get details of a Direct Link provider and retrieve all existing details.
|
| Provider.ServiceAsync |
|
| ServiceType.Service |
The SoftLayer_Network_DirectLink_ServiceType service allows users to create, update, delete, get details of a Direct Link Service Type and retrieve all existing details.
|
| ServiceType.ServiceAsync |
|
-
Class Summary
| Class |
Description |
| Location |
The SoftLayer_Network_DirectLink_Location presents a structure containing attributes of a Direct Link location, and its related object SoftLayer location.
|
| Location.Mask |
|
| Provider |
The SoftLayer_Network_DirectLink_Provider presents a structure containing attributes of a Direct Link provider.
|
| Provider.Mask |
|
| ServiceType |
The SoftLayer_Network_DirectLink_ServiceType presents a structure containing attributes of a Direct Link Service Type.
|
| ServiceType.Mask |
|