Class Interface
java.lang.Object
com.softlayer.api.Type
com.softlayer.api.service.Entity
com.softlayer.api.service.network.firewall.module.context.Interface
com.softlayer.api.service.network.firewall.Interface
@ApiType("SoftLayer_Network_Firewall_Interface") public class Interface extends Interface
The SoftLayer_Network_Firewall_Interface data type contains general information relating to a single SoftLayer firewall interface. This is the object which ties the firewall context access control list to a firewall. Use the [[SoftLayer Network Firewall Template]] service to pull SoftLayer recommended rule set templates. Use the [[SoftLayer Network Firewall Update Request]] service to submit a firewall update request.
- See Also:
- SoftLayer_Network_Firewall_Interface
-
Nested Class Summary
Nested Classes Modifier and Type Class Description static classInterface.Maskstatic interfaceInterface.ServiceThe SoftLayer_Network_Firewall_Interface service accesses general information relating to a single SoftLayer firewall interface.static interfaceInterface.ServiceAsync -
Field Summary
Fields inherited from class com.softlayer.api.service.network.firewall.module.context.Interface
firewallContextAccessControlListCount, firewallContextAccessControlLists, id, idSpecified, name, nameSpecified, networkVlan -
Constructor Summary
Constructors Constructor Description Interface() -
Method Summary
Modifier and Type Method Description Interface.ServiceasService(ApiClient client)static Interface.Serviceservice(ApiClient client)static Interface.Serviceservice(ApiClient client, Long id)Methods inherited from class com.softlayer.api.service.network.firewall.module.context.Interface
getFirewallContextAccessControlListCount, getFirewallContextAccessControlLists, getId, getName, getNetworkVlan, isIdSpecified, isNameSpecified, setFirewallContextAccessControlListCount, setId, setName, setNetworkVlan, unsetId, unsetName