Class Template
java.lang.Object
com.softlayer.api.Type
com.softlayer.api.service.Entity
com.softlayer.api.service.network.firewall.Template
@ApiType("SoftLayer_Network_Firewall_Template") public class Template extends Entity
The SoftLayer_Network_Firewall_Template type contains general information for a SoftLayer network firewall template.
Firewall templates are recommend rule sets for use with SoftLayer Hardware Firewall (Dedicated). These optimized templates are designed to balance security restriction with application availability. The templates given may be altered to provide custom network security, or may be used as-is for basic security. At least one rule set MUST be applied for the firewall to block traffic. Use the [[SoftLayer Network Component Firewall]] service to view current rules. Use the [[SoftLayer Network Firewall Update Request]] service to submit a firewall update request.
Firewall templates are recommend rule sets for use with SoftLayer Hardware Firewall (Dedicated). These optimized templates are designed to balance security restriction with application availability. The templates given may be altered to provide custom network security, or may be used as-is for basic security. At least one rule set MUST be applied for the firewall to block traffic. Use the [[SoftLayer Network Component Firewall]] service to view current rules. Use the [[SoftLayer Network Firewall Update Request]] service to submit a firewall update request.
- See Also:
- SoftLayer_Network_Firewall_Template
-
Nested Class Summary
Nested Classes Modifier and Type Class Description static classTemplate.Maskstatic interfaceTemplate.ServiceThe SoftLayer_Network_Firewall_Template service can be used to retrieve recommended SoftLayer network firewall templates and template rules.static interfaceTemplate.ServiceAsync -
Field Summary
Fields Modifier and Type Field Description protected LongidA Firewall template's internal identifier.protected booleanidSpecifiedprotected StringnameThe name of the firewall rules template.protected booleannameSpecifiedprotected LongruleCountA count of the rule set that belongs to this firewall rules template.protected List<Rule>rulesThe rule set that belongs to this firewall rules template. -
Constructor Summary
Constructors Constructor Description Template() -
Method Summary
Modifier and Type Method Description Template.ServiceasService(ApiClient client)LonggetId()StringgetName()LonggetRuleCount()List<Rule>getRules()booleanisIdSpecified()booleanisNameSpecified()static Template.Serviceservice(ApiClient client)static Template.Serviceservice(ApiClient client, Long id)voidsetId(Long id)voidsetName(String name)voidsetRuleCount(Long ruleCount)voidunsetId()voidunsetName()
-
Field Details
-
rules
The rule set that belongs to this firewall rules template. -
id
A Firewall template's internal identifier. -
idSpecified
protected boolean idSpecified -
name
The name of the firewall rules template. -
nameSpecified
protected boolean nameSpecified -
ruleCount
A count of the rule set that belongs to this firewall rules template.
-
-
Constructor Details
-
Template
public Template()
-
-
Method Details
-
getRules
-
getId
-
setId
-
isIdSpecified
public boolean isIdSpecified() -
unsetId
public void unsetId() -
getName
-
setName
-
isNameSpecified
public boolean isNameSpecified() -
unsetName
public void unsetName() -
getRuleCount
-
setRuleCount
-
asService
-
service
-
service
-