java.lang.Object
com.softlayer.api.Type
com.softlayer.api.service.Entity
com.softlayer.api.service.network.firewall.update.Request
Direct Known Subclasses:
Customer, Employee

@ApiType("SoftLayer_Network_Firewall_Update_Request")
public class Request
extends Entity
The SoftLayer_Network_Firewall_Update_Request data type contains information relating to a SoftLayer network firewall update request. Use the [[SoftLayer Network Component Firewall]] service to view current rules. Use the [[SoftLayer Network Firewall Template]] service to pull SoftLayer recommended rule set templates.
See Also:
SoftLayer_Network_Firewall_Update_Request
  • Field Details

    • authorizingUser

      @ApiProperty protected Interface authorizingUser
      The user that authorized this firewall update request.
    • guest

      @ApiProperty protected Guest guest
      The downstream virtual server that the rule set will be applied to.
    • hardware

      @ApiProperty protected Hardware hardware
      The downstream server that the rule set will be applied to.
    • networkComponentFirewall

      @ApiProperty protected Firewall networkComponentFirewall
      The network component firewall that the rule set will be applied to.
    • rules

      @ApiProperty protected List<Rule> rules
      The group of rules contained within the update request.
    • applyDate

      Timestamp of when the rules from the update request were applied to the firewall.
    • applyDateSpecified

      protected boolean applyDateSpecified
    • authorizingUserId

      @ApiProperty(canBeNullOrNotSet=true) protected Long authorizingUserId
      The unique identifier of the user that authorized the update request.
    • authorizingUserIdSpecified

      protected boolean authorizingUserIdSpecified
    • authorizingUserType

      @ApiProperty(canBeNullOrNotSet=true) protected String authorizingUserType
      The type of user that authorized the update request [EMP or USR].
    • authorizingUserTypeSpecified

      protected boolean authorizingUserTypeSpecified
    • bypassFlag

      @ApiProperty(canBeNullOrNotSet=true) protected Boolean bypassFlag
      Flag indicating whether the request is for a rule bypass configuration [0 or 1].
    • bypassFlagSpecified

      protected boolean bypassFlagSpecified
    • createDate

      @ApiProperty(canBeNullOrNotSet=true) protected GregorianCalendar createDate
      Timestamp of the creation of the record.
    • createDateSpecified

      protected boolean createDateSpecified
    • firewallContextAccessControlListId

      @ApiProperty(canBeNullOrNotSet=true) protected Long firewallContextAccessControlListId
      The unique identifier of the firewall access control list that the rule set is destined for.
    • firewallContextAccessControlListIdSpecified

      protected boolean firewallContextAccessControlListIdSpecified
    • hardwareId

      @ApiProperty(canBeNullOrNotSet=true) protected Long hardwareId
      The unique identifier of the server that the rule set is destined to protect.
    • hardwareIdSpecified

      protected boolean hardwareIdSpecified
    • id

      @ApiProperty(canBeNullOrNotSet=true) protected Long id
      The unique identifier of the firewall update request.
    • idSpecified

      protected boolean idSpecified
    • networkComponentFirewallId

      @ApiProperty(canBeNullOrNotSet=true) protected Long networkComponentFirewallId
      The unique identifier of the network component firewall that the rule set is destined for.
    • networkComponentFirewallIdSpecified

      protected boolean networkComponentFirewallIdSpecified
    • ruleCount

      @ApiProperty protected Long ruleCount
      A count of the group of rules contained within the update request.
  • Constructor Details

    • Request

      public Request()
  • Method Details

    • getAuthorizingUser

      public Interface getAuthorizingUser()
    • setAuthorizingUser

      public void setAuthorizingUser​(Interface authorizingUser)
    • getGuest

      public Guest getGuest()
    • setGuest

      public void setGuest​(Guest guest)
    • getHardware

      public Hardware getHardware()
    • setHardware

      public void setHardware​(Hardware hardware)
    • getNetworkComponentFirewall

      public Firewall getNetworkComponentFirewall()
    • setNetworkComponentFirewall

      public void setNetworkComponentFirewall​(Firewall networkComponentFirewall)
    • getRules

      public List<Rule> getRules()
    • getApplyDate

      public GregorianCalendar getApplyDate()
    • setApplyDate

      public void setApplyDate​(GregorianCalendar applyDate)
    • isApplyDateSpecified

      public boolean isApplyDateSpecified()
    • unsetApplyDate

      public void unsetApplyDate()
    • getAuthorizingUserId

      public Long getAuthorizingUserId()
    • setAuthorizingUserId

      public void setAuthorizingUserId​(Long authorizingUserId)
    • isAuthorizingUserIdSpecified

      public boolean isAuthorizingUserIdSpecified()
    • unsetAuthorizingUserId

      public void unsetAuthorizingUserId()
    • getAuthorizingUserType

      public String getAuthorizingUserType()
    • setAuthorizingUserType

      public void setAuthorizingUserType​(String authorizingUserType)
    • isAuthorizingUserTypeSpecified

      public boolean isAuthorizingUserTypeSpecified()
    • unsetAuthorizingUserType

      public void unsetAuthorizingUserType()
    • getBypassFlag

      public Boolean getBypassFlag()
    • setBypassFlag

      public void setBypassFlag​(Boolean bypassFlag)
    • isBypassFlagSpecified

      public boolean isBypassFlagSpecified()
    • unsetBypassFlag

      public void unsetBypassFlag()
    • getCreateDate

      public GregorianCalendar getCreateDate()
    • setCreateDate

      public void setCreateDate​(GregorianCalendar createDate)
    • isCreateDateSpecified

      public boolean isCreateDateSpecified()
    • unsetCreateDate

      public void unsetCreateDate()
    • getFirewallContextAccessControlListId

      public Long getFirewallContextAccessControlListId()
    • setFirewallContextAccessControlListId

      public void setFirewallContextAccessControlListId​(Long firewallContextAccessControlListId)
    • isFirewallContextAccessControlListIdSpecified

      public boolean isFirewallContextAccessControlListIdSpecified()
    • unsetFirewallContextAccessControlListId

      public void unsetFirewallContextAccessControlListId()
    • getHardwareId

      public Long getHardwareId()
    • setHardwareId

      public void setHardwareId​(Long hardwareId)
    • isHardwareIdSpecified

      public boolean isHardwareIdSpecified()
    • unsetHardwareId

      public void unsetHardwareId()
    • getId

      public Long getId()
    • setId

      public void setId​(Long id)
    • isIdSpecified

      public boolean isIdSpecified()
    • unsetId

      public void unsetId()
    • getNetworkComponentFirewallId

      public Long getNetworkComponentFirewallId()
    • setNetworkComponentFirewallId

      public void setNetworkComponentFirewallId​(Long networkComponentFirewallId)
    • isNetworkComponentFirewallIdSpecified

      public boolean isNetworkComponentFirewallIdSpecified()
    • unsetNetworkComponentFirewallId

      public void unsetNetworkComponentFirewallId()
    • getRuleCount

      public Long getRuleCount()
    • setRuleCount

      public void setRuleCount​(Long ruleCount)
    • asService

      public Request.Service asService​(ApiClient client)
    • service

      public static Request.Service service​(ApiClient client)
    • service

      public static Request.Service service​(ApiClient client, Long id)