Interface Request.ServiceAsync
- All Superinterfaces:
Maskable,ResultLimitable,ServiceAsync
- Enclosing class:
- Request
public static interface Request.ServiceAsync extends ServiceAsync
-
Method Summary
Methods inherited from interface com.softlayer.api.ResultLimitable
getLastResponseTotalItemCount, getResultLimit, setResultLimit
-
Method Details
-
withNewMask
Request.Mask withNewMask()Description copied from interface:MaskableOverwrite the existing mask on this service with a new one and return it- Specified by:
withNewMaskin interfaceMaskable
-
withMask
Request.Mask withMask()Description copied from interface:MaskableUse the existing mask on this service or create it if not present -
setMask
-
createObject
-
createObject
-
getFirewallUpdateRequestRuleAttributes
Async version ofRequest.Service.getFirewallUpdateRequestRuleAttributes() -
getFirewallUpdateRequestRuleAttributes
-
getObject
Async version ofRequest.Service.getObject() -
getObject
-
updateRuleNote
-
updateRuleNote
-
getAuthorizingUser
Async version ofRequest.Service.getAuthorizingUser() -
getAuthorizingUser
Async callback version ofRequest.Service.getAuthorizingUser() -
getGuest
Async version ofRequest.Service.getGuest() -
getGuest
Async callback version ofRequest.Service.getGuest() -
getHardware
Async version ofRequest.Service.getHardware() -
getHardware
Async callback version ofRequest.Service.getHardware() -
getNetworkComponentFirewall
Async version ofRequest.Service.getNetworkComponentFirewall() -
getNetworkComponentFirewall
Async callback version ofRequest.Service.getNetworkComponentFirewall() -
getRules
Async version ofRequest.Service.getRules() -
getRules
Async callback version ofRequest.Service.getRules()
-