Uses of Class
com.softlayer.api.service.network.firewall.update.Request
-
Uses of Request in com.softlayer.api.service.network.component
Fields in com.softlayer.api.service.network.component with type parameters of type Request Modifier and Type Field Description protected List<Request>Firewall. networkFirewallUpdateRequestThe update requests made for this firewall.Methods in com.softlayer.api.service.network.component that return types with arguments of type Request Modifier and Type Method Description List<Request>Firewall. getNetworkFirewallUpdateRequest()List<Request>Firewall.Service. getNetworkFirewallUpdateRequest()The update requests made for this firewall.Future<List<Request>>Firewall.ServiceAsync. getNetworkFirewallUpdateRequest()Async version ofFirewall.Service.getNetworkFirewallUpdateRequest()Method parameters in com.softlayer.api.service.network.component with type arguments of type Request Modifier and Type Method Description Future<?>Firewall.ServiceAsync. getNetworkFirewallUpdateRequest(ResponseHandler<List<Request>> callback)Async callback version ofFirewall.Service.getNetworkFirewallUpdateRequest() -
Uses of Request in com.softlayer.api.service.network.firewall
Fields in com.softlayer.api.service.network.firewall with type parameters of type Request Modifier and Type Field Description protected List<Request>AccessControlList. networkFirewallUpdateRequestsThe update requests made for this firewall.Methods in com.softlayer.api.service.network.firewall that return types with arguments of type Request Modifier and Type Method Description List<Request>AccessControlList. getNetworkFirewallUpdateRequests()List<Request>AccessControlList.Service. getNetworkFirewallUpdateRequests()The update requests made for this firewall.Future<List<Request>>AccessControlList.ServiceAsync. getNetworkFirewallUpdateRequests()Async version ofAccessControlList.Service.getNetworkFirewallUpdateRequests()Method parameters in com.softlayer.api.service.network.firewall with type arguments of type Request Modifier and Type Method Description Future<?>AccessControlList.ServiceAsync. getNetworkFirewallUpdateRequests(ResponseHandler<List<Request>> callback)Async callback version ofAccessControlList.Service.getNetworkFirewallUpdateRequests() -
Uses of Request in com.softlayer.api.service.network.firewall.update
Methods in com.softlayer.api.service.network.firewall.update that return Request Modifier and Type Method Description RequestRequest.Service. createObject(Request templateObject)Create a new firewall update request.RequestRequest.Service. getObject()''getObject'' returns a SoftLayer_Network_Firewall_Update_Request object.Methods in com.softlayer.api.service.network.firewall.update that return types with arguments of type Request Modifier and Type Method Description Future<Request>Request.ServiceAsync. createObject(Request templateObject)Future<Request>Request.ServiceAsync. getObject()Async version ofRequest.Service.getObject()Methods in com.softlayer.api.service.network.firewall.update with parameters of type Request Modifier and Type Method Description RequestRequest.Service. createObject(Request templateObject)Create a new firewall update request.Future<Request>Request.ServiceAsync. createObject(Request templateObject)Future<?>Request.ServiceAsync. createObject(Request templateObject, ResponseHandler<Request> callback)Method parameters in com.softlayer.api.service.network.firewall.update with type arguments of type Request Modifier and Type Method Description Future<?>Request.ServiceAsync. createObject(Request templateObject, ResponseHandler<Request> callback)Future<?>Request.ServiceAsync. getObject(ResponseHandler<Request> callback) -
Uses of Request in com.softlayer.api.service.network.firewall.update.request
Subclasses of Request in com.softlayer.api.service.network.firewall.update.request Modifier and Type Class Description classCustomerA SoftLayer_Ticket_Update_Customer is a single update made by a customer to a ticket.classEmployeeThe SoftLayer_Network_Firewall_Update_Request_Employee data type returns a user object for the SoftLayer employee that created the request.Fields in com.softlayer.api.service.network.firewall.update.request declared as Request Modifier and Type Field Description protected RequestRule. firewallUpdateRequestThe update request that this rule belongs to.Methods in com.softlayer.api.service.network.firewall.update.request that return Request Modifier and Type Method Description RequestRule. getFirewallUpdateRequest()RequestRule.Service. getFirewallUpdateRequest()The update request that this rule belongs to.Methods in com.softlayer.api.service.network.firewall.update.request that return types with arguments of type Request Modifier and Type Method Description Future<Request>Rule.ServiceAsync. getFirewallUpdateRequest()Async version ofRule.Service.getFirewallUpdateRequest()Methods in com.softlayer.api.service.network.firewall.update.request with parameters of type Request Modifier and Type Method Description voidRule. setFirewallUpdateRequest(Request firewallUpdateRequest)Method parameters in com.softlayer.api.service.network.firewall.update.request with type arguments of type Request Modifier and Type Method Description Future<?>Rule.ServiceAsync. getFirewallUpdateRequest(ResponseHandler<Request> callback)Async callback version ofRule.Service.getFirewallUpdateRequest() -
Uses of Request in com.softlayer.api.service.network.vlan
Fields in com.softlayer.api.service.network.vlan with type parameters of type Request Modifier and Type Field Description protected List<Request>Firewall. networkFirewallUpdateRequestsThe update requests made for this firewall.Methods in com.softlayer.api.service.network.vlan that return types with arguments of type Request Modifier and Type Method Description List<Request>Firewall. getNetworkFirewallUpdateRequests()List<Request>Firewall.Service. getNetworkFirewallUpdateRequests()The update requests made for this firewall.Future<List<Request>>Firewall.ServiceAsync. getNetworkFirewallUpdateRequests()Async version ofFirewall.Service.getNetworkFirewallUpdateRequests()Method parameters in com.softlayer.api.service.network.vlan with type arguments of type Request Modifier and Type Method Description Future<?>Firewall.ServiceAsync. getNetworkFirewallUpdateRequests(ResponseHandler<List<Request>> callback)Async callback version ofFirewall.Service.getNetworkFirewallUpdateRequests()