Class Member
java.lang.Object
com.softlayer.api.Type
com.softlayer.api.service.Entity
com.softlayer.api.service.network.gateway.Member
@ApiType("SoftLayer_Network_Gateway_Member") public class Member extends Entity
A network gateway member is a device that serves as a gateway. Once the hardware becomes a member of the gateway, only a reclaim can remove it. A reclaim on the last member of the gateway triggers a reclaim of the entire gateway.
- See Also:
- SoftLayer_Network_Gateway_Member
-
Nested Class Summary
Nested Classes Modifier and Type Class Description static classMember.Maskstatic interfaceMember.ServiceA network gateway member is a device that serves as a gateway.static interfaceMember.ServiceAsync -
Field Summary
Fields Modifier and Type Field Description protected AttributeattributesThe attributes for this member.protected HardwarehardwareThe device for this member.protected LonghardwareIdThe internal identifier of the hardware for this member.protected booleanhardwareIdSpecifiedprotected LongidA gateway member's internal identifier.protected booleanidSpecifiedprotected GatewaynetworkGatewayThe gateway this member belongs to.protected LongnetworkGatewayIdThe internal identifier of the gateway this member belongs to.protected booleannetworkGatewayIdSpecifiedprotected LongpriorityThe priority for this gateway member.protected booleanprioritySpecified -
Constructor Summary
Constructors Constructor Description Member() -
Method Summary
Modifier and Type Method Description Member.ServiceasService(ApiClient client)AttributegetAttributes()HardwaregetHardware()LonggetHardwareId()LonggetId()GatewaygetNetworkGateway()LonggetNetworkGatewayId()LonggetPriority()booleanisHardwareIdSpecified()booleanisIdSpecified()booleanisNetworkGatewayIdSpecified()booleanisPrioritySpecified()static Member.Serviceservice(ApiClient client)static Member.Serviceservice(ApiClient client, Long id)voidsetAttributes(Attribute attributes)voidsetHardware(Hardware hardware)voidsetHardwareId(Long hardwareId)voidsetId(Long id)voidsetNetworkGateway(Gateway networkGateway)voidsetNetworkGatewayId(Long networkGatewayId)voidsetPriority(Long priority)voidunsetHardwareId()voidunsetId()voidunsetNetworkGatewayId()voidunsetPriority()
-
Field Details
-
attributes
The attributes for this member. -
hardware
The device for this member. -
networkGateway
The gateway this member belongs to. -
hardwareId
The internal identifier of the hardware for this member. -
hardwareIdSpecified
protected boolean hardwareIdSpecified -
id
A gateway member's internal identifier. -
idSpecified
protected boolean idSpecified -
networkGatewayId
The internal identifier of the gateway this member belongs to. -
networkGatewayIdSpecified
protected boolean networkGatewayIdSpecified -
priority
The priority for this gateway member. This is set internally and cannot be provided on create. -
prioritySpecified
protected boolean prioritySpecified
-
-
Constructor Details
-
Member
public Member()
-
-
Method Details
-
getAttributes
-
setAttributes
-
getHardware
-
setHardware
-
getNetworkGateway
-
setNetworkGateway
-
getHardwareId
-
setHardwareId
-
isHardwareIdSpecified
public boolean isHardwareIdSpecified() -
unsetHardwareId
public void unsetHardwareId() -
getId
-
setId
-
isIdSpecified
public boolean isIdSpecified() -
unsetId
public void unsetId() -
getNetworkGatewayId
-
setNetworkGatewayId
-
isNetworkGatewayIdSpecified
public boolean isNetworkGatewayIdSpecified() -
unsetNetworkGatewayId
public void unsetNetworkGatewayId() -
getPriority
-
setPriority
-
isPrioritySpecified
public boolean isPrioritySpecified() -
unsetPriority
public void unsetPriority() -
asService
-
service
-
service
-