Interface Status.Service
- All Superinterfaces:
Maskable,ResultLimitable,Service
- Enclosing class:
- Status
@ApiService("SoftLayer_Network_Gateway_Status") public static interface Status.Service extends Service
A network gateway status is a value representing the state of a network gateway. The possible values are "ACTIVE" for when the gateway is ready for normal use and "UPDATING" for when the gateway is being updated.
- See Also:
- SoftLayer_Network_Gateway_Status
-
Method Summary
Modifier and Type Method Description Status.ServiceAsyncasAsync()Get an async version of this serviceStatusgetObject()voidsetMask(Status.Mask mask)Status.MaskwithMask()Use the existing mask on this service or create it if not presentStatus.MaskwithNewMask()Overwrite the existing mask on this service with a new one and return itMethods inherited from interface com.softlayer.api.ResultLimitable
getLastResponseTotalItemCount, getResultLimit, setResultLimit
-
Method Details
-
asAsync
Status.ServiceAsync asAsync()Description copied from interface:ServiceGet an async version of this service -
withNewMask
Status.Mask withNewMask()Description copied from interface:MaskableOverwrite the existing mask on this service with a new one and return it- Specified by:
withNewMaskin interfaceMaskable
-
withMask
Status.Mask withMask()Description copied from interface:MaskableUse the existing mask on this service or create it if not present -
setMask
-
getObject
-