Uses of Class
com.softlayer.api.service.network.gateway.Status
| Package | Description |
|---|---|
| com.softlayer.api.service.network | |
| com.softlayer.api.service.network.gateway |
-
Uses of Status in com.softlayer.api.service.network
Fields in com.softlayer.api.service.network declared as Status Modifier and Type Field Description protected StatusGateway. statusThe current status of the gateway.Methods in com.softlayer.api.service.network that return Status Modifier and Type Method Description StatusGateway. getStatus()StatusGateway.Service. getStatus()The current status of the gateway.Methods in com.softlayer.api.service.network that return types with arguments of type Status Modifier and Type Method Description Future<Status>Gateway.ServiceAsync. getStatus()Async version ofGateway.Service.getStatus()Methods in com.softlayer.api.service.network with parameters of type Status Modifier and Type Method Description voidGateway. setStatus(Status status)Method parameters in com.softlayer.api.service.network with type arguments of type Status Modifier and Type Method Description Future<?>Gateway.ServiceAsync. getStatus(ResponseHandler<Status> callback)Async callback version ofGateway.Service.getStatus() -
Uses of Status in com.softlayer.api.service.network.gateway
Methods in com.softlayer.api.service.network.gateway that return Status Modifier and Type Method Description StatusStatus.Service. getObject()Methods in com.softlayer.api.service.network.gateway that return types with arguments of type Status Modifier and Type Method Description Future<Status>Status.ServiceAsync. getObject()Async version ofStatus.Service.getObject()Method parameters in com.softlayer.api.service.network.gateway with type arguments of type Status Modifier and Type Method Description Future<?>Status.ServiceAsync. getObject(ResponseHandler<Status> callback)