Interface HealthMonitor.ServiceAsync
- All Superinterfaces:
Maskable,ResultLimitable,ServiceAsync
- Enclosing class:
- HealthMonitor
public static interface HealthMonitor.ServiceAsync extends ServiceAsync
-
Method Summary
Modifier and Type Method Description Future<HealthMonitor>getObject()Async version ofHealthMonitor.Service.getObject()Future<?>getObject(ResponseHandler<HealthMonitor> callback)voidsetMask(HealthMonitor.Mask mask)Future<LoadBalancer>updateLoadBalancerHealthMonitors(String loadBalancerUuid, List<LoadBalancerHealthMonitorConfiguration> healthMonitorConfigurations)Future<?>updateLoadBalancerHealthMonitors(String loadBalancerUuid, List<LoadBalancerHealthMonitorConfiguration> healthMonitorConfigurations, ResponseHandler<LoadBalancer> callback)HealthMonitor.MaskwithMask()Use the existing mask on this service or create it if not presentHealthMonitor.MaskwithNewMask()Overwrite the existing mask on this service with a new one and return itMethods inherited from interface com.softlayer.api.ResultLimitable
getLastResponseTotalItemCount, getResultLimit, setResultLimit
-
Method Details
-
withNewMask
HealthMonitor.Mask withNewMask()Description copied from interface:MaskableOverwrite the existing mask on this service with a new one and return it- Specified by:
withNewMaskin interfaceMaskable
-
withMask
HealthMonitor.Mask withMask()Description copied from interface:MaskableUse the existing mask on this service or create it if not present -
setMask
-
getObject
Future<HealthMonitor> getObject()Async version ofHealthMonitor.Service.getObject() -
getObject
-
updateLoadBalancerHealthMonitors
Future<LoadBalancer> updateLoadBalancerHealthMonitors(String loadBalancerUuid, List<LoadBalancerHealthMonitorConfiguration> healthMonitorConfigurations) -
updateLoadBalancerHealthMonitors
Future<?> updateLoadBalancerHealthMonitors(String loadBalancerUuid, List<LoadBalancerHealthMonitorConfiguration> healthMonitorConfigurations, ResponseHandler<LoadBalancer> callback)
-