Class LoadBalancer
java.lang.Object
com.softlayer.api.Type
com.softlayer.api.service.Entity
com.softlayer.api.service.network.lbaas.LoadBalancer
@ApiType("SoftLayer_Network_LBaaS_LoadBalancer") public class LoadBalancer extends Entity
The SoftLayer_Network_LBaaS_LoadBalancer type presents a structure containing attributes of a load balancer, and its related objects including listeners, pools and members.
- See Also:
- SoftLayer_Network_LBaaS_LoadBalancer
-
Nested Class Summary
Nested Classes Modifier and Type Class Description static classLoadBalancer.Maskstatic interfaceLoadBalancer.ServiceThe SoftLayer_Network_LBaaS_LoadBalancer service allows customers to create, edit, delete, get details of a load balancer instance and retrieve all existing load balancer instances.static interfaceLoadBalancer.ServiceAsync -
Field Summary
Fields Modifier and Type Field Description protected LongaccountIdThe account this load balancer belongs to.protected booleanaccountIdSpecifiedprotected StringaddressAddress (Host name) of a load balancer.protected booleanaddressSpecifiedprotected GregorianCalendarcreateDateSpecifies when a load balancer was created.protected booleancreateDateSpecifiedprotected LocationdatacenterDatacenter, where load balancer is located.protected StringdescriptionDescription of a load balancer.protected booleandescriptionSpecifiedprotected LonghealthMonitorCountA count of health monitors for the backend members.protected List<HealthMonitor>healthMonitorsHealth monitors for the backend members.protected LongidThe unique identifier of a load balancer.protected booleanidSpecifiedprotected LongisDataLogEnabledSpecifies whether the data log is enabled for the load balancer.protected booleanisDataLogEnabledSpecifiedprotected LongisPublicSpecifies whether the load balancer is a public or internal load balancer.protected booleanisPublicSpecifiedprotected Longl7PoolCountA count of l7Pools for load balancer.protected List<L7Pool>l7PoolsL7Pools for load balancer.protected LonglistenerCountA count of listeners assigned to load balancer.protected List<Listener>listenersListeners assigned to load balancer.protected LonglocationIdThis references to location with type datacenterprotected booleanlocationIdSpecifiedprotected LongmemberCountA count of members assigned to load balancer.protected List<Member>membersMembers assigned to load balancer.protected GregorianCalendarmodifyDateSpecifies when a load balancer was updated last.protected booleanmodifyDateSpecifiedprotected StringnameThe load balancer's name.protected booleannameSpecifiedprotected StringoperatingStatusThe operation status "ONLINE" or "OFFLINE" of a load balancer.protected booleanoperatingStatusSpecifiedprotected StringpreviousErrorTextError message of previous API call in case of failureprotected booleanpreviousErrorTextSpecifiedprotected StringprovisioningStatusThe provisioning status of a load balancer.protected booleanprovisioningStatusSpecifiedprotected LongsslCipherCountA count of list of preferred custom ciphers configured for the load balancer.protected List<SSLCipher>sslCipherslist of preferred custom ciphers configured for the load balancer.protected LongtypeSpecifies the type of load balancer.protected booleantypeSpecifiedprotected LonguseSystemPublicIpPoolApplicable for public load balancer only.protected booleanuseSystemPublicIpPoolSpecifiedprotected StringuuidThe UUID of a load balancer.protected booleanuuidSpecified -
Constructor Summary
Constructors Constructor Description LoadBalancer() -
Method Summary
-
Field Details
-
datacenter
Datacenter, where load balancer is located. -
healthMonitors
Health monitors for the backend members. -
l7Pools
L7Pools for load balancer. -
listeners
Listeners assigned to load balancer. -
members
Members assigned to load balancer. -
sslCiphers
list of preferred custom ciphers configured for the load balancer. -
accountId
The account this load balancer belongs to. -
accountIdSpecified
protected boolean accountIdSpecified -
address
Address (Host name) of a load balancer. -
addressSpecified
protected boolean addressSpecified -
createDate
Specifies when a load balancer was created. -
createDateSpecified
protected boolean createDateSpecified -
description
Description of a load balancer. -
descriptionSpecified
protected boolean descriptionSpecified -
id
The unique identifier of a load balancer. -
idSpecified
protected boolean idSpecified -
isDataLogEnabled
Specifies whether the data log is enabled for the load balancer. -
isDataLogEnabledSpecified
protected boolean isDataLogEnabledSpecified -
isPublic
Specifies whether the load balancer is a public or internal load balancer. -
isPublicSpecified
protected boolean isPublicSpecified -
locationId
This references to location with type datacenter -
locationIdSpecified
protected boolean locationIdSpecified -
modifyDate
Specifies when a load balancer was updated last. -
modifyDateSpecified
protected boolean modifyDateSpecified -
name
The load balancer's name. -
nameSpecified
protected boolean nameSpecified -
operatingStatus
The operation status "ONLINE" or "OFFLINE" of a load balancer. -
operatingStatusSpecified
protected boolean operatingStatusSpecified -
previousErrorText
Error message of previous API call in case of failure -
previousErrorTextSpecified
protected boolean previousErrorTextSpecified -
provisioningStatus
The provisioning status of a load balancer. -
provisioningStatusSpecified
protected boolean provisioningStatusSpecified -
type
Specifies the type of load balancer. -
typeSpecified
protected boolean typeSpecified -
useSystemPublicIpPool
Applicable for public load balancer only. It specifies whether the public IP addresses are allocated from system public IP pool (1, default) or public subnet (null | 0) from the account ordering the load balancer. For internal load balancer, useSystemPublicIpPool will be ignored, and it always defaults to 1. -
useSystemPublicIpPoolSpecified
protected boolean useSystemPublicIpPoolSpecified -
uuid
The UUID of a load balancer. -
uuidSpecified
protected boolean uuidSpecified -
healthMonitorCount
A count of health monitors for the backend members. -
l7PoolCount
A count of l7Pools for load balancer. -
listenerCount
A count of listeners assigned to load balancer. -
memberCount
A count of members assigned to load balancer. -
sslCipherCount
A count of list of preferred custom ciphers configured for the load balancer.
-
-
Constructor Details
-
LoadBalancer
public LoadBalancer()
-
-
Method Details
-
getDatacenter
-
setDatacenter
-
getHealthMonitors
-
getL7Pools
-
getListeners
-
getMembers
-
getSslCiphers
-
getAccountId
-
setAccountId
-
isAccountIdSpecified
public boolean isAccountIdSpecified() -
unsetAccountId
public void unsetAccountId() -
getAddress
-
setAddress
-
isAddressSpecified
public boolean isAddressSpecified() -
unsetAddress
public void unsetAddress() -
getCreateDate
-
setCreateDate
-
isCreateDateSpecified
public boolean isCreateDateSpecified() -
unsetCreateDate
public void unsetCreateDate() -
getDescription
-
setDescription
-
isDescriptionSpecified
public boolean isDescriptionSpecified() -
unsetDescription
public void unsetDescription() -
getId
-
setId
-
isIdSpecified
public boolean isIdSpecified() -
unsetId
public void unsetId() -
getIsDataLogEnabled
-
setIsDataLogEnabled
-
isIsDataLogEnabledSpecified
public boolean isIsDataLogEnabledSpecified() -
unsetIsDataLogEnabled
public void unsetIsDataLogEnabled() -
getIsPublic
-
setIsPublic
-
isIsPublicSpecified
public boolean isIsPublicSpecified() -
unsetIsPublic
public void unsetIsPublic() -
getLocationId
-
setLocationId
-
isLocationIdSpecified
public boolean isLocationIdSpecified() -
unsetLocationId
public void unsetLocationId() -
getModifyDate
-
setModifyDate
-
isModifyDateSpecified
public boolean isModifyDateSpecified() -
unsetModifyDate
public void unsetModifyDate() -
getName
-
setName
-
isNameSpecified
public boolean isNameSpecified() -
unsetName
public void unsetName() -
getOperatingStatus
-
setOperatingStatus
-
isOperatingStatusSpecified
public boolean isOperatingStatusSpecified() -
unsetOperatingStatus
public void unsetOperatingStatus() -
getPreviousErrorText
-
setPreviousErrorText
-
isPreviousErrorTextSpecified
public boolean isPreviousErrorTextSpecified() -
unsetPreviousErrorText
public void unsetPreviousErrorText() -
getProvisioningStatus
-
setProvisioningStatus
-
isProvisioningStatusSpecified
public boolean isProvisioningStatusSpecified() -
unsetProvisioningStatus
public void unsetProvisioningStatus() -
getType
-
setType
-
isTypeSpecified
public boolean isTypeSpecified() -
unsetType
public void unsetType() -
getUseSystemPublicIpPool
-
setUseSystemPublicIpPool
-
isUseSystemPublicIpPoolSpecified
public boolean isUseSystemPublicIpPoolSpecified() -
unsetUseSystemPublicIpPool
public void unsetUseSystemPublicIpPool() -
getUuid
-
setUuid
-
isUuidSpecified
public boolean isUuidSpecified() -
unsetUuid
public void unsetUuid() -
getHealthMonitorCount
-
setHealthMonitorCount
-
getL7PoolCount
-
setL7PoolCount
-
getListenerCount
-
setListenerCount
-
getMemberCount
-
setMemberCount
-
getSslCipherCount
-
setSslCipherCount
-
asService
-
service
-
service
-