Class LoadBalancerMonitoringMetricDataPoint
java.lang.Object
com.softlayer.api.Type
com.softlayer.api.service.Entity
com.softlayer.api.service.network.lbaas.LoadBalancerMonitoringMetricDataPoint
@ApiType("SoftLayer_Network_LBaaS_LoadBalancerMonitoringMetricDataPoint") public class LoadBalancerMonitoringMetricDataPoint extends Entity
SoftLayer_Network_LBaaS_LoadBalancerMonitoringMetricDataPoint is a collection of datapoints retrieved from a load balancer instance. The available metrics are:
- The metric value
- The timestamp when the metric value was obtained
-
Nested Class Summary
Nested Classes Modifier and Type Class Description static classLoadBalancerMonitoringMetricDataPoint.Mask -
Field Summary
Fields Modifier and Type Field Description protected LongepochTimestampEpoch Timeprotected booleanepochTimestampSpecifiedprotected BigDecimalvaluea valueprotected booleanvalueSpecified -
Constructor Summary
Constructors Constructor Description LoadBalancerMonitoringMetricDataPoint() -
Method Summary
Modifier and Type Method Description LonggetEpochTimestamp()BigDecimalgetValue()booleanisEpochTimestampSpecified()booleanisValueSpecified()voidsetEpochTimestamp(Long epochTimestamp)voidsetValue(BigDecimal value)voidunsetEpochTimestamp()voidunsetValue()
-
Field Details
-
epochTimestamp
Epoch Time -
epochTimestampSpecified
protected boolean epochTimestampSpecified -
value
a value -
valueSpecified
protected boolean valueSpecified
-
-
Constructor Details
-
LoadBalancerMonitoringMetricDataPoint
public LoadBalancerMonitoringMetricDataPoint()
-
-
Method Details
-
getEpochTimestamp
-
setEpochTimestamp
-
isEpochTimestampSpecified
public boolean isEpochTimestampSpecified() -
unsetEpochTimestamp
public void unsetEpochTimestamp() -
getValue
-
setValue
-
isValueSpecified
public boolean isValueSpecified() -
unsetValue
public void unsetValue()
-