Class SSLCipher
java.lang.Object
com.softlayer.api.Type
com.softlayer.api.service.Entity
com.softlayer.api.service.network.lbaas.SSLCipher
@ApiType("SoftLayer_Network_LBaaS_SSLCipher") public class SSLCipher extends Entity
The SoftLayer_Network_LBaaS_SSLCipher type presents a structure that contains attributes of load balancer cipher suites.
- See Also:
- SoftLayer_Network_LBaaS_SSLCipher
-
Nested Class Summary
Nested Classes Modifier and Type Class Description static classSSLCipher.Maskstatic interfaceSSLCipher.Servicestatic interfaceSSLCipher.ServiceAsync -
Field Summary
Fields Modifier and Type Field Description protected LongidCipher identifierprotected booleanidSpecifiedprotected StringnameName of the cipherprotected booleannameSpecified -
Constructor Summary
Constructors Constructor Description SSLCipher() -
Method Summary
Modifier and Type Method Description SSLCipher.ServiceasService(ApiClient client)LonggetId()StringgetName()booleanisIdSpecified()booleanisNameSpecified()static SSLCipher.Serviceservice(ApiClient client)static SSLCipher.Serviceservice(ApiClient client, Long id)voidsetId(Long id)voidsetName(String name)voidunsetId()voidunsetName()
-
Field Details
-
id
Cipher identifier -
idSpecified
protected boolean idSpecified -
name
Name of the cipher -
nameSpecified
protected boolean nameSpecified
-
-
Constructor Details
-
SSLCipher
public SSLCipher()
-
-
Method Details