Interface VirtualIpAddress.Service
- All Superinterfaces:
Maskable,ResultLimitable,Service
- Enclosing class:
- VirtualIpAddress
@ApiService("SoftLayer_Network_LoadBalancer_VirtualIpAddress") public static interface VirtualIpAddress.Service extends Service
Each SoftLayer customer that has purchased a load balancer will have one defined in the SoftLayer_Network_LoadBalancer_VirtualIpAddress service. Load balancers have a virtual IP address and a number of SoftLayer_Network_LoadBalancer_Service objects associated with them. The SoftLayer_Network_LoadBalancer_VirtualIpAddress object is the only way for a customer to make changes to their load balancer service.
Load balancers can be upgraded by using the upgradeConnectionLimit function, but this will upgrade your billing accordingly. Downgrades are currently not supported, please open a ticket to accomplish a downgrade.
Load balancers can be upgraded by using the upgradeConnectionLimit function, but this will upgrade your billing accordingly. Downgrades are currently not supported, please open a ticket to accomplish a downgrade.
-
Method Summary
Modifier and Type Method Description VirtualIpAddress.ServiceAsyncasAsync()Get an async version of this serviceBooleandisable()Disable a Virtual IP Address, removing it from load balancer rotation and denying all connections to that IP address.BooleaneditObject(VirtualIpAddress templateObject)Like any other API object, the load balancers can have their exposed properties edited by passing in a modified version of the object.Booleanenable()Enable a disabled Virtual IP Address, allowing connections back to the IP address.AccountgetAccount()The account that owns this load balancer.ItemgetBillingItem()The current billing item for the Load Balancer.LonggetCustomerManagedFlag()If false, this VIP and associated services may be edited via the portal or the API.BooleangetManagedResourceFlag()A flag indicating that the load balancer is a managed resource.VirtualIpAddressgetObject()getObject retrieves the SoftLayer_Network_LoadBalancer_VirtualIpAddress object whose ID number corresponds to the ID number of the init parameter passed to the SoftLayer_Network_LoadBalancer_VirtualIpAddress service.List<LoadBalancerService>getServices()the services on this load balancer.BooleankickAllConnections()Quickly remove all active external connections to a Virtual IP Address.voidsetMask(VirtualIpAddress.Mask mask)BooleanupgradeConnectionLimit()Upgrades the connection limit on the VirtualIp and changes the billing item on your account to reflect the change.VirtualIpAddress.MaskwithMask()Use the existing mask on this service or create it if not presentVirtualIpAddress.MaskwithNewMask()Overwrite the existing mask on this service with a new one and return itMethods inherited from interface com.softlayer.api.ResultLimitable
getLastResponseTotalItemCount, getResultLimit, setResultLimit
-
Method Details
-
asAsync
VirtualIpAddress.ServiceAsync asAsync()Description copied from interface:ServiceGet an async version of this service -
withNewMask
VirtualIpAddress.Mask withNewMask()Description copied from interface:MaskableOverwrite the existing mask on this service with a new one and return it- Specified by:
withNewMaskin interfaceMaskable
-
withMask
VirtualIpAddress.Mask withMask()Description copied from interface:MaskableUse the existing mask on this service or create it if not present -
setMask
-
disable
Disable a Virtual IP Address, removing it from load balancer rotation and denying all connections to that IP address. -
editObject
Like any other API object, the load balancers can have their exposed properties edited by passing in a modified version of the object. The load balancer object also can modify its services in this way. Simply request the load balancer object you wish to edit, then modify the objects in the services array and pass the modified object to this function. WARNING: Services cannot be deleted in this manner, you must call deleteObject() on the service to physically remove them from the load balancer. -
enable
Enable a disabled Virtual IP Address, allowing connections back to the IP address. -
getObject
getObject retrieves the SoftLayer_Network_LoadBalancer_VirtualIpAddress object whose ID number corresponds to the ID number of the init parameter passed to the SoftLayer_Network_LoadBalancer_VirtualIpAddress service. You can only retrieve Load Balancers assigned to your account. -
kickAllConnections
Quickly remove all active external connections to a Virtual IP Address. -
upgradeConnectionLimit
Upgrades the connection limit on the VirtualIp and changes the billing item on your account to reflect the change. This function will only upgrade you to the next "level" of service. The next level follows this pattern Current Level => Next Level 50 100 100 200 200 500 500 1000 1000 1200 1200 1500 1500 2000 2000 2500 2500 3000 -
getAccount
The account that owns this load balancer. -
getBillingItem
The current billing item for the Load Balancer. -
getCustomerManagedFlag
If false, this VIP and associated services may be edited via the portal or the API. If true, you must configure this VIP manually on the device. -
getManagedResourceFlag
A flag indicating that the load balancer is a managed resource. -
getServices
the services on this load balancer.
-