Class Syslog
java.lang.Object
com.softlayer.api.Type
com.softlayer.api.service.Entity
com.softlayer.api.service.network.logging.Syslog
@ApiType("SoftLayer_Network_Logging_Syslog") public class Syslog extends Entity
The Syslog class holds a single line from the Networking Firewall "Syslog" record, for firewall detected and blocked attempts on a server.
- See Also:
- SoftLayer_Network_Logging_Syslog
-
Nested Class Summary
Nested Classes Modifier and Type Class Description static classSyslog.Mask -
Field Summary
Fields Modifier and Type Field Description protected GregorianCalendarcreateDateTimestamp for when the connection was blocked by the firewallprotected booleancreateDateSpecifiedprotected StringdestinationIpAddressThe Destination IP Address of the blocked connection (your end)protected booleandestinationIpAddressSpecifiedprotected LongdestinationPortThe Destination Port of the blocked connection (your end)protected booleandestinationPortSpecifiedprotected StringeventTypeThis tells you what kind of firewall event this log line is for: accept or deny.protected booleaneventTypeSpecifiedprotected StringmessageRaw syslog message for the eventprotected booleanmessageSpecifiedprotected StringprotocolConnection protocol used to make the call that was blocked (tcp, udp, etc)protected booleanprotocolSpecifiedprotected StringsourceIpAddressThe Source IP Address of the call that was blocked (attacker's end)protected booleansourceIpAddressSpecifiedprotected LongsourcePortThe Source Port where the blocked connection was established (attacker's end)protected booleansourcePortSpecifiedprotected LongtotalEventsIf this is an aggregation of syslog events, this property shows the total events.protected booleantotalEventsSpecified -
Constructor Summary
Constructors Constructor Description Syslog() -
Method Summary
-
Field Details
-
createDate
Timestamp for when the connection was blocked by the firewall -
createDateSpecified
protected boolean createDateSpecified -
destinationIpAddress
The Destination IP Address of the blocked connection (your end) -
destinationIpAddressSpecified
protected boolean destinationIpAddressSpecified -
destinationPort
The Destination Port of the blocked connection (your end) -
destinationPortSpecified
protected boolean destinationPortSpecified -
eventType
This tells you what kind of firewall event this log line is for: accept or deny. -
eventTypeSpecified
protected boolean eventTypeSpecified -
message
Raw syslog message for the event -
messageSpecified
protected boolean messageSpecified -
protocol
Connection protocol used to make the call that was blocked (tcp, udp, etc) -
protocolSpecified
protected boolean protocolSpecified -
sourceIpAddress
The Source IP Address of the call that was blocked (attacker's end) -
sourceIpAddressSpecified
protected boolean sourceIpAddressSpecified -
sourcePort
The Source Port where the blocked connection was established (attacker's end) -
sourcePortSpecified
protected boolean sourcePortSpecified -
totalEvents
If this is an aggregation of syslog events, this property shows the total events. -
totalEventsSpecified
protected boolean totalEventsSpecified
-
-
Constructor Details
-
Syslog
public Syslog()
-
-
Method Details
-
getCreateDate
-
setCreateDate
-
isCreateDateSpecified
public boolean isCreateDateSpecified() -
unsetCreateDate
public void unsetCreateDate() -
getDestinationIpAddress
-
setDestinationIpAddress
-
isDestinationIpAddressSpecified
public boolean isDestinationIpAddressSpecified() -
unsetDestinationIpAddress
public void unsetDestinationIpAddress() -
getDestinationPort
-
setDestinationPort
-
isDestinationPortSpecified
public boolean isDestinationPortSpecified() -
unsetDestinationPort
public void unsetDestinationPort() -
getEventType
-
setEventType
-
isEventTypeSpecified
public boolean isEventTypeSpecified() -
unsetEventType
public void unsetEventType() -
getMessage
-
setMessage
-
isMessageSpecified
public boolean isMessageSpecified() -
unsetMessage
public void unsetMessage() -
getProtocol
-
setProtocol
-
isProtocolSpecified
public boolean isProtocolSpecified() -
unsetProtocol
public void unsetProtocol() -
getSourceIpAddress
-
setSourceIpAddress
-
isSourceIpAddressSpecified
public boolean isSourceIpAddressSpecified() -
unsetSourceIpAddress
public void unsetSourceIpAddress() -
getSourcePort
-
setSourcePort
-
isSourcePortSpecified
public boolean isSourcePortSpecified() -
unsetSourcePort
public void unsetSourcePort() -
getTotalEvents
-
setTotalEvents
-
isTotalEventsSpecified
public boolean isTotalEventsSpecified() -
unsetTotalEvents
public void unsetTotalEvents()
-