Class Account
java.lang.Object
com.softlayer.api.Type
com.softlayer.api.service.Entity
com.softlayer.api.service.network.media.transcode.Account
@ApiType("SoftLayer_Network_Media_Transcode_Account") public class Account extends Entity
The SoftLayer_Network_Media_Transcode_Account contains information regarding a transcode account.
-
Nested Class Summary
Nested Classes Modifier and Type Class Description static classAccount.Maskstatic interfaceAccount.ServiceTranscoding is a service which allows you to transcode media files to different formats.static interfaceAccount.ServiceAsync -
Field Summary
Fields Modifier and Type Field Description protected AccountaccountThe SoftLayer account informationprotected LongaccountIdThe internal identifier of a SoftLayer accountprotected booleanaccountIdSpecifiedprotected GregorianCalendarcreateDateThe created dateprotected booleancreateDateSpecifiedprotected LongidThe internal identifier of a transcode accountprotected booleanidSpecifiedprotected GregorianCalendarmodifyDateThe last modified dateprotected booleanmodifyDateSpecifiedprotected LongtranscodeJobCountA count of transcode jobsprotected List<Job>transcodeJobsTranscode jobs -
Constructor Summary
Constructors Constructor Description Account() -
Method Summary
Modifier and Type Method Description Account.ServiceasService(ApiClient client)AccountgetAccount()LonggetAccountId()GregorianCalendargetCreateDate()LonggetId()GregorianCalendargetModifyDate()LonggetTranscodeJobCount()List<Job>getTranscodeJobs()booleanisAccountIdSpecified()booleanisCreateDateSpecified()booleanisIdSpecified()booleanisModifyDateSpecified()static Account.Serviceservice(ApiClient client)static Account.Serviceservice(ApiClient client, Long id)voidsetAccount(Account account)voidsetAccountId(Long accountId)voidsetCreateDate(GregorianCalendar createDate)voidsetId(Long id)voidsetModifyDate(GregorianCalendar modifyDate)voidsetTranscodeJobCount(Long transcodeJobCount)voidunsetAccountId()voidunsetCreateDate()voidunsetId()voidunsetModifyDate()
-
Field Details
-
account
The SoftLayer account information -
transcodeJobs
Transcode jobs -
accountId
The internal identifier of a SoftLayer account -
accountIdSpecified
protected boolean accountIdSpecified -
createDate
The created date -
createDateSpecified
protected boolean createDateSpecified -
id
The internal identifier of a transcode account -
idSpecified
protected boolean idSpecified -
modifyDate
The last modified date -
modifyDateSpecified
protected boolean modifyDateSpecified -
transcodeJobCount
A count of transcode jobs
-
-
Constructor Details
-
Account
public Account()
-
-
Method Details
-
getAccount
-
setAccount
-
getTranscodeJobs
-
getAccountId
-
setAccountId
-
isAccountIdSpecified
public boolean isAccountIdSpecified() -
unsetAccountId
public void unsetAccountId() -
getCreateDate
-
setCreateDate
-
isCreateDateSpecified
public boolean isCreateDateSpecified() -
unsetCreateDate
public void unsetCreateDate() -
getId
-
setId
-
isIdSpecified
public boolean isIdSpecified() -
unsetId
public void unsetId() -
getModifyDate
-
setModifyDate
-
isModifyDateSpecified
public boolean isModifyDateSpecified() -
unsetModifyDate
public void unsetModifyDate() -
getTranscodeJobCount
-
setTranscodeJobCount
-
asService
-
service
-
service
-