Uses of Class
com.softlayer.api.service.network.media.transcode.Account
| Package | Description |
|---|---|
| com.softlayer.api.service | |
| com.softlayer.api.service.network.media.transcode |
-
Uses of Account in com.softlayer.api.service
Fields in com.softlayer.api.service with type parameters of type Account Modifier and Type Field Description protected List<Account>Account. transcodeAccountsAn account's associated Transcode account.Methods in com.softlayer.api.service that return types with arguments of type Account Modifier and Type Method Description List<Account>Account. getTranscodeAccounts()List<Account>Account.Service. getTranscodeAccounts()An account's associated Transcode account.Future<List<Account>>Account.ServiceAsync. getTranscodeAccounts()Async version ofAccount.Service.getTranscodeAccounts()Method parameters in com.softlayer.api.service with type arguments of type Account Modifier and Type Method Description Future<?>Account.ServiceAsync. getTranscodeAccounts(ResponseHandler<List<Account>> callback)Async callback version ofAccount.Service.getTranscodeAccounts() -
Uses of Account in com.softlayer.api.service.network.media.transcode
Fields in com.softlayer.api.service.network.media.transcode declared as Account Modifier and Type Field Description protected AccountJob. transcodeAccountThe transcode service accountMethods in com.softlayer.api.service.network.media.transcode that return Account Modifier and Type Method Description AccountAccount.Service. getObject()getObject method retrieves the SoftLayer_Network_Media_Transcode_Account object whose ID number corresponds to the ID number of the initial parameter passed to the SoftLayer_Network_Media_Transcode_Account service.AccountJob. getTranscodeAccount()AccountJob.Service. getTranscodeAccount()The transcode service accountMethods in com.softlayer.api.service.network.media.transcode that return types with arguments of type Account Modifier and Type Method Description Future<Account>Account.ServiceAsync. getObject()Async version ofAccount.Service.getObject()Future<Account>Job.ServiceAsync. getTranscodeAccount()Async version ofJob.Service.getTranscodeAccount()Methods in com.softlayer.api.service.network.media.transcode with parameters of type Account Modifier and Type Method Description voidJob. setTranscodeAccount(Account transcodeAccount)Method parameters in com.softlayer.api.service.network.media.transcode with type arguments of type Account Modifier and Type Method Description Future<?>Account.ServiceAsync. getObject(ResponseHandler<Account> callback)Future<?>Job.ServiceAsync. getTranscodeAccount(ResponseHandler<Account> callback)Async callback version ofJob.Service.getTranscodeAccount()