Class Delivery
java.lang.Object
com.softlayer.api.Type
com.softlayer.api.service.Entity
com.softlayer.api.service.network.message.Delivery
- Direct Known Subclasses:
Sendgrid
@ApiType("SoftLayer_Network_Message_Delivery") public class Delivery extends Entity
- See Also:
- SoftLayer_Network_Message_Delivery
-
Nested Class Summary
Nested Classes Modifier and Type Class Description static classDelivery.Maskstatic interfaceDelivery.Servicestatic interfaceDelivery.ServiceAsync -
Field Summary
Fields Modifier and Type Field Description protected AccountaccountThe SoftLayer customer account that a network message delivery account belongs to.protected LongaccountIdprotected booleanaccountIdSpecifiedprotected ItembillingItemThe billing item for a network message delivery account.protected GregorianCalendarcreateDateprotected booleancreateDateSpecifiedprotected Longidprotected booleanidSpecifiedprotected GregorianCalendarmodifyDateprotected booleanmodifyDateSpecifiedprotected Stringpasswordprotected booleanpasswordSpecifiedprotected TypetypeThe message delivery type of a network message delivery account.protected LongtypeIdprotected booleantypeIdSpecifiedprotected Stringusernameprotected booleanusernameSpecifiedprotected VendorvendorThe vendor for a network message delivery account.protected LongvendorIdprotected booleanvendorIdSpecified -
Constructor Summary
Constructors Constructor Description Delivery() -
Method Summary
-
Field Details
-
account
The SoftLayer customer account that a network message delivery account belongs to. -
billingItem
The billing item for a network message delivery account. -
type
The message delivery type of a network message delivery account. -
vendor
The vendor for a network message delivery account. -
accountId
-
accountIdSpecified
protected boolean accountIdSpecified -
createDate
-
createDateSpecified
protected boolean createDateSpecified -
id
-
idSpecified
protected boolean idSpecified -
modifyDate
-
modifyDateSpecified
protected boolean modifyDateSpecified -
password
-
passwordSpecified
protected boolean passwordSpecified -
typeId
-
typeIdSpecified
protected boolean typeIdSpecified -
username
-
usernameSpecified
protected boolean usernameSpecified -
vendorId
-
vendorIdSpecified
protected boolean vendorIdSpecified
-
-
Constructor Details
-
Delivery
public Delivery()
-
-
Method Details
-
getAccount
-
setAccount
-
getBillingItem
-
setBillingItem
-
getType
-
setType
-
getVendor
-
setVendor
-
getAccountId
-
setAccountId
-
isAccountIdSpecified
public boolean isAccountIdSpecified() -
unsetAccountId
public void unsetAccountId() -
getCreateDate
-
setCreateDate
-
isCreateDateSpecified
public boolean isCreateDateSpecified() -
unsetCreateDate
public void unsetCreateDate() -
getId
-
setId
-
isIdSpecified
public boolean isIdSpecified() -
unsetId
public void unsetId() -
getModifyDate
-
setModifyDate
-
isModifyDateSpecified
public boolean isModifyDateSpecified() -
unsetModifyDate
public void unsetModifyDate() -
getPassword
-
setPassword
-
isPasswordSpecified
public boolean isPasswordSpecified() -
unsetPassword
public void unsetPassword() -
getTypeId
-
setTypeId
-
isTypeIdSpecified
public boolean isTypeIdSpecified() -
unsetTypeId
public void unsetTypeId() -
getUsername
-
setUsername
-
isUsernameSpecified
public boolean isUsernameSpecified() -
unsetUsername
public void unsetUsername() -
getVendorId
-
setVendorId
-
isVendorIdSpecified
public boolean isVendorIdSpecified() -
unsetVendorId
public void unsetVendorId() -
asService
-
service
-
service
-