Interface Delivery.ServiceAsync
- All Superinterfaces:
Maskable,ResultLimitable,ServiceAsync
- All Known Subinterfaces:
Sendgrid.ServiceAsync
- Enclosing class:
- Delivery
public static interface Delivery.ServiceAsync extends ServiceAsync
-
Method Summary
Methods inherited from interface com.softlayer.api.ResultLimitable
getLastResponseTotalItemCount, getResultLimit, setResultLimit
-
Method Details
-
withNewMask
Delivery.Mask withNewMask()Description copied from interface:MaskableOverwrite the existing mask on this service with a new one and return it- Specified by:
withNewMaskin interfaceMaskable
-
withMask
Delivery.Mask withMask()Description copied from interface:MaskableUse the existing mask on this service or create it if not present -
setMask
-
editObject
-
editObject
-
getObject
Async version ofDelivery.Service.getObject() -
getObject
-
getAccount
Async version ofDelivery.Service.getAccount() -
getAccount
Async callback version ofDelivery.Service.getAccount() -
getBillingItem
Async version ofDelivery.Service.getBillingItem() -
getBillingItem
Async callback version ofDelivery.Service.getBillingItem() -
getType
Async version ofDelivery.Service.getType() -
getType
Async callback version ofDelivery.Service.getType() -
getVendor
Async version ofDelivery.Service.getVendor() -
getVendor
Async callback version ofDelivery.Service.getVendor()
-