-
-
Class Summary
| Class |
Description |
| Backbone |
A SoftLayer_Network_Backbone represents a single backbone connection from SoftLayer to the public Internet, from the Internet to the SoftLayer private network, or a link that connects the private networks between SoftLayer's datacenters.
|
| Backbone.Mask |
|
| Component |
Every piece of hardware running in SoftLayer's datacenters connected to the public, private, or management networks (where applicable) have a corresponding network component.
|
| Component.Mask |
|
| Gateway |
A network gateway is a set of members which have a configurable set of VLANs trunked through them.
|
| Gateway.Mask |
|
| Monitor |
|
| Monitor.Mask |
|
| Pod |
SoftLayer_Network_Pod refers to a portion of a data center that share a Backend Customer Router (BCR) and usually a front-end counterpart known as a Frontend Customer Router (FCR).
|
| Pod.Mask |
|
| SecurityGroup |
The SoftLayer_Network_SecurityGroup data type contains general information for a single security group.
|
| SecurityGroup.Mask |
|
| Storage |
The SoftLayer_Network_Storage data type contains general information regarding a Storage product such as account id, access username and password, the Storage product type, and the server the Storage service is associated with.
|
| Storage.Mask |
|
| Subnet |
The SoftLayer_Network_Subnet data type contains general information relating to a single SoftLayer subnet.
|
| Subnet.Mask |
|
| Vlan |
The SoftLayer_Network_Vlan data type models a single VLAN within SoftLayer's public and private networks.
|
| Vlan.Mask |
|