Uses of Class
com.softlayer.api.service.network.security.scanner.Request
| Package | Description |
|---|---|
| com.softlayer.api.service | |
| com.softlayer.api.service.network.security.scanner | |
| com.softlayer.api.service.virtual |
-
Uses of Request in com.softlayer.api.service
Fields in com.softlayer.api.service with type parameters of type Request Modifier and Type Field Description protected List<Request>Account. securityScanRequestsAn account's vulnerability scan requests.protected List<Request>Hardware. securityScanRequestsInformation regarding a piece of hardware's vulnerability scan requests.Methods in com.softlayer.api.service that return types with arguments of type Request Modifier and Type Method Description List<Request>Account. getSecurityScanRequests()List<Request>Account.Service. getSecurityScanRequests()An account's vulnerability scan requests.Future<List<Request>>Account.ServiceAsync. getSecurityScanRequests()Async version ofAccount.Service.getSecurityScanRequests()List<Request>Hardware. getSecurityScanRequests()List<Request>Hardware.Service. getSecurityScanRequests()Information regarding a piece of hardware's vulnerability scan requests.Future<List<Request>>Hardware.ServiceAsync. getSecurityScanRequests()Async version ofHardware.Service.getSecurityScanRequests()Method parameters in com.softlayer.api.service with type arguments of type Request Modifier and Type Method Description Future<?>Account.ServiceAsync. getSecurityScanRequests(ResponseHandler<List<Request>> callback)Async callback version ofAccount.Service.getSecurityScanRequests()Future<?>Hardware.ServiceAsync. getSecurityScanRequests(ResponseHandler<List<Request>> callback)Async callback version ofHardware.Service.getSecurityScanRequests() -
Uses of Request in com.softlayer.api.service.network.security.scanner
Methods in com.softlayer.api.service.network.security.scanner that return Request Modifier and Type Method Description RequestRequest.Service. createObject(Request templateObject)Create a new vulnerability scan request.RequestRequest.Service. getObject()getObject retrieves the SoftLayer_Network_Security_Scanner_Request object whose ID number corresponds to the ID number of the init parameter passed to the SoftLayer_Network_Security_Scanner_Request service.Methods in com.softlayer.api.service.network.security.scanner that return types with arguments of type Request Modifier and Type Method Description Future<Request>Request.ServiceAsync. createObject(Request templateObject)Future<Request>Request.ServiceAsync. getObject()Async version ofRequest.Service.getObject()Methods in com.softlayer.api.service.network.security.scanner with parameters of type Request Modifier and Type Method Description RequestRequest.Service. createObject(Request templateObject)Create a new vulnerability scan request.Future<Request>Request.ServiceAsync. createObject(Request templateObject)Future<?>Request.ServiceAsync. createObject(Request templateObject, ResponseHandler<Request> callback)Method parameters in com.softlayer.api.service.network.security.scanner with type arguments of type Request Modifier and Type Method Description Future<?>Request.ServiceAsync. createObject(Request templateObject, ResponseHandler<Request> callback)Future<?>Request.ServiceAsync. getObject(ResponseHandler<Request> callback) -
Uses of Request in com.softlayer.api.service.virtual
Fields in com.softlayer.api.service.virtual with type parameters of type Request Modifier and Type Field Description protected List<Request>Guest. securityScanRequestsA guest's vulnerability scan requests.Methods in com.softlayer.api.service.virtual that return types with arguments of type Request Modifier and Type Method Description List<Request>Guest. getSecurityScanRequests()List<Request>Guest.Service. getSecurityScanRequests()A guest's vulnerability scan requests.Future<List<Request>>Guest.ServiceAsync. getSecurityScanRequests()Async version ofGuest.Service.getSecurityScanRequests()Method parameters in com.softlayer.api.service.virtual with type arguments of type Request Modifier and Type Method Description Future<?>Guest.ServiceAsync. getSecurityScanRequests(ResponseHandler<List<Request>> callback)Async callback version ofGuest.Service.getSecurityScanRequests()