Class Status
java.lang.Object
com.softlayer.api.Type
com.softlayer.api.service.Entity
com.softlayer.api.service.network.security.scanner.request.Status
@ApiType("SoftLayer_Network_Security_Scanner_Request_Status") public class Status extends Entity
The SoftLayer_Network_Security_Scanner_Request_Status data type represents the current status of a vulnerability scan. The status messages are as follows:
*Scan Pending
*Scan Processing
*Scan Complete
*Scan Cancelled
*Generating Report.
The status of a vulnerability scan will change over the course of a scan's execution.
*Scan Pending
*Scan Processing
*Scan Complete
*Scan Cancelled
*Generating Report.
The status of a vulnerability scan will change over the course of a scan's execution.
-
Nested Class Summary
Nested Classes Modifier and Type Class Description static classStatus.Mask -
Field Summary
Fields Modifier and Type Field Description protected LongidThe identifier of a vulnerability scan's status.protected booleanidSpecifiedprotected StringnameThe status message of a vulnerability scan.protected booleannameSpecifiedFields inherited from class com.softlayer.api.Type
unknownProperties -
Constructor Summary
Constructors Constructor Description Status() -
Method Summary
Methods inherited from class com.softlayer.api.Type
getUnknownProperties, setUnknownProperties
-
Field Details
-
id
The identifier of a vulnerability scan's status. -
idSpecified
protected boolean idSpecified -
name
The status message of a vulnerability scan. -
nameSpecified
protected boolean nameSpecified
-
-
Constructor Details
-
Status
public Status()
-
-
Method Details
-
getId
-
setId
-
isIdSpecified
public boolean isIdSpecified() -
unsetId
public void unsetId() -
getName
-
setName
-
isNameSpecified
public boolean isNameSpecified() -
unsetName
public void unsetName()
-