Class RequestRules
java.lang.Object
com.softlayer.api.Type
com.softlayer.api.service.Entity
com.softlayer.api.service.network.securitygroup.Request
com.softlayer.api.service.network.securitygroup.RequestRules
@ApiType("SoftLayer_Network_SecurityGroup_RequestRules") public class RequestRules extends Request
The SoftLayer_Network_SecurityGroup_RequestRules data type contains the ID of a specific request sent to the API, as well as an associative array of the rules that were created, edited, or removed by the request.
-
Nested Class Summary
Nested Classes Modifier and Type Class Description static classRequestRules.Mask -
Field Summary
Fields Modifier and Type Field Description protected List<Rule>rulesWhether the API call was valid or not.protected booleanrulesSpecifiedFields inherited from class com.softlayer.api.service.network.securitygroup.Request
requestId, requestIdSpecified -
Constructor Summary
Constructors Constructor Description RequestRules() -
Method Summary
Modifier and Type Method Description List<Rule>getRules()booleanisRulesSpecified()voidunsetRules()Methods inherited from class com.softlayer.api.service.network.securitygroup.Request
getRequestId, isRequestIdSpecified, setRequestId, unsetRequestId
-
Field Details
-
rules
Whether the API call was valid or not. -
rulesSpecified
protected boolean rulesSpecified
-
-
Constructor Details
-
RequestRules
public RequestRules()
-
-
Method Details
-
getRules
-
isRulesSpecified
public boolean isRulesSpecified() -
unsetRules
public void unsetRules()
-