Class Backup
java.lang.Object
com.softlayer.api.Type
com.softlayer.api.service.Entity
com.softlayer.api.service.network.Storage
com.softlayer.api.service.network.storage.Backup
- Direct Known Subclasses:
Evault
@ApiType("SoftLayer_Network_Storage_Backup") public class Backup extends Storage
The SoftLayer_Network_Storage_Backup contains general information regarding a Storage backup service such as account id, username, maximum capacity, password, Storage's product type and the server id.
- See Also:
- SoftLayer_Network_Storage_Backup
-
Nested Class Summary
Nested Classes Modifier and Type Class Description static classBackup.MaskNested classes/interfaces inherited from class com.softlayer.api.service.network.Storage
Storage.Service, Storage.ServiceAsync -
Field Summary
Fields Modifier and Type Field Description protected LongcurrentCyclePeakUsagePeak number of bytes used in the vault for the current billing cycle.protected LongpreviousCyclePeakUsagePeak number of bytes used in the vault for the previous billing cycle.Fields inherited from class com.softlayer.api.service.network.Storage
account, accountId, accountIdSpecified, accountPassword, activeTransactionCount, activeTransactions, allowedHardware, allowedHardwareCount, allowedIpAddressCount, allowedIpAddresses, allowedReplicationHardware, allowedReplicationHardwareCount, allowedReplicationIpAddressCount, allowedReplicationIpAddresses, allowedReplicationSubnetCount, allowedReplicationSubnets, allowedReplicationVirtualGuestCount, allowedReplicationVirtualGuests, allowedSubnetCount, allowedSubnets, allowedVirtualGuestCount, allowedVirtualGuests, billingItem, billingItemCategory, bytesUsed, capacityGb, capacityGbSpecified, createDate, createDateSpecified, creationScheduleId, credentialCount, credentials, dailySchedule, dependentDuplicate, dependentDuplicateCount, dependentDuplicates, eventCount, events, fileNetworkMountAddress, guestId, guestIdSpecified, hardware, hardwareId, hardwareIdSpecified, hasEncryptionAtRest, hostId, hostIdSpecified, hourlySchedule, id, idSpecified, intervalSchedule, iops, iscsiLunCount, iscsiLuns, iscsiTargetIpAddressCount, iscsiTargetIpAddresses, isDependentDuplicateProvisionCompleted, isReadyForSnapshot, isReadyToMount, lunId, manualSnapshotCount, manualSnapshots, metricTrackingObject, mountableFlag, moveAndSplitStatus, nasType, nasTypeSpecified, notes, notesSpecified, notificationSubscriberCount, notificationSubscribers, originalSnapshotName, originalVolumeName, originalVolumeSize, osType, osTypeId, parentPartnershipCount, parentPartnerships, parentVolume, partnershipCount, partnerships, password, passwordSpecified, permissionsGroupCount, permissionsGroups, properties, propertyCount, provisionedIops, replicatingLunCount, replicatingLuns, replicatingVolume, replicationEventCount, replicationEvents, replicationPartnerCount, replicationPartners, replicationSchedule, replicationStatus, scheduleCount, schedules, serviceProviderId, serviceProviderIdSpecified, serviceResource, serviceResourceBackendIpAddress, serviceResourceName, snapshotCapacityGb, snapshotCount, snapshotCreationTimestamp, snapshotDeletionThresholdPercentage, snapshots, snapshotSizeBytes, snapshotSpaceAvailable, staasVersion, storageGroupCount, storageGroups, storageTierLevel, storageType, storageTypeId, storageTypeIdSpecified, totalBytesUsed, totalScheduleSnapshotRetentionCount, upgradableFlag, upgradableFlagSpecified, usageNotification, username, usernameSpecified, vendorName, virtualGuest, volumeHistory, volumeHistoryCount, volumeStatus, webccAccount, weeklySchedule -
Constructor Summary
Constructors Constructor Description Backup() -
Method Summary
Modifier and Type Method Description LonggetCurrentCyclePeakUsage()LonggetPreviousCyclePeakUsage()voidsetCurrentCyclePeakUsage(Long currentCyclePeakUsage)voidsetPreviousCyclePeakUsage(Long previousCyclePeakUsage)Methods inherited from class com.softlayer.api.service.network.Storage
asService, getAccount, getAccountId, getAccountPassword, getActiveTransactionCount, getActiveTransactions, getAllowedHardware, getAllowedHardwareCount, getAllowedIpAddressCount, getAllowedIpAddresses, getAllowedReplicationHardware, getAllowedReplicationHardwareCount, getAllowedReplicationIpAddressCount, getAllowedReplicationIpAddresses, getAllowedReplicationSubnetCount, getAllowedReplicationSubnets, getAllowedReplicationVirtualGuestCount, getAllowedReplicationVirtualGuests, getAllowedSubnetCount, getAllowedSubnets, getAllowedVirtualGuestCount, getAllowedVirtualGuests, getBillingItem, getBillingItemCategory, getBytesUsed, getCapacityGb, getCreateDate, getCreationScheduleId, getCredentialCount, getCredentials, getDailySchedule, getDependentDuplicate, getDependentDuplicateCount, getDependentDuplicates, getEventCount, getEvents, getFileNetworkMountAddress, getGuestId, getHardware, getHardwareId, getHasEncryptionAtRest, getHostId, getHourlySchedule, getId, getIntervalSchedule, getIops, getIscsiLunCount, getIscsiLuns, getIscsiTargetIpAddressCount, getIscsiTargetIpAddresses, getIsDependentDuplicateProvisionCompleted, getIsReadyForSnapshot, getIsReadyToMount, getLunId, getManualSnapshotCount, getManualSnapshots, getMetricTrackingObject, getMountableFlag, getMoveAndSplitStatus, getNasType, getNotes, getNotificationSubscriberCount, getNotificationSubscribers, getOriginalSnapshotName, getOriginalVolumeName, getOriginalVolumeSize, getOsType, getOsTypeId, getParentPartnershipCount, getParentPartnerships, getParentVolume, getPartnershipCount, getPartnerships, getPassword, getPermissionsGroupCount, getPermissionsGroups, getProperties, getPropertyCount, getProvisionedIops, getReplicatingLunCount, getReplicatingLuns, getReplicatingVolume, getReplicationEventCount, getReplicationEvents, getReplicationPartnerCount, getReplicationPartners, getReplicationSchedule, getReplicationStatus, getScheduleCount, getSchedules, getServiceProviderId, getServiceResource, getServiceResourceBackendIpAddress, getServiceResourceName, getSnapshotCapacityGb, getSnapshotCount, getSnapshotCreationTimestamp, getSnapshotDeletionThresholdPercentage, getSnapshots, getSnapshotSizeBytes, getSnapshotSpaceAvailable, getStaasVersion, getStorageGroupCount, getStorageGroups, getStorageTierLevel, getStorageType, getStorageTypeId, getTotalBytesUsed, getTotalScheduleSnapshotRetentionCount, getUpgradableFlag, getUsageNotification, getUsername, getVendorName, getVirtualGuest, getVolumeHistory, getVolumeHistoryCount, getVolumeStatus, getWebccAccount, getWeeklySchedule, isAccountIdSpecified, isCapacityGbSpecified, isCreateDateSpecified, isGuestIdSpecified, isHardwareIdSpecified, isHostIdSpecified, isIdSpecified, isNasTypeSpecified, isNotesSpecified, isPasswordSpecified, isServiceProviderIdSpecified, isStorageTypeIdSpecified, isUpgradableFlagSpecified, isUsernameSpecified, service, service, setAccount, setAccountId, setAccountPassword, setActiveTransactionCount, setAllowedHardwareCount, setAllowedIpAddressCount, setAllowedReplicationHardwareCount, setAllowedReplicationIpAddressCount, setAllowedReplicationSubnetCount, setAllowedReplicationVirtualGuestCount, setAllowedSubnetCount, setAllowedVirtualGuestCount, setBillingItem, setBillingItemCategory, setBytesUsed, setCapacityGb, setCreateDate, setCreationScheduleId, setCredentialCount, setDailySchedule, setDependentDuplicate, setDependentDuplicateCount, setEventCount, setFileNetworkMountAddress, setGuestId, setHardware, setHardwareId, setHasEncryptionAtRest, setHostId, setHourlySchedule, setId, setIntervalSchedule, setIops, setIscsiLunCount, setIscsiTargetIpAddressCount, setIsDependentDuplicateProvisionCompleted, setIsReadyForSnapshot, setIsReadyToMount, setLunId, setManualSnapshotCount, setMetricTrackingObject, setMountableFlag, setMoveAndSplitStatus, setNasType, setNotes, setNotificationSubscriberCount, setOriginalSnapshotName, setOriginalVolumeName, setOriginalVolumeSize, setOsType, setOsTypeId, setParentPartnershipCount, setParentVolume, setPartnershipCount, setPassword, setPermissionsGroupCount, setPropertyCount, setProvisionedIops, setReplicatingLunCount, setReplicatingVolume, setReplicationEventCount, setReplicationPartnerCount, setReplicationSchedule, setReplicationStatus, setScheduleCount, setServiceProviderId, setServiceResource, setServiceResourceBackendIpAddress, setServiceResourceName, setSnapshotCapacityGb, setSnapshotCount, setSnapshotCreationTimestamp, setSnapshotDeletionThresholdPercentage, setSnapshotSizeBytes, setSnapshotSpaceAvailable, setStaasVersion, setStorageGroupCount, setStorageTierLevel, setStorageType, setStorageTypeId, setTotalBytesUsed, setTotalScheduleSnapshotRetentionCount, setUpgradableFlag, setUsageNotification, setUsername, setVendorName, setVirtualGuest, setVolumeHistoryCount, setVolumeStatus, setWebccAccount, setWeeklySchedule, unsetAccountId, unsetCapacityGb, unsetCreateDate, unsetGuestId, unsetHardwareId, unsetHostId, unsetId, unsetNasType, unsetNotes, unsetPassword, unsetServiceProviderId, unsetStorageTypeId, unsetUpgradableFlag, unsetUsername
-
Field Details
-
currentCyclePeakUsage
Peak number of bytes used in the vault for the current billing cycle. -
previousCyclePeakUsage
Peak number of bytes used in the vault for the previous billing cycle.
-
-
Constructor Details
-
Backup
public Backup()
-
-
Method Details