java.lang.Object
com.softlayer.api.Type
com.softlayer.api.service.Entity
com.softlayer.api.service.network.storage.Event

@ApiType("SoftLayer_Network_Storage_Event")
public class Event
extends Entity
Storage volumes can create various events to keep track of what has occurred to the volume. Events provide an audit trail that can be used to verify that various tasks have occurred, such as snapshots to be created by a schedule or remote replication synchronization.
See Also:
SoftLayer_Network_Storage_Event
  • Field Details

    • schedule

      @ApiProperty protected Schedule schedule
      A schedule that is associated with an event. Not all events will have a schedule.
    • type

      @ApiProperty protected Type type
      A Storage volume's event type. The type provides a standardized definition for an event.
    • volume

      @ApiProperty protected Storage volume
      The associated volume for an event.
    • createDate

      @ApiProperty(canBeNullOrNotSet=true) protected GregorianCalendar createDate
      The date an event was created.
    • createDateSpecified

      protected boolean createDateSpecified
    • message

      @ApiProperty(canBeNullOrNotSet=true) protected String message
      The message text for an event.
    • messageSpecified

      protected boolean messageSpecified
    • scheduleId

      @ApiProperty(canBeNullOrNotSet=true) protected Long scheduleId
      An identifier for the schedule which is associated with an event.
    • scheduleIdSpecified

      protected boolean scheduleIdSpecified
    • typeId

      @ApiProperty(canBeNullOrNotSet=true) protected Long typeId
      An identifier for the type of an event.
    • typeIdSpecified

      protected boolean typeIdSpecified
    • volumeId

      @ApiProperty(canBeNullOrNotSet=true) protected Long volumeId
      The volume id which an event is associated with.
    • volumeIdSpecified

      protected boolean volumeIdSpecified
  • Constructor Details

    • Event

      public Event()
  • Method Details

    • getSchedule

      public Schedule getSchedule()
    • setSchedule

      public void setSchedule​(Schedule schedule)
    • getType

      public Type getType()
    • setType

      public void setType​(Type type)
    • getVolume

      public Storage getVolume()
    • setVolume

      public void setVolume​(Storage volume)
    • getCreateDate

      public GregorianCalendar getCreateDate()
    • setCreateDate

      public void setCreateDate​(GregorianCalendar createDate)
    • isCreateDateSpecified

      public boolean isCreateDateSpecified()
    • unsetCreateDate

      public void unsetCreateDate()
    • getMessage

      public String getMessage()
    • setMessage

      public void setMessage​(String message)
    • isMessageSpecified

      public boolean isMessageSpecified()
    • unsetMessage

      public void unsetMessage()
    • getScheduleId

      public Long getScheduleId()
    • setScheduleId

      public void setScheduleId​(Long scheduleId)
    • isScheduleIdSpecified

      public boolean isScheduleIdSpecified()
    • unsetScheduleId

      public void unsetScheduleId()
    • getTypeId

      public Long getTypeId()
    • setTypeId

      public void setTypeId​(Long typeId)
    • isTypeIdSpecified

      public boolean isTypeIdSpecified()
    • unsetTypeId

      public void unsetTypeId()
    • getVolumeId

      public Long getVolumeId()
    • setVolumeId

      public void setVolumeId​(Long volumeId)
    • isVolumeIdSpecified

      public boolean isVolumeIdSpecified()
    • unsetVolumeId

      public void unsetVolumeId()