Class Schedule
java.lang.Object
com.softlayer.api.Type
com.softlayer.api.service.Entity
com.softlayer.api.service.network.storage.Schedule
@ApiType("SoftLayer_Network_Storage_Schedule") public class Schedule extends Entity
Schedules can be created for select Storage services, such as iscsi. These schedules are used to perform various tasks such as scheduling snapshots or synchronizing replicants.
- See Also:
- SoftLayer_Network_Storage_Schedule
-
Nested Class Summary
Nested Classes Modifier and Type Class Description static classSchedule.Maskstatic interfaceSchedule.ServiceSchedules can be created for select Storage services, such as iscsi.static interfaceSchedule.ServiceAsync -
Field Summary
Fields Modifier and Type Field Description protected LongactiveA flag which determines if a schedule is active.protected booleanactiveSpecifiedprotected GregorianCalendarcreateDateThe date a schedule was created.protected booleancreateDateSpecifiedprotected StringdayThe hour parameter of this schedule.protected StringdayOfMonthThe day of the month parameter of this schedule.protected StringdayOfWeekThe day of the week parameter of this schedule.protected LongeventCountA count of events which have been created as the result of a schedule execution.protected List<Event>eventsEvents which have been created as the result of a schedule execution.protected StringhourThe hour parameter of this schedule.protected LongidA schedule's internal identifier.protected booleanidSpecifiedprotected StringminuteThe minute parameter of this schedule.protected GregorianCalendarmodifyDateThe date a schedule was last modified.protected booleanmodifyDateSpecifiedprotected StringmonthOfYearThe month of the year parameter of this schedule.protected StringnameA schedule's name, for example 'Daily'.protected booleannameSpecifiedprotected PartnershippartnershipThe associated partnership for a schedule.protected LongpartnershipIdThe partnership id which a schedule is associated with.protected booleanpartnershipIdSpecifiedprotected List<Property>propertiesProperties used for configuration of a schedule.protected LongpropertyCountA count of properties used for configuration of a schedule.protected LongreplicaSnapshotCountA count of replica snapshots which have been created as the result of this schedule's execution.protected List<Storage>replicaSnapshotsReplica snapshots which have been created as the result of this schedule's execution.protected StringretentionCountThe number of snapshots this schedule is configured to retain.protected StringsecondThe minute parameter of this schedule.protected LongsnapshotCountA count of snapshots which have been created as the result of this schedule's execution.protected List<Storage>snapshotsSnapshots which have been created as the result of this schedule's execution.protected TypetypeThe type provides a standardized definition for a schedule.protected LongtypeIdThe type id which a schedule is associated with.protected booleantypeIdSpecifiedprotected StoragevolumeThe associated volume for a schedule.protected LongvolumeIdThe volume id which a schedule is associated with.protected booleanvolumeIdSpecified -
Constructor Summary
Constructors Constructor Description Schedule() -
Method Summary
-
Field Details
-
day
The hour parameter of this schedule. -
dayOfMonth
The day of the month parameter of this schedule. -
dayOfWeek
The day of the week parameter of this schedule. -
events
Events which have been created as the result of a schedule execution. -
hour
The hour parameter of this schedule. -
minute
The minute parameter of this schedule. -
monthOfYear
The month of the year parameter of this schedule. -
partnership
The associated partnership for a schedule. -
properties
Properties used for configuration of a schedule. -
replicaSnapshots
Replica snapshots which have been created as the result of this schedule's execution. -
retentionCount
The number of snapshots this schedule is configured to retain. -
second
The minute parameter of this schedule. -
snapshots
Snapshots which have been created as the result of this schedule's execution. -
type
The type provides a standardized definition for a schedule. -
volume
The associated volume for a schedule. -
active
A flag which determines if a schedule is active. -
activeSpecified
protected boolean activeSpecified -
createDate
The date a schedule was created. -
createDateSpecified
protected boolean createDateSpecified -
id
A schedule's internal identifier. -
idSpecified
protected boolean idSpecified -
modifyDate
The date a schedule was last modified. -
modifyDateSpecified
protected boolean modifyDateSpecified -
name
A schedule's name, for example 'Daily'. -
nameSpecified
protected boolean nameSpecified -
partnershipId
The partnership id which a schedule is associated with. -
partnershipIdSpecified
protected boolean partnershipIdSpecified -
typeId
The type id which a schedule is associated with. -
typeIdSpecified
protected boolean typeIdSpecified -
volumeId
The volume id which a schedule is associated with. -
volumeIdSpecified
protected boolean volumeIdSpecified -
eventCount
A count of events which have been created as the result of a schedule execution. -
propertyCount
A count of properties used for configuration of a schedule. -
replicaSnapshotCount
A count of replica snapshots which have been created as the result of this schedule's execution. -
snapshotCount
A count of snapshots which have been created as the result of this schedule's execution.
-
-
Constructor Details
-
Schedule
public Schedule()
-
-
Method Details
-
getDay
-
setDay
-
getDayOfMonth
-
setDayOfMonth
-
getDayOfWeek
-
setDayOfWeek
-
getEvents
-
getHour
-
setHour
-
getMinute
-
setMinute
-
getMonthOfYear
-
setMonthOfYear
-
getPartnership
-
setPartnership
-
getProperties
-
getReplicaSnapshots
-
getRetentionCount
-
setRetentionCount
-
getSecond
-
setSecond
-
getSnapshots
-
getType
-
setType
-
getVolume
-
setVolume
-
getActive
-
setActive
-
isActiveSpecified
public boolean isActiveSpecified() -
unsetActive
public void unsetActive() -
getCreateDate
-
setCreateDate
-
isCreateDateSpecified
public boolean isCreateDateSpecified() -
unsetCreateDate
public void unsetCreateDate() -
getId
-
setId
-
isIdSpecified
public boolean isIdSpecified() -
unsetId
public void unsetId() -
getModifyDate
-
setModifyDate
-
isModifyDateSpecified
public boolean isModifyDateSpecified() -
unsetModifyDate
public void unsetModifyDate() -
getName
-
setName
-
isNameSpecified
public boolean isNameSpecified() -
unsetName
public void unsetName() -
getPartnershipId
-
setPartnershipId
-
isPartnershipIdSpecified
public boolean isPartnershipIdSpecified() -
unsetPartnershipId
public void unsetPartnershipId() -
getTypeId
-
setTypeId
-
isTypeIdSpecified
public boolean isTypeIdSpecified() -
unsetTypeId
public void unsetTypeId() -
getVolumeId
-
setVolumeId
-
isVolumeIdSpecified
public boolean isVolumeIdSpecified() -
unsetVolumeId
public void unsetVolumeId() -
getEventCount
-
setEventCount
-
getPropertyCount
-
setPropertyCount
-
getReplicaSnapshotCount
-
setReplicaSnapshotCount
-
getSnapshotCount
-
setSnapshotCount
-
asService
-
service
-
service
-