Uses of Class
com.softlayer.api.service.network.storage.Event
| Package | Description |
|---|---|
| com.softlayer.api.service | |
| com.softlayer.api.service.network | |
| com.softlayer.api.service.network.storage |
-
Uses of Event in com.softlayer.api.service
Fields in com.softlayer.api.service with type parameters of type Event Modifier and Type Field Description protected List<Event>Account. replicationEventsThe Replication events for all Network Storage volumes on an account.Methods in com.softlayer.api.service that return types with arguments of type Event Modifier and Type Method Description List<Event>Account. getReplicationEvents()List<Event>Account.Service. getReplicationEvents()The Replication events for all Network Storage volumes on an account.Future<List<Event>>Account.ServiceAsync. getReplicationEvents()Async version ofAccount.Service.getReplicationEvents()Method parameters in com.softlayer.api.service with type arguments of type Event Modifier and Type Method Description Future<?>Account.ServiceAsync. getReplicationEvents(ResponseHandler<List<Event>> callback)Async callback version ofAccount.Service.getReplicationEvents() -
Uses of Event in com.softlayer.api.service.network
Fields in com.softlayer.api.service.network with type parameters of type Event Modifier and Type Field Description protected List<Event>Storage. eventsThe events which have taken place on a network storage volume.protected List<Event>Storage. replicationEventsThe volume replication events.Methods in com.softlayer.api.service.network that return types with arguments of type Event Modifier and Type Method Description List<Event>Storage. getEvents()List<Event>Storage.Service. getEvents()The events which have taken place on a network storage volume.Future<List<Event>>Storage.ServiceAsync. getEvents()Async version ofStorage.Service.getEvents()List<Event>Storage. getReplicationEvents()List<Event>Storage.Service. getReplicationEvents()The volume replication events.Future<List<Event>>Storage.ServiceAsync. getReplicationEvents()Async version ofStorage.Service.getReplicationEvents()Method parameters in com.softlayer.api.service.network with type arguments of type Event Modifier and Type Method Description Future<?>Storage.ServiceAsync. getEvents(ResponseHandler<List<Event>> callback)Async callback version ofStorage.Service.getEvents()Future<?>Storage.ServiceAsync. getReplicationEvents(ResponseHandler<List<Event>> callback)Async callback version ofStorage.Service.getReplicationEvents() -
Uses of Event in com.softlayer.api.service.network.storage
Fields in com.softlayer.api.service.network.storage with type parameters of type Event Modifier and Type Field Description protected List<Event>Schedule. eventsEvents which have been created as the result of a schedule execution.Methods in com.softlayer.api.service.network.storage that return types with arguments of type Event Modifier and Type Method Description List<Event>Schedule. getEvents()List<Event>Schedule.Service. getEvents()Events which have been created as the result of a schedule execution.Future<List<Event>>Schedule.ServiceAsync. getEvents()Async version ofSchedule.Service.getEvents()Method parameters in com.softlayer.api.service.network.storage with type arguments of type Event Modifier and Type Method Description Future<?>Schedule.ServiceAsync. getEvents(ResponseHandler<List<Event>> callback)Async callback version ofSchedule.Service.getEvents()