Class Object
java.lang.Object
com.softlayer.api.Type
com.softlayer.api.service.Entity
com.softlayer.api.service.network.Storage
com.softlayer.api.service.network.storage.openstack.Object
@ApiType("SoftLayer_Network_Storage_OpenStack_Object") public class Object extends Storage
The SoftLayer_Network_Storage_OpenStack_Object data type models OpenStack specific object storage objects. These storages authenticate through Keystone to access Swift.
-
Nested Class Summary
Nested Classes Modifier and Type Class Description static classObject.MaskNested classes/interfaces inherited from class com.softlayer.api.service.network.Storage
Storage.Service, Storage.ServiceAsync -
Field Summary
Fields Modifier and Type Field Description protected LongbandwidthBillingItemCountA count of the billing item tied to an OpenStack Object Storage's bandwidth service.protected List<Item>bandwidthBillingItemsThe billing item tied to an OpenStack Object Storage's bandwidth service.Fields inherited from class com.softlayer.api.service.network.Storage
account, accountId, accountIdSpecified, accountPassword, activeTransactionCount, activeTransactions, allowedHardware, allowedHardwareCount, allowedIpAddressCount, allowedIpAddresses, allowedReplicationHardware, allowedReplicationHardwareCount, allowedReplicationIpAddressCount, allowedReplicationIpAddresses, allowedReplicationSubnetCount, allowedReplicationSubnets, allowedReplicationVirtualGuestCount, allowedReplicationVirtualGuests, allowedSubnetCount, allowedSubnets, allowedVirtualGuestCount, allowedVirtualGuests, billingItem, billingItemCategory, bytesUsed, capacityGb, capacityGbSpecified, createDate, createDateSpecified, creationScheduleId, credentialCount, credentials, dailySchedule, dependentDuplicate, dependentDuplicateCount, dependentDuplicates, eventCount, events, fileNetworkMountAddress, guestId, guestIdSpecified, hardware, hardwareId, hardwareIdSpecified, hasEncryptionAtRest, hostId, hostIdSpecified, hourlySchedule, id, idSpecified, intervalSchedule, iops, iscsiLunCount, iscsiLuns, iscsiTargetIpAddressCount, iscsiTargetIpAddresses, isDependentDuplicateProvisionCompleted, isReadyForSnapshot, isReadyToMount, lunId, manualSnapshotCount, manualSnapshots, metricTrackingObject, mountableFlag, moveAndSplitStatus, nasType, nasTypeSpecified, notes, notesSpecified, notificationSubscriberCount, notificationSubscribers, originalSnapshotName, originalVolumeName, originalVolumeSize, osType, osTypeId, parentPartnershipCount, parentPartnerships, parentVolume, partnershipCount, partnerships, password, passwordSpecified, permissionsGroupCount, permissionsGroups, properties, propertyCount, provisionedIops, replicatingLunCount, replicatingLuns, replicatingVolume, replicationEventCount, replicationEvents, replicationPartnerCount, replicationPartners, replicationSchedule, replicationStatus, scheduleCount, schedules, serviceProviderId, serviceProviderIdSpecified, serviceResource, serviceResourceBackendIpAddress, serviceResourceName, snapshotCapacityGb, snapshotCount, snapshotCreationTimestamp, snapshotDeletionThresholdPercentage, snapshots, snapshotSizeBytes, snapshotSpaceAvailable, staasVersion, storageGroupCount, storageGroups, storageTierLevel, storageType, storageTypeId, storageTypeIdSpecified, totalBytesUsed, totalScheduleSnapshotRetentionCount, upgradableFlag, upgradableFlagSpecified, usageNotification, username, usernameSpecified, vendorName, virtualGuest, volumeHistory, volumeHistoryCount, volumeStatus, webccAccount, weeklySchedule -
Constructor Summary
Constructors Constructor Description Object() -
Method Summary
Modifier and Type Method Description LonggetBandwidthBillingItemCount()List<Item>getBandwidthBillingItems()voidsetBandwidthBillingItemCount(Long bandwidthBillingItemCount)Methods inherited from class com.softlayer.api.service.network.Storage
asService, getAccount, getAccountId, getAccountPassword, getActiveTransactionCount, getActiveTransactions, getAllowedHardware, getAllowedHardwareCount, getAllowedIpAddressCount, getAllowedIpAddresses, getAllowedReplicationHardware, getAllowedReplicationHardwareCount, getAllowedReplicationIpAddressCount, getAllowedReplicationIpAddresses, getAllowedReplicationSubnetCount, getAllowedReplicationSubnets, getAllowedReplicationVirtualGuestCount, getAllowedReplicationVirtualGuests, getAllowedSubnetCount, getAllowedSubnets, getAllowedVirtualGuestCount, getAllowedVirtualGuests, getBillingItem, getBillingItemCategory, getBytesUsed, getCapacityGb, getCreateDate, getCreationScheduleId, getCredentialCount, getCredentials, getDailySchedule, getDependentDuplicate, getDependentDuplicateCount, getDependentDuplicates, getEventCount, getEvents, getFileNetworkMountAddress, getGuestId, getHardware, getHardwareId, getHasEncryptionAtRest, getHostId, getHourlySchedule, getId, getIntervalSchedule, getIops, getIscsiLunCount, getIscsiLuns, getIscsiTargetIpAddressCount, getIscsiTargetIpAddresses, getIsDependentDuplicateProvisionCompleted, getIsReadyForSnapshot, getIsReadyToMount, getLunId, getManualSnapshotCount, getManualSnapshots, getMetricTrackingObject, getMountableFlag, getMoveAndSplitStatus, getNasType, getNotes, getNotificationSubscriberCount, getNotificationSubscribers, getOriginalSnapshotName, getOriginalVolumeName, getOriginalVolumeSize, getOsType, getOsTypeId, getParentPartnershipCount, getParentPartnerships, getParentVolume, getPartnershipCount, getPartnerships, getPassword, getPermissionsGroupCount, getPermissionsGroups, getProperties, getPropertyCount, getProvisionedIops, getReplicatingLunCount, getReplicatingLuns, getReplicatingVolume, getReplicationEventCount, getReplicationEvents, getReplicationPartnerCount, getReplicationPartners, getReplicationSchedule, getReplicationStatus, getScheduleCount, getSchedules, getServiceProviderId, getServiceResource, getServiceResourceBackendIpAddress, getServiceResourceName, getSnapshotCapacityGb, getSnapshotCount, getSnapshotCreationTimestamp, getSnapshotDeletionThresholdPercentage, getSnapshots, getSnapshotSizeBytes, getSnapshotSpaceAvailable, getStaasVersion, getStorageGroupCount, getStorageGroups, getStorageTierLevel, getStorageType, getStorageTypeId, getTotalBytesUsed, getTotalScheduleSnapshotRetentionCount, getUpgradableFlag, getUsageNotification, getUsername, getVendorName, getVirtualGuest, getVolumeHistory, getVolumeHistoryCount, getVolumeStatus, getWebccAccount, getWeeklySchedule, isAccountIdSpecified, isCapacityGbSpecified, isCreateDateSpecified, isGuestIdSpecified, isHardwareIdSpecified, isHostIdSpecified, isIdSpecified, isNasTypeSpecified, isNotesSpecified, isPasswordSpecified, isServiceProviderIdSpecified, isStorageTypeIdSpecified, isUpgradableFlagSpecified, isUsernameSpecified, service, service, setAccount, setAccountId, setAccountPassword, setActiveTransactionCount, setAllowedHardwareCount, setAllowedIpAddressCount, setAllowedReplicationHardwareCount, setAllowedReplicationIpAddressCount, setAllowedReplicationSubnetCount, setAllowedReplicationVirtualGuestCount, setAllowedSubnetCount, setAllowedVirtualGuestCount, setBillingItem, setBillingItemCategory, setBytesUsed, setCapacityGb, setCreateDate, setCreationScheduleId, setCredentialCount, setDailySchedule, setDependentDuplicate, setDependentDuplicateCount, setEventCount, setFileNetworkMountAddress, setGuestId, setHardware, setHardwareId, setHasEncryptionAtRest, setHostId, setHourlySchedule, setId, setIntervalSchedule, setIops, setIscsiLunCount, setIscsiTargetIpAddressCount, setIsDependentDuplicateProvisionCompleted, setIsReadyForSnapshot, setIsReadyToMount, setLunId, setManualSnapshotCount, setMetricTrackingObject, setMountableFlag, setMoveAndSplitStatus, setNasType, setNotes, setNotificationSubscriberCount, setOriginalSnapshotName, setOriginalVolumeName, setOriginalVolumeSize, setOsType, setOsTypeId, setParentPartnershipCount, setParentVolume, setPartnershipCount, setPassword, setPermissionsGroupCount, setPropertyCount, setProvisionedIops, setReplicatingLunCount, setReplicatingVolume, setReplicationEventCount, setReplicationPartnerCount, setReplicationSchedule, setReplicationStatus, setScheduleCount, setServiceProviderId, setServiceResource, setServiceResourceBackendIpAddress, setServiceResourceName, setSnapshotCapacityGb, setSnapshotCount, setSnapshotCreationTimestamp, setSnapshotDeletionThresholdPercentage, setSnapshotSizeBytes, setSnapshotSpaceAvailable, setStaasVersion, setStorageGroupCount, setStorageTierLevel, setStorageType, setStorageTypeId, setTotalBytesUsed, setTotalScheduleSnapshotRetentionCount, setUpgradableFlag, setUsageNotification, setUsername, setVendorName, setVirtualGuest, setVolumeHistoryCount, setVolumeStatus, setWebccAccount, setWeeklySchedule, unsetAccountId, unsetCapacityGb, unsetCreateDate, unsetGuestId, unsetHardwareId, unsetHostId, unsetId, unsetNasType, unsetNotes, unsetPassword, unsetServiceProviderId, unsetStorageTypeId, unsetUpgradableFlag, unsetUsername
-
Field Details
-
bandwidthBillingItems
The billing item tied to an OpenStack Object Storage's bandwidth service. -
bandwidthBillingItemCount
A count of the billing item tied to an OpenStack Object Storage's bandwidth service.
-
-
Constructor Details
-
Object
public Object()
-
-
Method Details