Interface IpAddress.Service
- All Superinterfaces:
Maskable,ResultLimitable,Service
- Enclosing class:
- IpAddress
@ApiService("SoftLayer_Network_Subnet_IpAddress") public static interface IpAddress.Service extends Service
Every SoftLayer IP address is defined in the SoftLayer_Network_Subnet_IpAddress service. SoftLayer IP addresses are assigned to a SoftLayer_Network_Subnet. The SoftLayer_Network_Subnet_IpAddress service gives you information about an IP address such if it is reserved, a network address, or a gateway. Use the data returned by these methods with other API services to get more detailed information about your services.
SoftLayer customers can order and manage IP addresses through the customer portal. If you need to cancel a subnet please open a sales ticket in our customer portal and our account management staff will assist you.
SoftLayer customers can order and manage IP addresses through the customer portal. If you need to cancel a subnet please open a sales ticket in our customer portal and our account management staff will assist you.
- See Also:
- SoftLayer_Network_Subnet_IpAddress
-
Method Summary
Modifier and Type Method Description BooleanallowAccessToNetworkStorage(Storage networkStorageTemplateObject)This method is used to allow access to a SoftLayer_Network_Storage volume that supports host- or network-level access control.BooleanallowAccessToNetworkStorageList(List<Storage> networkStorageTemplateObjects)This method is used to allow access to multiple SoftLayer_Network_Storage volumes that support host- or network-level access control.IpAddress.ServiceAsyncasAsync()Get an async version of this serviceBooleaneditObject(IpAddress templateObject)Edit a subnet IP address.BooleaneditObjects(List<IpAddress> templateObjects)This function is used to edit multiple objects at the same time.IpAddressfindByIpv4Address(String ipAddress)Search for an IP address record by IPv4 address.HostgetAllowedHost()The SoftLayer_Network_Storage_Allowed_Host information to connect this IP Address to Network Storage supporting access control lists.List<Storage>getAllowedNetworkStorage()The SoftLayer_Network_Storage objects that this SoftLayer_Hardware has access to.List<Storage>getAllowedNetworkStorageReplicas()The SoftLayer_Network_Storage objects whose Replica that this SoftLayer_Hardware has access to.ControllergetApplicationDeliveryController()The application delivery controller using this address.List<Storage>getAttachedNetworkStorages(String nasType)This method is retrieve a list of SoftLayer_Network_Storage volumes that are authorized access to this SoftLayer_Network_Subnet_IpAddress.List<Storage>getAvailableNetworkStorages(String nasType)This method retrieves a list of SoftLayer_Network_Storage volumes that can be authorized to this SoftLayer_Network_Subnet_IpAddress.IpAddressgetByIpAddress(String ipAddress)Search for an IP address record by IP address.List<Translation>getContextTunnelTranslations()An IPSec network tunnel's address translations.List<Subnet>getEndpointSubnets()All the subnets routed to an IP address.ComponentgetGuestNetworkComponent()A network component that is statically routed to an IP address.IpAddressgetGuestNetworkComponentBinding()A network component that is statically routed to an IP address.HardwaregetHardware()A server that this IP address is routed to.ComponentgetNetworkComponent()A network component that is statically routed to an IP address.IpAddressgetObject()getObject retrieves the SoftLayer_Network_Subnet_IpAddress object whose ID number corresponds to the ID number of the init parameter passed to the SoftLayer_Network_Subnet_IpAddress service.GatewaygetPrivateNetworkGateway()The network gateway appliance using this address as the private IP address.List<Address>getProtectionAddress()GatewaygetPublicNetworkGateway()The network gateway appliance using this address as the public IP address.ComponentgetRemoteManagementNetworkComponent()An IPMI-based management network component of the IP address.SubnetgetSubnet()An IP address' associated subnet.List<Syslog>getSyslogEventsOneDay()All events for this IP address stored in the datacenter syslogs from the last 24 hoursList<Syslog>getSyslogEventsSevenDays()All events for this IP address stored in the datacenter syslogs from the last 7 daysList<Syslog>getTopTenSyslogEventsByDestinationPortOneDay()Top Ten network datacenter syslog events, grouped by destination port, for the last 24 hoursList<Syslog>getTopTenSyslogEventsByDestinationPortSevenDays()Top Ten network datacenter syslog events, grouped by destination port, for the last 7 daysList<Syslog>getTopTenSyslogEventsByProtocolsOneDay()Top Ten network datacenter syslog events, grouped by source port, for the last 24 hoursList<Syslog>getTopTenSyslogEventsByProtocolsSevenDays()Top Ten network datacenter syslog events, grouped by source port, for the last 7 daysList<Syslog>getTopTenSyslogEventsBySourceIpOneDay()Top Ten network datacenter syslog events, grouped by source ip address, for the last 24 hoursList<Syslog>getTopTenSyslogEventsBySourceIpSevenDays()Top Ten network datacenter syslog events, grouped by source ip address, for the last 7 daysList<Syslog>getTopTenSyslogEventsBySourcePortOneDay()Top Ten network datacenter syslog events, grouped by source port, for the last 24 hoursList<Syslog>getTopTenSyslogEventsBySourcePortSevenDays()Top Ten network datacenter syslog events, grouped by source port, for the last 7 daysGuestgetVirtualGuest()A virtual guest that this IP address is routed to.List<VirtualLicense>getVirtualLicenses()Virtual licenses allocated for an IP Address.BooleanremoveAccessToNetworkStorageList(List<Storage> networkStorageTemplateObjects)This method is used to remove access to multiple SoftLayer_Network_Storage volumesvoidsetMask(IpAddress.Mask mask)IpAddress.MaskwithMask()Use the existing mask on this service or create it if not presentIpAddress.MaskwithNewMask()Overwrite the existing mask on this service with a new one and return itMethods inherited from interface com.softlayer.api.ResultLimitable
getLastResponseTotalItemCount, getResultLimit, setResultLimit
-
Method Details
-
asAsync
IpAddress.ServiceAsync asAsync()Description copied from interface:ServiceGet an async version of this service -
withNewMask
IpAddress.Mask withNewMask()Description copied from interface:MaskableOverwrite the existing mask on this service with a new one and return it- Specified by:
withNewMaskin interfaceMaskable
-
withMask
IpAddress.Mask withMask()Description copied from interface:MaskableUse the existing mask on this service or create it if not present -
setMask
-
allowAccessToNetworkStorage
@ApiMethod(instanceRequired=true) Boolean allowAccessToNetworkStorage(Storage networkStorageTemplateObject)This method is used to allow access to a SoftLayer_Network_Storage volume that supports host- or network-level access control. -
allowAccessToNetworkStorageList
@ApiMethod(instanceRequired=true) Boolean allowAccessToNetworkStorageList(List<Storage> networkStorageTemplateObjects)This method is used to allow access to multiple SoftLayer_Network_Storage volumes that support host- or network-level access control. -
editObject
Edit a subnet IP address. -
editObjects
This function is used to edit multiple objects at the same time. -
findByIpv4Address
Search for an IP address record by IPv4 address. -
getAttachedNetworkStorages
This method is retrieve a list of SoftLayer_Network_Storage volumes that are authorized access to this SoftLayer_Network_Subnet_IpAddress. -
getAvailableNetworkStorages
This method retrieves a list of SoftLayer_Network_Storage volumes that can be authorized to this SoftLayer_Network_Subnet_IpAddress. -
getByIpAddress
Search for an IP address record by IP address. -
getObject
getObject retrieves the SoftLayer_Network_Subnet_IpAddress object whose ID number corresponds to the ID number of the init parameter passed to the SoftLayer_Network_Subnet_IpAddress service. You can only retrieve the IP address whose subnet is associated with a VLAN that is associated with the account that your portal user is assigned to. -
removeAccessToNetworkStorageList
@ApiMethod(instanceRequired=true) Boolean removeAccessToNetworkStorageList(List<Storage> networkStorageTemplateObjects)This method is used to remove access to multiple SoftLayer_Network_Storage volumes -
getAllowedHost
The SoftLayer_Network_Storage_Allowed_Host information to connect this IP Address to Network Storage supporting access control lists. -
getAllowedNetworkStorage
The SoftLayer_Network_Storage objects that this SoftLayer_Hardware has access to. -
getAllowedNetworkStorageReplicas
The SoftLayer_Network_Storage objects whose Replica that this SoftLayer_Hardware has access to. -
getApplicationDeliveryController
The application delivery controller using this address. -
getContextTunnelTranslations
An IPSec network tunnel's address translations. These translations use a SoftLayer ip address from an assigned static NAT subnet to deliver the packets to the remote (customer) destination. -
getEndpointSubnets
All the subnets routed to an IP address. -
getGuestNetworkComponent
A network component that is statically routed to an IP address. -
getGuestNetworkComponentBinding
A network component that is statically routed to an IP address. -
getHardware
A server that this IP address is routed to. -
getNetworkComponent
A network component that is statically routed to an IP address. -
getPrivateNetworkGateway
The network gateway appliance using this address as the private IP address. -
getProtectionAddress
-
getPublicNetworkGateway
The network gateway appliance using this address as the public IP address. -
getRemoteManagementNetworkComponent
An IPMI-based management network component of the IP address. -
getSubnet
An IP address' associated subnet. -
getSyslogEventsOneDay
All events for this IP address stored in the datacenter syslogs from the last 24 hours -
getSyslogEventsSevenDays
All events for this IP address stored in the datacenter syslogs from the last 7 days -
getTopTenSyslogEventsByDestinationPortOneDay
Top Ten network datacenter syslog events, grouped by destination port, for the last 24 hours -
getTopTenSyslogEventsByDestinationPortSevenDays
Top Ten network datacenter syslog events, grouped by destination port, for the last 7 days -
getTopTenSyslogEventsByProtocolsOneDay
Top Ten network datacenter syslog events, grouped by source port, for the last 24 hours -
getTopTenSyslogEventsByProtocolsSevenDays
Top Ten network datacenter syslog events, grouped by source port, for the last 7 days -
getTopTenSyslogEventsBySourceIpOneDay
Top Ten network datacenter syslog events, grouped by source ip address, for the last 24 hours -
getTopTenSyslogEventsBySourceIpSevenDays
Top Ten network datacenter syslog events, grouped by source ip address, for the last 7 days -
getTopTenSyslogEventsBySourcePortOneDay
Top Ten network datacenter syslog events, grouped by source port, for the last 24 hours -
getTopTenSyslogEventsBySourcePortSevenDays
Top Ten network datacenter syslog events, grouped by source port, for the last 7 days -
getVirtualGuest
A virtual guest that this IP address is routed to. -
getVirtualLicenses
Virtual licenses allocated for an IP Address.
-