Class Registration
java.lang.Object
com.softlayer.api.Type
com.softlayer.api.service.Entity
com.softlayer.api.service.network.subnet.Registration
@ApiType("SoftLayer_Network_Subnet_Registration") public class Registration extends Entity
The subnet registration data type contains general information relating to a single subnet registration instance. These registration instances can be updated to reflect changes, and will record the changes in the [[SoftLayer_Network_Subnet_Registration_Event|events]].
- See Also:
- SoftLayer_Network_Subnet_Registration
-
Nested Class Summary
Nested Classes Modifier and Type Class Description static classRegistration.Maskstatic interfaceRegistration.ServiceSubnet registration objects are used to request and track registration of the subnet with the appropriate Regional Internet Registry (RIR).static interfaceRegistration.ServiceAsync -
Field Summary
Fields Modifier and Type Field Description protected AccountaccountThe account that this registration belongs to.protected LongaccountIdThe registration object's associated [[SoftLayer_Account|account]] idprotected booleanaccountIdSpecifiedprotected LongcidrThe CIDR prefix for the registered subnetprotected booleancidrSpecifiedprotected GregorianCalendarcreateDateprotected booleancreateDateSpecifiedprotected LongdetailReferenceCountA count of the cross-reference records that tie the [[SoftLayer_Account_Regional_Registry_Detail]] objects to the registration object.protected List<Details>detailReferencesThe cross-reference records that tie the [[SoftLayer_Account_Regional_Registry_Detail]] objects to the registration object.protected LongeventCountA count of the related registration events.protected List<Event>eventsThe related registration events.protected LongidUnique ID of the registration objectprotected booleanidSpecifiedprotected GregorianCalendarmodifyDateprotected booleanmodifyDateSpecifiedprotected DetailnetworkDetailThe "network" detail object.protected StringnetworkHandleThe RIR-specific handle or name of the registered subnet.protected booleannetworkHandleSpecifiedprotected StringnetworkIdentifierThe base IP address of the registered subnetprotected booleannetworkIdentifierSpecifiedprotected DetailpersonDetailThe "person" detail object.protected RegistryregionalInternetRegistryThe related Regional Internet Registry.protected HandleregionalInternetRegistryHandleThe RIR handle that this registration object belongs to.protected LongregionalInternetRegistryHandleIdThe registration object's associated [[SoftLayer_Account_Rwhois_Handle|RIR handle]] idprotected booleanregionalInternetRegistryHandleIdSpecifiedprotected LongregionalInternetRegistryIdThe registration object's associated [[SoftLayer_Network_Regional_Internet_Registry|RIR]] idprotected booleanregionalInternetRegistryIdSpecifiedprotected StatusstatusThe status of this registration.protected LongstatusIdThe registration object's associated [[SoftLayer_Network_Subnet_Registration_Status|status]] idprotected booleanstatusIdSpecifiedprotected SubnetsubnetThe subnet that this registration pertains to. -
Constructor Summary
Constructors Constructor Description Registration() -
Method Summary
-
Field Details
-
account
The account that this registration belongs to. -
detailReferences
The cross-reference records that tie the [[SoftLayer_Account_Regional_Registry_Detail]] objects to the registration object. -
events
The related registration events. -
networkDetail
The "network" detail object. -
personDetail
The "person" detail object. -
regionalInternetRegistry
The related Regional Internet Registry. -
regionalInternetRegistryHandle
The RIR handle that this registration object belongs to. This field may not be populated until the registration is complete. -
status
The status of this registration. -
subnet
The subnet that this registration pertains to. -
accountId
The registration object's associated [[SoftLayer_Account|account]] id -
accountIdSpecified
protected boolean accountIdSpecified -
cidr
The CIDR prefix for the registered subnet -
cidrSpecified
protected boolean cidrSpecified -
createDate
-
createDateSpecified
protected boolean createDateSpecified -
id
Unique ID of the registration object -
idSpecified
protected boolean idSpecified -
modifyDate
-
modifyDateSpecified
protected boolean modifyDateSpecified -
networkHandle
The RIR-specific handle or name of the registered subnet. This field is read-only. -
networkHandleSpecified
protected boolean networkHandleSpecified -
networkIdentifier
The base IP address of the registered subnet -
networkIdentifierSpecified
protected boolean networkIdentifierSpecified -
regionalInternetRegistryHandleId
The registration object's associated [[SoftLayer_Account_Rwhois_Handle|RIR handle]] id -
regionalInternetRegistryHandleIdSpecified
protected boolean regionalInternetRegistryHandleIdSpecified -
regionalInternetRegistryId
The registration object's associated [[SoftLayer_Network_Regional_Internet_Registry|RIR]] id -
regionalInternetRegistryIdSpecified
protected boolean regionalInternetRegistryIdSpecified -
statusId
The registration object's associated [[SoftLayer_Network_Subnet_Registration_Status|status]] id -
statusIdSpecified
protected boolean statusIdSpecified -
detailReferenceCount
A count of the cross-reference records that tie the [[SoftLayer_Account_Regional_Registry_Detail]] objects to the registration object. -
eventCount
A count of the related registration events.
-
-
Constructor Details
-
Registration
public Registration()
-
-
Method Details
-
getAccount
-
setAccount
-
getDetailReferences
-
getEvents
-
getNetworkDetail
-
setNetworkDetail
-
getPersonDetail
-
setPersonDetail
-
getRegionalInternetRegistry
-
setRegionalInternetRegistry
-
getRegionalInternetRegistryHandle
-
setRegionalInternetRegistryHandle
-
getStatus
-
setStatus
-
getSubnet
-
setSubnet
-
getAccountId
-
setAccountId
-
isAccountIdSpecified
public boolean isAccountIdSpecified() -
unsetAccountId
public void unsetAccountId() -
getCidr
-
setCidr
-
isCidrSpecified
public boolean isCidrSpecified() -
unsetCidr
public void unsetCidr() -
getCreateDate
-
setCreateDate
-
isCreateDateSpecified
public boolean isCreateDateSpecified() -
unsetCreateDate
public void unsetCreateDate() -
getId
-
setId
-
isIdSpecified
public boolean isIdSpecified() -
unsetId
public void unsetId() -
getModifyDate
-
setModifyDate
-
isModifyDateSpecified
public boolean isModifyDateSpecified() -
unsetModifyDate
public void unsetModifyDate() -
getNetworkHandle
-
setNetworkHandle
-
isNetworkHandleSpecified
public boolean isNetworkHandleSpecified() -
unsetNetworkHandle
public void unsetNetworkHandle() -
getNetworkIdentifier
-
setNetworkIdentifier
-
isNetworkIdentifierSpecified
public boolean isNetworkIdentifierSpecified() -
unsetNetworkIdentifier
public void unsetNetworkIdentifier() -
getRegionalInternetRegistryHandleId
-
setRegionalInternetRegistryHandleId
-
isRegionalInternetRegistryHandleIdSpecified
public boolean isRegionalInternetRegistryHandleIdSpecified() -
unsetRegionalInternetRegistryHandleId
public void unsetRegionalInternetRegistryHandleId() -
getRegionalInternetRegistryId
-
setRegionalInternetRegistryId
-
isRegionalInternetRegistryIdSpecified
public boolean isRegionalInternetRegistryIdSpecified() -
unsetRegionalInternetRegistryId
public void unsetRegionalInternetRegistryId() -
getStatusId
-
setStatusId
-
isStatusIdSpecified
public boolean isStatusIdSpecified() -
unsetStatusId
public void unsetStatusId() -
getDetailReferenceCount
-
setDetailReferenceCount
-
getEventCount
-
setEventCount
-
asService
-
service
-
service
-