Class Context
java.lang.Object
com.softlayer.api.Type
com.softlayer.api.service.Entity
com.softlayer.api.service.network.tunnel.module.Context
@ApiType("SoftLayer_Network_Tunnel_Module_Context") public class Context extends Entity
The SoftLayer_Network_Tunnel_Module_Context data type contains general information relating to a single SoftLayer network tunnel. The SoftLayer_Network_Tunnel_Module_Context is useful to gather information such as related customer subnets (remote) and internal subnets (local) associated with the network tunnel as well as other information needed to manage the network tunnel. Account and billing information related to the network tunnel can also be retrieved.
- See Also:
- SoftLayer_Network_Tunnel_Module_Context
-
Nested Class Summary
Nested Classes Modifier and Type Class Description static classContext.Maskstatic interfaceContext.ServiceA SoftLayer network tunnel allows customer to authenticate and encrypt all IP traffic between two locations.static interfaceContext.ServiceAsync -
Field Summary
Fields Modifier and Type Field Description protected AccountaccountThe account that a network tunnel belongs to.protected LongaccountIdA network tunnel's account identifier.protected booleanaccountIdSpecifiedprotected TransactionactiveTransactionThe transaction that is currently applying configurations for the network tunnel.protected LongaddressTranslationCountA count of a network tunnel's address translations.protected List<Translation>addressTranslationsA network tunnel's address translations.protected LongadvancedConfigurationFlagA flag used to specify when advanced configurations, complex configurations that require manual setup, are being applied to network devices for a network tunnel.protected booleanadvancedConfigurationFlagSpecifiedprotected LongallAvailableServiceSubnetCountA count of subnets that provide access to SoftLayer services such as the management portal and the SoftLayer API.protected List<Subnet>allAvailableServiceSubnetsSubnets that provide access to SoftLayer services such as the management portal and the SoftLayer API.protected ItembillingItemThe current billing item for network tunnel.protected GregorianCalendarcreateDateThe date a network tunnel was created.protected booleancreateDateSpecifiedprotected StringcustomerPeerIpAddressThe remote end of a network tunnel.protected booleancustomerPeerIpAddressSpecifiedprotected LongcustomerSubnetCountA count of remote subnets that are allowed access through a network tunnel.protected List<Subnet>customerSubnetsRemote subnets that are allowed access through a network tunnel.protected LocationdatacenterThe datacenter location for one end of the network tunnel that allows access to account's private subnets.protected StringfriendlyNameThe name giving to a network tunnel by a user.protected booleanfriendlyNameSpecifiedprotected LongidA network tunnel's unique identifier.protected booleanidSpecifiedprotected StringinternalPeerIpAddressThe local end of a network tunnel.protected booleaninternalPeerIpAddressSpecifiedprotected LonginternalSubnetCountA count of private subnets that can be accessed through the network tunnel.protected List<Subnet>internalSubnetsPrivate subnets that can be accessed through the network tunnel.protected GregorianCalendarmodifyDateThe date a network tunnel was last modified.protected booleanmodifyDateSpecifiedprotected StringnameA network tunnel's unique name used on the network device.protected booleannameSpecifiedprotected StringphaseOneAuthenticationAuthentication used to generate keys for protecting the negotiations for a network tunnel.protected booleanphaseOneAuthenticationSpecifiedprotected LongphaseOneDiffieHellmanGroupDetermines the strength of the key used in the key exchange process.protected booleanphaseOneDiffieHellmanGroupSpecifiedprotected StringphaseOneEncryptionEncryption used to generate keys for protecting the negotiations for a network tunnel.protected booleanphaseOneEncryptionSpecifiedprotected LongphaseOneKeylifeAmount of time (in seconds) allowed to pass before the encryption key expires.protected booleanphaseOneKeylifeSpecifiedprotected StringphaseTwoAuthenticationThe authentication used in phase 2 proposal negotiation process.protected booleanphaseTwoAuthenticationSpecifiedprotected LongphaseTwoDiffieHellmanGroupDetermines the strength of the key used in the key exchange process.protected booleanphaseTwoDiffieHellmanGroupSpecifiedprotected StringphaseTwoEncryptionThe encryption used in phase 2 proposal negotiation process.protected booleanphaseTwoEncryptionSpecifiedprotected LongphaseTwoKeylifeAmount of time (in seconds) allowed to pass before the encryption key expires.protected booleanphaseTwoKeylifeSpecifiedprotected LongphaseTwoPerfectForwardSecrecyDetermines if the generated keys are made from previous keys.protected booleanphaseTwoPerfectForwardSecrecySpecifiedprotected StringpresharedKeyA key used so that peers authenticate each other.protected booleanpresharedKeySpecifiedprotected LongserviceSubnetCountA count of service subnets that can be access through the network tunnel.protected List<Subnet>serviceSubnetsService subnets that can be access through the network tunnel.protected LongstaticRouteSubnetCountA count of subnets used for a network tunnel's address translations.protected List<Subnet>staticRouteSubnetsSubnets used for a network tunnel's address translations.protected List<Transaction>transactionHistoryThe transaction history for this network tunnel.protected LongtransactionHistoryCountA count of the transaction history for this network tunnel. -
Constructor Summary
Constructors Constructor Description Context() -
Method Summary
-
Field Details
-
account
The account that a network tunnel belongs to. -
activeTransaction
The transaction that is currently applying configurations for the network tunnel. -
addressTranslations
A network tunnel's address translations. -
allAvailableServiceSubnets
Subnets that provide access to SoftLayer services such as the management portal and the SoftLayer API. -
billingItem
The current billing item for network tunnel. -
customerSubnets
Remote subnets that are allowed access through a network tunnel. -
datacenter
The datacenter location for one end of the network tunnel that allows access to account's private subnets. -
internalSubnets
Private subnets that can be accessed through the network tunnel. -
serviceSubnets
Service subnets that can be access through the network tunnel. -
staticRouteSubnets
Subnets used for a network tunnel's address translations. -
transactionHistory
The transaction history for this network tunnel. -
accountId
A network tunnel's account identifier. -
accountIdSpecified
protected boolean accountIdSpecified -
advancedConfigurationFlag
A flag used to specify when advanced configurations, complex configurations that require manual setup, are being applied to network devices for a network tunnel. When the flag is set to true (1), a network tunnel cannot be configured through the management portal nor the API. -
advancedConfigurationFlagSpecified
protected boolean advancedConfigurationFlagSpecified -
createDate
The date a network tunnel was created. -
createDateSpecified
protected boolean createDateSpecified -
customerPeerIpAddress
The remote end of a network tunnel. This end of the network tunnel resides on an outside network and will be sending and receiving the IPSec packets. -
customerPeerIpAddressSpecified
protected boolean customerPeerIpAddressSpecified -
friendlyName
The name giving to a network tunnel by a user. -
friendlyNameSpecified
protected boolean friendlyNameSpecified -
id
A network tunnel's unique identifier. -
idSpecified
protected boolean idSpecified -
internalPeerIpAddress
The local end of a network tunnel. This end of the network tunnel resides on the SoftLayer networks and allows access to remote end of the tunnel to subnets on SoftLayer networks. -
internalPeerIpAddressSpecified
protected boolean internalPeerIpAddressSpecified -
modifyDate
The date a network tunnel was last modified.
NOTE: This date should NOT be used to determine when the network tunnel configurations were last applied to the network device. -
modifyDateSpecified
protected boolean modifyDateSpecified -
name
A network tunnel's unique name used on the network device. -
nameSpecified
protected boolean nameSpecified -
phaseOneAuthentication
Authentication used to generate keys for protecting the negotiations for a network tunnel. -
phaseOneAuthenticationSpecified
protected boolean phaseOneAuthenticationSpecified -
phaseOneDiffieHellmanGroup
Determines the strength of the key used in the key exchange process. The higher the group number the stronger the key is and the more secure it is. However, processing time will increase as the strength of the key increases. Both peers in the must use the Diffie-Hellman Group. -
phaseOneDiffieHellmanGroupSpecified
protected boolean phaseOneDiffieHellmanGroupSpecified -
phaseOneEncryption
Encryption used to generate keys for protecting the negotiations for a network tunnel. -
phaseOneEncryptionSpecified
protected boolean phaseOneEncryptionSpecified -
phaseOneKeylife
Amount of time (in seconds) allowed to pass before the encryption key expires. A new key is generated without interrupting service. Valid times are from 120 to 172800 seconds. -
phaseOneKeylifeSpecified
protected boolean phaseOneKeylifeSpecified -
phaseTwoAuthentication
The authentication used in phase 2 proposal negotiation process. -
phaseTwoAuthenticationSpecified
protected boolean phaseTwoAuthenticationSpecified -
phaseTwoDiffieHellmanGroup
Determines the strength of the key used in the key exchange process. The higher the group number the stronger the key is and the more secure it is. However, processing time will increase as the strength of the key increases. Both peers must use the Diffie-Hellman Group. -
phaseTwoDiffieHellmanGroupSpecified
protected boolean phaseTwoDiffieHellmanGroupSpecified -
phaseTwoEncryption
The encryption used in phase 2 proposal negotiation process. -
phaseTwoEncryptionSpecified
protected boolean phaseTwoEncryptionSpecified -
phaseTwoKeylife
Amount of time (in seconds) allowed to pass before the encryption key expires. A new key is generated without interrupting service. Valid times are from 120 to 172800 seconds. -
phaseTwoKeylifeSpecified
protected boolean phaseTwoKeylifeSpecified -
phaseTwoPerfectForwardSecrecy
Determines if the generated keys are made from previous keys. When PFS is specified, a Diffie-Hellman exchange occurs each time a new security association is negotiated. -
phaseTwoPerfectForwardSecrecySpecified
protected boolean phaseTwoPerfectForwardSecrecySpecified -
presharedKey
A key used so that peers authenticate each other. This key is hashed by using the phase one encryption and phase one authentication. -
presharedKeySpecified
protected boolean presharedKeySpecified -
addressTranslationCount
A count of a network tunnel's address translations. -
allAvailableServiceSubnetCount
A count of subnets that provide access to SoftLayer services such as the management portal and the SoftLayer API. -
customerSubnetCount
A count of remote subnets that are allowed access through a network tunnel. -
internalSubnetCount
A count of private subnets that can be accessed through the network tunnel. -
serviceSubnetCount
A count of service subnets that can be access through the network tunnel. -
staticRouteSubnetCount
A count of subnets used for a network tunnel's address translations. -
transactionHistoryCount
A count of the transaction history for this network tunnel.
-
-
Constructor Details
-
Context
public Context()
-
-
Method Details
-
getAccount
-
setAccount
-
getActiveTransaction
-
setActiveTransaction
-
getAddressTranslations
-
getAllAvailableServiceSubnets
-
getBillingItem
-
setBillingItem
-
getCustomerSubnets
-
getDatacenter
-
setDatacenter
-
getInternalSubnets
-
getServiceSubnets
-
getStaticRouteSubnets
-
getTransactionHistory
-
getAccountId
-
setAccountId
-
isAccountIdSpecified
public boolean isAccountIdSpecified() -
unsetAccountId
public void unsetAccountId() -
getAdvancedConfigurationFlag
-
setAdvancedConfigurationFlag
-
isAdvancedConfigurationFlagSpecified
public boolean isAdvancedConfigurationFlagSpecified() -
unsetAdvancedConfigurationFlag
public void unsetAdvancedConfigurationFlag() -
getCreateDate
-
setCreateDate
-
isCreateDateSpecified
public boolean isCreateDateSpecified() -
unsetCreateDate
public void unsetCreateDate() -
getCustomerPeerIpAddress
-
setCustomerPeerIpAddress
-
isCustomerPeerIpAddressSpecified
public boolean isCustomerPeerIpAddressSpecified() -
unsetCustomerPeerIpAddress
public void unsetCustomerPeerIpAddress() -
getFriendlyName
-
setFriendlyName
-
isFriendlyNameSpecified
public boolean isFriendlyNameSpecified() -
unsetFriendlyName
public void unsetFriendlyName() -
getId
-
setId
-
isIdSpecified
public boolean isIdSpecified() -
unsetId
public void unsetId() -
getInternalPeerIpAddress
-
setInternalPeerIpAddress
-
isInternalPeerIpAddressSpecified
public boolean isInternalPeerIpAddressSpecified() -
unsetInternalPeerIpAddress
public void unsetInternalPeerIpAddress() -
getModifyDate
-
setModifyDate
-
isModifyDateSpecified
public boolean isModifyDateSpecified() -
unsetModifyDate
public void unsetModifyDate() -
getName
-
setName
-
isNameSpecified
public boolean isNameSpecified() -
unsetName
public void unsetName() -
getPhaseOneAuthentication
-
setPhaseOneAuthentication
-
isPhaseOneAuthenticationSpecified
public boolean isPhaseOneAuthenticationSpecified() -
unsetPhaseOneAuthentication
public void unsetPhaseOneAuthentication() -
getPhaseOneDiffieHellmanGroup
-
setPhaseOneDiffieHellmanGroup
-
isPhaseOneDiffieHellmanGroupSpecified
public boolean isPhaseOneDiffieHellmanGroupSpecified() -
unsetPhaseOneDiffieHellmanGroup
public void unsetPhaseOneDiffieHellmanGroup() -
getPhaseOneEncryption
-
setPhaseOneEncryption
-
isPhaseOneEncryptionSpecified
public boolean isPhaseOneEncryptionSpecified() -
unsetPhaseOneEncryption
public void unsetPhaseOneEncryption() -
getPhaseOneKeylife
-
setPhaseOneKeylife
-
isPhaseOneKeylifeSpecified
public boolean isPhaseOneKeylifeSpecified() -
unsetPhaseOneKeylife
public void unsetPhaseOneKeylife() -
getPhaseTwoAuthentication
-
setPhaseTwoAuthentication
-
isPhaseTwoAuthenticationSpecified
public boolean isPhaseTwoAuthenticationSpecified() -
unsetPhaseTwoAuthentication
public void unsetPhaseTwoAuthentication() -
getPhaseTwoDiffieHellmanGroup
-
setPhaseTwoDiffieHellmanGroup
-
isPhaseTwoDiffieHellmanGroupSpecified
public boolean isPhaseTwoDiffieHellmanGroupSpecified() -
unsetPhaseTwoDiffieHellmanGroup
public void unsetPhaseTwoDiffieHellmanGroup() -
getPhaseTwoEncryption
-
setPhaseTwoEncryption
-
isPhaseTwoEncryptionSpecified
public boolean isPhaseTwoEncryptionSpecified() -
unsetPhaseTwoEncryption
public void unsetPhaseTwoEncryption() -
getPhaseTwoKeylife
-
setPhaseTwoKeylife
-
isPhaseTwoKeylifeSpecified
public boolean isPhaseTwoKeylifeSpecified() -
unsetPhaseTwoKeylife
public void unsetPhaseTwoKeylife() -
getPhaseTwoPerfectForwardSecrecy
-
setPhaseTwoPerfectForwardSecrecy
-
isPhaseTwoPerfectForwardSecrecySpecified
public boolean isPhaseTwoPerfectForwardSecrecySpecified() -
unsetPhaseTwoPerfectForwardSecrecy
public void unsetPhaseTwoPerfectForwardSecrecy() -
getPresharedKey
-
setPresharedKey
-
isPresharedKeySpecified
public boolean isPresharedKeySpecified() -
unsetPresharedKey
public void unsetPresharedKey() -
getAddressTranslationCount
-
setAddressTranslationCount
-
getAllAvailableServiceSubnetCount
-
setAllAvailableServiceSubnetCount
-
getCustomerSubnetCount
-
setCustomerSubnetCount
-
getInternalSubnetCount
-
setInternalSubnetCount
-
getServiceSubnetCount
-
setServiceSubnetCount
-
getStaticRouteSubnetCount
-
setStaticRouteSubnetCount
-
getTransactionHistoryCount
-
setTransactionHistoryCount
-
asService
-
service
-
service
-