Class Firewall
java.lang.Object
com.softlayer.api.Type
com.softlayer.api.service.Entity
com.softlayer.api.service.network.vlan.Firewall
@ApiType("SoftLayer_Network_Vlan_Firewall") public class Firewall extends Entity
The SoftLayer_Network_Vlan_Firewall data type contains general information relating to a single SoftLayer VLAN firewall. This is the object which ties the running rules to a specific downstream server. Use the [[SoftLayer Network Firewall Template]] service to pull SoftLayer recommended rule set templates. Use the [[SoftLayer Network Firewall Update Request]] service to submit a firewall update request.
- See Also:
- SoftLayer_Network_Vlan_Firewall
-
Nested Class Summary
Nested Classes Modifier and Type Class Description static classFirewall.Maskstatic interfaceFirewall.ServiceThe SoftLayer_Network_Vlan_Firewall service accesses general information relating to a single SoftLayer VLAN firewall.static interfaceFirewall.ServiceAsync -
Field Summary
Fields Modifier and Type Field Description protected LongaccountIdprotected StringadministrativeBypassFlagA flag to indicate if the firewall is in administrative bypass mode.protected booleanadministrativeBypassFlagSpecifiedprotected BigDecimalbandwidthAllocationA firewall's allotted bandwidth (measured in GB).protected List<Usage>billingCycleBandwidthUsageThe raw bandwidth usage data for the current billing cycle.protected LongbillingCycleBandwidthUsageCountA count of the raw bandwidth usage data for the current billing cycle.protected UsagebillingCyclePrivateBandwidthUsageThe raw private bandwidth usage data for the current billing cycle.protected UsagebillingCyclePublicBandwidthUsageThe raw public bandwidth usage data for the current billing cycle.protected ItembillingItemThe billing item for a Hardware Firewall (Dedicated).protected StringbypassRequestStatusAdministrative bypass request status.protected BooleancustomerManagedFlagWhether or not this firewall can be directly logged in to.protected booleancustomerManagedFlagSpecifiedprotected LocationdatacenterThe datacenter that the firewall resides in.protected StringfirewallTypeThe firewall device type.protected StringfullyQualifiedDomainNameA name reflecting the hostname and domain of the firewall.protected LongidA firewall's unique identifier.protected booleanidSpecifiedprotected PasswordmanagementCredentialsThe credentials to log in to a firewall device.protected ObjectmetricTrackingObjectA firewall's metric tracking object.protected LongmetricTrackingObjectIdThe metric tracking object ID for this firewall.protected LongnetworkFirewallUpdateRequestCountA count of the update requests made for this firewall.protected List<Request>networkFirewallUpdateRequestsThe update requests made for this firewall.protected GatewaynetworkGatewayThe gateway associated with this firewall, if any.protected VlannetworkVlanThe VLAN object that a firewall is associated with and protecting.protected LongnetworkVlanCountA count of the VLAN objects that a firewall is associated with and protecting.protected List<Vlan>networkVlansThe VLAN objects that a firewall is associated with and protecting.protected StringprimaryIpAddressA firewall's primary IP address.protected booleanprimaryIpAddressSpecifiedprotected LongruleCountA count of the currently running rule set of this network component firewall.protected List<Rule>rulesThe currently running rule set of this network component firewall.protected LongtagReferenceCountA count ofprotected List<Reference>tagReferencesprotected RequestupgradeRequestA firewall's associated upgrade request object, if any. -
Constructor Summary
Constructors Constructor Description Firewall() -
Method Summary
-
Field Details
-
accountId
-
bandwidthAllocation
A firewall's allotted bandwidth (measured in GB). -
billingCycleBandwidthUsage
The raw bandwidth usage data for the current billing cycle. One object will be returned for each network this firewall is attached to. -
billingCyclePrivateBandwidthUsage
The raw private bandwidth usage data for the current billing cycle. -
billingCyclePublicBandwidthUsage
The raw public bandwidth usage data for the current billing cycle. -
billingItem
The billing item for a Hardware Firewall (Dedicated). -
bypassRequestStatus
Administrative bypass request status. -
datacenter
The datacenter that the firewall resides in. -
firewallType
The firewall device type. -
fullyQualifiedDomainName
A name reflecting the hostname and domain of the firewall. This is created from the combined values of the firewall's logical name and vlan number automatically, and thus can not be edited directly. -
managementCredentials
The credentials to log in to a firewall device. This is only present for dedicated appliances. -
metricTrackingObject
A firewall's metric tracking object. -
metricTrackingObjectId
The metric tracking object ID for this firewall. -
networkFirewallUpdateRequests
The update requests made for this firewall. -
networkGateway
The gateway associated with this firewall, if any. -
networkVlan
The VLAN object that a firewall is associated with and protecting. -
networkVlans
The VLAN objects that a firewall is associated with and protecting. -
rules
The currently running rule set of this network component firewall. -
tagReferences
-
upgradeRequest
A firewall's associated upgrade request object, if any. -
administrativeBypassFlag
A flag to indicate if the firewall is in administrative bypass mode. In other words, no rules are being applied to the traffic coming through. -
administrativeBypassFlagSpecified
protected boolean administrativeBypassFlagSpecified -
customerManagedFlag
Whether or not this firewall can be directly logged in to. -
customerManagedFlagSpecified
protected boolean customerManagedFlagSpecified -
id
A firewall's unique identifier. -
idSpecified
protected boolean idSpecified -
primaryIpAddress
A firewall's primary IP address. This field will be the IP shown when doing network traces and reverse DNS and is a read-only property. -
primaryIpAddressSpecified
protected boolean primaryIpAddressSpecified -
billingCycleBandwidthUsageCount
A count of the raw bandwidth usage data for the current billing cycle. One object will be returned for each network this firewall is attached to. -
networkFirewallUpdateRequestCount
A count of the update requests made for this firewall. -
networkVlanCount
A count of the VLAN objects that a firewall is associated with and protecting. -
ruleCount
A count of the currently running rule set of this network component firewall. -
tagReferenceCount
A count of
-
-
Constructor Details
-
Firewall
public Firewall()
-
-
Method Details
-
getAccountId
-
setAccountId
-
getBandwidthAllocation
-
setBandwidthAllocation
-
getBillingCycleBandwidthUsage
-
getBillingCyclePrivateBandwidthUsage
-
setBillingCyclePrivateBandwidthUsage
-
getBillingCyclePublicBandwidthUsage
-
setBillingCyclePublicBandwidthUsage
-
getBillingItem
-
setBillingItem
-
getBypassRequestStatus
-
setBypassRequestStatus
-
getDatacenter
-
setDatacenter
-
getFirewallType
-
setFirewallType
-
getFullyQualifiedDomainName
-
setFullyQualifiedDomainName
-
getManagementCredentials
-
setManagementCredentials
-
getMetricTrackingObject
-
setMetricTrackingObject
-
getMetricTrackingObjectId
-
setMetricTrackingObjectId
-
getNetworkFirewallUpdateRequests
-
getNetworkGateway
-
setNetworkGateway
-
getNetworkVlan
-
setNetworkVlan
-
getNetworkVlans
-
getRules
-
getTagReferences
-
getUpgradeRequest
-
setUpgradeRequest
-
getAdministrativeBypassFlag
-
setAdministrativeBypassFlag
-
isAdministrativeBypassFlagSpecified
public boolean isAdministrativeBypassFlagSpecified() -
unsetAdministrativeBypassFlag
public void unsetAdministrativeBypassFlag() -
getCustomerManagedFlag
-
setCustomerManagedFlag
-
isCustomerManagedFlagSpecified
public boolean isCustomerManagedFlagSpecified() -
unsetCustomerManagedFlag
public void unsetCustomerManagedFlag() -
getId
-
setId
-
isIdSpecified
public boolean isIdSpecified() -
unsetId
public void unsetId() -
getPrimaryIpAddress
-
setPrimaryIpAddress
-
isPrimaryIpAddressSpecified
public boolean isPrimaryIpAddressSpecified() -
unsetPrimaryIpAddress
public void unsetPrimaryIpAddress() -
getBillingCycleBandwidthUsageCount
-
setBillingCycleBandwidthUsageCount
-
getNetworkFirewallUpdateRequestCount
-
setNetworkFirewallUpdateRequestCount
-
getNetworkVlanCount
-
setNetworkVlanCount
-
getRuleCount
-
setRuleCount
-
getTagReferenceCount
-
setTagReferenceCount
-
asService
-
service
-
service
-