Interface Mobile.ServiceAsync
- All Superinterfaces:
Maskable,Notification.ServiceAsync,ResultLimitable,ServiceAsync
- Enclosing class:
- Mobile
public static interface Mobile.ServiceAsync extends Notification.ServiceAsync
-
Method Summary
Modifier and Type Method Description Future<Boolean>createSubscriberForMobileDevice(String keyName, Long resourceTableId, Long userRecordId)Future<?>createSubscriberForMobileDevice(String keyName, Long resourceTableId, Long userRecordId, ResponseHandler<Boolean> callback)Future<Mobile>getObjectForMobile()Async version ofMobile.Service.getObjectForMobile()Future<?>getObjectForMobile(ResponseHandler<Mobile> callback)voidsetMask(Mobile.Mask mask)Mobile.MaskwithMask()Use the existing mask on this service or create it if not presentMobile.MaskwithNewMask()Overwrite the existing mask on this service with a new one and return itMethods inherited from interface com.softlayer.api.service.Notification.ServiceAsync
getAllObjects, getAllObjects, getObject, getObject, getPreferences, getPreferences, getRequiredPreferences, getRequiredPreferences, setMaskMethods inherited from interface com.softlayer.api.ResultLimitable
getLastResponseTotalItemCount, getResultLimit, setResultLimit
-
Method Details
-
withNewMask
Mobile.Mask withNewMask()Description copied from interface:MaskableOverwrite the existing mask on this service with a new one and return it- Specified by:
withNewMaskin interfaceMaskable- Specified by:
withNewMaskin interfaceNotification.ServiceAsync
-
withMask
Mobile.Mask withMask()Description copied from interface:MaskableUse the existing mask on this service or create it if not present- Specified by:
withMaskin interfaceMaskable- Specified by:
withMaskin interfaceNotification.ServiceAsync
-
setMask
-
createSubscriberForMobileDevice
-
createSubscriberForMobileDevice
-
getObjectForMobile
Async version ofMobile.Service.getObjectForMobile() -
getObjectForMobile
-