Class Preference
java.lang.Object
com.softlayer.api.Type
com.softlayer.api.service.Entity
com.softlayer.api.service.notification.Preference
@ApiType("SoftLayer_Notification_Preference") public class Preference extends Entity
Retrieve details for preferences. Preferences are used to allow the subscriber to modify their subscription in various ways. Details such as friendly name, keyname maximum and minimum values can be retrieved. These provide details to help configure subscriber preferences correctly.
- See Also:
- SoftLayer_Notification_Preference
-
Nested Class Summary
Nested Classes Modifier and Type Class Description static classPreference.Mask -
Field Summary
Fields Modifier and Type Field Description protected StringdescriptionA description of what the preference is used for.protected booleandescriptionSpecifiedprotected LongidUnique identifier for the notification preference.protected booleanidSpecifiedprotected StringkeyNameName that can be used by external systems to refer to preference.protected booleankeyNameSpecifiedprotected StringmaximumValueLargest value allowed for the preference.protected booleanmaximumValueSpecifiedprotected StringminimumValueSmallest value allowed for the preference.protected booleanminimumValueSpecifiedprotected StringnameFriendly name for the notification.protected booleannameSpecifiedprotected StringunitsThe unit of measure used for the preference's value, minimum and maximum as well.protected booleanunitsSpecifiedprotected StringvalueDefault value used when setting up preferences for a new subscriber.protected booleanvalueSpecified -
Constructor Summary
Constructors Constructor Description Preference() -
Method Summary
Modifier and Type Method Description StringgetDescription()LonggetId()StringgetKeyName()StringgetMaximumValue()StringgetMinimumValue()StringgetName()StringgetUnits()StringgetValue()booleanisDescriptionSpecified()booleanisIdSpecified()booleanisKeyNameSpecified()booleanisMaximumValueSpecified()booleanisMinimumValueSpecified()booleanisNameSpecified()booleanisUnitsSpecified()booleanisValueSpecified()voidsetDescription(String description)voidsetId(Long id)voidsetKeyName(String keyName)voidsetMaximumValue(String maximumValue)voidsetMinimumValue(String minimumValue)voidsetName(String name)voidsetUnits(String units)voidsetValue(String value)voidunsetDescription()voidunsetId()voidunsetKeyName()voidunsetMaximumValue()voidunsetMinimumValue()voidunsetName()voidunsetUnits()voidunsetValue()
-
Field Details
-
description
A description of what the preference is used for. -
descriptionSpecified
protected boolean descriptionSpecified -
id
Unique identifier for the notification preference. -
idSpecified
protected boolean idSpecified -
keyName
Name that can be used by external systems to refer to preference. -
keyNameSpecified
protected boolean keyNameSpecified -
maximumValue
Largest value allowed for the preference. -
maximumValueSpecified
protected boolean maximumValueSpecified -
minimumValue
Smallest value allowed for the preference. -
minimumValueSpecified
protected boolean minimumValueSpecified -
name
Friendly name for the notification. -
nameSpecified
protected boolean nameSpecified -
units
The unit of measure used for the preference's value, minimum and maximum as well. -
unitsSpecified
protected boolean unitsSpecified -
value
Default value used when setting up preferences for a new subscriber. -
valueSpecified
protected boolean valueSpecified
-
-
Constructor Details
-
Preference
public Preference()
-
-
Method Details
-
getDescription
-
setDescription
-
isDescriptionSpecified
public boolean isDescriptionSpecified() -
unsetDescription
public void unsetDescription() -
getId
-
setId
-
isIdSpecified
public boolean isIdSpecified() -
unsetId
public void unsetId() -
getKeyName
-
setKeyName
-
isKeyNameSpecified
public boolean isKeyNameSpecified() -
unsetKeyName
public void unsetKeyName() -
getMaximumValue
-
setMaximumValue
-
isMaximumValueSpecified
public boolean isMaximumValueSpecified() -
unsetMaximumValue
public void unsetMaximumValue() -
getMinimumValue
-
setMinimumValue
-
isMinimumValueSpecified
public boolean isMinimumValueSpecified() -
unsetMinimumValue
public void unsetMinimumValue() -
getName
-
setName
-
isNameSpecified
public boolean isNameSpecified() -
unsetName
public void unsetName() -
getUnits
-
setUnits
-
isUnitsSpecified
public boolean isUnitsSpecified() -
unsetUnits
public void unsetUnits() -
getValue
-
setValue
-
isValueSpecified
public boolean isValueSpecified() -
unsetValue
public void unsetValue()
-