Interface Event.ServiceAsync
- All Superinterfaces:
Maskable,ResultLimitable,ServiceAsync
- Enclosing class:
- Event
public static interface Event.ServiceAsync extends ServiceAsync
-
Method Summary
Methods inherited from interface com.softlayer.api.ResultLimitable
getLastResponseTotalItemCount, getResultLimit, setResultLimit
-
Method Details
-
withNewMask
Event.Mask withNewMask()Description copied from interface:MaskableOverwrite the existing mask on this service with a new one and return it- Specified by:
withNewMaskin interfaceMaskable
-
withMask
Event.Mask withMask()Description copied from interface:MaskableUse the existing mask on this service or create it if not present -
setMask
-
acknowledgeNotification
Async version ofEvent.Service.acknowledgeNotification() -
acknowledgeNotification
-
getAllObjects
Async version ofEvent.Service.getAllObjects() -
getAllObjects
-
getAttachedFile
Async version ofEvent.Service.getAttachedFile(java.lang.Long) -
getAttachedFile
-
getImpactedAccountCount
Async version ofEvent.Service.getImpactedAccountCount() -
getImpactedAccountCount
-
getImpactedDeviceCount
Async version ofEvent.Service.getImpactedDeviceCount() -
getImpactedDeviceCount
-
getImpactedDevices
Async version ofEvent.Service.getImpactedDevices() -
getImpactedDevices
-
getObject
Async version ofEvent.Service.getObject() -
getObject
-
getAcknowledgedFlag
Async version ofEvent.Service.getAcknowledgedFlag() -
getAcknowledgedFlag
Async callback version ofEvent.Service.getAcknowledgedFlag() -
getAttachments
Future<List<Attachment>> getAttachments()Async version ofEvent.Service.getAttachments() -
getAttachments
Async callback version ofEvent.Service.getAttachments() -
getFirstUpdate
Async version ofEvent.Service.getFirstUpdate() -
getFirstUpdate
Async callback version ofEvent.Service.getFirstUpdate() -
getImpactedAccounts
Async version ofEvent.Service.getImpactedAccounts() -
getImpactedAccounts
Async callback version ofEvent.Service.getImpactedAccounts() -
getImpactedResources
Async version ofEvent.Service.getImpactedResources() -
getImpactedResources
Async callback version ofEvent.Service.getImpactedResources() -
getImpactedUsers
Async version ofEvent.Service.getImpactedUsers() -
getImpactedUsers
Async callback version ofEvent.Service.getImpactedUsers() -
getLastUpdate
Async version ofEvent.Service.getLastUpdate() -
getLastUpdate
Async callback version ofEvent.Service.getLastUpdate() -
getNotificationOccurrenceEventType
Async version ofEvent.Service.getNotificationOccurrenceEventType() -
getNotificationOccurrenceEventType
Async callback version ofEvent.Service.getNotificationOccurrenceEventType() -
getStatusCode
Async version ofEvent.Service.getStatusCode() -
getStatusCode
Async callback version ofEvent.Service.getStatusCode() -
getUpdates
Async version ofEvent.Service.getUpdates() -
getUpdates
Async callback version ofEvent.Service.getUpdates()
-