Interface User.Service
- All Superinterfaces:
Maskable,ResultLimitable,Service
- Enclosing class:
- User
@ApiService("SoftLayer_Notification_Occurrence_User") public static interface User.Service extends Service
- See Also:
- SoftLayer_Notification_Occurrence_User
-
Method Summary
Modifier and Type Method Description Booleanacknowledge()User.ServiceAsyncasAsync()Get an async version of this serviceList<User>getAllObjects()LonggetImpactedDeviceCount()List<Resource>getImpactedResources()A collection of resources impacted by the associated event.EventgetNotificationOccurrenceEvent()The associated event.UsergetObject()CustomergetUser()The impacted user.voidsetMask(User.Mask mask)User.MaskwithMask()Use the existing mask on this service or create it if not presentUser.MaskwithNewMask()Overwrite the existing mask on this service with a new one and return itMethods inherited from interface com.softlayer.api.ResultLimitable
getLastResponseTotalItemCount, getResultLimit, setResultLimit
-
Method Details
-
asAsync
User.ServiceAsync asAsync()Description copied from interface:ServiceGet an async version of this service -
withNewMask
User.Mask withNewMask()Description copied from interface:MaskableOverwrite the existing mask on this service with a new one and return it- Specified by:
withNewMaskin interfaceMaskable
-
withMask
User.Mask withMask()Description copied from interface:MaskableUse the existing mask on this service or create it if not present -
setMask
-
acknowledge
-
getAllObjects
-
getImpactedDeviceCount
-
getObject
-
getImpactedResources
A collection of resources impacted by the associated event. -
getNotificationOccurrenceEvent
The associated event. -
getUser
The impacted user.
-