Interface Promotion.Service
- All Superinterfaces:
Maskable,ResultLimitable,Service
- Enclosing class:
- Promotion
@ApiService("SoftLayer_Product_Promotion") public static interface Promotion.Service extends Service
The promotion web service is used to find information regarding a specific promotion using a promotion code.
- See Also:
- SoftLayer_Product_Promotion
-
Method Summary
Modifier and Type Method Description Promotion.ServiceAsyncasAsync()Get an async version of this servicePromotionfindByPromoCode(String code)Retrieves a promotion using its code.PromotiongetObject()voidsetMask(Promotion.Mask mask)Promotion.MaskwithMask()Use the existing mask on this service or create it if not presentPromotion.MaskwithNewMask()Overwrite the existing mask on this service with a new one and return itMethods inherited from interface com.softlayer.api.ResultLimitable
getLastResponseTotalItemCount, getResultLimit, setResultLimit
-
Method Details
-
asAsync
Promotion.ServiceAsync asAsync()Description copied from interface:ServiceGet an async version of this service -
withNewMask
Promotion.Mask withNewMask()Description copied from interface:MaskableOverwrite the existing mask on this service with a new one and return it- Specified by:
withNewMaskin interfaceMaskable
-
withMask
Promotion.Mask withMask()Description copied from interface:MaskableUse the existing mask on this service or create it if not present -
setMask
-
findByPromoCode
Retrieves a promotion using its code. -
getObject
- See Also:
- SoftLayer_Product_Promotion::getObject
-