Interface Option.ServiceAsync
- All Superinterfaces:
Maskable,ResultLimitable,ServiceAsync
- Enclosing class:
- Option
public static interface Option.ServiceAsync extends ServiceAsync
-
Method Summary
Modifier and Type Method Description Future<List<Option>>getAllOptions()Async version ofOption.Service.getAllOptions()Future<?>getAllOptions(ResponseHandler<List<Option>> callback)Future<Option>getObject()Async version ofOption.Service.getObject()Future<?>getObject(ResponseHandler<Option> callback)Future<List<Option>>getOptions(String type)Async version ofOption.Service.getOptions(java.lang.String)Future<?>getOptions(String type, ResponseHandler<List<Option>> callback)voidsetMask(Option.Mask mask)Option.MaskwithMask()Use the existing mask on this service or create it if not presentOption.MaskwithNewMask()Overwrite the existing mask on this service with a new one and return itMethods inherited from interface com.softlayer.api.ResultLimitable
getLastResponseTotalItemCount, getResultLimit, setResultLimit
-
Method Details
-
withNewMask
Option.Mask withNewMask()Description copied from interface:MaskableOverwrite the existing mask on this service with a new one and return it- Specified by:
withNewMaskin interfaceMaskable
-
withMask
Option.Mask withMask()Description copied from interface:MaskableUse the existing mask on this service or create it if not present -
setMask
-
getAllOptions
Async version ofOption.Service.getAllOptions() -
getAllOptions
-
getObject
Async version ofOption.Service.getObject() -
getObject
-
getOptions
Async version ofOption.Service.getOptions(java.lang.String) -
getOptions
-