Interface Classification.ServiceAsync
- All Superinterfaces:
Maskable,ResultLimitable,ServiceAsync
- Enclosing class:
- Classification
public static interface Classification.ServiceAsync extends ServiceAsync
-
Method Summary
Methods inherited from interface com.softlayer.api.ResultLimitable
getLastResponseTotalItemCount, getResultLimit, setResultLimit
-
Method Details
-
withNewMask
Classification.Mask withNewMask()Description copied from interface:MaskableOverwrite the existing mask on this service with a new one and return it- Specified by:
withNewMaskin interfaceMaskable
-
withMask
Classification.Mask withMask()Description copied from interface:MaskableUse the existing mask on this service or create it if not present -
setMask
-
getMaintenanceClassification
Async version ofClassification.Service.getMaintenanceClassification(java.lang.Long) -
getMaintenanceClassification
Future<?> getMaintenanceClassification(Long maintenanceClassificationId, ResponseHandler<List<Classification>> callback) -
getMaintenanceClassificationsByItemCategory
Async version ofClassification.Service.getMaintenanceClassificationsByItemCategory() -
getMaintenanceClassificationsByItemCategory
-
getObject
Future<Classification> getObject()Async version ofClassification.Service.getObject() -
getObject
-
getItemCategories
Async version ofClassification.Service.getItemCategories() -
getItemCategories
Async callback version ofClassification.Service.getItemCategories()
-