Interface Window.Service
- All Superinterfaces:
Maskable,ResultLimitable,Service
- Enclosing class:
- Window
@ApiService("SoftLayer_Provisioning_Maintenance_Window") public static interface Window.Service extends Service
The SoftLayer_Provisioning_Maintenance_Window service returns available maintenance windows at SoftLayer data centers.
-
Method Summary
Modifier and Type Method Description BooleanaddCustomerUpgradeWindow(Window customerUpgradeWindow)getMaintenceWindowForTicket() returns a booleanWindow.ServiceAsyncasAsync()Get an async version of this serviceList<Classification>getMaintenanceClassifications()getMaintenanceClassifications() returns an object of maintenance classificationsWindowgetMaintenanceStartEndTime(Long ticketId)getMaintenanceStartEndTime() returns a specific maintenance windowList<Window>getMaintenanceWindowForTicket(Long maintenanceWindowId)getMaintenceWindowForTicket() returns a specific maintenance windowList<Window>getMaintenanceWindows(GregorianCalendar beginDate, GregorianCalendar endDate, Long locationId, Long slotsNeeded)This method returns a list of available maintenance windowsList<Ticket>getMaintenanceWindowTicketsByTicketId(Long ticketId)getMaintenanceWindowTicketsByTicketId() returns a list maintenance window ticket records by ticket idList<Window>getMaintenceWindows(GregorianCalendar beginDate, GregorianCalendar endDate, Long locationId, Long slotsNeeded)(DEPRECATED) Use [[SoftLayer_Provisioning_Maintenance_Window::getMaintenanceWindows|getMaintenanceWindows]] method.voidsetMask(Window.Mask mask)BooleanupdateCustomerUpgradeWindow(GregorianCalendar maintenanceStartTime, Long newMaintenanceWindowId, Long ticketId)getMaintenceWindowForTicket() returns a booleanWindow.MaskwithMask()Use the existing mask on this service or create it if not presentWindow.MaskwithNewMask()Overwrite the existing mask on this service with a new one and return itMethods inherited from interface com.softlayer.api.ResultLimitable
getLastResponseTotalItemCount, getResultLimit, setResultLimit
-
Method Details
-
asAsync
Window.ServiceAsync asAsync()Description copied from interface:ServiceGet an async version of this service -
withNewMask
Window.Mask withNewMask()Description copied from interface:MaskableOverwrite the existing mask on this service with a new one and return it- Specified by:
withNewMaskin interfaceMaskable
-
withMask
Window.Mask withMask()Description copied from interface:MaskableUse the existing mask on this service or create it if not present -
setMask
-
addCustomerUpgradeWindow
getMaintenceWindowForTicket() returns a boolean -
getMaintenanceClassifications
getMaintenanceClassifications() returns an object of maintenance classifications -
getMaintenanceStartEndTime
getMaintenanceStartEndTime() returns a specific maintenance window -
getMaintenanceWindowForTicket
getMaintenceWindowForTicket() returns a specific maintenance window -
getMaintenanceWindowTicketsByTicketId
getMaintenanceWindowTicketsByTicketId() returns a list maintenance window ticket records by ticket id -
getMaintenanceWindows
@ApiMethod List<Window> getMaintenanceWindows(GregorianCalendar beginDate, GregorianCalendar endDate, Long locationId, Long slotsNeeded)This method returns a list of available maintenance windows -
getMaintenceWindows
@ApiMethod List<Window> getMaintenceWindows(GregorianCalendar beginDate, GregorianCalendar endDate, Long locationId, Long slotsNeeded)(DEPRECATED) Use [[SoftLayer_Provisioning_Maintenance_Window::getMaintenanceWindows|getMaintenanceWindows]] method. -
updateCustomerUpgradeWindow
@ApiMethod Boolean updateCustomerUpgradeWindow(GregorianCalendar maintenanceStartTime, Long newMaintenanceWindowId, Long ticketId)getMaintenceWindowForTicket() returns a boolean
-