Class Transaction
java.lang.Object
com.softlayer.api.Type
com.softlayer.api.service.Entity
com.softlayer.api.service.provisioning.version1.Transaction
@ApiType("SoftLayer_Provisioning_Version1_Transaction") public class Transaction extends Entity
The SoftLayer_Provisioning_Version1_Transaction data type contains general information relating to a single SoftLayer hardware transaction.
SoftLayer customers are unable to change their hardware transactions.
SoftLayer customers are unable to change their hardware transactions.
-
Nested Class Summary
Nested Classes Modifier and Type Class Description static classTransaction.Mask -
Field Summary
Fields Modifier and Type Field Description protected AccountaccountThe account that a transaction belongs to.protected GregorianCalendarcreateDateThe date a transaction was created.protected booleancreateDateSpecifiedprotected LongelapsedSecondsThe amount of seconds that have elapsed since the transaction was last modified.protected booleanelapsedSecondsSpecifiedprotected GuestguestThe guest record for this transaction.protected LongguestIdA transaction's associated guest identification number.protected booleanguestIdSpecifiedprotected HardwarehardwareThe hardware object for this transaction.protected LonghardwareIdA transaction's associated hardware identification number.protected booleanhardwareIdSpecifiedprotected LongidA transaction's identifying number.protected booleanidSpecifiedprotected List<Transaction>loopbackprotected LongloopbackCountA count ofprotected GregorianCalendarmodifyDateThe date a transaction was last modified.protected booleanmodifyDateSpecifiedprotected LongpendingTransactionCountA count ofprotected List<Transaction>pendingTransactionsprotected GregorianCalendarstatusChangeDateThe date the transaction status was last modified.protected booleanstatusChangeDateSpecifiedprotected List<Attachment>ticketScheduledActionReferenceprotected LongticketScheduledActionReferenceCountA count ofprotected GrouptransactionGroupA transaction's group.protected StatustransactionStatusA transaction's status.Fields inherited from class com.softlayer.api.Type
unknownProperties -
Constructor Summary
Constructors Constructor Description Transaction() -
Method Summary
Methods inherited from class com.softlayer.api.Type
getUnknownProperties, setUnknownProperties
-
Field Details
-
account
The account that a transaction belongs to. -
guest
The guest record for this transaction. -
hardware
The hardware object for this transaction. -
loopback
-
pendingTransactions
-
ticketScheduledActionReference
-
transactionGroup
A transaction's group. This group object determines what type of service is being done on the hardware. -
transactionStatus
A transaction's status. This status object determines the state it is in the transaction group. -
createDate
The date a transaction was created. -
createDateSpecified
protected boolean createDateSpecified -
elapsedSeconds
The amount of seconds that have elapsed since the transaction was last modified. -
elapsedSecondsSpecified
protected boolean elapsedSecondsSpecified -
guestId
A transaction's associated guest identification number. -
guestIdSpecified
protected boolean guestIdSpecified -
hardwareId
A transaction's associated hardware identification number. -
hardwareIdSpecified
protected boolean hardwareIdSpecified -
id
A transaction's identifying number. -
idSpecified
protected boolean idSpecified -
modifyDate
The date a transaction was last modified. -
modifyDateSpecified
protected boolean modifyDateSpecified -
statusChangeDate
The date the transaction status was last modified. -
statusChangeDateSpecified
protected boolean statusChangeDateSpecified -
loopbackCount
A count of -
pendingTransactionCount
A count of -
ticketScheduledActionReferenceCount
A count of
-
-
Constructor Details
-
Transaction
public Transaction()
-
-
Method Details
-
getAccount
-
setAccount
-
getGuest
-
setGuest
-
getHardware
-
setHardware
-
getLoopback
-
getPendingTransactions
-
getTicketScheduledActionReference
-
getTransactionGroup
-
setTransactionGroup
-
getTransactionStatus
-
setTransactionStatus
-
getCreateDate
-
setCreateDate
-
isCreateDateSpecified
public boolean isCreateDateSpecified() -
unsetCreateDate
public void unsetCreateDate() -
getElapsedSeconds
-
setElapsedSeconds
-
isElapsedSecondsSpecified
public boolean isElapsedSecondsSpecified() -
unsetElapsedSeconds
public void unsetElapsedSeconds() -
getGuestId
-
setGuestId
-
isGuestIdSpecified
public boolean isGuestIdSpecified() -
unsetGuestId
public void unsetGuestId() -
getHardwareId
-
setHardwareId
-
isHardwareIdSpecified
public boolean isHardwareIdSpecified() -
unsetHardwareId
public void unsetHardwareId() -
getId
-
setId
-
isIdSpecified
public boolean isIdSpecified() -
unsetId
public void unsetId() -
getModifyDate
-
setModifyDate
-
isModifyDateSpecified
public boolean isModifyDateSpecified() -
unsetModifyDate
public void unsetModifyDate() -
getStatusChangeDate
-
setStatusChangeDate
-
isStatusChangeDateSpecified
public boolean isStatusChangeDateSpecified() -
unsetStatusChangeDate
public void unsetStatusChangeDate() -
getLoopbackCount
-
setLoopbackCount
-
getPendingTransactionCount
-
setPendingTransactionCount
-
getTicketScheduledActionReferenceCount
-
setTicketScheduledActionReferenceCount
-