Class Configuration
java.lang.Object
com.softlayer.api.Type
com.softlayer.api.service.Entity
com.softlayer.api.service.resource.Configuration
@ApiType("SoftLayer_Resource_Configuration") public class Configuration extends Entity
The Resource Configuration service enables the user to update data regarding a resource from which the request originates. It is a requirement that the request must have an authentication token as well as originate from the backend network of the resource.
- See Also:
- SoftLayer_Resource_Configuration
-
Nested Class Summary
Nested Classes Modifier and Type Class Description static classConfiguration.Maskstatic interfaceConfiguration.ServiceThe Resource Configuration service enables the user to update data regarding a resource from which the request originates.static interfaceConfiguration.ServiceAsync -
Field Summary
Fields inherited from class com.softlayer.api.Type
unknownProperties -
Constructor Summary
Constructors Constructor Description Configuration() -
Method Summary
Modifier and Type Method Description static Configuration.Serviceservice(ApiClient client)Methods inherited from class com.softlayer.api.Type
getUnknownProperties, setUnknownProperties
-
Constructor Details
-
Configuration
public Configuration()
-
-
Method Details
-
service
-