Package com.softlayer.api.service.scale
Class Asset
java.lang.Object
com.softlayer.api.Type
com.softlayer.api.service.Entity
com.softlayer.api.service.scale.Asset
@ApiType("SoftLayer_Scale_Asset") public class Asset extends Entity
The base asset of a scale group. Assets are fixed, non-volatile units of a scale group. They are pinned to the group and will not be automatically added or removed. Their primary purpose is to provide information for the policies to use to determine when to scale members.
- See Also:
- SoftLayer_Scale_Asset
-
Nested Class Summary
Nested Classes Modifier and Type Class Description static classAsset.Maskstatic interfaceAsset.ServiceThe base asset of a scale group.static interfaceAsset.ServiceAsync -
Field Summary
Fields Modifier and Type Field Description protected GregorianCalendarcreateDateWhen this asset was created.protected booleancreateDateSpecifiedprotected BooleandeleteFlagWhen set and true any edit that happens on this object, be it calling edit on this directly or setting as a child while editing a parent object, will end up being a deletion.protected booleandeleteFlagSpecifiedprotected LongidAn asset's internal identifier.protected booleanidSpecifiedprotected GroupscaleGroupThe group this asset belongs to.protected LongscaleGroupIdThe identifier of the group this asset belongs to.protected booleanscaleGroupIdSpecifiedFields inherited from class com.softlayer.api.Type
unknownProperties -
Constructor Summary
Constructors Constructor Description Asset() -
Method Summary
Modifier and Type Method Description Asset.ServiceasService(ApiClient client)GregorianCalendargetCreateDate()BooleangetDeleteFlag()LonggetId()GroupgetScaleGroup()LonggetScaleGroupId()booleanisCreateDateSpecified()booleanisDeleteFlagSpecified()booleanisIdSpecified()booleanisScaleGroupIdSpecified()static Asset.Serviceservice(ApiClient client)static Asset.Serviceservice(ApiClient client, Long id)voidsetCreateDate(GregorianCalendar createDate)voidsetDeleteFlag(Boolean deleteFlag)voidsetId(Long id)voidsetScaleGroup(Group scaleGroup)voidsetScaleGroupId(Long scaleGroupId)voidunsetCreateDate()voidunsetDeleteFlag()voidunsetId()voidunsetScaleGroupId()Methods inherited from class com.softlayer.api.Type
getUnknownProperties, setUnknownProperties
-
Field Details
-
scaleGroup
The group this asset belongs to. -
createDate
When this asset was created. -
createDateSpecified
protected boolean createDateSpecified -
deleteFlag
When set and true any edit that happens on this object, be it calling edit on this directly or setting as a child while editing a parent object, will end up being a deletion. -
deleteFlagSpecified
protected boolean deleteFlagSpecified -
id
An asset's internal identifier. -
idSpecified
protected boolean idSpecified -
scaleGroupId
The identifier of the group this asset belongs to. -
scaleGroupIdSpecified
protected boolean scaleGroupIdSpecified
-
-
Constructor Details
-
Asset
public Asset()
-
-
Method Details
-
getScaleGroup
-
setScaleGroup
-
getCreateDate
-
setCreateDate
-
isCreateDateSpecified
public boolean isCreateDateSpecified() -
unsetCreateDate
public void unsetCreateDate() -
getDeleteFlag
-
setDeleteFlag
-
isDeleteFlagSpecified
public boolean isDeleteFlagSpecified() -
unsetDeleteFlag
public void unsetDeleteFlag() -
getId
-
setId
-
isIdSpecified
public boolean isIdSpecified() -
unsetId
public void unsetId() -
getScaleGroupId
-
setScaleGroupId
-
isScaleGroupIdSpecified
public boolean isScaleGroupIdSpecified() -
unsetScaleGroupId
public void unsetScaleGroupId() -
asService
-
service
-
service
-