Interface OneTime.Service
- All Superinterfaces:
Maskable,ResultLimitable,Service,Trigger.Service
- Enclosing class:
- OneTime
@ApiService("SoftLayer_Scale_Policy_Trigger_OneTime") public static interface OneTime.Service extends Trigger.Service
A trigger that will only execute once on the given date. If the auto scale group is suspended this will not occur.
- See Also:
- SoftLayer_Scale_Policy_Trigger_OneTime
-
Method Summary
Modifier and Type Method Description OneTime.ServiceAsyncasAsync()Get an async version of this serviceOneTimecreateObject(OneTime templateObject)OneTimegetObjectForOneTime()voidsetMask(OneTime.Mask mask)OneTime.MaskwithMask()Use the existing mask on this service or create it if not presentOneTime.MaskwithNewMask()Overwrite the existing mask on this service with a new one and return itMethods inherited from interface com.softlayer.api.ResultLimitable
getLastResponseTotalItemCount, getResultLimit, setResultLimitMethods inherited from interface com.softlayer.api.service.scale.policy.Trigger.Service
createObject, deleteObject, editObject, getObject, getScalePolicy, getType, setMask
-
Method Details
-
asAsync
OneTime.ServiceAsync asAsync()Description copied from interface:ServiceGet an async version of this service- Specified by:
asAsyncin interfaceService- Specified by:
asAsyncin interfaceTrigger.Service
-
withNewMask
OneTime.Mask withNewMask()Description copied from interface:MaskableOverwrite the existing mask on this service with a new one and return it- Specified by:
withNewMaskin interfaceMaskable- Specified by:
withNewMaskin interfaceTrigger.Service
-
withMask
OneTime.Mask withMask()Description copied from interface:MaskableUse the existing mask on this service or create it if not present- Specified by:
withMaskin interfaceMaskable- Specified by:
withMaskin interfaceTrigger.Service
-
setMask
-
createObject
-
getObjectForOneTime
-