Class ResourceUse
java.lang.Object
com.softlayer.api.Type
com.softlayer.api.service.Entity
com.softlayer.api.service.scale.policy.Trigger
com.softlayer.api.service.scale.policy.trigger.ResourceUse
@ApiType("SoftLayer_Scale_Policy_Trigger_ResourceUse") public class ResourceUse extends Trigger
A trigger that will only execute only when all guests on the group (both static and member) satisfy certain resource watches.
-
Nested Class Summary
Nested Classes Modifier and Type Class Description static classResourceUse.Maskstatic interfaceResourceUse.ServiceA trigger that will only execute only when all guests on the group (both static and member) satisfy certain resource watches.static interfaceResourceUse.ServiceAsync -
Field Summary
Fields Modifier and Type Field Description protected LongwatchCountA count of the resource watches for this trigger.protected List<Watch>watchesThe resource watches for this trigger.Fields inherited from class com.softlayer.api.service.scale.policy.Trigger
createDate, createDateSpecified, deleteFlag, deleteFlagSpecified, id, idSpecified, modifyDate, modifyDateSpecified, scalePolicy, scalePolicyId, scalePolicyIdSpecified, type, typeId, typeIdSpecified -
Constructor Summary
Constructors Constructor Description ResourceUse() -
Method Summary
Modifier and Type Method Description ResourceUse.ServiceasService(ApiClient client)LonggetWatchCount()List<Watch>getWatches()static ResourceUse.Serviceservice(ApiClient client)static ResourceUse.Serviceservice(ApiClient client, Long id)voidsetWatchCount(Long watchCount)Methods inherited from class com.softlayer.api.service.scale.policy.Trigger
getCreateDate, getDeleteFlag, getId, getModifyDate, getScalePolicy, getScalePolicyId, getType, getTypeId, isCreateDateSpecified, isDeleteFlagSpecified, isIdSpecified, isModifyDateSpecified, isScalePolicyIdSpecified, isTypeIdSpecified, setCreateDate, setDeleteFlag, setId, setModifyDate, setScalePolicy, setScalePolicyId, setType, setTypeId, unsetCreateDate, unsetDeleteFlag, unsetId, unsetModifyDate, unsetScalePolicyId, unsetTypeId
-
Field Details
-
watches
The resource watches for this trigger. -
watchCount
A count of the resource watches for this trigger.
-
-
Constructor Details
-
ResourceUse
public ResourceUse()
-
-
Method Details