Class Policy
java.lang.Object
com.softlayer.api.Type
com.softlayer.api.service.Entity
com.softlayer.api.service.scale.termination.Policy
@ApiType("SoftLayer_Scale_Termination_Policy") public class Policy extends Entity
A policy for automatic removal of members from a group. This policy determines which members are chosen first for removal. The values can be:
* OLDEST - The oldest member is the next one removed.
* NEWEST - The newest member is the next one removed.
* CLOSEST_TO_NEXT_CHARGE - The member closest to the next charge is removed. This is helpful for billing because it
will let you remove the member you have gotten the most out of. Note, this is usually closest to the next billing hour.
* OLDEST - The oldest member is the next one removed.
* NEWEST - The newest member is the next one removed.
* CLOSEST_TO_NEXT_CHARGE - The member closest to the next charge is removed. This is helpful for billing because it
will let you remove the member you have gotten the most out of. Note, this is usually closest to the next billing hour.
- See Also:
- SoftLayer_Scale_Termination_Policy
-
Nested Class Summary
Nested Classes Modifier and Type Class Description static classPolicy.Maskstatic interfacePolicy.ServiceA policy for automatic removal of members from a group.static interfacePolicy.ServiceAsync -
Field Summary
Fields Modifier and Type Field Description protected LongidA termination policy's internal identifier.protected booleanidSpecifiedprotected StringkeyNameA termination policy's programmatic name.protected booleankeyNameSpecifiedprotected StringnameA termination policy's human-friendly name.protected booleannameSpecified -
Constructor Summary
Constructors Constructor Description Policy() -
Method Summary
Modifier and Type Method Description Policy.ServiceasService(ApiClient client)LonggetId()StringgetKeyName()StringgetName()booleanisIdSpecified()booleanisKeyNameSpecified()booleanisNameSpecified()static Policy.Serviceservice(ApiClient client)static Policy.Serviceservice(ApiClient client, Long id)voidsetId(Long id)voidsetKeyName(String keyName)voidsetName(String name)voidunsetId()voidunsetKeyName()voidunsetName()
-
Field Details
-
id
A termination policy's internal identifier. -
idSpecified
protected boolean idSpecified -
keyName
A termination policy's programmatic name. -
keyNameSpecified
protected boolean keyNameSpecified -
name
A termination policy's human-friendly name. -
nameSpecified
protected boolean nameSpecified
-
-
Constructor Details
-
Policy
public Policy()
-
-
Method Details
-
getId
-
setId
-
isIdSpecified
public boolean isIdSpecified() -
unsetId
public void unsetId() -
getKeyName
-
setKeyName
-
isKeyNameSpecified
public boolean isKeyNameSpecified() -
unsetKeyName
public void unsetKeyName() -
getName
-
setName
-
isNameSpecified
public boolean isNameSpecified() -
unsetName
public void unsetName() -
asService
-
service
-
service
-