Interface Policy.Service
- All Superinterfaces:
Maskable,ResultLimitable,Service
- Enclosing class:
- Policy
@ApiService("SoftLayer_Scale_Termination_Policy") public static interface Policy.Service extends Service
A policy for automatic removal of members from a group. This policy determines which members are chosen first for removal. The values can be:
* OLDEST - The oldest member is the next one removed.
* NEWEST - The newest member is the next one removed.
* CLOSEST_TO_NEXT_CHARGE - The member closest to the next charge is removed. This is helpful for billing because it
will let you remove the member you have gotten the most out of. Note, this is usually closest to the next billing hour.
* OLDEST - The oldest member is the next one removed.
* NEWEST - The newest member is the next one removed.
* CLOSEST_TO_NEXT_CHARGE - The member closest to the next charge is removed. This is helpful for billing because it
will let you remove the member you have gotten the most out of. Note, this is usually closest to the next billing hour.
- See Also:
- SoftLayer_Scale_Termination_Policy
-
Method Summary
Modifier and Type Method Description Policy.ServiceAsyncasAsync()Get an async version of this serviceList<Policy>getAllObjects()PolicygetObject()voidsetMask(Policy.Mask mask)Policy.MaskwithMask()Use the existing mask on this service or create it if not presentPolicy.MaskwithNewMask()Overwrite the existing mask on this service with a new one and return itMethods inherited from interface com.softlayer.api.ResultLimitable
getLastResponseTotalItemCount, getResultLimit, setResultLimit
-
Method Details
-
asAsync
Policy.ServiceAsync asAsync()Description copied from interface:ServiceGet an async version of this service -
withNewMask
Policy.Mask withNewMask()Description copied from interface:MaskableOverwrite the existing mask on this service with a new one and return it- Specified by:
withNewMaskin interfaceMaskable
-
withMask
Policy.Mask withMask()Description copied from interface:MaskableUse the existing mask on this service or create it if not present -
setMask
-
getAllObjects
-
getObject
-