Interface Certificate.ServiceAsync
- All Superinterfaces:
Maskable,ResultLimitable,ServiceAsync
- Enclosing class:
- Certificate
public static interface Certificate.ServiceAsync extends ServiceAsync
-
Method Summary
Methods inherited from interface com.softlayer.api.ResultLimitable
getLastResponseTotalItemCount, getResultLimit, setResultLimit
-
Method Details
-
withNewMask
Certificate.Mask withNewMask()Description copied from interface:MaskableOverwrite the existing mask on this service with a new one and return it- Specified by:
withNewMaskin interfaceMaskable
-
withMask
Certificate.Mask withMask()Description copied from interface:MaskableUse the existing mask on this service or create it if not present -
setMask
-
createObject
-
createObject
-
deleteObject
Async version ofCertificate.Service.deleteObject() -
deleteObject
-
editObject
-
editObject
-
findByCommonName
Async version ofCertificate.Service.findByCommonName(java.lang.String) -
findByCommonName
-
getObject
Future<Certificate> getObject()Async version ofCertificate.Service.getObject() -
getObject
-
getPemFormat
Async version ofCertificate.Service.getPemFormat() -
getPemFormat
-
getAssociatedServiceCount
Async version ofCertificate.Service.getAssociatedServiceCount() -
getAssociatedServiceCount
Async callback version ofCertificate.Service.getAssociatedServiceCount() -
getLbaasListeners
Async version ofCertificate.Service.getLbaasListeners() -
getLbaasListeners
Async callback version ofCertificate.Service.getLbaasListeners() -
getLoadBalancerVirtualIpAddresses
Future<List<VirtualIpAddress>> getLoadBalancerVirtualIpAddresses()Async version ofCertificate.Service.getLoadBalancerVirtualIpAddresses() -
getLoadBalancerVirtualIpAddresses
Async callback version ofCertificate.Service.getLoadBalancerVirtualIpAddresses()
-