Class Entry
java.lang.Object
com.softlayer.api.Type
com.softlayer.api.service.Entity
com.softlayer.api.service.security.certificate.Entry
@ApiType("SoftLayer_Security_Certificate_Entry") public class Entry extends Entity
- See Also:
- SoftLayer_Security_Certificate_Entry
-
Nested Class Summary
Nested Classes Modifier and Type Class Description static classEntry.Mask -
Field Summary
Fields Modifier and Type Field Description protected LongcertificateIdThe ID of the certificate record.protected booleancertificateIdSpecifiedprotected StringcommonNameThe common name (usually a domain name) encoded within the certificate.protected booleancommonNameSpecifiedprotected LongkeySizeThe size (number of bits) of the public key represented by the certificate.protected booleankeySizeSpecifiedprotected StringorganizationNameThe organizational name encoded in the certificate.protected booleanorganizationNameSpecifiedprotected GregorianCalendarvalidityBeginThe UTC timestamp representing the beginning of the certificate's validityprotected booleanvalidityBeginSpecifiedprotected LongvalidityDaysThe number of days remaining in the validity period for the certificate.protected booleanvalidityDaysSpecifiedprotected GregorianCalendarvalidityEndThe UTC timestamp representing the end of the certificate's validity period.protected booleanvalidityEndSpecified -
Constructor Summary
Constructors Constructor Description Entry() -
Method Summary
Modifier and Type Method Description LonggetCertificateId()StringgetCommonName()LonggetKeySize()StringgetOrganizationName()GregorianCalendargetValidityBegin()LonggetValidityDays()GregorianCalendargetValidityEnd()booleanisCertificateIdSpecified()booleanisCommonNameSpecified()booleanisKeySizeSpecified()booleanisOrganizationNameSpecified()booleanisValidityBeginSpecified()booleanisValidityDaysSpecified()booleanisValidityEndSpecified()voidsetCertificateId(Long certificateId)voidsetCommonName(String commonName)voidsetKeySize(Long keySize)voidsetOrganizationName(String organizationName)voidsetValidityBegin(GregorianCalendar validityBegin)voidsetValidityDays(Long validityDays)voidsetValidityEnd(GregorianCalendar validityEnd)voidunsetCertificateId()voidunsetCommonName()voidunsetKeySize()voidunsetOrganizationName()voidunsetValidityBegin()voidunsetValidityDays()voidunsetValidityEnd()
-
Field Details
-
certificateId
The ID of the certificate record. -
certificateIdSpecified
protected boolean certificateIdSpecified -
commonName
The common name (usually a domain name) encoded within the certificate. -
commonNameSpecified
protected boolean commonNameSpecified -
keySize
The size (number of bits) of the public key represented by the certificate. -
keySizeSpecified
protected boolean keySizeSpecified -
organizationName
The organizational name encoded in the certificate. -
organizationNameSpecified
protected boolean organizationNameSpecified -
validityBegin
The UTC timestamp representing the beginning of the certificate's validity -
validityBeginSpecified
protected boolean validityBeginSpecified -
validityDays
The number of days remaining in the validity period for the certificate. -
validityDaysSpecified
protected boolean validityDaysSpecified -
validityEnd
The UTC timestamp representing the end of the certificate's validity period. -
validityEndSpecified
protected boolean validityEndSpecified
-
-
Constructor Details
-
Entry
public Entry()
-
-
Method Details
-
getCertificateId
-
setCertificateId
-
isCertificateIdSpecified
public boolean isCertificateIdSpecified() -
unsetCertificateId
public void unsetCertificateId() -
getCommonName
-
setCommonName
-
isCommonNameSpecified
public boolean isCommonNameSpecified() -
unsetCommonName
public void unsetCommonName() -
getKeySize
-
setKeySize
-
isKeySizeSpecified
public boolean isKeySizeSpecified() -
unsetKeySize
public void unsetKeySize() -
getOrganizationName
-
setOrganizationName
-
isOrganizationNameSpecified
public boolean isOrganizationNameSpecified() -
unsetOrganizationName
public void unsetOrganizationName() -
getValidityBegin
-
setValidityBegin
-
isValidityBeginSpecified
public boolean isValidityBeginSpecified() -
unsetValidityBegin
public void unsetValidityBegin() -
getValidityDays
-
setValidityDays
-
isValidityDaysSpecified
public boolean isValidityDaysSpecified() -
unsetValidityDays
public void unsetValidityDays() -
getValidityEnd
-
setValidityEnd
-
isValidityEndSpecified
public boolean isValidityEndSpecified() -
unsetValidityEnd
public void unsetValidityEnd()
-