Interface Status.Service
- All Superinterfaces:
Maskable,ResultLimitable,Service
- Enclosing class:
- Status
@ApiService("SoftLayer_Security_Certificate_Request_Status") public static interface Status.Service extends Service
SoftLayer_Security_Certificate_Request_Status indicates the status of your SSL certificate request. When you submit an SSL certificate order, the associated certificate request will be in the "Pending CA Approval" status. This is the only status in which can cancel your order.
Once the certificate authority (CA) approves your order, the status will change to "Approved". Once your order is approved, you will receive your fulfillment email from the CA. The email will contain your SSL certificate. SoftLayer does not store your SSL certificate in our system. If you lose the email from your CA, you can have the fulfillment email sent again via the SoftLayer customer portal or by using [[SoftLayer_Security_Certificate_Request/resendEmail|resendEmail]]. Your approved order will be picked up by SoftLayer's billing system and it will complete the payment process. Finally, your order will change to "Complete" status when the payment process is successful.
There might be a chance that your SSL certificate order could rejected by a CA. Our automated system will put a rejected order into "Canceled" status. You can contact SoftLayer Support for more details.
Once the certificate authority (CA) approves your order, the status will change to "Approved". Once your order is approved, you will receive your fulfillment email from the CA. The email will contain your SSL certificate. SoftLayer does not store your SSL certificate in our system. If you lose the email from your CA, you can have the fulfillment email sent again via the SoftLayer customer portal or by using [[SoftLayer_Security_Certificate_Request/resendEmail|resendEmail]]. Your approved order will be picked up by SoftLayer's billing system and it will complete the payment process. Finally, your order will change to "Complete" status when the payment process is successful.
There might be a chance that your SSL certificate order could rejected by a CA. Our automated system will put a rejected order into "Canceled" status. You can contact SoftLayer Support for more details.
-
Method Summary
Modifier and Type Method Description Status.ServiceAsyncasAsync()Get an async version of this serviceStatusgetObject()List<Status>getSslRequestStatuses()Returns all SSL certificate request status objectsvoidsetMask(Status.Mask mask)Status.MaskwithMask()Use the existing mask on this service or create it if not presentStatus.MaskwithNewMask()Overwrite the existing mask on this service with a new one and return itMethods inherited from interface com.softlayer.api.ResultLimitable
getLastResponseTotalItemCount, getResultLimit, setResultLimit
-
Method Details
-
asAsync
Status.ServiceAsync asAsync()Description copied from interface:ServiceGet an async version of this service -
withNewMask
Status.Mask withNewMask()Description copied from interface:MaskableOverwrite the existing mask on this service with a new one and return it- Specified by:
withNewMaskin interfaceMaskable
-
withMask
Status.Mask withMask()Description copied from interface:MaskableUse the existing mask on this service or create it if not present -
setMask
-
getObject
-
getSslRequestStatuses
Returns all SSL certificate request status objects
-