Class AccountLicense
java.lang.Object
com.softlayer.api.Type
com.softlayer.api.service.Entity
com.softlayer.api.service.software.AccountLicense
@ApiType("SoftLayer_Software_AccountLicense") public class AccountLicense extends Entity
SoftLayer_Software_AccountLicense is a class that represents software licenses that are tied only to a customer's account and not to any particular hardware, IP address, etc.
- See Also:
- SoftLayer_Software_AccountLicense
-
Nested Class Summary
Nested Classes Modifier and Type Class Description static classAccountLicense.Maskstatic interfaceAccountLicense.ServiceSoftLayer_Software_AccountLicense is the application class that handles a special type of Software License.static interfaceAccountLicense.ServiceAsync -
Field Summary
Fields Modifier and Type Field Description protected AccountaccountThe customer account this Account License belongs to.protected LongaccountIdThe ID of the SoftLayer Account to which this Account License belongs to.protected booleanaccountIdSpecifiedprotected ItembillingItemThe billing item for a software account license.protected StringcapacitySome Account Licenses have capacity information such as CPU specified in the units key.protected booleancapacitySpecifiedprotected StringkeyThe License Key for this specific Account License.protected booleankeySpecifiedprotected DescriptionsoftwareDescriptionThe SoftLayer_Software_Description that this account license is for.protected StringunitsThe unit of measurement that an account license has the capacity of.protected booleanunitsSpecified -
Constructor Summary
Constructors Constructor Description AccountLicense() -
Method Summary
Modifier and Type Method Description AccountgetAccount()LonggetAccountId()ItemgetBillingItem()StringgetCapacity()StringgetKey()DescriptiongetSoftwareDescription()StringgetUnits()booleanisAccountIdSpecified()booleanisCapacitySpecified()booleanisKeySpecified()booleanisUnitsSpecified()static AccountLicense.Serviceservice(ApiClient client)voidsetAccount(Account account)voidsetAccountId(Long accountId)voidsetBillingItem(Item billingItem)voidsetCapacity(String capacity)voidsetKey(String key)voidsetSoftwareDescription(Description softwareDescription)voidsetUnits(String units)voidunsetAccountId()voidunsetCapacity()voidunsetKey()voidunsetUnits()
-
Field Details
-
account
The customer account this Account License belongs to. -
billingItem
The billing item for a software account license. -
softwareDescription
The SoftLayer_Software_Description that this account license is for. -
accountId
The ID of the SoftLayer Account to which this Account License belongs to. -
accountIdSpecified
protected boolean accountIdSpecified -
capacity
Some Account Licenses have capacity information such as CPU specified in the units key. This provides the numerical representation of the capacity of the units. -
capacitySpecified
protected boolean capacitySpecified -
key
The License Key for this specific Account License. -
keySpecified
protected boolean keySpecified -
units
The unit of measurement that an account license has the capacity of. -
unitsSpecified
protected boolean unitsSpecified
-
-
Constructor Details
-
AccountLicense
public AccountLicense()
-
-
Method Details
-
getAccount
-
setAccount
-
getBillingItem
-
setBillingItem
-
getSoftwareDescription
-
setSoftwareDescription
-
getAccountId
-
setAccountId
-
isAccountIdSpecified
public boolean isAccountIdSpecified() -
unsetAccountId
public void unsetAccountId() -
getCapacity
-
setCapacity
-
isCapacitySpecified
public boolean isCapacitySpecified() -
unsetCapacity
public void unsetCapacity() -
getKey
-
setKey
-
isKeySpecified
public boolean isKeySpecified() -
unsetKey
public void unsetKey() -
getUnits
-
setUnits
-
isUnitsSpecified
public boolean isUnitsSpecified() -
unsetUnits
public void unsetUnits() -
service
-