Class License
java.lang.Object
com.softlayer.api.Type
com.softlayer.api.service.Entity
com.softlayer.api.service.software.License
@ApiType("SoftLayer_Software_License") public class License extends Entity
This class describes a specific type of license, like a Microsoft Windows Site License, a GPL license, or a license of another type.
- See Also:
- SoftLayer_Software_License
-
Nested Class Summary
Nested Classes Modifier and Type Class Description static classLicense.Mask -
Field Summary
Fields Modifier and Type Field Description protected AccountaccountThe account that owns this specific License instance.protected LongidAn ID number for this specific License type.protected booleanidSpecifiedprotected AccountownerThe account that owns this specific License instance.protected DescriptionsoftwareDescriptionA Description of the software that this license instance is valid for.protected LongsoftwareDescriptionIdThe ID number of a Software Description that this specific license is valid for.protected booleansoftwareDescriptionIdSpecified -
Constructor Summary
Constructors Constructor Description License() -
Method Summary
Modifier and Type Method Description AccountgetAccount()LonggetId()AccountgetOwner()DescriptiongetSoftwareDescription()LonggetSoftwareDescriptionId()booleanisIdSpecified()booleanisSoftwareDescriptionIdSpecified()voidsetAccount(Account account)voidsetId(Long id)voidsetOwner(Account owner)voidsetSoftwareDescription(Description softwareDescription)voidsetSoftwareDescriptionId(Long softwareDescriptionId)voidunsetId()voidunsetSoftwareDescriptionId()
-
Field Details
-
account
The account that owns this specific License instance. -
owner
The account that owns this specific License instance. -
softwareDescription
A Description of the software that this license instance is valid for. -
id
An ID number for this specific License type. -
idSpecified
protected boolean idSpecified -
softwareDescriptionId
The ID number of a Software Description that this specific license is valid for. -
softwareDescriptionIdSpecified
protected boolean softwareDescriptionIdSpecified
-
-
Constructor Details
-
License
public License()
-
-
Method Details
-
getAccount
-
setAccount
-
getOwner
-
setOwner
-
getSoftwareDescription
-
setSoftwareDescription
-
getId
-
setId
-
isIdSpecified
public boolean isIdSpecified() -
unsetId
public void unsetId() -
getSoftwareDescriptionId
-
setSoftwareDescriptionId
-
isSoftwareDescriptionIdSpecified
public boolean isSoftwareDescriptionIdSpecified() -
unsetSoftwareDescriptionId
public void unsetSoftwareDescriptionId()
-