Uses of Class
com.softlayer.api.service.software.Component
-
Uses of Component in com.softlayer.api.service
Fields in com.softlayer.api.service declared as Component Modifier and Type Field Description protected ComponentHardware. antivirusSpywareSoftwareComponentInformation regarding an antivirus/spyware software component object.protected ComponentHardware. continuousDataProtectionSoftwareComponentA continuous data protection/server backup software component object.protected ComponentHardware. hostIpsSoftwareComponentInformation regarding a host IPS software component object.protected ComponentHardware. virtualizationPlatformA piece of hardware's virtualization platform software.Fields in com.softlayer.api.service with type parameters of type Component Modifier and Type Field Description protected List<Component>Hardware. softwareComponentsInformation regarding a piece of hardware's installed software.Methods in com.softlayer.api.service that return Component Modifier and Type Method Description ComponentHardware. getAntivirusSpywareSoftwareComponent()ComponentHardware.Service. getAntivirusSpywareSoftwareComponent()Information regarding an antivirus/spyware software component object.ComponentHardware. getContinuousDataProtectionSoftwareComponent()ComponentHardware.Service. getContinuousDataProtectionSoftwareComponent()A continuous data protection/server backup software component object.ComponentHardware. getHostIpsSoftwareComponent()ComponentHardware.Service. getHostIpsSoftwareComponent()Information regarding a host IPS software component object.ComponentHardware. getVirtualizationPlatform()ComponentHardware.Service. getVirtualizationPlatform()A piece of hardware's virtualization platform software.Methods in com.softlayer.api.service with parameters of type Component Modifier and Type Method Description voidHardware. setAntivirusSpywareSoftwareComponent(Component antivirusSpywareSoftwareComponent)voidHardware. setContinuousDataProtectionSoftwareComponent(Component continuousDataProtectionSoftwareComponent)voidHardware. setHostIpsSoftwareComponent(Component hostIpsSoftwareComponent)voidHardware. setVirtualizationPlatform(Component virtualizationPlatform) -
Uses of Component in com.softlayer.api.service.billing.item.software
Fields in com.softlayer.api.service.billing.item.software declared as Component Modifier and Type Field Description protected ComponentComponent. resourceThe software component that this billing item points to.Methods in com.softlayer.api.service.billing.item.software that return Component Modifier and Type Method Description ComponentComponent. getResource()Methods in com.softlayer.api.service.billing.item.software with parameters of type Component Modifier and Type Method Description voidComponent. setResource(Component resource) -
Uses of Component in com.softlayer.api.service.billing.item.software.component.operatingsystem.addon.citrix
Fields in com.softlayer.api.service.billing.item.software.component.operatingsystem.addon.citrix declared as Component Modifier and Type Field Description protected ComponentEssentials. resourceThe Citrix Essentials software component that a billing item is associated with.Methods in com.softlayer.api.service.billing.item.software.component.operatingsystem.addon.citrix that return Component Modifier and Type Method Description ComponentEssentials. getResource()Methods in com.softlayer.api.service.billing.item.software.component.operatingsystem.addon.citrix with parameters of type Component Modifier and Type Method Description voidEssentials. setResource(Component resource) -
Uses of Component in com.softlayer.api.service.billing.item.software.component.virtual.operatingsystem
Fields in com.softlayer.api.service.billing.item.software.component.virtual.operatingsystem declared as Component Modifier and Type Field Description protected ComponentRedhat. resourceThe software component to which this billing item points.Methods in com.softlayer.api.service.billing.item.software.component.virtual.operatingsystem that return Component Modifier and Type Method Description ComponentRedhat. getResource()Methods in com.softlayer.api.service.billing.item.software.component.virtual.operatingsystem with parameters of type Component Modifier and Type Method Description voidRedhat. setResource(Component resource) -
Uses of Component in com.softlayer.api.service.container.hardware.server
Fields in com.softlayer.api.service.container.hardware.server with type parameters of type Component Modifier and Type Field Description protected List<Component>Details. softwareThe software that belong to a piece of hardware.Methods in com.softlayer.api.service.container.hardware.server that return types with arguments of type Component Modifier and Type Method Description List<Component>Details. getSoftware() -
Uses of Component in com.softlayer.api.service.network.storage.backup.evault
Fields in com.softlayer.api.service.network.storage.backup.evault declared as Component Modifier and Type Field Description protected ComponentVersion6. softwareComponentThe software component for the EVault base client.Methods in com.softlayer.api.service.network.storage.backup.evault that return Component Modifier and Type Method Description ComponentVersion6. getSoftwareComponent()Methods in com.softlayer.api.service.network.storage.backup.evault with parameters of type Component Modifier and Type Method Description voidVersion6. setSoftwareComponent(Component softwareComponent) -
Uses of Component in com.softlayer.api.service.software
Methods in com.softlayer.api.service.software that return Component Modifier and Type Method Description ComponentComponent.Service. getObject()getObject retrieves the SoftLayer_Software_Component object whose ID corresponds to the ID number of the init parameter passed to the SoftLayer_Software_Component service.Methods in com.softlayer.api.service.software that return types with arguments of type Component Modifier and Type Method Description Future<Component>Component.ServiceAsync. getObject()Async version ofComponent.Service.getObject()Method parameters in com.softlayer.api.service.software with type arguments of type Component Modifier and Type Method Description Future<?>Component.ServiceAsync. getObject(ResponseHandler<Component> callback) -
Uses of Component in com.softlayer.api.service.software.component
Subclasses of Component in com.softlayer.api.service.software.component Modifier and Type Class Description classAnalyticsThis object specifies a specific type of Software Component: An analytics instance.classAntivirusSpywareThis object specifies a specific type of Software Component: An Anti-virus/spyware instance.classControlPanelThis object specifies a specific type of Software Component: A control panel instance.classHostIpsThis object specifies a specific type of Software Component: A Host Intrusion Protection System instance.classOperatingSystemSoftLayer_Software_Component_OperatingSystem extends the [[SoftLayer_Software_Component]] data type to include operating system specific properties.classPackageThis object specifies a specific type of Software Component: A package instance.classSecurityThis object specifies a specific type of Software Component: A security instance.Fields in com.softlayer.api.service.software.component declared as Component Modifier and Type Field Description protected ComponentPassword. softwareThe SoftLayer_Software_Component instance that this username/password pair is valid for.Methods in com.softlayer.api.service.software.component that return Component Modifier and Type Method Description ComponentPassword. getSoftware()ComponentPassword.Service. getSoftware()The SoftLayer_Software_Component instance that this username/password pair is valid for.Methods in com.softlayer.api.service.software.component that return types with arguments of type Component Modifier and Type Method Description Future<Component>Password.ServiceAsync. getSoftware()Async version ofPassword.Service.getSoftware()Methods in com.softlayer.api.service.software.component with parameters of type Component Modifier and Type Method Description voidPassword. setSoftware(Component software)Method parameters in com.softlayer.api.service.software.component with type arguments of type Component Modifier and Type Method Description Future<?>Password.ServiceAsync. getSoftware(ResponseHandler<Component> callback)Async callback version ofPassword.Service.getSoftware() -
Uses of Component in com.softlayer.api.service.software.component.analytics
Subclasses of Component in com.softlayer.api.service.software.component.analytics Modifier and Type Class Description classUrchinThis object specifies a specific Software Component: An Urchin instance. -
Uses of Component in com.softlayer.api.service.software.component.antivirusspyware
Subclasses of Component in com.softlayer.api.service.software.component.antivirusspyware Modifier and Type Class Description classMcafeeThe SoftLayer_Software_Component_AntivirusSpyware_Mcafee represents a single anti-virus/spyware software component. -
Uses of Component in com.softlayer.api.service.software.component.antivirusspyware.mcafee.epo
Subclasses of Component in com.softlayer.api.service.software.component.antivirusspyware.mcafee.epo Modifier and Type Class Description classVersion36The SoftLayer_Software_Component_AntivirusSpyware_Mcafee_Epo_Version36 data type represents a single McAfee Secure anti-virus/spyware software component that uses the ePolicy Orchestrator version 3.6 backend.classVersion45The SoftLayer_Software_Component_AntivirusSpyware_Mcafee_Epo_Version45 data type represents a single McAfee Secure anti-virus/spyware software component that uses the ePolicy Orchestrator version 4.5 backend.classVersion51The SoftLayer_Software_Component_AntivirusSpyware_Mcafee_Epo_Version51 data type represents a single McAfee Secure anti-virus/spyware software component that contacts the McAfee ePO Server version 5.1 backend. -
Uses of Component in com.softlayer.api.service.software.component.controlpanel
Subclasses of Component in com.softlayer.api.service.software.component.controlpanel Modifier and Type Class Description classCpanelThis object specifies a specific Software Component: A cPanel instance.classIderaThis object specifies a specific type of control panel Software Component: An Idera instance.classMicrosoftThis object is a parent class for Microsoft Products, like Web MatrixclassParallelsThis object is a parent class for SWSoft Products, like PleskclassR1softThis object specifies a specific type of control panel Software Component: A R1soft instance.classSwsoftThis object is a parent class for SWSoft Products, like PleskclassWebhostAutomationThis object specifies a specific Software Component: A Helm instance produced by Webhost Automation. -
Uses of Component in com.softlayer.api.service.software.component.controlpanel.idera
Subclasses of Component in com.softlayer.api.service.software.component.controlpanel.idera Modifier and Type Class Description classServerBackupThis object specifies a specific type of Software Component: A Idera Server Backup instance. -
Uses of Component in com.softlayer.api.service.software.component.controlpanel.microsoft
Subclasses of Component in com.softlayer.api.service.software.component.controlpanel.microsoft Modifier and Type Class Description classWebPlatformThis object specifies a specific Software Component: A WebPlatform instance. -
Uses of Component in com.softlayer.api.service.software.component.controlpanel.parallels
Subclasses of Component in com.softlayer.api.service.software.component.controlpanel.parallels Modifier and Type Class Description classPleskThis object specifies a specific Software Component: A Plesk instance produced by SWSoft. -
Uses of Component in com.softlayer.api.service.software.component.controlpanel.r1soft
Subclasses of Component in com.softlayer.api.service.software.component.controlpanel.r1soft Modifier and Type Class Description classCdpThis object specifies a specific type of Software Component: A R1soft continuous data protection instance.classServerBackupThis object specifies a specific type of Software Component: A R1Soft Server Backup instance. -
Uses of Component in com.softlayer.api.service.software.component.hostips
Subclasses of Component in com.softlayer.api.service.software.component.hostips Modifier and Type Class Description classMcafeeThe SoftLayer_Software_Component_HostIps_Mcafee represents a single host IPS software component. -
Uses of Component in com.softlayer.api.service.software.component.hostips.mcafee.epo
Subclasses of Component in com.softlayer.api.service.software.component.hostips.mcafee.epo Modifier and Type Class Description classVersion51The SoftLayer_Software_Component_HostIps_Mcafee_Epo_Version51 data type represents a single McAfee Secure Host IPS software component that uses the ePO Server. -
Uses of Component in com.softlayer.api.service.software.component.hostips.mcafee.epo.version36
Subclasses of Component in com.softlayer.api.service.software.component.hostips.mcafee.epo.version36 Modifier and Type Class Description classHipsThe SoftLayer_Software_Component_HostIps_Mcafee_Epo_Version36_Hips data type represents a single McAfee Secure Host IPS software component that uses the ePolicy Orchestrator version 3.6 backend. -
Uses of Component in com.softlayer.api.service.software.component.hostips.mcafee.epo.version36.hips
Subclasses of Component in com.softlayer.api.service.software.component.hostips.mcafee.epo.version36.hips Modifier and Type Class Description classVersion6The SoftLayer_Software_Component_HostIps_Mcafee_Epo_Version36_Hips_Version6 data type represents a single McAfee Secure Host IPS software component for version 6 of the Host IPS client and uses the ePolicy Orchestrator version 3.6 backend.classVersion7The SoftLayer_Software_Component_HostIps_Mcafee_Epo_Version36_Hips_Version7 data type represents a single McAfee Secure Host IPS software component for version 7 of the Host IPS client and uses the ePolicy Orchestrator version 3.6 backend. -
Uses of Component in com.softlayer.api.service.software.component.hostips.mcafee.epo.version45
Subclasses of Component in com.softlayer.api.service.software.component.hostips.mcafee.epo.version45 Modifier and Type Class Description classHipsThe SoftLayer_Software_Component_HostIps_Mcafee_Epo_Version45_Hips data type represents a single McAfee Secure Host IPS software component that uses the ePolicy Orchestrator version 4.5 backend. -
Uses of Component in com.softlayer.api.service.software.component.hostips.mcafee.epo.version45.hips
Subclasses of Component in com.softlayer.api.service.software.component.hostips.mcafee.epo.version45.hips Modifier and Type Class Description classVersion7The SoftLayer_Software_Component_HostIps_Mcafee_Epo_Version45_Hips_Version7 data type represents a single McAfee Secure Host IPS software component for version 7 of the Host IPS client and uses the ePolicy Orchestrator version 4.5 backend.classVersion8The SoftLayer_Software_Component_HostIps_Mcafee_Epo_Version45_Hips_Version8 data type represents a single McAfee Secure Host IPS software component for version 8 of the Host IPS client and uses the ePolicy Orchestrator version 4.5 backend. -
Uses of Component in com.softlayer.api.service.software.component.password
Fields in com.softlayer.api.service.software.component.password declared as Component Modifier and Type Field Description protected ComponentHistory. softwareComponentAn installed and licensed instance of a piece of softwareMethods in com.softlayer.api.service.software.component.password that return Component Modifier and Type Method Description ComponentHistory. getSoftwareComponent()Methods in com.softlayer.api.service.software.component.password with parameters of type Component Modifier and Type Method Description voidHistory. setSoftwareComponent(Component softwareComponent) -
Uses of Component in com.softlayer.api.service.software.component.pkg
Subclasses of Component in com.softlayer.api.service.software.component.pkg Modifier and Type Class Description classManagementThis object specifies a specific type of Software Component: A package management instance. -
Uses of Component in com.softlayer.api.service.software.component.pkg.management
Subclasses of Component in com.softlayer.api.service.software.component.pkg.management Modifier and Type Class Description classKspliceThis object specifies a specific type of Software Component: A Ksplice instance. -
Uses of Component in com.softlayer.api.service.software.component.security
Subclasses of Component in com.softlayer.api.service.software.component.security Modifier and Type Class Description classSafeNetThis object specifies a specific Software Component: A SafeNet instance. -
Uses of Component in com.softlayer.api.service.virtual
Fields in com.softlayer.api.service.virtual declared as Component Modifier and Type Field Description protected ComponentGuest. antivirusSpywareSoftwareComponentA antivirus / spyware software component object.protected ComponentGuest. continuousDataProtectionSoftwareComponentA continuous data protection software component object.protected ComponentGuest. controlPanelA guest's control panel.protected ComponentGuest. hostIpsSoftwareComponentA host IPS software component object.Fields in com.softlayer.api.service.virtual with type parameters of type Component Modifier and Type Field Description protected List<Component>Guest. softwareComponentsA guest's installed software.Methods in com.softlayer.api.service.virtual that return Component Modifier and Type Method Description ComponentGuest. getAntivirusSpywareSoftwareComponent()ComponentGuest.Service. getAntivirusSpywareSoftwareComponent()A antivirus / spyware software component object.ComponentGuest. getContinuousDataProtectionSoftwareComponent()ComponentGuest.Service. getContinuousDataProtectionSoftwareComponent()A continuous data protection software component object.ComponentGuest. getControlPanel()ComponentGuest.Service. getControlPanel()A guest's control panel.ComponentGuest. getHostIpsSoftwareComponent()ComponentGuest.Service. getHostIpsSoftwareComponent()A host IPS software component object.Methods in com.softlayer.api.service.virtual that return types with arguments of type Component Modifier and Type Method Description Future<Component>Guest.ServiceAsync. getAntivirusSpywareSoftwareComponent()Async version ofGuest.Service.getAntivirusSpywareSoftwareComponent()Future<Component>Guest.ServiceAsync. getContinuousDataProtectionSoftwareComponent()Async version ofGuest.Service.getContinuousDataProtectionSoftwareComponent()Future<Component>Guest.ServiceAsync. getControlPanel()Async version ofGuest.Service.getControlPanel()Future<Component>Guest.ServiceAsync. getHostIpsSoftwareComponent()Async version ofGuest.Service.getHostIpsSoftwareComponent()List<Component>Guest. getSoftwareComponents()List<Component>Guest.Service. getSoftwareComponents()A guest's installed software.Future<List<Component>>Guest.ServiceAsync. getSoftwareComponents()Async version ofGuest.Service.getSoftwareComponents()Methods in com.softlayer.api.service.virtual with parameters of type Component Modifier and Type Method Description voidGuest. setAntivirusSpywareSoftwareComponent(Component antivirusSpywareSoftwareComponent)voidGuest. setContinuousDataProtectionSoftwareComponent(Component continuousDataProtectionSoftwareComponent)voidGuest. setControlPanel(Component controlPanel)voidGuest. setHostIpsSoftwareComponent(Component hostIpsSoftwareComponent)Method parameters in com.softlayer.api.service.virtual with type arguments of type Component Modifier and Type Method Description Future<?>Guest.ServiceAsync. getAntivirusSpywareSoftwareComponent(ResponseHandler<Component> callback)Async callback version ofGuest.Service.getAntivirusSpywareSoftwareComponent()Future<?>Guest.ServiceAsync. getContinuousDataProtectionSoftwareComponent(ResponseHandler<Component> callback)Async callback version ofGuest.Service.getContinuousDataProtectionSoftwareComponent()Future<?>Guest.ServiceAsync. getControlPanel(ResponseHandler<Component> callback)Async callback version ofGuest.Service.getControlPanel()Future<?>Guest.ServiceAsync. getHostIpsSoftwareComponent(ResponseHandler<Component> callback)Async callback version ofGuest.Service.getHostIpsSoftwareComponent()Future<?>Guest.ServiceAsync. getSoftwareComponents(ResponseHandler<List<Component>> callback)Async callback version ofGuest.Service.getSoftwareComponents()