Uses of Class
com.softlayer.api.service.software.VirtualLicense
-
Uses of VirtualLicense in com.softlayer.api.service
Fields in com.softlayer.api.service with type parameters of type VirtualLicense Modifier and Type Field Description protected List<VirtualLicense>Account. activeVirtualLicensesThe virtual software licenses controlled by an accountprotected List<VirtualLicense>Hardware. virtualLicensesInformation regarding a piece of hardware's virtual software licenses.Methods in com.softlayer.api.service that return types with arguments of type VirtualLicense Modifier and Type Method Description List<VirtualLicense>Account. getActiveVirtualLicenses()List<VirtualLicense>Account.Service. getActiveVirtualLicenses()The virtual software licenses controlled by an accountFuture<List<VirtualLicense>>Account.ServiceAsync. getActiveVirtualLicenses()Async version ofAccount.Service.getActiveVirtualLicenses()List<VirtualLicense>Hardware. getVirtualLicenses()List<VirtualLicense>Hardware.Service. getVirtualLicenses()Information regarding a piece of hardware's virtual software licenses.Future<List<VirtualLicense>>Hardware.ServiceAsync. getVirtualLicenses()Async version ofHardware.Service.getVirtualLicenses()Method parameters in com.softlayer.api.service with type arguments of type VirtualLicense Modifier and Type Method Description Future<?>Account.ServiceAsync. getActiveVirtualLicenses(ResponseHandler<List<VirtualLicense>> callback)Async callback version ofAccount.Service.getActiveVirtualLicenses()Future<?>Hardware.ServiceAsync. getVirtualLicenses(ResponseHandler<List<VirtualLicense>> callback)Async callback version ofHardware.Service.getVirtualLicenses() -
Uses of VirtualLicense in com.softlayer.api.service.billing.item.software.component.virtual.operatingsystem
Fields in com.softlayer.api.service.billing.item.software.component.virtual.operatingsystem declared as VirtualLicense Modifier and Type Field Description protected VirtualLicenseMicrosoft. resourceThe software virtual license to which this billing item points.Methods in com.softlayer.api.service.billing.item.software.component.virtual.operatingsystem that return VirtualLicense Modifier and Type Method Description VirtualLicenseMicrosoft. getResource()Methods in com.softlayer.api.service.billing.item.software.component.virtual.operatingsystem with parameters of type VirtualLicense Modifier and Type Method Description voidMicrosoft. setResource(VirtualLicense resource) -
Uses of VirtualLicense in com.softlayer.api.service.network.subnet
Fields in com.softlayer.api.service.network.subnet with type parameters of type VirtualLicense Modifier and Type Field Description protected List<VirtualLicense>IpAddress. virtualLicensesVirtual licenses allocated for an IP Address.Methods in com.softlayer.api.service.network.subnet that return types with arguments of type VirtualLicense Modifier and Type Method Description List<VirtualLicense>IpAddress. getVirtualLicenses()List<VirtualLicense>IpAddress.Service. getVirtualLicenses()Virtual licenses allocated for an IP Address.Future<List<VirtualLicense>>IpAddress.ServiceAsync. getVirtualLicenses()Async version ofIpAddress.Service.getVirtualLicenses()Method parameters in com.softlayer.api.service.network.subnet with type arguments of type VirtualLicense Modifier and Type Method Description Future<?>IpAddress.ServiceAsync. getVirtualLicenses(ResponseHandler<List<VirtualLicense>> callback)Async callback version ofIpAddress.Service.getVirtualLicenses() -
Uses of VirtualLicense in com.softlayer.api.service.software
Methods in com.softlayer.api.service.software that return VirtualLicense Modifier and Type Method Description VirtualLicenseVirtualLicense.Service. getObject()getObject retrieves the SoftLayer_Software_VirtualLicense object whose ID number corresponds to the ID number of the init parameter passed to the SoftLayer_Software_VirtualLicense service.Methods in com.softlayer.api.service.software that return types with arguments of type VirtualLicense Modifier and Type Method Description Future<VirtualLicense>VirtualLicense.ServiceAsync. getObject()Async version ofVirtualLicense.Service.getObject()Method parameters in com.softlayer.api.service.software with type arguments of type VirtualLicense Modifier and Type Method Description Future<?>VirtualLicense.ServiceAsync. getObject(ResponseHandler<VirtualLicense> callback)