-
-
Class Summary
| Class |
Description |
| Analytics |
This object specifies a specific type of Software Component: An analytics instance.
|
| Analytics.Mask |
|
| AntivirusSpyware |
This object specifies a specific type of Software Component: An Anti-virus/spyware instance.
|
| AntivirusSpyware.Mask |
|
| ControlPanel |
This object specifies a specific type of Software Component: A control panel instance.
|
| ControlPanel.Mask |
|
| HostIps |
This object specifies a specific type of Software Component: A Host Intrusion Protection System instance.
|
| HostIps.Mask |
|
| OperatingSystem |
SoftLayer_Software_Component_OperatingSystem extends the [[SoftLayer_Software_Component]] data type to include operating system specific properties.
|
| OperatingSystem.Mask |
|
| Package |
This object specifies a specific type of Software Component: A package instance.
|
| Package.Mask |
|
| Password |
This SoftLayer_Software_Component_Password data type contains a password for a specific software component instance.
|
| Password.Mask |
|
| Security |
This object specifies a specific type of Software Component: A security instance.
|
| Security.Mask |
|