Uses of Class
com.softlayer.api.service.software.description.Feature
| Package | Description |
|---|---|
| com.softlayer.api.service.software |
-
Uses of Feature in com.softlayer.api.service.software
Fields in com.softlayer.api.service.software with type parameters of type Feature Modifier and Type Field Description protected List<Feature>Description. featuresThe feature attributes of a software description.Methods in com.softlayer.api.service.software that return types with arguments of type Feature Modifier and Type Method Description List<Feature>Description. getFeatures()List<Feature>Description.Service. getFeatures()The feature attributes of a software description.Future<List<Feature>>Description.ServiceAsync. getFeatures()Async version ofDescription.Service.getFeatures()Method parameters in com.softlayer.api.service.software with type arguments of type Feature Modifier and Type Method Description Future<?>Description.ServiceAsync. getFeatures(ResponseHandler<List<Feature>> callback)Async callback version ofDescription.Service.getFeatures()