Package com.softlayer.api.service.user
Class Employee
java.lang.Object
com.softlayer.api.Type
com.softlayer.api.service.Entity
com.softlayer.api.service.user.Interface
com.softlayer.api.service.user.Employee
@ApiType("SoftLayer_User_Employee") public class Employee extends Interface
A SoftLayer_User_Employee models a single SoftLayer employee for the purposes of ticket updates created by SoftLayer employees. SoftLayer portal and API users cannot see individual employee names in ticket responses. SoftLayer employees can be assigned to customer accounts as a personal support representative. Employee names and email will be available if an employee is assigned to the account.
- See Also:
- SoftLayer_User_Employee
-
Nested Class Summary
Nested Classes Modifier and Type Class Description static classEmployee.Mask -
Field Summary
Fields Modifier and Type Field Description protected List<Chat>chatTranscriptprotected LongchatTranscriptCountA count ofprotected StringdisplayNameprotected booleandisplayNameSpecifiedprotected StringemailA SoftLayer employee's email address.protected booleanemailSpecifiedprotected DepartmentemployeeDepartmentThe department that a SoftLayer employee belongs to.protected LongemployeeDepartmentIdA SoftLayer employee's [[SoftLayer_User_Employee_Department|department]] id.protected booleanemployeeDepartmentIdSpecifiedprotected StringfirstNameA SoftLayer employee's first name.protected booleanfirstNameSpecifiedprotected StringlastNameA SoftLayer employee's last name.protected booleanlastNameSpecifiedprotected LonglayoutProfileCountA count ofprotected List<Profile>layoutProfilesprotected ObjectmetricTrackingObjectprotected StringofficePhoneprotected booleanofficePhoneSpecifiedprotected LongsecurityLevelCountA count ofprotected List<Level>securityLevelsprotected List<Activity>ticketActivitiesprotected LongticketActivityCountA count ofprotected LongticketAttachmentReferenceCountA count ofprotected List<Attachment>ticketAttachmentReferencesprotected StringusernameA representation of a SoftLayer employee's username.protected booleanusernameSpecified -
Constructor Summary
Constructors Constructor Description Employee() -
Method Summary
-
Field Details
-
chatTranscript
-
employeeDepartment
The department that a SoftLayer employee belongs to. -
layoutProfiles
-
metricTrackingObject
-
securityLevels
-
ticketActivities
-
ticketAttachmentReferences
-
displayName
-
displayNameSpecified
protected boolean displayNameSpecified -
email
A SoftLayer employee's email address. Email addresses are only visible to [[SoftLayer_Account|SoftLayer Accounts]] that are assigned to an employee -
emailSpecified
protected boolean emailSpecified -
employeeDepartmentId
A SoftLayer employee's [[SoftLayer_User_Employee_Department|department]] id. -
employeeDepartmentIdSpecified
protected boolean employeeDepartmentIdSpecified -
firstName
A SoftLayer employee's first name. First names are only visible to [[SoftLayer_Account|SoftLayer Accounts]] that are assigned to an employee -
firstNameSpecified
protected boolean firstNameSpecified -
lastName
A SoftLayer employee's last name. Last names are only visible to [[SoftLayer_Account|SoftLayer Accounts]] that are assigned to an employee -
lastNameSpecified
protected boolean lastNameSpecified -
officePhone
-
officePhoneSpecified
protected boolean officePhoneSpecified -
username
A representation of a SoftLayer employee's username. In all cases this should simply state "Employee". -
usernameSpecified
protected boolean usernameSpecified -
chatTranscriptCount
A count of -
layoutProfileCount
A count of -
securityLevelCount
A count of -
ticketActivityCount
A count of -
ticketAttachmentReferenceCount
A count of
-
-
Constructor Details
-
Employee
public Employee()
-
-
Method Details
-
getChatTranscript
-
getEmployeeDepartment
-
setEmployeeDepartment
-
getLayoutProfiles
-
getMetricTrackingObject
-
setMetricTrackingObject
-
getSecurityLevels
-
getTicketActivities
-
getTicketAttachmentReferences
-
getDisplayName
-
setDisplayName
-
isDisplayNameSpecified
public boolean isDisplayNameSpecified() -
unsetDisplayName
public void unsetDisplayName() -
getEmail
-
setEmail
-
isEmailSpecified
public boolean isEmailSpecified() -
unsetEmail
public void unsetEmail() -
getEmployeeDepartmentId
-
setEmployeeDepartmentId
-
isEmployeeDepartmentIdSpecified
public boolean isEmployeeDepartmentIdSpecified() -
unsetEmployeeDepartmentId
public void unsetEmployeeDepartmentId() -
getFirstName
-
setFirstName
-
isFirstNameSpecified
public boolean isFirstNameSpecified() -
unsetFirstName
public void unsetFirstName() -
getLastName
-
setLastName
-
isLastNameSpecified
public boolean isLastNameSpecified() -
unsetLastName
public void unsetLastName() -
getOfficePhone
-
setOfficePhone
-
isOfficePhoneSpecified
public boolean isOfficePhoneSpecified() -
unsetOfficePhone
public void unsetOfficePhone() -
getUsername
-
setUsername
-
isUsernameSpecified
public boolean isUsernameSpecified() -
unsetUsername
public void unsetUsername() -
getChatTranscriptCount
-
setChatTranscriptCount
-
getLayoutProfileCount
-
setLayoutProfileCount
-
getSecurityLevelCount
-
setSecurityLevelCount
-
getTicketActivityCount
-
setTicketActivityCount
-
getTicketAttachmentReferenceCount
-
setTicketAttachmentReferenceCount
-