Package com.softlayer.api.service.user
Class Preference
java.lang.Object
com.softlayer.api.Type
com.softlayer.api.service.Entity
com.softlayer.api.service.user.Preference
@ApiType("SoftLayer_User_Preference") public class Preference extends Entity
The SoftLayer_User_Preference data type contains a single user preference to a specific preference type.
- See Also:
- SoftLayer_User_Preference
-
Nested Class Summary
Nested Classes Modifier and Type Class Description static classPreference.Mask -
Field Summary
Fields Modifier and Type Field Description protected StringdescriptionDescription of the user preferenceprotected TypetypeType of user preferenceprotected StringvalueThe users current preference valueprotected booleanvalueSpecified -
Constructor Summary
Constructors Constructor Description Preference() -
Method Summary
Modifier and Type Method Description StringgetDescription()TypegetType()StringgetValue()booleanisValueSpecified()voidsetDescription(String description)voidsetType(Type type)voidsetValue(String value)voidunsetValue()
-
Field Details
-
description
Description of the user preference -
type
Type of user preference -
value
The users current preference value -
valueSpecified
protected boolean valueSpecified
-
-
Constructor Details
-
Preference
public Preference()
-
-
Method Details
-
getDescription
-
setDescription
-
getType
-
setType
-
getValue
-
setValue
-
isValueSpecified
public boolean isValueSpecified() -
unsetValue
public void unsetValue()
-