Interface ApiAuthentication.ServiceAsync
- All Superinterfaces:
Maskable,ResultLimitable,ServiceAsync
- Enclosing class:
- ApiAuthentication
public static interface ApiAuthentication.ServiceAsync extends ServiceAsync
-
Method Summary
Modifier and Type Method Description Future<ApiAuthentication>editObject(ApiAuthentication templateObject)Future<?>editObject(ApiAuthentication templateObject, ResponseHandler<ApiAuthentication> callback)Future<ApiAuthentication>getObject()Async version ofApiAuthentication.Service.getObject()Future<?>getObject(ResponseHandler<ApiAuthentication> callback)Future<Customer>getUser()Async version ofApiAuthentication.Service.getUser()Future<?>getUser(ResponseHandler<Customer> callback)Async callback version ofApiAuthentication.Service.getUser()voidsetMask(ApiAuthentication.Mask mask)ApiAuthentication.MaskwithMask()Use the existing mask on this service or create it if not presentApiAuthentication.MaskwithNewMask()Overwrite the existing mask on this service with a new one and return itMethods inherited from interface com.softlayer.api.ResultLimitable
getLastResponseTotalItemCount, getResultLimit, setResultLimit
-
Method Details
-
withNewMask
ApiAuthentication.Mask withNewMask()Description copied from interface:MaskableOverwrite the existing mask on this service with a new one and return it- Specified by:
withNewMaskin interfaceMaskable
-
withMask
ApiAuthentication.Mask withMask()Description copied from interface:MaskableUse the existing mask on this service or create it if not present -
setMask
-
editObject
-
editObject
Future<?> editObject(ApiAuthentication templateObject, ResponseHandler<ApiAuthentication> callback) -
getObject
Future<ApiAuthentication> getObject()Async version ofApiAuthentication.Service.getObject() -
getObject
-
getUser
Async version ofApiAuthentication.Service.getUser() -
getUser
Async callback version ofApiAuthentication.Service.getUser()
-