Interface MobileDevice.ServiceAsync
- All Superinterfaces:
Maskable,ResultLimitable,ServiceAsync
- Enclosing class:
- MobileDevice
public static interface MobileDevice.ServiceAsync extends ServiceAsync
-
Method Summary
Methods inherited from interface com.softlayer.api.ResultLimitable
getLastResponseTotalItemCount, getResultLimit, setResultLimit
-
Method Details
-
withNewMask
MobileDevice.Mask withNewMask()Description copied from interface:MaskableOverwrite the existing mask on this service with a new one and return it- Specified by:
withNewMaskin interfaceMaskable
-
withMask
MobileDevice.Mask withMask()Description copied from interface:MaskableUse the existing mask on this service or create it if not present -
setMask
-
createObject
-
createObject
-
deleteObject
Async version ofMobileDevice.Service.deleteObject() -
deleteObject
-
editObject
-
editObject
-
getObject
Future<MobileDevice> getObject()Async version ofMobileDevice.Service.getObject() -
getObject
-
getAvailablePushNotificationSubscriptions
Future<List<Notification>> getAvailablePushNotificationSubscriptions()Async version ofMobileDevice.Service.getAvailablePushNotificationSubscriptions() -
getAvailablePushNotificationSubscriptions
Async callback version ofMobileDevice.Service.getAvailablePushNotificationSubscriptions() -
getCustomer
Async version ofMobileDevice.Service.getCustomer() -
getCustomer
Async callback version ofMobileDevice.Service.getCustomer() -
getOperatingSystem
Future<OperatingSystem> getOperatingSystem()Async version ofMobileDevice.Service.getOperatingSystem() -
getOperatingSystem
Async callback version ofMobileDevice.Service.getOperatingSystem() -
getPushNotificationSubscriptions
Future<List<Subscriber>> getPushNotificationSubscriptions()Async version ofMobileDevice.Service.getPushNotificationSubscriptions() -
getPushNotificationSubscriptions
Async callback version ofMobileDevice.Service.getPushNotificationSubscriptions() -
getType
Async version ofMobileDevice.Service.getType() -
getType
Async callback version ofMobileDevice.Service.getType()
-