Interface OpenIdConnect.ServiceAsync
- All Superinterfaces:
Customer.ServiceAsync,Maskable,ResultLimitable,ServiceAsync
- Enclosing class:
- OpenIdConnect
public static interface OpenIdConnect.ServiceAsync extends Customer.ServiceAsync
-
Method Summary
Methods inherited from interface com.softlayer.api.service.user.Customer.ServiceAsync
acknowledgeSupportPolicy, acknowledgeSupportPolicy, addApiAuthenticationKey, addApiAuthenticationKey, addBulkDedicatedHostAccess, addBulkDedicatedHostAccess, addBulkHardwareAccess, addBulkHardwareAccess, addBulkPortalPermission, addBulkPortalPermission, addBulkRoles, addBulkRoles, addBulkVirtualGuestAccess, addBulkVirtualGuestAccess, addDedicatedHostAccess, addDedicatedHostAccess, addExternalBinding, addExternalBinding, addHardwareAccess, addHardwareAccess, addNotificationSubscriber, addNotificationSubscriber, addPortalPermission, addPortalPermission, addRole, addRole, addVirtualGuestAccess, addVirtualGuestAccess, assignNewParentId, assignNewParentId, changePreference, changePreference, checkExternalAuthenticationStatus, checkExternalAuthenticationStatus, createNotificationSubscriber, createNotificationSubscriber, createObject, createObject, createSubscriberDeliveryMethods, createSubscriberDeliveryMethods, deactivateNotificationSubscriber, deactivateNotificationSubscriber, editObject, editObject, editObjects, editObjects, findUserPreference, findUserPreference, getAccount, getAccount, getActions, getActions, getActiveExternalAuthenticationVendors, getActiveExternalAuthenticationVendors, getAdditionalEmails, getAdditionalEmails, getAgentImpersonationToken, getAgentImpersonationToken, getAllowedDedicatedHostIds, getAllowedDedicatedHostIds, getAllowedHardwareIds, getAllowedHardwareIds, getAllowedVirtualGuestIds, getAllowedVirtualGuestIds, getApiAuthenticationKeys, getApiAuthenticationKeys, getAuthenticationToken, getAuthenticationToken, getChildUsers, getChildUsers, getClosedTickets, getClosedTickets, getDedicatedHosts, getDedicatedHosts, getExternalBindings, getExternalBindings, getHardware, getHardware, getHardwareCount, getHardwareCount, getHardwareNotifications, getHardwareNotifications, getHasAcknowledgedSupportPolicyFlag, getHasAcknowledgedSupportPolicyFlag, getHasFullDedicatedHostAccessFlag, getHasFullDedicatedHostAccessFlag, getHasFullHardwareAccessFlag, getHasFullHardwareAccessFlag, getHasFullVirtualGuestAccessFlag, getHasFullVirtualGuestAccessFlag, getIbmIdLink, getIbmIdLink, getImpersonationToken, getImpersonationToken, getLayoutProfiles, getLayoutProfiles, getLocale, getLocale, getLoginAttempts, getLoginAttempts, getLoginToken, getLoginToken, getMobileDevices, getMobileDevices, getNotificationSubscribers, getNotificationSubscribers, getObject, getObject, getOpenIdConnectMigrationState, getOpenIdConnectMigrationState, getOpenTickets, getOpenTickets, getOverrides, getOverrides, getParent, getParent, getPasswordRequirements, getPasswordRequirements, getPermissions, getPermissions, getPortalLoginToken, getPortalLoginToken, getPreference, getPreference, getPreferences, getPreferences, getPreferenceTypes, getPreferenceTypes, getRequirementsForPasswordSet, getRequirementsForPasswordSet, getRoles, getRoles, getSalesforceUserLink, getSalesforceUserLink, getSecurityAnswers, getSecurityAnswers, getSubscribers, getSubscribers, getSuccessfulLogins, getSuccessfulLogins, getSupportedLocales, getSupportedLocales, getSupportPolicyAcknowledgementRequiredFlag, getSupportPolicyAcknowledgementRequiredFlag, getSupportPolicyDocument, getSupportPolicyDocument, getSupportPolicyName, getSupportPolicyName, getSurveyRequiredFlag, getSurveyRequiredFlag, getSurveys, getSurveys, getTickets, getTickets, getTimezone, getTimezone, getUnsuccessfulLogins, getUnsuccessfulLogins, getUserLinks, getUserLinks, getUserPreferences, getUserPreferences, getUserStatus, getUserStatus, getVirtualGuestCount, getVirtualGuestCount, getVirtualGuests, getVirtualGuests, initiateExternalAuthentication, initiateExternalAuthentication, inTerminalStatus, inTerminalStatus, inviteUserToLinkOpenIdConnect, inviteUserToLinkOpenIdConnect, isMasterUser, isMasterUser, performExternalAuthentication, performExternalAuthentication, removeAllDedicatedHostAccessForThisUser, removeAllDedicatedHostAccessForThisUser, removeAllHardwareAccessForThisUser, removeAllHardwareAccessForThisUser, removeAllVirtualAccessForThisUser, removeAllVirtualAccessForThisUser, removeApiAuthenticationKey, removeApiAuthenticationKey, removeBulkDedicatedHostAccess, removeBulkDedicatedHostAccess, removeBulkHardwareAccess, removeBulkHardwareAccess, removeBulkPortalPermission, removeBulkPortalPermission, removeBulkRoles, removeBulkRoles, removeBulkVirtualGuestAccess, removeBulkVirtualGuestAccess, removeDedicatedHostAccess, removeDedicatedHostAccess, removeExternalBinding, removeExternalBinding, removeHardwareAccess, removeHardwareAccess, removePortalPermission, removePortalPermission, removeRole, removeRole, removeSecurityAnswers, removeSecurityAnswers, removeVirtualGuestAccess, removeVirtualGuestAccess, samlAuthenticate, samlAuthenticate, samlBeginAuthentication, samlBeginAuthentication, samlBeginLogout, samlBeginLogout, samlLogout, samlLogout, setMask, silentlyMigrateUserOpenIdConnect, silentlyMigrateUserOpenIdConnect, updateNotificationSubscriber, updateNotificationSubscriber, updateSecurityAnswers, updateSecurityAnswers, updateSubscriberDeliveryMethod, updateSubscriberDeliveryMethod, updateVpnPassword, updateVpnPassword, updateVpnUser, updateVpnUser, validateAuthenticationToken, validateAuthenticationTokenMethods inherited from interface com.softlayer.api.ResultLimitable
getLastResponseTotalItemCount, getResultLimit, setResultLimit
-
Method Details
-
withNewMask
OpenIdConnect.Mask withNewMask()Description copied from interface:MaskableOverwrite the existing mask on this service with a new one and return it- Specified by:
withNewMaskin interfaceCustomer.ServiceAsync- Specified by:
withNewMaskin interfaceMaskable
-
withMask
OpenIdConnect.Mask withMask()Description copied from interface:MaskableUse the existing mask on this service or create it if not present- Specified by:
withMaskin interfaceCustomer.ServiceAsync- Specified by:
withMaskin interfaceMaskable
-
setMask
-
activateOpenIdConnectUser
-
activateOpenIdConnectUser
-
checkPhoneFactorAuthenticationForPasswordSet
Future<Boolean> checkPhoneFactorAuthenticationForPasswordSet(PasswordSet passwordSet, Binding authenticationContainer)- Specified by:
checkPhoneFactorAuthenticationForPasswordSetin interfaceCustomer.ServiceAsync
-
checkPhoneFactorAuthenticationForPasswordSet
Future<?> checkPhoneFactorAuthenticationForPasswordSet(PasswordSet passwordSet, Binding authenticationContainer, ResponseHandler<Boolean> callback)- Specified by:
checkPhoneFactorAuthenticationForPasswordSetin interfaceCustomer.ServiceAsync
-
completeInvitationAfterLogin
-
completeInvitationAfterLogin
-
createObject
Future<OpenIdConnect> createObject(OpenIdConnect templateObject, String password, String vpnPassword) -
createObject
Future<?> createObject(OpenIdConnect templateObject, String password, String vpnPassword, ResponseHandler<OpenIdConnect> callback) -
createOpenIdConnectUserAndCompleteInvitation
-
createOpenIdConnectUserAndCompleteInvitation
-
declineInvitation
-
declineInvitation
Future<?> declineInvitation(String providerType, String registrationCode, ResponseHandler<Void> callback) -
getDefaultAccount
Async version ofOpenIdConnect.Service.getDefaultAccount(java.lang.String)- Specified by:
getDefaultAccountin interfaceCustomer.ServiceAsync
-
getDefaultAccount
- Specified by:
getDefaultAccountin interfaceCustomer.ServiceAsync
-
getLoginAccountInfoOpenIdConnect
-
getLoginAccountInfoOpenIdConnect
Future<?> getLoginAccountInfoOpenIdConnect(String providerType, String accessToken, ResponseHandler<LoginAccountInfo> callback) -
getMappedAccounts
Async version ofOpenIdConnect.Service.getMappedAccounts(java.lang.String)- Specified by:
getMappedAccountsin interfaceCustomer.ServiceAsync
-
getMappedAccounts
- Specified by:
getMappedAccountsin interfaceCustomer.ServiceAsync
-
getObjectForOpenIdConnect
Future<OpenIdConnect> getObjectForOpenIdConnect()Async version ofOpenIdConnect.Service.getObjectForOpenIdConnect() -
getObjectForOpenIdConnect
-
getOpenIdRegistrationInfoFromCode
Future<RegistrationInformation> getOpenIdRegistrationInfoFromCode(String providerType, String registrationCode) -
getOpenIdRegistrationInfoFromCode
Future<?> getOpenIdRegistrationInfoFromCode(String providerType, String registrationCode, ResponseHandler<RegistrationInformation> callback) -
getPortalLoginTokenOpenIdConnect
-
getPortalLoginTokenOpenIdConnect
-
getRequirementsForPasswordSetForOpenIdConnect
-
getRequirementsForPasswordSetForOpenIdConnect
Future<?> getRequirementsForPasswordSetForOpenIdConnect(PasswordSet passwordSet, ResponseHandler<PasswordSet> callback) -
getUserForUnifiedInvitation
Future<OpenIdConnect> getUserForUnifiedInvitation(String openIdConnectUserId, String uniqueIdentifier, String searchInvitationsNotLinksFlag) -
getUserForUnifiedInvitation
Future<?> getUserForUnifiedInvitation(String openIdConnectUserId, String uniqueIdentifier, String searchInvitationsNotLinksFlag, ResponseHandler<OpenIdConnect> callback) -
getUserIdForPasswordSet
Async version ofOpenIdConnect.Service.getUserIdForPasswordSet(java.lang.String)- Specified by:
getUserIdForPasswordSetin interfaceCustomer.ServiceAsync
-
getUserIdForPasswordSet
- Specified by:
getUserIdForPasswordSetin interfaceCustomer.ServiceAsync
-
initiatePortalPasswordChange
Async version ofOpenIdConnect.Service.initiatePortalPasswordChange(java.lang.String)- Specified by:
initiatePortalPasswordChangein interfaceCustomer.ServiceAsync
-
initiatePortalPasswordChange
- Specified by:
initiatePortalPasswordChangein interfaceCustomer.ServiceAsync
-
initiatePortalPasswordChangeByBrandAgent
- Specified by:
initiatePortalPasswordChangeByBrandAgentin interfaceCustomer.ServiceAsync
-
initiatePortalPasswordChangeByBrandAgent
Future<?> initiatePortalPasswordChangeByBrandAgent(String username, ResponseHandler<Boolean> callback)- Specified by:
initiatePortalPasswordChangeByBrandAgentin interfaceCustomer.ServiceAsync
-
isValidPortalPassword
Async version ofOpenIdConnect.Service.isValidPortalPassword(java.lang.String)- Specified by:
isValidPortalPasswordin interfaceCustomer.ServiceAsync
-
isValidPortalPassword
- Specified by:
isValidPortalPasswordin interfaceCustomer.ServiceAsync
-
processPasswordSetRequest
Future<Boolean> processPasswordSetRequest(PasswordSet passwordSet, Binding authenticationContainer)- Specified by:
processPasswordSetRequestin interfaceCustomer.ServiceAsync
-
processPasswordSetRequest
Future<?> processPasswordSetRequest(PasswordSet passwordSet, Binding authenticationContainer, ResponseHandler<Boolean> callback)- Specified by:
processPasswordSetRequestin interfaceCustomer.ServiceAsync
-
selfPasswordChange
- Specified by:
selfPasswordChangein interfaceCustomer.ServiceAsync
-
selfPasswordChange
Future<?> selfPasswordChange(String currentPassword, String newPassword, ResponseHandler<Void> callback)- Specified by:
selfPasswordChangein interfaceCustomer.ServiceAsync
-
setDefaultAccount
- Specified by:
setDefaultAccountin interfaceCustomer.ServiceAsync
-
setDefaultAccount
Future<?> setDefaultAccount(String providerType, Long accountId, ResponseHandler<Account> callback)- Specified by:
setDefaultAccountin interfaceCustomer.ServiceAsync
-