Interface OperatingSystem.Service
- All Superinterfaces:
Maskable,ResultLimitable,Service
- Enclosing class:
- OperatingSystem
@ApiService("SoftLayer_User_Customer_MobileDevice_OperatingSystem") public static interface OperatingSystem.Service extends Service
-
Method Summary
Modifier and Type Method Description OperatingSystem.ServiceAsyncasAsync()Get an async version of this serviceList<OperatingSystem>getAllObjects()OperatingSystemgetObject()voidsetMask(OperatingSystem.Mask mask)OperatingSystem.MaskwithMask()Use the existing mask on this service or create it if not presentOperatingSystem.MaskwithNewMask()Overwrite the existing mask on this service with a new one and return itMethods inherited from interface com.softlayer.api.ResultLimitable
getLastResponseTotalItemCount, getResultLimit, setResultLimit
-
Method Details
-
asAsync
OperatingSystem.ServiceAsync asAsync()Description copied from interface:ServiceGet an async version of this service -
withNewMask
OperatingSystem.Mask withNewMask()Description copied from interface:MaskableOverwrite the existing mask on this service with a new one and return it- Specified by:
withNewMaskin interfaceMaskable
-
withMask
OperatingSystem.Mask withMask()Description copied from interface:MaskableUse the existing mask on this service or create it if not present -
setMask
-
getAllObjects
-
getObject
-