Interface OperatingSystem.ServiceAsync
- All Superinterfaces:
Maskable,ResultLimitable,ServiceAsync
- Enclosing class:
- OperatingSystem
public static interface OperatingSystem.ServiceAsync extends ServiceAsync
-
Method Summary
Modifier and Type Method Description Future<List<OperatingSystem>>getAllObjects()Async version ofOperatingSystem.Service.getAllObjects()Future<?>getAllObjects(ResponseHandler<List<OperatingSystem>> callback)Future<OperatingSystem>getObject()Async version ofOperatingSystem.Service.getObject()Future<?>getObject(ResponseHandler<OperatingSystem> callback)voidsetMask(OperatingSystem.Mask mask)OperatingSystem.MaskwithMask()Use the existing mask on this service or create it if not presentOperatingSystem.MaskwithNewMask()Overwrite the existing mask on this service with a new one and return itMethods inherited from interface com.softlayer.api.ResultLimitable
getLastResponseTotalItemCount, getResultLimit, setResultLimit
-
Method Details
-
withNewMask
OperatingSystem.Mask withNewMask()Description copied from interface:MaskableOverwrite the existing mask on this service with a new one and return it- Specified by:
withNewMaskin interfaceMaskable
-
withMask
OperatingSystem.Mask withMask()Description copied from interface:MaskableUse the existing mask on this service or create it if not present -
setMask
-
getAllObjects
Future<List<OperatingSystem>> getAllObjects()Async version ofOperatingSystem.Service.getAllObjects() -
getAllObjects
-
getObject
Future<OperatingSystem> getObject()Async version ofOperatingSystem.Service.getObject() -
getObject
-