Interface Answer.Service
- All Superinterfaces:
Maskable,ResultLimitable,Service
- Enclosing class:
- Answer
@ApiService("SoftLayer_User_Customer_Security_Answer") public static interface Answer.Service extends Service
An account's user have security answers for secondary security measures. These questions/answers can be found during login and password update. These questions/answers are also needed for password reset.
- See Also:
- SoftLayer_User_Customer_Security_Answer
-
Method Summary
Modifier and Type Method Description Answer.ServiceAsyncasAsync()Get an async version of this serviceAnswergetObject()getObject retrieves the SoftLayer_User_Customer_Security_Answer object whose ID number corresponds to the ID number of the init parameter passed to the SoftLayer_User_Customer_Security_Answer service.QuestiongetQuestion()The question the security answer is associated with.CustomergetUser()The user who the security answer belongs to.voidsetMask(Answer.Mask mask)Answer.MaskwithMask()Use the existing mask on this service or create it if not presentAnswer.MaskwithNewMask()Overwrite the existing mask on this service with a new one and return itMethods inherited from interface com.softlayer.api.ResultLimitable
getLastResponseTotalItemCount, getResultLimit, setResultLimit
-
Method Details
-
asAsync
Answer.ServiceAsync asAsync()Description copied from interface:ServiceGet an async version of this service -
withNewMask
Answer.Mask withNewMask()Description copied from interface:MaskableOverwrite the existing mask on this service with a new one and return it- Specified by:
withNewMaskin interfaceMaskable
-
withMask
Answer.Mask withMask()Description copied from interface:MaskableUse the existing mask on this service or create it if not present -
setMask
-
getObject
getObject retrieves the SoftLayer_User_Customer_Security_Answer object whose ID number corresponds to the ID number of the init parameter passed to the SoftLayer_User_Customer_Security_Answer service. -
getQuestion
The question the security answer is associated with. -
getUser
The user who the security answer belongs to.
-