Interface Binding.Service
- All Superinterfaces:
Maskable,ResultLimitable,Service
- All Known Subinterfaces:
Binding.Service,Phone.Service,Totp.Service,Verisign.Service
- Enclosing class:
- Binding
@ApiService("SoftLayer_User_External_Binding") public static interface Binding.Service extends Service
<<<
- See Also:
- SoftLayer_User_External_Binding
-
Method Summary
Modifier and Type Method Description Binding.ServiceAsyncasAsync()Get an async version of this serviceBooleandeleteObject()Delete an external authentication binding.List<Attribute>getAttributes()Attributes of an external authentication binding.ItemgetBillingItem()Information regarding the billing item for external authentication.StringgetNote()An optional note for identifying the external binding.BindinggetObject()TypegetType()The type of external authentication binding.VendorgetVendor()The vendor of an external authentication binding.voidsetMask(Binding.Mask mask)BooleanupdateNote(String text)Update the note of an external binding.Binding.MaskwithMask()Use the existing mask on this service or create it if not presentBinding.MaskwithNewMask()Overwrite the existing mask on this service with a new one and return itMethods inherited from interface com.softlayer.api.ResultLimitable
getLastResponseTotalItemCount, getResultLimit, setResultLimit
-
Method Details
-
asAsync
Binding.ServiceAsync asAsync()Description copied from interface:ServiceGet an async version of this service -
withNewMask
Binding.Mask withNewMask()Description copied from interface:MaskableOverwrite the existing mask on this service with a new one and return it- Specified by:
withNewMaskin interfaceMaskable
-
withMask
Binding.Mask withMask()Description copied from interface:MaskableUse the existing mask on this service or create it if not present -
setMask
-
deleteObject
Delete an external authentication binding. If the external binding currently has an active billing item associated you will be prevented from deleting the binding. The alternative method to remove an external authentication binding is to use the service cancellation form. -
getObject
-
updateNote
Update the note of an external binding. The note is an optional property that is used to store information about a binding. -
getAttributes
Attributes of an external authentication binding. -
getBillingItem
Information regarding the billing item for external authentication. -
getNote
An optional note for identifying the external binding.- See Also:
- SoftLayer_User_External_Binding::getNote
-
getType
The type of external authentication binding.- See Also:
- SoftLayer_User_External_Binding::getType
-
getVendor
The vendor of an external authentication binding.
-