Interface Binding.ServiceAsync
- All Superinterfaces:
Maskable,ResultLimitable,ServiceAsync
- All Known Subinterfaces:
Binding.ServiceAsync,Phone.ServiceAsync,Totp.ServiceAsync,Verisign.ServiceAsync
- Enclosing class:
- Binding
public static interface Binding.ServiceAsync extends ServiceAsync
-
Method Summary
Methods inherited from interface com.softlayer.api.ResultLimitable
getLastResponseTotalItemCount, getResultLimit, setResultLimit
-
Method Details
-
withNewMask
Binding.Mask withNewMask()Description copied from interface:MaskableOverwrite the existing mask on this service with a new one and return it- Specified by:
withNewMaskin interfaceMaskable
-
withMask
Binding.Mask withMask()Description copied from interface:MaskableUse the existing mask on this service or create it if not present -
setMask
-
deleteObject
Async version ofBinding.Service.deleteObject() -
deleteObject
-
getObject
Async version ofBinding.Service.getObject() -
getObject
-
updateNote
Async version ofBinding.Service.updateNote(java.lang.String) -
updateNote
-
getAttributes
Async version ofBinding.Service.getAttributes() -
getAttributes
Async callback version ofBinding.Service.getAttributes() -
getBillingItem
Async version ofBinding.Service.getBillingItem() -
getBillingItem
Async callback version ofBinding.Service.getBillingItem() -
getNote
Async version ofBinding.Service.getNote() -
getNote
Async callback version ofBinding.Service.getNote() -
getType
Async version ofBinding.Service.getType() -
getType
Async callback version ofBinding.Service.getType() -
getVendor
Async version ofBinding.Service.getVendor() -
getVendor
Async callback version ofBinding.Service.getVendor()
-