Class Attribute
java.lang.Object
com.softlayer.api.Type
com.softlayer.api.service.Entity
com.softlayer.api.service.user.external.binding.Attribute
- Direct Known Subclasses:
Attribute
@ApiType("SoftLayer_User_External_Binding_Attribute") public class Attribute extends Entity
The SoftLayer_User_External_Binding_Attribute data type contains the value for a single attribute associated with an external binding. External binding attributes contain additional information about an external binding. An attribute can be generic or specific to a 3rd party vendor. For example these attributes relate to Verisign:
*Credential Type
*Credential State
*Credential Expiration Date
*Credential Last Update Date
*Credential Type
*Credential State
*Credential Expiration Date
*Credential Last Update Date
-
Nested Class Summary
Nested Classes Modifier and Type Class Description static classAttribute.Mask -
Field Summary
Fields Modifier and Type Field Description protected BindingexternalBindingThe external authentication binding an attribute belongs to.protected StringvalueThe value of an external binding attribute.protected booleanvalueSpecified -
Constructor Summary
Constructors Constructor Description Attribute() -
Method Summary
Modifier and Type Method Description BindinggetExternalBinding()StringgetValue()booleanisValueSpecified()voidsetExternalBinding(Binding externalBinding)voidsetValue(String value)voidunsetValue()
-
Field Details
-
externalBinding
The external authentication binding an attribute belongs to. -
value
The value of an external binding attribute. -
valueSpecified
protected boolean valueSpecified
-
-
Constructor Details
-
Attribute
public Attribute()
-
-
Method Details
-
getExternalBinding
-
setExternalBinding
-
getValue
-
setValue
-
isValueSpecified
public boolean isValueSpecified() -
unsetValue
public void unsetValue()
-