Class Vendor
java.lang.Object
com.softlayer.api.Type
com.softlayer.api.service.Entity
com.softlayer.api.service.user.external.binding.Vendor
- Direct Known Subclasses:
Vendor
@ApiType("SoftLayer_User_External_Binding_Vendor") public class Vendor extends Entity
The SoftLayer_User_External_Binding_Vendor data type contains information for a single external binding vendor. This information includes a user friendly vendor name, a unique version of the vendor name, and a unique internal identifier that can be used when creating a new external binding.
- See Also:
- SoftLayer_User_External_Binding_Vendor
-
Nested Class Summary
Nested Classes Modifier and Type Class Description static classVendor.Maskstatic interfaceVendor.ServiceThe SoftLayer_User_External_Binding_Vendor service is used to retrieve a list of available 3rd party vendors that SoftLayer supports for external bindings.static interfaceVendor.ServiceAsync -
Field Summary
Fields Modifier and Type Field Description protected LongidThe unique identifier for an external binding vendor.protected booleanidSpecifiedprotected StringkeyNameA unique version of the name property.protected booleankeyNameSpecifiedprotected StringnameThe user friendly name of an external binding vendor.protected booleannameSpecified -
Constructor Summary
Constructors Constructor Description Vendor() -
Method Summary
Modifier and Type Method Description Vendor.ServiceasService(ApiClient client)LonggetId()StringgetKeyName()StringgetName()booleanisIdSpecified()booleanisKeyNameSpecified()booleanisNameSpecified()static Vendor.Serviceservice(ApiClient client)static Vendor.Serviceservice(ApiClient client, Long id)voidsetId(Long id)voidsetKeyName(String keyName)voidsetName(String name)voidunsetId()voidunsetKeyName()voidunsetName()
-
Field Details
-
id
The unique identifier for an external binding vendor. -
idSpecified
protected boolean idSpecified -
keyName
A unique version of the name property. -
keyNameSpecified
protected boolean keyNameSpecified -
name
The user friendly name of an external binding vendor. -
nameSpecified
protected boolean nameSpecified
-
-
Constructor Details
-
Vendor
public Vendor()
-
-
Method Details
-
getId
-
setId
-
isIdSpecified
public boolean isIdSpecified() -
unsetId
public void unsetId() -
getKeyName
-
setKeyName
-
isKeyNameSpecified
public boolean isKeyNameSpecified() -
unsetKeyName
public void unsetKeyName() -
getName
-
setName
-
isNameSpecified
public boolean isNameSpecified() -
unsetName
public void unsetName() -
asService
-
service
-
service
-