Interface Vendor.Service
- All Superinterfaces:
Maskable,ResultLimitable,Service
- All Known Subinterfaces:
Vendor.Service
- Enclosing class:
- Vendor
@ApiService("SoftLayer_User_External_Binding_Vendor") public static interface Vendor.Service extends Service
The SoftLayer_User_External_Binding_Vendor service is used to retrieve a list of available 3rd party vendors that SoftLayer supports for external bindings.
- See Also:
- SoftLayer_User_External_Binding_Vendor
-
Method Summary
Modifier and Type Method Description Vendor.ServiceAsyncasAsync()Get an async version of this serviceList<Vendor>getAllObjects()getAllObjects() will return a list of the available external binding vendors that SoftLayer supports.VendorgetObject()voidsetMask(Vendor.Mask mask)Vendor.MaskwithMask()Use the existing mask on this service or create it if not presentVendor.MaskwithNewMask()Overwrite the existing mask on this service with a new one and return itMethods inherited from interface com.softlayer.api.ResultLimitable
getLastResponseTotalItemCount, getResultLimit, setResultLimit
-
Method Details
-
asAsync
Vendor.ServiceAsync asAsync()Description copied from interface:ServiceGet an async version of this service -
withNewMask
Vendor.Mask withNewMask()Description copied from interface:MaskableOverwrite the existing mask on this service with a new one and return it- Specified by:
withNewMaskin interfaceMaskable
-
withMask
Vendor.Mask withMask()Description copied from interface:MaskableUse the existing mask on this service or create it if not present -
setMask
-
getAllObjects
getAllObjects() will return a list of the available external binding vendors that SoftLayer supports. Use this list to select the appropriate vendor when creating a new external binding. -
getObject
-