Uses of Class
com.softlayer.api.service.user.security.Question
-
Uses of Question in com.softlayer.api.service.container.user.customer
Fields in com.softlayer.api.service.container.user.customer with type parameters of type Question Modifier and Type Field Description protected List<Question>PasswordSet. securityQuestionsArray of SoftLayer_User_Security_Question.Methods in com.softlayer.api.service.container.user.customer that return types with arguments of type Question Modifier and Type Method Description List<Question>PasswordSet. getSecurityQuestions() -
Uses of Question in com.softlayer.api.service.user
Method parameters in com.softlayer.api.service.user with type arguments of type Question Modifier and Type Method Description BooleanCustomer.Service. updateSecurityAnswers(List<Question> questions, List<String> answers)Update a user's login security questions and answers on the SoftLayer customer portal.Future<Boolean>Customer.ServiceAsync. updateSecurityAnswers(List<Question> questions, List<String> answers)Future<?>Customer.ServiceAsync. updateSecurityAnswers(List<Question> questions, List<String> answers, ResponseHandler<Boolean> callback) -
Uses of Question in com.softlayer.api.service.user.customer.security
Fields in com.softlayer.api.service.user.customer.security declared as Question Modifier and Type Field Description protected QuestionAnswer. questionThe question the security answer is associated with.Methods in com.softlayer.api.service.user.customer.security that return Question Modifier and Type Method Description QuestionAnswer. getQuestion()QuestionAnswer.Service. getQuestion()The question the security answer is associated with.Methods in com.softlayer.api.service.user.customer.security that return types with arguments of type Question Modifier and Type Method Description Future<Question>Answer.ServiceAsync. getQuestion()Async version ofAnswer.Service.getQuestion()Methods in com.softlayer.api.service.user.customer.security with parameters of type Question Modifier and Type Method Description voidAnswer. setQuestion(Question question)Method parameters in com.softlayer.api.service.user.customer.security with type arguments of type Question Modifier and Type Method Description Future<?>Answer.ServiceAsync. getQuestion(ResponseHandler<Question> callback)Async callback version ofAnswer.Service.getQuestion() -
Uses of Question in com.softlayer.api.service.user.security
Methods in com.softlayer.api.service.user.security that return Question Modifier and Type Method Description QuestionQuestion.Service. getObject()getAllObjects retrieves all the SoftLayer_User_Security_Question objects where it is set to be viewable.Methods in com.softlayer.api.service.user.security that return types with arguments of type Question Modifier and Type Method Description List<Question>Question.Service. getAllObjects()Retrieve all viewable security questions.Future<List<Question>>Question.ServiceAsync. getAllObjects()Async version ofQuestion.Service.getAllObjects()Future<Question>Question.ServiceAsync. getObject()Async version ofQuestion.Service.getObject()Method parameters in com.softlayer.api.service.user.security with type arguments of type Question Modifier and Type Method Description Future<?>Question.ServiceAsync. getAllObjects(ResponseHandler<List<Question>> callback)Future<?>Question.ServiceAsync. getObject(ResponseHandler<Question> callback)