Interface DedicatedHost.ServiceAsync
- All Superinterfaces:
Maskable,ResultLimitable,ServiceAsync
- Enclosing class:
- DedicatedHost
public static interface DedicatedHost.ServiceAsync extends ServiceAsync
-
Method Summary
Methods inherited from interface com.softlayer.api.ResultLimitable
getLastResponseTotalItemCount, getResultLimit, setResultLimit
-
Method Details
-
withNewMask
DedicatedHost.Mask withNewMask()Description copied from interface:MaskableOverwrite the existing mask on this service with a new one and return it- Specified by:
withNewMaskin interfaceMaskable
-
withMask
DedicatedHost.Mask withMask()Description copied from interface:MaskableUse the existing mask on this service or create it if not present -
setMask
-
deleteObject
Async version ofDedicatedHost.Service.deleteObject() -
deleteObject
-
editObject
-
editObject
-
getAvailableRouters
-
getAvailableRouters
Future<?> getAvailableRouters(DedicatedHost dedicatedHost, ResponseHandler<List<Hardware>> callback) -
getObject
Future<DedicatedHost> getObject()Async version ofDedicatedHost.Service.getObject() -
getObject
-
setTags
Async version ofDedicatedHost.Service.setTags(java.lang.String) -
setTags
-
getAccount
Async version ofDedicatedHost.Service.getAccount() -
getAccount
Async callback version ofDedicatedHost.Service.getAccount() -
getAllocationStatus
Future<AllocationStatus> getAllocationStatus()Async version ofDedicatedHost.Service.getAllocationStatus() -
getAllocationStatus
Async callback version ofDedicatedHost.Service.getAllocationStatus() -
getBackendRouter
Async version ofDedicatedHost.Service.getBackendRouter() -
getBackendRouter
Async callback version ofDedicatedHost.Service.getBackendRouter() -
getBillingItem
Future<DedicatedHost> getBillingItem()Async version ofDedicatedHost.Service.getBillingItem() -
getBillingItem
Async callback version ofDedicatedHost.Service.getBillingItem() -
getDatacenter
Async version ofDedicatedHost.Service.getDatacenter() -
getDatacenter
Async callback version ofDedicatedHost.Service.getDatacenter() -
getGuests
Async version ofDedicatedHost.Service.getGuests() -
getGuests
Async callback version ofDedicatedHost.Service.getGuests() -
getInternalTagReferences
Async version ofDedicatedHost.Service.getInternalTagReferences() -
getInternalTagReferences
Async callback version ofDedicatedHost.Service.getInternalTagReferences() -
getPciDeviceAllocationStatus
Future<AllocationStatus> getPciDeviceAllocationStatus()Async version ofDedicatedHost.Service.getPciDeviceAllocationStatus() -
getPciDeviceAllocationStatus
Async callback version ofDedicatedHost.Service.getPciDeviceAllocationStatus() -
getPciDevices
Async version ofDedicatedHost.Service.getPciDevices() -
getPciDevices
Async callback version ofDedicatedHost.Service.getPciDevices() -
getTagReferences
Async version ofDedicatedHost.Service.getTagReferences() -
getTagReferences
Async callback version ofDedicatedHost.Service.getTagReferences()
-