Interface PlacementGroup.Service
- All Superinterfaces:
Maskable,ResultLimitable,Service
- Enclosing class:
- PlacementGroup
@ApiService("SoftLayer_Virtual_PlacementGroup") public static interface PlacementGroup.Service extends Service
SoftLayer_Virtual_PlacementGroup is a collection of virtual guests to be placed relative to each other according to a rule.
- See Also:
- SoftLayer_Virtual_PlacementGroup
-
Method Summary
Modifier and Type Method Description PlacementGroup.ServiceAsyncasAsync()Get an async version of this servicePlacementGroupcreateObject(PlacementGroup templateObject)Add a placement group to your account for use during VSI provisioning.BooleandeleteObject()Delete a placement group from your account.BooleaneditObject(PlacementGroup templateObject)Update a placement group.AccountgetAccount()The account that the placement group is implemented on.List<Hardware>getAvailableRouters(Long datacenterId)Returns all routers available for use with placement groups.BackendgetBackendRouter()The router the placement group is implemented on.List<Guest>getGuests()The virtual guests that are members of the placement group.PlacementGroupgetObject()RulegetRule()The placement rule that the placement group is implementing.voidsetMask(PlacementGroup.Mask mask)PlacementGroup.MaskwithMask()Use the existing mask on this service or create it if not presentPlacementGroup.MaskwithNewMask()Overwrite the existing mask on this service with a new one and return itMethods inherited from interface com.softlayer.api.ResultLimitable
getLastResponseTotalItemCount, getResultLimit, setResultLimit
-
Method Details
-
asAsync
PlacementGroup.ServiceAsync asAsync()Description copied from interface:ServiceGet an async version of this service -
withNewMask
PlacementGroup.Mask withNewMask()Description copied from interface:MaskableOverwrite the existing mask on this service with a new one and return it- Specified by:
withNewMaskin interfaceMaskable
-
withMask
PlacementGroup.Mask withMask()Description copied from interface:MaskableUse the existing mask on this service or create it if not present -
setMask
-
createObject
Add a placement group to your account for use during VSI provisioning. -
deleteObject
Delete a placement group from your account. -
editObject
Update a placement group. -
getAvailableRouters
Returns all routers available for use with placement groups. If a datacenter location ID is provided, this method will further restrict the list of routers to ones contained within that datacenter. -
getObject
-
getAccount
The account that the placement group is implemented on. -
getBackendRouter
The router the placement group is implemented on. -
getGuests
The virtual guests that are members of the placement group. -
getRule
The placement rule that the placement group is implementing.
-