Class ReservedCapacityGroup
java.lang.Object
com.softlayer.api.Type
com.softlayer.api.service.Entity
com.softlayer.api.service.virtual.ReservedCapacityGroup
@ApiType("SoftLayer_Virtual_ReservedCapacityGroup") public class ReservedCapacityGroup extends Entity
This data type presents the structure for a virtual reserved capacity group.
- See Also:
- SoftLayer_Virtual_ReservedCapacityGroup
-
Nested Class Summary
Nested Classes Modifier and Type Class Description static classReservedCapacityGroup.Maskstatic interfaceReservedCapacityGroup.ServiceSoftLayer_Virtual_ReservedCapacityGroup reserves capacity for a group of guests that have not yet been provisioned.static interfaceReservedCapacityGroup.ServiceAsync -
Field Summary
Fields Modifier and Type Field Description protected AccountaccountThe account that the reserved capacity group is implemented on.protected LongaccountIdThe unique ID of the account that created the reserved capacity group.protected booleanaccountIdSpecifiedprotected LongavailableInstanceCountA count of the instances available for guest provisions on this reserved capacity group.protected List<Instance>availableInstancesThe instances available for guest provisions on this reserved capacity group.protected BackendbackendRouterThe router the reserved capacity group is implemented on.protected LongbackendRouterIdThe reserved capacity group's backend router's associated unique ID.protected booleanbackendRouterIdSpecifiedprotected GregorianCalendarcreateDateThe date that the reserved capacity group was created.protected booleancreateDateSpecifiedprotected LongidThe reserved capacity group's associated unique ID.protected booleanidSpecifiedprotected LonginstanceCountA count of the guest instances that are members of this reserved capacity group.protected List<Instance>instancesThe guest instances that are members of this reserved capacity group.protected LonginstancesCountThe number of instances that are members of this reserved capacity group.protected GregorianCalendarmodifyDateThe date that the reserved capacity group was last modified.protected booleanmodifyDateSpecifiedprotected StringnameThe reserved capacity group's name.protected booleannameSpecifiedprotected LongoccupiedInstanceCountA count of the instances already occupied by a guest on this reserved capacity group.protected List<Instance>occupiedInstancesThe instances already occupied by a guest on this reserved capacity group. -
Constructor Summary
Constructors Constructor Description ReservedCapacityGroup() -
Method Summary
-
Field Details
-
account
The account that the reserved capacity group is implemented on. -
availableInstances
The instances available for guest provisions on this reserved capacity group. -
backendRouter
The router the reserved capacity group is implemented on. -
instances
The guest instances that are members of this reserved capacity group. -
instancesCount
The number of instances that are members of this reserved capacity group. -
occupiedInstances
The instances already occupied by a guest on this reserved capacity group. -
accountId
The unique ID of the account that created the reserved capacity group. -
accountIdSpecified
protected boolean accountIdSpecified -
backendRouterId
The reserved capacity group's backend router's associated unique ID. -
backendRouterIdSpecified
protected boolean backendRouterIdSpecified -
createDate
The date that the reserved capacity group was created. -
createDateSpecified
protected boolean createDateSpecified -
id
The reserved capacity group's associated unique ID. -
idSpecified
protected boolean idSpecified -
modifyDate
The date that the reserved capacity group was last modified. -
modifyDateSpecified
protected boolean modifyDateSpecified -
name
The reserved capacity group's name. -
nameSpecified
protected boolean nameSpecified -
availableInstanceCount
A count of the instances available for guest provisions on this reserved capacity group. -
instanceCount
A count of the guest instances that are members of this reserved capacity group. -
occupiedInstanceCount
A count of the instances already occupied by a guest on this reserved capacity group.
-
-
Constructor Details
-
ReservedCapacityGroup
public ReservedCapacityGroup()
-
-
Method Details
-
getAccount
-
setAccount
-
getAvailableInstances
-
getBackendRouter
-
setBackendRouter
-
getInstances
-
getInstancesCount
-
setInstancesCount
-
getOccupiedInstances
-
getAccountId
-
setAccountId
-
isAccountIdSpecified
public boolean isAccountIdSpecified() -
unsetAccountId
public void unsetAccountId() -
getBackendRouterId
-
setBackendRouterId
-
isBackendRouterIdSpecified
public boolean isBackendRouterIdSpecified() -
unsetBackendRouterId
public void unsetBackendRouterId() -
getCreateDate
-
setCreateDate
-
isCreateDateSpecified
public boolean isCreateDateSpecified() -
unsetCreateDate
public void unsetCreateDate() -
getId
-
setId
-
isIdSpecified
public boolean isIdSpecified() -
unsetId
public void unsetId() -
getModifyDate
-
setModifyDate
-
isModifyDateSpecified
public boolean isModifyDateSpecified() -
unsetModifyDate
public void unsetModifyDate() -
getName
-
setName
-
isNameSpecified
public boolean isNameSpecified() -
unsetName
public void unsetName() -
getAvailableInstanceCount
-
setAvailableInstanceCount
-
getInstanceCount
-
setInstanceCount
-
getOccupiedInstanceCount
-
setOccupiedInstanceCount
-
asService
-
service
-
service
-