Interface ReservedCapacityGroup.Service
- All Superinterfaces:
Maskable,ResultLimitable,Service
- Enclosing class:
- ReservedCapacityGroup
@ApiService("SoftLayer_Virtual_ReservedCapacityGroup") public static interface ReservedCapacityGroup.Service extends Service
SoftLayer_Virtual_ReservedCapacityGroup reserves capacity for a group of guests that have not yet been provisioned.
- See Also:
- SoftLayer_Virtual_ReservedCapacityGroup
-
Method Summary
Modifier and Type Method Description ReservedCapacityGroup.ServiceAsyncasAsync()Get an async version of this serviceBooleaneditObject(ReservedCapacityGroup templateObject)Update a reserved capacity group.AccountgetAccount()The account that the reserved capacity group is implemented on.List<Instance>getAvailableInstances()The instances available for guest provisions on this reserved capacity group.BackendgetBackendRouter()The router the reserved capacity group is implemented on.List<Instance>getInstances()The guest instances that are members of this reserved capacity group.LonggetInstancesCount()The number of instances that are members of this reserved capacity group.ReservedCapacityGroupgetObject()List<Instance>getOccupiedInstances()The instances already occupied by a guest on this reserved capacity group.voidsetMask(ReservedCapacityGroup.Mask mask)ReservedCapacityGroup.MaskwithMask()Use the existing mask on this service or create it if not presentReservedCapacityGroup.MaskwithNewMask()Overwrite the existing mask on this service with a new one and return itMethods inherited from interface com.softlayer.api.ResultLimitable
getLastResponseTotalItemCount, getResultLimit, setResultLimit
-
Method Details
-
asAsync
ReservedCapacityGroup.ServiceAsync asAsync()Description copied from interface:ServiceGet an async version of this service -
withNewMask
ReservedCapacityGroup.Mask withNewMask()Description copied from interface:MaskableOverwrite the existing mask on this service with a new one and return it- Specified by:
withNewMaskin interfaceMaskable
-
withMask
ReservedCapacityGroup.Mask withMask()Description copied from interface:MaskableUse the existing mask on this service or create it if not present -
setMask
-
editObject
Update a reserved capacity group. -
getObject
-
getAccount
The account that the reserved capacity group is implemented on. -
getAvailableInstances
The instances available for guest provisions on this reserved capacity group. -
getBackendRouter
The router the reserved capacity group is implemented on. -
getInstances
The guest instances that are members of this reserved capacity group. -
getInstancesCount
The number of instances that are members of this reserved capacity group. -
getOccupiedInstances
The instances already occupied by a guest on this reserved capacity group.
-