Uses of Class
com.softlayer.api.service.virtual.Host
| Package | Description |
|---|---|
| com.softlayer.api.service | |
| com.softlayer.api.service.virtual | |
| com.softlayer.api.service.virtual.host |
-
Uses of Host in com.softlayer.api.service
Fields in com.softlayer.api.service declared as Host Modifier and Type Field Description protected HostHardware. virtualHostA piece of hardware's virtual host record.Methods in com.softlayer.api.service that return Host Modifier and Type Method Description HostHardware. getVirtualHost()HostHardware.Service. getVirtualHost()A piece of hardware's virtual host record.HostHardware.Service. importVirtualHost()The '''importVirtualHost''' method attempts to import the host record for the virtualization platform running on a server.Methods in com.softlayer.api.service that return types with arguments of type Host Modifier and Type Method Description Future<Host>Hardware.ServiceAsync. getVirtualHost()Async version ofHardware.Service.getVirtualHost()Future<Host>Hardware.ServiceAsync. importVirtualHost()Async version ofHardware.Service.importVirtualHost()Methods in com.softlayer.api.service with parameters of type Host Modifier and Type Method Description voidHardware. setVirtualHost(Host virtualHost)Method parameters in com.softlayer.api.service with type arguments of type Host Modifier and Type Method Description Future<?>Hardware.ServiceAsync. getVirtualHost(ResponseHandler<Host> callback)Async callback version ofHardware.Service.getVirtualHost()Future<?>Hardware.ServiceAsync. importVirtualHost(ResponseHandler<Host> callback) -
Uses of Host in com.softlayer.api.service.virtual
Fields in com.softlayer.api.service.virtual declared as Host Modifier and Type Field Description protected HostGuest. hostThe virtual host on which a virtual guest resides (available only on private clouds).Methods in com.softlayer.api.service.virtual that return Host Modifier and Type Method Description HostGuest. getHost()HostGuest.Service. getHost()The virtual host on which a virtual guest resides (available only on private clouds).HostHost.Service. getObject()Methods in com.softlayer.api.service.virtual that return types with arguments of type Host Modifier and Type Method Description Future<Host>Guest.ServiceAsync. getHost()Async version ofGuest.Service.getHost()Future<Host>Host.ServiceAsync. getObject()Async version ofHost.Service.getObject()Methods in com.softlayer.api.service.virtual with parameters of type Host Modifier and Type Method Description voidGuest. setHost(Host host)Method parameters in com.softlayer.api.service.virtual with type arguments of type Host Modifier and Type Method Description Future<?>Guest.ServiceAsync. getHost(ResponseHandler<Host> callback)Async callback version ofGuest.Service.getHost()Future<?>Host.ServiceAsync. getObject(ResponseHandler<Host> callback) -
Uses of Host in com.softlayer.api.service.virtual.host
Fields in com.softlayer.api.service.virtual.host declared as Host Modifier and Type Field Description protected HostPciDevice. hostMethods in com.softlayer.api.service.virtual.host that return Host Modifier and Type Method Description HostPciDevice. getHost()Methods in com.softlayer.api.service.virtual.host with parameters of type Host Modifier and Type Method Description voidPciDevice. setHost(Host host)