Uses of Class
com.softlayer.api.service.virtual.ReservedCapacityGroup
| Package | Description |
|---|---|
| com.softlayer.api.service | |
| com.softlayer.api.service.virtual | |
| com.softlayer.api.service.virtual.reservedcapacitygroup |
-
Uses of ReservedCapacityGroup in com.softlayer.api.service
Fields in com.softlayer.api.service with type parameters of type ReservedCapacityGroup Modifier and Type Field Description protected List<ReservedCapacityGroup>Account. reservedCapacityGroupsThe reserved capacity groups owned by this account.Methods in com.softlayer.api.service that return types with arguments of type ReservedCapacityGroup Modifier and Type Method Description List<ReservedCapacityGroup>Account. getReservedCapacityGroups()List<ReservedCapacityGroup>Account.Service. getReservedCapacityGroups()The reserved capacity groups owned by this account.Future<List<ReservedCapacityGroup>>Account.ServiceAsync. getReservedCapacityGroups()Async version ofAccount.Service.getReservedCapacityGroups()Method parameters in com.softlayer.api.service with type arguments of type ReservedCapacityGroup Modifier and Type Method Description Future<?>Account.ServiceAsync. getReservedCapacityGroups(ResponseHandler<List<ReservedCapacityGroup>> callback)Async callback version ofAccount.Service.getReservedCapacityGroups() -
Uses of ReservedCapacityGroup in com.softlayer.api.service.virtual
Fields in com.softlayer.api.service.virtual declared as ReservedCapacityGroup Modifier and Type Field Description protected ReservedCapacityGroupGuest. reservedCapacityGroupThe reserved capacity group the guest is associated with.Methods in com.softlayer.api.service.virtual that return ReservedCapacityGroup Modifier and Type Method Description ReservedCapacityGroupReservedCapacityGroup.Service. getObject()ReservedCapacityGroupGuest. getReservedCapacityGroup()ReservedCapacityGroupGuest.Service. getReservedCapacityGroup()The reserved capacity group the guest is associated with.Methods in com.softlayer.api.service.virtual that return types with arguments of type ReservedCapacityGroup Modifier and Type Method Description Future<ReservedCapacityGroup>ReservedCapacityGroup.ServiceAsync. getObject()Async version ofReservedCapacityGroup.Service.getObject()Future<ReservedCapacityGroup>Guest.ServiceAsync. getReservedCapacityGroup()Async version ofGuest.Service.getReservedCapacityGroup()Methods in com.softlayer.api.service.virtual with parameters of type ReservedCapacityGroup Modifier and Type Method Description BooleanReservedCapacityGroup.Service. editObject(ReservedCapacityGroup templateObject)Update a reserved capacity group.Future<Boolean>ReservedCapacityGroup.ServiceAsync. editObject(ReservedCapacityGroup templateObject)Future<?>ReservedCapacityGroup.ServiceAsync. editObject(ReservedCapacityGroup templateObject, ResponseHandler<Boolean> callback)voidGuest. setReservedCapacityGroup(ReservedCapacityGroup reservedCapacityGroup)Method parameters in com.softlayer.api.service.virtual with type arguments of type ReservedCapacityGroup Modifier and Type Method Description Future<?>ReservedCapacityGroup.ServiceAsync. getObject(ResponseHandler<ReservedCapacityGroup> callback)Future<?>Guest.ServiceAsync. getReservedCapacityGroup(ResponseHandler<ReservedCapacityGroup> callback)Async callback version ofGuest.Service.getReservedCapacityGroup() -
Uses of ReservedCapacityGroup in com.softlayer.api.service.virtual.reservedcapacitygroup
Fields in com.softlayer.api.service.virtual.reservedcapacitygroup declared as ReservedCapacityGroup Modifier and Type Field Description protected ReservedCapacityGroupInstance. reservedCapacityGroupThe reserved instances that are members of this reserved capacity group.Methods in com.softlayer.api.service.virtual.reservedcapacitygroup that return ReservedCapacityGroup Modifier and Type Method Description ReservedCapacityGroupInstance. getReservedCapacityGroup()ReservedCapacityGroupInstance.Service. getReservedCapacityGroup()The reserved instances that are members of this reserved capacity group.Methods in com.softlayer.api.service.virtual.reservedcapacitygroup that return types with arguments of type ReservedCapacityGroup Modifier and Type Method Description Future<ReservedCapacityGroup>Instance.ServiceAsync. getReservedCapacityGroup()Async version ofInstance.Service.getReservedCapacityGroup()Methods in com.softlayer.api.service.virtual.reservedcapacitygroup with parameters of type ReservedCapacityGroup Modifier and Type Method Description voidInstance. setReservedCapacityGroup(ReservedCapacityGroup reservedCapacityGroup)Method parameters in com.softlayer.api.service.virtual.reservedcapacitygroup with type arguments of type ReservedCapacityGroup Modifier and Type Method Description Future<?>Instance.ServiceAsync. getReservedCapacityGroup(ResponseHandler<ReservedCapacityGroup> callback)Async callback version ofInstance.Service.getReservedCapacityGroup()