Class Image
java.lang.Object
com.softlayer.api.Type
com.softlayer.api.service.Entity
com.softlayer.api.service.virtual.disk.Image
@ApiType("SoftLayer_Virtual_Disk_Image") public class Image extends Entity
The virtual disk image data type presents the structure in which a virtual disk image will be presented.
Virtual block devices are assigned to disk images.
Virtual block devices are assigned to disk images.
- See Also:
- SoftLayer_Virtual_Disk_Image
-
Nested Class Summary
Nested Classes Modifier and Type Class Description static classImage.Maskstatic interfaceImage.Servicestatic interfaceImage.ServiceAsync -
Field Summary
Fields Modifier and Type Field Description protected ImagebillingItemThe billing item for a virtual disk image.protected LongblockDeviceCountA count of the block devices that a disk image is attached to.protected List<Device>blockDevicesThe block devices that a disk image is attached to.protected BooleanbootableVolumeFlagprotected LongcapacityA disk image's size measured in gigabytes.protected booleancapacitySpecifiedprotected StringchecksumA disk image's unique md5 checksum.protected StringchecksumAlgorithmA column to save the Algorithm being used to store the checksum.protected booleanchecksumAlgorithmSpecifiedprotected booleanchecksumSpecifiedprotected BooleancloudInitFlagCheck if cloud-init is enabled.protected LongcoalescedDiskImageCountA count ofprotected List<Image>coalescedDiskImagesprotected BooleancopyOnWriteFlagprotected GregorianCalendarcreateDateThe date a disk image was created.protected booleancreateDateSpecifiedprotected StringdescriptionA brief description of a virtual disk image.protected booleandescriptionSpecifiedprotected StringdiskFileExtensionReturn disk file extensionprotected GroupdiskImageStorageGroupprotected LongidA disk image's unique ID.protected booleanidSpecifiedprotected StringimportedDiskTypeReturn imported disk typeprotected BooleanisEncryptedReturn if image is encryptedprotected BooleanlocalDiskFlagprotected BooleanmetadataFlagWhether this disk image is meant for storage of custom user data supplied with a Cloud Computing Instance order.protected GregorianCalendarmodifyDateThe date a disk image was last modified.protected booleanmodifyDateSpecifiedprotected StringnameA descriptive name used to identify a disk image to a user.protected booleannameSpecifiedprotected LongparentIdThe ID of the the disk image that this disk image is based on, if applicable.protected booleanparentIdSpecifiedprotected LongsoftwareReferenceCountA count of references to the software that resides on a disk image.protected List<Software>softwareReferencesReferences to the software that resides on a disk image.protected ImagesourceDiskImageThe original disk image that the current disk image was cloned from.protected LongstorageGroupCountA count of the storage group for a virtual disk image.protected StringstorageGroupDetailsReturn storage group details for symantec diskprotected List<Group>storageGroupsThe storage group for a virtual disk image.protected RepositorystorageRepositoryThe storage repository that a disk image resides in.protected LongstorageRepositoryIdThe [[SoftLayer_Virtual_Storage_Repository|storage repository]] that a disk image is in.protected booleanstorageRepositoryIdSpecifiedprotected TypestorageRepositoryTypeThe type of storage repository that a disk image resides in.protected StringsupportedHardwareReturn supported hardware component IDs for symantec diskprotected TemplatetemplateBlockDeviceThe template that attaches a disk image to a [[SoftLayer_Virtual_Guest_Block_Device_Template_Group|archive]].protected TypetypeA virtual disk image's type.protected LongtypeIdA disk image's [[SoftLayer_Virtual_Disk_Image_Type|type]] IDprotected booleantypeIdSpecifiedprotected StringunitsThe unit of storage in which the size of the image is measured.protected booleanunitsSpecifiedprotected StringuuidA disk image's unique ID on a virtualization platform.protected booleanuuidSpecified -
Constructor Summary
Constructors Constructor Description Image() -
Method Summary
-
Field Details
-
billingItem
The billing item for a virtual disk image. -
blockDevices
The block devices that a disk image is attached to. Block devices connect computing instances to disk images. -
bootableVolumeFlag
-
cloudInitFlag
Check if cloud-init is enabled. -
coalescedDiskImages
-
copyOnWriteFlag
-
diskFileExtension
Return disk file extension -
diskImageStorageGroup
-
importedDiskType
Return imported disk type -
isEncrypted
Return if image is encrypted -
localDiskFlag
-
metadataFlag
Whether this disk image is meant for storage of custom user data supplied with a Cloud Computing Instance order. -
softwareReferences
References to the software that resides on a disk image. -
sourceDiskImage
The original disk image that the current disk image was cloned from. -
storageGroupDetails
Return storage group details for symantec disk -
storageGroups
The storage group for a virtual disk image. -
storageRepository
The storage repository that a disk image resides in. -
storageRepositoryType
The type of storage repository that a disk image resides in. -
supportedHardware
Return supported hardware component IDs for symantec disk -
templateBlockDevice
The template that attaches a disk image to a [[SoftLayer_Virtual_Guest_Block_Device_Template_Group|archive]]. -
type
A virtual disk image's type. -
capacity
A disk image's size measured in gigabytes. -
capacitySpecified
protected boolean capacitySpecified -
checksum
A disk image's unique md5 checksum. -
checksumSpecified
protected boolean checksumSpecified -
checksumAlgorithm
A column to save the Algorithm being used to store the checksum. -
checksumAlgorithmSpecified
protected boolean checksumAlgorithmSpecified -
createDate
The date a disk image was created. -
createDateSpecified
protected boolean createDateSpecified -
description
A brief description of a virtual disk image. -
descriptionSpecified
protected boolean descriptionSpecified -
id
A disk image's unique ID. -
idSpecified
protected boolean idSpecified -
modifyDate
The date a disk image was last modified. -
modifyDateSpecified
protected boolean modifyDateSpecified -
name
A descriptive name used to identify a disk image to a user. -
nameSpecified
protected boolean nameSpecified -
parentId
The ID of the the disk image that this disk image is based on, if applicable. -
parentIdSpecified
protected boolean parentIdSpecified -
storageRepositoryId
The [[SoftLayer_Virtual_Storage_Repository|storage repository]] that a disk image is in. -
storageRepositoryIdSpecified
protected boolean storageRepositoryIdSpecified -
typeId
A disk image's [[SoftLayer_Virtual_Disk_Image_Type|type]] ID -
typeIdSpecified
protected boolean typeIdSpecified -
units
The unit of storage in which the size of the image is measured. Defaults to "GB" for gigabytes. -
unitsSpecified
protected boolean unitsSpecified -
uuid
A disk image's unique ID on a virtualization platform. -
uuidSpecified
protected boolean uuidSpecified -
blockDeviceCount
A count of the block devices that a disk image is attached to. Block devices connect computing instances to disk images. -
coalescedDiskImageCount
A count of -
softwareReferenceCount
A count of references to the software that resides on a disk image. -
storageGroupCount
A count of the storage group for a virtual disk image.
-
-
Constructor Details
-
Image
public Image()
-
-
Method Details
-
getBillingItem
-
setBillingItem
-
getBlockDevices
-
getBootableVolumeFlag
-
setBootableVolumeFlag
-
getCloudInitFlag
-
setCloudInitFlag
-
getCoalescedDiskImages
-
getCopyOnWriteFlag
-
setCopyOnWriteFlag
-
getDiskFileExtension
-
setDiskFileExtension
-
getDiskImageStorageGroup
-
setDiskImageStorageGroup
-
getImportedDiskType
-
setImportedDiskType
-
getIsEncrypted
-
setIsEncrypted
-
getLocalDiskFlag
-
setLocalDiskFlag
-
getMetadataFlag
-
setMetadataFlag
-
getSoftwareReferences
-
getSourceDiskImage
-
setSourceDiskImage
-
getStorageGroupDetails
-
setStorageGroupDetails
-
getStorageGroups
-
getStorageRepository
-
setStorageRepository
-
getStorageRepositoryType
-
setStorageRepositoryType
-
getSupportedHardware
-
setSupportedHardware
-
getTemplateBlockDevice
-
setTemplateBlockDevice
-
getType
-
setType
-
getCapacity
-
setCapacity
-
isCapacitySpecified
public boolean isCapacitySpecified() -
unsetCapacity
public void unsetCapacity() -
getChecksum
-
setChecksum
-
isChecksumSpecified
public boolean isChecksumSpecified() -
unsetChecksum
public void unsetChecksum() -
getChecksumAlgorithm
-
setChecksumAlgorithm
-
isChecksumAlgorithmSpecified
public boolean isChecksumAlgorithmSpecified() -
unsetChecksumAlgorithm
public void unsetChecksumAlgorithm() -
getCreateDate
-
setCreateDate
-
isCreateDateSpecified
public boolean isCreateDateSpecified() -
unsetCreateDate
public void unsetCreateDate() -
getDescription
-
setDescription
-
isDescriptionSpecified
public boolean isDescriptionSpecified() -
unsetDescription
public void unsetDescription() -
getId
-
setId
-
isIdSpecified
public boolean isIdSpecified() -
unsetId
public void unsetId() -
getModifyDate
-
setModifyDate
-
isModifyDateSpecified
public boolean isModifyDateSpecified() -
unsetModifyDate
public void unsetModifyDate() -
getName
-
setName
-
isNameSpecified
public boolean isNameSpecified() -
unsetName
public void unsetName() -
getParentId
-
setParentId
-
isParentIdSpecified
public boolean isParentIdSpecified() -
unsetParentId
public void unsetParentId() -
getStorageRepositoryId
-
setStorageRepositoryId
-
isStorageRepositoryIdSpecified
public boolean isStorageRepositoryIdSpecified() -
unsetStorageRepositoryId
public void unsetStorageRepositoryId() -
getTypeId
-
setTypeId
-
isTypeIdSpecified
public boolean isTypeIdSpecified() -
unsetTypeId
public void unsetTypeId() -
getUnits
-
setUnits
-
isUnitsSpecified
public boolean isUnitsSpecified() -
unsetUnits
public void unsetUnits() -
getUuid
-
setUuid
-
isUuidSpecified
public boolean isUuidSpecified() -
unsetUuid
public void unsetUuid() -
getBlockDeviceCount
-
setBlockDeviceCount
-
getCoalescedDiskImageCount
-
setCoalescedDiskImageCount
-
getSoftwareReferenceCount
-
setSoftwareReferenceCount
-
getStorageGroupCount
-
setStorageGroupCount
-
asService
-
service
-
service
-