Class Software
java.lang.Object
com.softlayer.api.Type
com.softlayer.api.service.Entity
com.softlayer.api.service.virtual.disk.image.Software
@ApiType("SoftLayer_Virtual_Disk_Image_Software") public class Software extends Entity
A SoftLayer_Virtual_Disk_Image_Software record connects a computing instance's virtual disk images with software records. This can be useful if a disk image is directly associated with software such as operating systems.
- See Also:
- SoftLayer_Virtual_Disk_Image_Software
-
Nested Class Summary
Nested Classes Modifier and Type Class Description static classSoftware.Mask -
Field Summary
Fields Modifier and Type Field Description protected ImagediskImageThe virtual disk image that is associated with software.protected LongidThe unique identifier of a virtual disk image to software relationship.protected booleanidSpecifiedprotected LongpasswordCountA count of username/Password pairs used for access to a Software Installation.protected List<Password>passwordsUsername/Password pairs used for access to a Software Installation.protected DescriptionsoftwareDescriptionThe software associated with a virtual disk image.protected LongsoftwareDescriptionIdThe unique identifier of the software that a virtual disk image is associated with.protected booleansoftwareDescriptionIdSpecifiedFields inherited from class com.softlayer.api.Type
unknownProperties -
Constructor Summary
Constructors Constructor Description Software() -
Method Summary
Modifier and Type Method Description ImagegetDiskImage()LonggetId()LonggetPasswordCount()List<Password>getPasswords()DescriptiongetSoftwareDescription()LonggetSoftwareDescriptionId()booleanisIdSpecified()booleanisSoftwareDescriptionIdSpecified()voidsetDiskImage(Image diskImage)voidsetId(Long id)voidsetPasswordCount(Long passwordCount)voidsetSoftwareDescription(Description softwareDescription)voidsetSoftwareDescriptionId(Long softwareDescriptionId)voidunsetId()voidunsetSoftwareDescriptionId()Methods inherited from class com.softlayer.api.Type
getUnknownProperties, setUnknownProperties
-
Field Details
-
diskImage
The virtual disk image that is associated with software. -
passwords
Username/Password pairs used for access to a Software Installation. -
softwareDescription
The software associated with a virtual disk image. -
id
The unique identifier of a virtual disk image to software relationship. -
idSpecified
protected boolean idSpecified -
softwareDescriptionId
The unique identifier of the software that a virtual disk image is associated with. -
softwareDescriptionIdSpecified
protected boolean softwareDescriptionIdSpecified -
passwordCount
A count of username/Password pairs used for access to a Software Installation.
-
-
Constructor Details
-
Software
public Software()
-
-
Method Details
-
getDiskImage
-
setDiskImage
-
getPasswords
-
getSoftwareDescription
-
setSoftwareDescription
-
getId
-
setId
-
isIdSpecified
public boolean isIdSpecified() -
unsetId
public void unsetId() -
getSoftwareDescriptionId
-
setSoftwareDescriptionId
-
isSoftwareDescriptionIdSpecified
public boolean isSoftwareDescriptionIdSpecified() -
unsetSoftwareDescriptionId
public void unsetSoftwareDescriptionId() -
getPasswordCount
-
setPasswordCount
-