Uses of Class
com.softlayer.api.service.virtual.guest.Attribute
| Package | Description |
|---|---|
| com.softlayer.api.service.virtual | |
| com.softlayer.api.service.virtual.guest.attribute |
-
Uses of Attribute in com.softlayer.api.service.virtual
Fields in com.softlayer.api.service.virtual declared as Attribute Modifier and Type Field Description protected AttributeGuest. transientWebhookURIThe endpoint used to notify customers their transient guest is terminating.Fields in com.softlayer.api.service.virtual with type parameters of type Attribute Modifier and Type Field Description protected List<Attribute>Guest. attributesprotected List<Attribute>Guest. userDataA base64 encoded string containing custom user data for a Cloud Computing Instance order.Methods in com.softlayer.api.service.virtual that return Attribute Modifier and Type Method Description AttributeGuest. getTransientWebhookURI()AttributeGuest.Service. getTransientWebhookURI()The endpoint used to notify customers their transient guest is terminating.Methods in com.softlayer.api.service.virtual that return types with arguments of type Attribute Modifier and Type Method Description List<Attribute>Guest. getAttributes()List<Attribute>Guest.Service. getAttributes()Future<List<Attribute>>Guest.ServiceAsync. getAttributes()Async version ofGuest.Service.getAttributes()Future<Attribute>Guest.ServiceAsync. getTransientWebhookURI()Async version ofGuest.Service.getTransientWebhookURI()List<Attribute>Guest. getUserData()List<Attribute>Guest.Service. getUserData()A base64 encoded string containing custom user data for a Cloud Computing Instance order.Future<List<Attribute>>Guest.ServiceAsync. getUserData()Async version ofGuest.Service.getUserData()Methods in com.softlayer.api.service.virtual with parameters of type Attribute Modifier and Type Method Description voidGuest. setTransientWebhookURI(Attribute transientWebhookURI)Method parameters in com.softlayer.api.service.virtual with type arguments of type Attribute Modifier and Type Method Description Future<?>Guest.ServiceAsync. getAttributes(ResponseHandler<List<Attribute>> callback)Async callback version ofGuest.Service.getAttributes()Future<?>Guest.ServiceAsync. getTransientWebhookURI(ResponseHandler<Attribute> callback)Async callback version ofGuest.Service.getTransientWebhookURI()Future<?>Guest.ServiceAsync. getUserData(ResponseHandler<List<Attribute>> callback)Async callback version ofGuest.Service.getUserData() -
Uses of Attribute in com.softlayer.api.service.virtual.guest.attribute
Subclasses of Attribute in com.softlayer.api.service.virtual.guest.attribute Modifier and Type Class Description classUserData