Interface Rule.ServiceAsync
- All Superinterfaces:
Maskable,ResultLimitable,ServiceAsync
- Enclosing class:
- Rule
public static interface Rule.ServiceAsync extends ServiceAsync
-
Method Summary
Modifier and Type Method Description Future<List<Rule>>getAllObjects()Async version ofRule.Service.getAllObjects()Future<?>getAllObjects(ResponseHandler<List<Rule>> callback)Future<Rule>getObject()Async version ofRule.Service.getObject()Future<?>getObject(ResponseHandler<Rule> callback)voidsetMask(Rule.Mask mask)Rule.MaskwithMask()Use the existing mask on this service or create it if not presentRule.MaskwithNewMask()Overwrite the existing mask on this service with a new one and return itMethods inherited from interface com.softlayer.api.ResultLimitable
getLastResponseTotalItemCount, getResultLimit, setResultLimit
-
Method Details
-
withNewMask
Rule.Mask withNewMask()Description copied from interface:MaskableOverwrite the existing mask on this service with a new one and return it- Specified by:
withNewMaskin interfaceMaskable
-
withMask
Rule.Mask withMask()Description copied from interface:MaskableUse the existing mask on this service or create it if not present -
setMask
-
getAllObjects
Async version ofRule.Service.getAllObjects() -
getAllObjects
-
getObject
Async version ofRule.Service.getObject() -
getObject
-