Interface Order.ServiceAsync
- All Superinterfaces:
Maskable,ResultLimitable,ServiceAsync
- Enclosing class:
- Order
public static interface Order.ServiceAsync extends ServiceAsync
-
Method Summary
Modifier and Type Method Description Future<Response>placeWorkspaceOrder(Container orderContainer)Future<?>placeWorkspaceOrder(Container orderContainer, ResponseHandler<Response> callback)voidsetMask(Order.Mask mask)Future<Response>verifyWorkspaceOrder(Container orderContainer)Future<?>verifyWorkspaceOrder(Container orderContainer, ResponseHandler<Response> callback)Order.MaskwithMask()Use the existing mask on this service or create it if not presentOrder.MaskwithNewMask()Overwrite the existing mask on this service with a new one and return itMethods inherited from interface com.softlayer.api.ResultLimitable
getLastResponseTotalItemCount, getResultLimit, setResultLimit
-
Method Details
-
withNewMask
Order.Mask withNewMask()Description copied from interface:MaskableOverwrite the existing mask on this service with a new one and return it- Specified by:
withNewMaskin interfaceMaskable
-
withMask
Order.Mask withMask()Description copied from interface:MaskableUse the existing mask on this service or create it if not present -
setMask
-
placeWorkspaceOrder
-
placeWorkspaceOrder
-
verifyWorkspaceOrder
-
verifyWorkspaceOrder
-