Class Order
java.lang.Object
com.softlayer.api.Type
com.softlayer.api.service.Entity
com.softlayer.api.service.container.product.Order
- Direct Known Subclasses:
AsAService,AsAService,Binding,Certificate,Cloud,Cluster,Controller,Dedicated,DedicatedHost,Delivery,Enterprise,External,Firewall,Global,Hub,Image,Interconnect,Ipsec,Iscsi,License,LoadBalancer,Modification,MultiConfiguration,Nas,NewCustomerSetup,Object,OrderService,Package,PerformanceStorage,Plugin,Registration,Replication,Request,Request,Reseller,ReservedCapacity,Server,SnapshotSpace,SnapshotSpace,Subnet,Support,Upgrade,Vault,Virtual,Vlan
@ApiType("SoftLayer_Container_Product_Order") public class Order extends Entity
This is the datatype that needs to be populated and sent to SoftLayer_Product_Order::placeOrder. This datatype has everything required to place an order with SoftLayer.
- See Also:
- SoftLayer_Container_Product_Order
-
Nested Class Summary
Nested Classes Modifier and Type Class Description static classOrder.Mask -
Field Summary
Fields Modifier and Type Field Description protected BooleanbigDataOrderFlagFlag for identifying an order for Big Data Deployment.protected booleanbigDataOrderFlagSpecifiedprotected InformationbillingInformationBilling Information associated with an order.protected booleanbillingInformationSpecifiedprotected LongbillingOrderItemIdThis is the ID of the [[SoftLayer_Billing_Order_Item]] of this configuration/container.protected booleanbillingOrderItemIdSpecifiedprotected StringcancelUrlThe URL to which PayPal redirects browser after checkout has been canceled before completion of a payment.protected booleancancelUrlSpecifiedprotected StringcontainerIdentifierUser-specified description to identify a particular order container.protected booleancontainerIdentifierSpecifiedprotected StringcontainerSplHashThis hash is internally-generated and is used to for tracking order containers.protected booleancontainerSplHashSpecifiedprotected StringcurrencyShortNameThe currency type chosen at checkout.protected booleancurrencyShortNameSpecifiedprotected StringdeviceFingerprintIdDevice Fingerprint Identifier - Optional.protected booleandeviceFingerprintIdSpecifiedprotected StringdisplayLayerSessionIdThis is the configuration identifier for tracking orders on the HTML order forms.protected booleandisplayLayerSessionIdSpecifiedprotected BooleanextendedHardwareTestingprotected booleanextendedHardwareTestingSpecifiedprotected PriceflexibleCreditProgramPriceThe [[SoftLayer_Product_Item_Price]] for the Flexible Credit Program discount.protected booleanflexibleCreditProgramPriceSpecifiedprotected BooleangdprConsentFlagThis flag indicates that the customer consented to the GDPR terms for the quote.protected booleangdprConsentFlagSpecifiedprotected List<Hardware>hardwareFor orders that contain servers (bare metal, virtual server, big data, etc.), the hardware property is required.protected booleanhardwareSpecifiedprotected StringimageTemplateGlobalIdentifierAn optional virtual disk image template identifier to be used as an installation base for a computing instance orderprotected booleanimageTemplateGlobalIdentifierSpecifiedprotected LongimageTemplateIdAn optional virtual disk image template identifier to be used as an installation base for a computing instance orderprotected booleanimageTemplateIdSpecifiedprotected LongisManagedOrderFlag to identify a "managed" order.protected booleanisManagedOrderSpecifiedprotected List<Answer>itemCategoryQuestionAnswersThe collection of [[SoftLayer_Container_Product_Item_Category_Question_Answer]] for any product category that has additional questions requiring user input.protected booleanitemCategoryQuestionAnswersSpecifiedprotected StringlocationThe [[SoftLayer_Location_Region]] keyname or specific [[SoftLayer_Location_Datacenter]] id where the order should be provisioned.protected LocationlocationObjectThis [[SoftLayer_Location]] object will be determined from thelocationproperty and will be returned in the order verification or placement response.protected booleanlocationObjectSpecifiedprotected booleanlocationSpecifiedprotected StringmessageA generic message about the order.protected booleanmessageSpecifiedprotected List<Order>orderContainersOrders may contain an array of configurations.protected booleanorderContainersSpecifiedprotected List<String>orderHostnamesThis is deprecated and does not do anything.protected booleanorderHostnamesSpecifiedprotected List<Exception>orderVerificationExceptionsCollection of exceptions resulting from the verification of the order.protected booleanorderVerificationExceptionsSpecifiedprotected LongpackageIdThe [[SoftLayer_Product_Package]] id for an order container.protected booleanpackageIdSpecifiedprotected StringpaymentTypeThe Payment Type is Optional.protected booleanpaymentTypeSpecifiedprotected BigDecimalpostTaxRecurringThe post-tax recurring charge for the order.protected BigDecimalpostTaxRecurringHourlyThe post-tax recurring hourly charge for the order.protected booleanpostTaxRecurringHourlySpecifiedprotected BigDecimalpostTaxRecurringMonthlyThe post-tax recurring monthly charge for the order.protected booleanpostTaxRecurringMonthlySpecifiedprotected booleanpostTaxRecurringSpecifiedprotected BigDecimalpostTaxSetupThe post-tax setup fees of the order.protected booleanpostTaxSetupSpecifiedprotected EventpresaleEventIf there are any presale events available for an order, this value will be populated.protected booleanpresaleEventSpecifiedprotected LongpresetIdA preset configuration id for the package.protected booleanpresetIdSpecifiedprotected BigDecimalpreTaxRecurringThe pre-tax recurring total of the order.protected BigDecimalpreTaxRecurringHourlyThe pre-tax hourly recurring total of the order.protected booleanpreTaxRecurringHourlySpecifiedprotected BigDecimalpreTaxRecurringMonthlyThe pre-tax monthly recurring total of the order.protected booleanpreTaxRecurringMonthlySpecifiedprotected booleanpreTaxRecurringSpecifiedprotected BigDecimalpreTaxSetupThe pre-tax setup fee total of the order.protected booleanpreTaxSetupSpecifiedprotected List<Price>pricesThis is a collection of [[SoftLayer_Product_Item_Price]] objects.protected booleanpricesSpecifiedprotected LongprimaryDiskPartitionIdThe id of a [[SoftLayer_Hardware_Component_Partition_Template]].protected booleanprimaryDiskPartitionIdSpecifiedprotected List<String>prioritiesPriorities to set on replication set servers.protected booleanprioritiesSpecifiedprotected BooleanprivateCloudOrderFlagFlag for identifying a container as Virtual Server (Private Node).protected booleanprivateCloudOrderFlagSpecifiedprotected StringprivateCloudOrderTypeType of Virtual Server (Private Node) order.protected booleanprivateCloudOrderTypeSpecifiedprotected StringpromotionCodeOptional promotion code for an order.protected booleanpromotionCodeSpecifiedprotected List<Property>propertiesGeneric properties.protected booleanpropertiesSpecifiedprotected BigDecimalproratedInitialChargeThe Prorated Initial Charge plus the balance on the account.protected booleanproratedInitialChargeSpecifiedprotected BigDecimalproratedOrderTotalThis is the same as the proratedInitialCharge, except the balance on the account is ignored.protected booleanproratedOrderTotalSpecifiedprotected List<String>provisionScriptsThe URLs for scripts to execute on their respective servers after they have been provisioned.protected booleanprovisionScriptsSpecifiedprotected LongquantityThe quantity of the item being orderedprotected booleanquantitySpecifiedprotected StringquoteNameA custom name to be assigned to the quote.protected booleanquoteNameSpecifiedprotected StringregionalGroupSpecifying a regional group name allows you to not worry about placing your server or service at a specific datacenter, but to any datacenter within that regional group.protected booleanregionalGroupSpecifiedprotected LongresourceGroupIdAn optional resource group identifier specifying the resource group to attach the order toprotected booleanresourceGroupIdSpecifiedprotected StringresourceGroupNameThis variable specifies the name of the resource group the server configuration belongs to.protected booleanresourceGroupNameSpecifiedprotected LongresourceGroupTemplateIdAn optional resource group template identifier to be used as a deployment base for a Virtual Server (Private Node) order.protected booleanresourceGroupTemplateIdSpecifiedprotected StringreturnUrlThe URL to which PayPal redirects browser after a payment is completed.protected booleanreturnUrlSpecifiedprotected BooleansendQuoteEmailFlagThis flag indicates that the quote should be sent to the email address associated with the account or order.protected booleansendQuoteEmailFlagSpecifiedprotected LongserverCoreCountThe number of cores for the server being ordered.protected booleanserverCoreCountSpecifiedprotected StringserviceTokenThe token of a requesting service.protected booleanserviceTokenSpecifiedprotected LongsourceVirtualGuestIdAn optional computing instance identifier to be used as an installation base for a computing instance orderprotected booleansourceVirtualGuestIdSpecifiedprotected List<SshKeys>sshKeysThe containers which hold SoftLayer_Security_Ssh_Key IDs to add to their respective servers.protected booleansshKeysSpecifiedprotected LongstepIdAn optional parameter for step-based order processing.protected booleanstepIdSpecifiedprotected List<Group>storageGroups
For orders that want to add storage groups such as RAID across multiple disks, simply add [[SoftLayer_Container_Product_Order_Storage_Group]] objects to this array.protected booleanstorageGroupsSpecifiedprotected StringtaxCacheHashThe order container may not contain the final tax rates when it is returned from [[SoftLayer_Product_Order/verifyOrder|verifyOrder]].protected booleantaxCacheHashSpecifiedprotected BooleantaxCompletedFlagFlag to indicate if the order container has the final tax rates for the order.protected booleantaxCompletedFlagSpecifiedprotected PricetechIncubatorItemPriceThe SoftLayer_Product_Item_Price for the Tech Incubator discount.protected booleantechIncubatorItemPriceSpecifiedprotected BigDecimaltotalRecurringTaxThe total tax portion of the recurring fees.protected booleantotalRecurringTaxSpecifiedprotected BigDecimaltotalSetupTaxThe tax amount of the setup fees.protected booleantotalSetupTaxSpecifiedprotected List<Price>usagePricesThis is a collection of [[SoftLayer_Product_Item_Price]] objects which will be used when the service offering being ordered generates usage.protected booleanusagePricesSpecifiedprotected BooleanuseHourlyPricingAn optional flag to use hourly pricing instead of standard monthly pricing.protected booleanuseHourlyPricingSpecifiedprotected List<Guest>virtualGuestsFor virtual guest (virtual server) orders, this property is required if you did not specify data in thehardwareproperty.protected booleanvirtualGuestsSpecified -
Constructor Summary
Constructors Constructor Description Order() -
Method Summary
-
Field Details
-
bigDataOrderFlag
Flag for identifying an order for Big Data Deployment. -
bigDataOrderFlagSpecified
protected boolean bigDataOrderFlagSpecified -
billingInformation
Billing Information associated with an order. For existing customers this information is completely ignored. Do not send this information for existing customers. -
billingInformationSpecified
protected boolean billingInformationSpecified -
billingOrderItemId
This is the ID of the [[SoftLayer_Billing_Order_Item]] of this configuration/container. It is used for rebuilding an order container from a quote and is set automatically. -
billingOrderItemIdSpecified
protected boolean billingOrderItemIdSpecified -
cancelUrl
The URL to which PayPal redirects browser after checkout has been canceled before completion of a payment. -
cancelUrlSpecified
protected boolean cancelUrlSpecified -
containerIdentifier
User-specified description to identify a particular order container. This is useful if you have a multi-configuration order (multipleorderContainers) and you want to be able to easily determine one from another. Populating this value may be helpful if an exception is thrown when placing an order and it's tied to a specific order container. -
containerIdentifierSpecified
protected boolean containerIdentifierSpecified -
containerSplHash
This hash is internally-generated and is used to for tracking order containers. -
containerSplHashSpecified
protected boolean containerSplHashSpecified -
currencyShortName
The currency type chosen at checkout. -
currencyShortNameSpecified
protected boolean currencyShortNameSpecified -
deviceFingerprintId
Device Fingerprint Identifier - Optional. -
deviceFingerprintIdSpecified
protected boolean deviceFingerprintIdSpecified -
displayLayerSessionId
This is the configuration identifier for tracking orders on the HTML order forms. -
displayLayerSessionIdSpecified
protected boolean displayLayerSessionIdSpecified -
extendedHardwareTesting
-
extendedHardwareTestingSpecified
protected boolean extendedHardwareTestingSpecified -
flexibleCreditProgramPrice
The [[SoftLayer_Product_Item_Price]] for the Flexible Credit Program discount. TheoneTimeFeefield contains the calculated discount being applied to the order. -
flexibleCreditProgramPriceSpecified
protected boolean flexibleCreditProgramPriceSpecified -
gdprConsentFlag
This flag indicates that the customer consented to the GDPR terms for the quote. -
gdprConsentFlagSpecified
protected boolean gdprConsentFlagSpecified -
hardware
For orders that contain servers (bare metal, virtual server, big data, etc.), the hardware property is required. This property is an array of [[SoftLayer_Hardware]] objects. Thehostnameanddomainproperties are required for each hardware object. Note that virtual server ([[SoftLayer_Container_Product_Order_Virtual_Guest]]) orders may populate this field instead of thevirtualGuestsproperty. -
hardwareSpecified
protected boolean hardwareSpecified -
imageTemplateGlobalIdentifier
An optional virtual disk image template identifier to be used as an installation base for a computing instance order -
imageTemplateGlobalIdentifierSpecified
protected boolean imageTemplateGlobalIdentifierSpecified -
imageTemplateId
An optional virtual disk image template identifier to be used as an installation base for a computing instance order -
imageTemplateIdSpecified
protected boolean imageTemplateIdSpecified -
isManagedOrder
Flag to identify a "managed" order. This value is set internally. -
isManagedOrderSpecified
protected boolean isManagedOrderSpecified -
itemCategoryQuestionAnswers
The collection of [[SoftLayer_Container_Product_Item_Category_Question_Answer]] for any product category that has additional questions requiring user input. -
itemCategoryQuestionAnswersSpecified
protected boolean itemCategoryQuestionAnswersSpecified -
location
The [[SoftLayer_Location_Region]] keyname or specific [[SoftLayer_Location_Datacenter]] id where the order should be provisioned. If this value is provided and theregionalGroupproperty is also specified, an exception will be thrown indicating that only 1 is allowed. -
locationSpecified
protected boolean locationSpecified -
locationObject
This [[SoftLayer_Location]] object will be determined from thelocationproperty and will be returned in the order verification or placement response. Any value specified here will get overwritten by the verification process. -
locationObjectSpecified
protected boolean locationObjectSpecified -
message
A generic message about the order. Does not need to be sent in with any orders. -
messageSpecified
protected boolean messageSpecified -
orderContainers
Orders may contain an array of configurations. Populating this property allows you to purchase multiple configurations within a single order. Each order container will have its own individual settings independent of the other order containers. For example, it is possible to order a bare metal server in one configuration and a virtual server in another.
IforderContainersis populated on the base order container, most of the configuration-specific properties are ignored on the base container. For example,prices,locationandpackageIdwill be ignored on the base container, but since thebillingInformationis a property that's not specific to a single order container (but the order as a whole) it must be populated on the base container. -
orderContainersSpecified
protected boolean orderContainersSpecified -
orderHostnames
This is deprecated and does not do anything. -
orderHostnamesSpecified
protected boolean orderHostnamesSpecified -
orderVerificationExceptions
Collection of exceptions resulting from the verification of the order. This value is set internally and is not required for end users when placing an order. When placing API orders, users can use this value to determine the container-specific exception that was thrown. -
orderVerificationExceptionsSpecified
protected boolean orderVerificationExceptionsSpecified -
packageId
The [[SoftLayer_Product_Package]] id for an order container. This is required to place an order. -
packageIdSpecified
protected boolean packageIdSpecified -
paymentType
The Payment Type is Optional. If nothing is sent in, then the normal method of payment will be used. For paypal customers, this means a paypalToken will be returned in the receipt. This token is to be used on the paypal website to complete the order. For Credit Card customers, the card on file in our system will be used to make an initial authorization. To force the order to use a payment type, use one of the following: CARD_ON_FILE or PAYPAL -
paymentTypeSpecified
protected boolean paymentTypeSpecified -
postTaxRecurring
The post-tax recurring charge for the order. This is the sum of preTaxRecurring + totalRecurringTax. -
postTaxRecurringSpecified
protected boolean postTaxRecurringSpecified -
postTaxRecurringHourly
The post-tax recurring hourly charge for the order. Since taxes are not calculated for hourly orders, this value will be the same as preTaxRecurringHourly. -
postTaxRecurringHourlySpecified
protected boolean postTaxRecurringHourlySpecified -
postTaxRecurringMonthly
The post-tax recurring monthly charge for the order. This is the sum of preTaxRecurringMonthly + totalRecurringTax. -
postTaxRecurringMonthlySpecified
protected boolean postTaxRecurringMonthlySpecified -
postTaxSetup
The post-tax setup fees of the order. This is the sum of preTaxSetup + totalSetupTax; -
postTaxSetupSpecified
protected boolean postTaxSetupSpecified -
preTaxRecurring
The pre-tax recurring total of the order. If there are mixed monthly and hourly prices on the order, this will be the sum of preTaxRecurringHourly and preTaxRecurringMonthly. -
preTaxRecurringSpecified
protected boolean preTaxRecurringSpecified -
preTaxRecurringHourly
The pre-tax hourly recurring total of the order. If there are only monthly prices on the order, this value will be 0. -
preTaxRecurringHourlySpecified
protected boolean preTaxRecurringHourlySpecified -
preTaxRecurringMonthly
The pre-tax monthly recurring total of the order. If there are only hourly prices on the order, this value will be 0. -
preTaxRecurringMonthlySpecified
protected boolean preTaxRecurringMonthlySpecified -
preTaxSetup
The pre-tax setup fee total of the order. -
preTaxSetupSpecified
protected boolean preTaxSetupSpecified -
presaleEvent
If there are any presale events available for an order, this value will be populated. It is set internally and is not required for end users when placing an order. See [[SoftLayer_Sales_Presale_Event]] for more info. -
presaleEventSpecified
protected boolean presaleEventSpecified -
presetId
A preset configuration id for the package. Is required if not submitting any prices. -
presetIdSpecified
protected boolean presetIdSpecified -
prices
This is a collection of [[SoftLayer_Product_Item_Price]] objects. The only required property to populate for an item price object when ordering is itsid- all other supplied information about the price (e.g., recurringFee, setupFee, etc.) will be ignored. Unless the [[SoftLayer_Product_Package]] associated with the order allows for preset prices, this property is required to place an order. -
pricesSpecified
protected boolean pricesSpecified -
primaryDiskPartitionId
The id of a [[SoftLayer_Hardware_Component_Partition_Template]]. This property is optional. If no partition template is provided, a default will be used according to the operating system chosen with the order. Using the [[SoftLayer_Hardware_Component_Partition_OperatingSystem]] service, getPartitionTemplates will return those available for the particular operating system. -
primaryDiskPartitionIdSpecified
protected boolean primaryDiskPartitionIdSpecified -
priorities
Priorities to set on replication set servers. -
prioritiesSpecified
protected boolean prioritiesSpecified -
privateCloudOrderFlag
Flag for identifying a container as Virtual Server (Private Node). -
privateCloudOrderFlagSpecified
protected boolean privateCloudOrderFlagSpecified -
privateCloudOrderType
Type of Virtual Server (Private Node) order. Potential values: INITIAL, ADDHOST, ADDIPS, ADDZONE -
privateCloudOrderTypeSpecified
protected boolean privateCloudOrderTypeSpecified -
promotionCode
Optional promotion code for an order. -
promotionCodeSpecified
protected boolean promotionCodeSpecified -
properties
Generic properties. -
propertiesSpecified
protected boolean propertiesSpecified -
proratedInitialCharge
The Prorated Initial Charge plus the balance on the account. Only the recurring fees are prorated. Here's how the calculation works: We take the postTaxRecurring value and we prorate it based on the time between now and the next bill date for this account. After this, we add in the setup fee since this is not prorated. Then, if there is a balance on the account, we add that to the account. In the event that there is a credit balance on the account, we will subtract this amount from the order total. If the credit balance on the account is greater than the prorated initial charge, the order will go through without a charge to the credit card on the account or requiring a paypal payment. The credit on the account will be reduced by the order total, and the order will await approval from sales, as normal. If there is a pending order already in the system, We will ignore the balance on the account completely, in the calculation of the initial charge. This is to protect against two orders coming into the system and getting the benefit of a credit balance, or worse, both orders being charged the order amount + the balance on the account. -
proratedInitialChargeSpecified
protected boolean proratedInitialChargeSpecified -
proratedOrderTotal
This is the same as the proratedInitialCharge, except the balance on the account is ignored. This is the prorated total amount of the order. -
proratedOrderTotalSpecified
protected boolean proratedOrderTotalSpecified -
provisionScripts
The URLs for scripts to execute on their respective servers after they have been provisioned. Provision scripts are not available for Microsoft Windows servers. -
provisionScriptsSpecified
protected boolean provisionScriptsSpecified -
quantity
The quantity of the item being ordered -
quantitySpecified
protected boolean quantitySpecified -
quoteName
A custom name to be assigned to the quote. -
quoteNameSpecified
protected boolean quoteNameSpecified -
regionalGroup
Specifying a regional group name allows you to not worry about placing your server or service at a specific datacenter, but to any datacenter within that regional group. See [[SoftLayer_Location_Group_Regional]] to get a list of available regional group names.
locationandregionalGroupare mutually exclusive on an order container. If both location and regionalGroup are provided, an exception will be thrown indicating that only 1 is allowed.
If a regional group is provided and VLANs are specified (within thehardwareorvirtualGuestsproperties), we will use the datacenter where the VLANs are located. If no VLANs are specified, we will use the preferred datacenter on the regional group object. -
regionalGroupSpecified
protected boolean regionalGroupSpecified -
resourceGroupId
An optional resource group identifier specifying the resource group to attach the order to -
resourceGroupIdSpecified
protected boolean resourceGroupIdSpecified -
resourceGroupName
This variable specifies the name of the resource group the server configuration belongs to. For MongoDB Replica sets, it would be the replica set name. -
resourceGroupNameSpecified
protected boolean resourceGroupNameSpecified -
resourceGroupTemplateId
An optional resource group template identifier to be used as a deployment base for a Virtual Server (Private Node) order. -
resourceGroupTemplateIdSpecified
protected boolean resourceGroupTemplateIdSpecified -
returnUrl
The URL to which PayPal redirects browser after a payment is completed. -
returnUrlSpecified
protected boolean returnUrlSpecified -
sendQuoteEmailFlag
This flag indicates that the quote should be sent to the email address associated with the account or order. -
sendQuoteEmailFlagSpecified
protected boolean sendQuoteEmailFlagSpecified -
serverCoreCount
The number of cores for the server being ordered. This value is set internally. -
serverCoreCountSpecified
protected boolean serverCoreCountSpecified -
serviceToken
The token of a requesting service. Do not set. -
serviceTokenSpecified
protected boolean serviceTokenSpecified -
sourceVirtualGuestId
An optional computing instance identifier to be used as an installation base for a computing instance order -
sourceVirtualGuestIdSpecified
protected boolean sourceVirtualGuestIdSpecified -
sshKeys
The containers which hold SoftLayer_Security_Ssh_Key IDs to add to their respective servers. The order of containers passed in needs to match the order they are assigned to either hardware or virtualGuests. SSH Keys will not be assigned for servers with Microsoft Windows. -
sshKeysSpecified
protected boolean sshKeysSpecified -
stepId
An optional parameter for step-based order processing. -
stepIdSpecified
protected boolean stepIdSpecified -
storageGroups
For orders that want to add storage groups such as RAID across multiple disks, simply add [[SoftLayer_Container_Product_Order_Storage_Group]] objects to this array. Storage groups will only be used if the 'RAID' disk controller price is selected. Any other disk controller types will ignore the storage groups set here.
The first storage group in this array will be considered the primary storage group, which is used for the OS. Any other storage groups will act as data storage.
-
storageGroupsSpecified
protected boolean storageGroupsSpecified -
taxCacheHash
The order container may not contain the final tax rates when it is returned from [[SoftLayer_Product_Order/verifyOrder|verifyOrder]]. This hash will facilitate checking if the tax rates have finished being calculated and retrieving the accurate tax rate values. -
taxCacheHashSpecified
protected boolean taxCacheHashSpecified -
taxCompletedFlag
Flag to indicate if the order container has the final tax rates for the order. Some tax rates are calculated in the background because they take longer, and they might not be finished when the container is returned from [[SoftLayer_Product_Order/verifyOrder|verifyOrder]]. -
taxCompletedFlagSpecified
protected boolean taxCompletedFlagSpecified -
techIncubatorItemPrice
The SoftLayer_Product_Item_Price for the Tech Incubator discount. The oneTimeFee field contain the calculated discount being applied to the order. -
techIncubatorItemPriceSpecified
protected boolean techIncubatorItemPriceSpecified -
totalRecurringTax
The total tax portion of the recurring fees. -
totalRecurringTaxSpecified
protected boolean totalRecurringTaxSpecified -
totalSetupTax
The tax amount of the setup fees. -
totalSetupTaxSpecified
protected boolean totalSetupTaxSpecified -
usagePrices
This is a collection of [[SoftLayer_Product_Item_Price]] objects which will be used when the service offering being ordered generates usage. This is a read-only property. Setting this property will not change the order. -
usagePricesSpecified
protected boolean usagePricesSpecified -
useHourlyPricing
An optional flag to use hourly pricing instead of standard monthly pricing. -
useHourlyPricingSpecified
protected boolean useHourlyPricingSpecified -
virtualGuests
For virtual guest (virtual server) orders, this property is required if you did not specify data in thehardwareproperty. This is an array of [[SoftLayer_Virtual_Guest]] objects. Thehostnameanddomainproperties are required for each virtual guest object. There is no need to specify data in this property and thehardwareproperty - only one is required for virtual server orders. -
virtualGuestsSpecified
protected boolean virtualGuestsSpecified
-
-
Constructor Details
-
Order
public Order()
-
-
Method Details
-
getBigDataOrderFlag
-
setBigDataOrderFlag
-
isBigDataOrderFlagSpecified
public boolean isBigDataOrderFlagSpecified() -
unsetBigDataOrderFlag
public void unsetBigDataOrderFlag() -
getBillingInformation
-
setBillingInformation
-
isBillingInformationSpecified
public boolean isBillingInformationSpecified() -
unsetBillingInformation
public void unsetBillingInformation() -
getBillingOrderItemId
-
setBillingOrderItemId
-
isBillingOrderItemIdSpecified
public boolean isBillingOrderItemIdSpecified() -
unsetBillingOrderItemId
public void unsetBillingOrderItemId() -
getCancelUrl
-
setCancelUrl
-
isCancelUrlSpecified
public boolean isCancelUrlSpecified() -
unsetCancelUrl
public void unsetCancelUrl() -
getContainerIdentifier
-
setContainerIdentifier
-
isContainerIdentifierSpecified
public boolean isContainerIdentifierSpecified() -
unsetContainerIdentifier
public void unsetContainerIdentifier() -
getContainerSplHash
-
setContainerSplHash
-
isContainerSplHashSpecified
public boolean isContainerSplHashSpecified() -
unsetContainerSplHash
public void unsetContainerSplHash() -
getCurrencyShortName
-
setCurrencyShortName
-
isCurrencyShortNameSpecified
public boolean isCurrencyShortNameSpecified() -
unsetCurrencyShortName
public void unsetCurrencyShortName() -
getDeviceFingerprintId
-
setDeviceFingerprintId
-
isDeviceFingerprintIdSpecified
public boolean isDeviceFingerprintIdSpecified() -
unsetDeviceFingerprintId
public void unsetDeviceFingerprintId() -
getDisplayLayerSessionId
-
setDisplayLayerSessionId
-
isDisplayLayerSessionIdSpecified
public boolean isDisplayLayerSessionIdSpecified() -
unsetDisplayLayerSessionId
public void unsetDisplayLayerSessionId() -
getExtendedHardwareTesting
-
setExtendedHardwareTesting
-
isExtendedHardwareTestingSpecified
public boolean isExtendedHardwareTestingSpecified() -
unsetExtendedHardwareTesting
public void unsetExtendedHardwareTesting() -
getFlexibleCreditProgramPrice
-
setFlexibleCreditProgramPrice
-
isFlexibleCreditProgramPriceSpecified
public boolean isFlexibleCreditProgramPriceSpecified() -
unsetFlexibleCreditProgramPrice
public void unsetFlexibleCreditProgramPrice() -
getGdprConsentFlag
-
setGdprConsentFlag
-
isGdprConsentFlagSpecified
public boolean isGdprConsentFlagSpecified() -
unsetGdprConsentFlag
public void unsetGdprConsentFlag() -
getHardware
-
isHardwareSpecified
public boolean isHardwareSpecified() -
unsetHardware
public void unsetHardware() -
getImageTemplateGlobalIdentifier
-
setImageTemplateGlobalIdentifier
-
isImageTemplateGlobalIdentifierSpecified
public boolean isImageTemplateGlobalIdentifierSpecified() -
unsetImageTemplateGlobalIdentifier
public void unsetImageTemplateGlobalIdentifier() -
getImageTemplateId
-
setImageTemplateId
-
isImageTemplateIdSpecified
public boolean isImageTemplateIdSpecified() -
unsetImageTemplateId
public void unsetImageTemplateId() -
getIsManagedOrder
-
setIsManagedOrder
-
isIsManagedOrderSpecified
public boolean isIsManagedOrderSpecified() -
unsetIsManagedOrder
public void unsetIsManagedOrder() -
getItemCategoryQuestionAnswers
-
isItemCategoryQuestionAnswersSpecified
public boolean isItemCategoryQuestionAnswersSpecified() -
unsetItemCategoryQuestionAnswers
public void unsetItemCategoryQuestionAnswers() -
getLocation
-
setLocation
-
isLocationSpecified
public boolean isLocationSpecified() -
unsetLocation
public void unsetLocation() -
getLocationObject
-
setLocationObject
-
isLocationObjectSpecified
public boolean isLocationObjectSpecified() -
unsetLocationObject
public void unsetLocationObject() -
getMessage
-
setMessage
-
isMessageSpecified
public boolean isMessageSpecified() -
unsetMessage
public void unsetMessage() -
getOrderContainers
-
isOrderContainersSpecified
public boolean isOrderContainersSpecified() -
unsetOrderContainers
public void unsetOrderContainers() -
getOrderHostnames
-
isOrderHostnamesSpecified
public boolean isOrderHostnamesSpecified() -
unsetOrderHostnames
public void unsetOrderHostnames() -
getOrderVerificationExceptions
-
isOrderVerificationExceptionsSpecified
public boolean isOrderVerificationExceptionsSpecified() -
unsetOrderVerificationExceptions
public void unsetOrderVerificationExceptions() -
getPackageId
-
setPackageId
-
isPackageIdSpecified
public boolean isPackageIdSpecified() -
unsetPackageId
public void unsetPackageId() -
getPaymentType
-
setPaymentType
-
isPaymentTypeSpecified
public boolean isPaymentTypeSpecified() -
unsetPaymentType
public void unsetPaymentType() -
getPostTaxRecurring
-
setPostTaxRecurring
-
isPostTaxRecurringSpecified
public boolean isPostTaxRecurringSpecified() -
unsetPostTaxRecurring
public void unsetPostTaxRecurring() -
getPostTaxRecurringHourly
-
setPostTaxRecurringHourly
-
isPostTaxRecurringHourlySpecified
public boolean isPostTaxRecurringHourlySpecified() -
unsetPostTaxRecurringHourly
public void unsetPostTaxRecurringHourly() -
getPostTaxRecurringMonthly
-
setPostTaxRecurringMonthly
-
isPostTaxRecurringMonthlySpecified
public boolean isPostTaxRecurringMonthlySpecified() -
unsetPostTaxRecurringMonthly
public void unsetPostTaxRecurringMonthly() -
getPostTaxSetup
-
setPostTaxSetup
-
isPostTaxSetupSpecified
public boolean isPostTaxSetupSpecified() -
unsetPostTaxSetup
public void unsetPostTaxSetup() -
getPreTaxRecurring
-
setPreTaxRecurring
-
isPreTaxRecurringSpecified
public boolean isPreTaxRecurringSpecified() -
unsetPreTaxRecurring
public void unsetPreTaxRecurring() -
getPreTaxRecurringHourly
-
setPreTaxRecurringHourly
-
isPreTaxRecurringHourlySpecified
public boolean isPreTaxRecurringHourlySpecified() -
unsetPreTaxRecurringHourly
public void unsetPreTaxRecurringHourly() -
getPreTaxRecurringMonthly
-
setPreTaxRecurringMonthly
-
isPreTaxRecurringMonthlySpecified
public boolean isPreTaxRecurringMonthlySpecified() -
unsetPreTaxRecurringMonthly
public void unsetPreTaxRecurringMonthly() -
getPreTaxSetup
-
setPreTaxSetup
-
isPreTaxSetupSpecified
public boolean isPreTaxSetupSpecified() -
unsetPreTaxSetup
public void unsetPreTaxSetup() -
getPresaleEvent
-
setPresaleEvent
-
isPresaleEventSpecified
public boolean isPresaleEventSpecified() -
unsetPresaleEvent
public void unsetPresaleEvent() -
getPresetId
-
setPresetId
-
isPresetIdSpecified
public boolean isPresetIdSpecified() -
unsetPresetId
public void unsetPresetId() -
getPrices
-
isPricesSpecified
public boolean isPricesSpecified() -
unsetPrices
public void unsetPrices() -
getPrimaryDiskPartitionId
-
setPrimaryDiskPartitionId
-
isPrimaryDiskPartitionIdSpecified
public boolean isPrimaryDiskPartitionIdSpecified() -
unsetPrimaryDiskPartitionId
public void unsetPrimaryDiskPartitionId() -
getPriorities
-
isPrioritiesSpecified
public boolean isPrioritiesSpecified() -
unsetPriorities
public void unsetPriorities() -
getPrivateCloudOrderFlag
-
setPrivateCloudOrderFlag
-
isPrivateCloudOrderFlagSpecified
public boolean isPrivateCloudOrderFlagSpecified() -
unsetPrivateCloudOrderFlag
public void unsetPrivateCloudOrderFlag() -
getPrivateCloudOrderType
-
setPrivateCloudOrderType
-
isPrivateCloudOrderTypeSpecified
public boolean isPrivateCloudOrderTypeSpecified() -
unsetPrivateCloudOrderType
public void unsetPrivateCloudOrderType() -
getPromotionCode
-
setPromotionCode
-
isPromotionCodeSpecified
public boolean isPromotionCodeSpecified() -
unsetPromotionCode
public void unsetPromotionCode() -
getProperties
-
isPropertiesSpecified
public boolean isPropertiesSpecified() -
unsetProperties
public void unsetProperties() -
getProratedInitialCharge
-
setProratedInitialCharge
-
isProratedInitialChargeSpecified
public boolean isProratedInitialChargeSpecified() -
unsetProratedInitialCharge
public void unsetProratedInitialCharge() -
getProratedOrderTotal
-
setProratedOrderTotal
-
isProratedOrderTotalSpecified
public boolean isProratedOrderTotalSpecified() -
unsetProratedOrderTotal
public void unsetProratedOrderTotal() -
getProvisionScripts
-
isProvisionScriptsSpecified
public boolean isProvisionScriptsSpecified() -
unsetProvisionScripts
public void unsetProvisionScripts() -
getQuantity
-
setQuantity
-
isQuantitySpecified
public boolean isQuantitySpecified() -
unsetQuantity
public void unsetQuantity() -
getQuoteName
-
setQuoteName
-
isQuoteNameSpecified
public boolean isQuoteNameSpecified() -
unsetQuoteName
public void unsetQuoteName() -
getRegionalGroup
-
setRegionalGroup
-
isRegionalGroupSpecified
public boolean isRegionalGroupSpecified() -
unsetRegionalGroup
public void unsetRegionalGroup() -
getResourceGroupId
-
setResourceGroupId
-
isResourceGroupIdSpecified
public boolean isResourceGroupIdSpecified() -
unsetResourceGroupId
public void unsetResourceGroupId() -
getResourceGroupName
-
setResourceGroupName
-
isResourceGroupNameSpecified
public boolean isResourceGroupNameSpecified() -
unsetResourceGroupName
public void unsetResourceGroupName() -
getResourceGroupTemplateId
-
setResourceGroupTemplateId
-
isResourceGroupTemplateIdSpecified
public boolean isResourceGroupTemplateIdSpecified() -
unsetResourceGroupTemplateId
public void unsetResourceGroupTemplateId() -
getReturnUrl
-
setReturnUrl
-
isReturnUrlSpecified
public boolean isReturnUrlSpecified() -
unsetReturnUrl
public void unsetReturnUrl() -
getSendQuoteEmailFlag
-
setSendQuoteEmailFlag
-
isSendQuoteEmailFlagSpecified
public boolean isSendQuoteEmailFlagSpecified() -
unsetSendQuoteEmailFlag
public void unsetSendQuoteEmailFlag() -
getServerCoreCount
-
setServerCoreCount
-
isServerCoreCountSpecified
public boolean isServerCoreCountSpecified() -
unsetServerCoreCount
public void unsetServerCoreCount() -
getServiceToken
-
setServiceToken
-
isServiceTokenSpecified
public boolean isServiceTokenSpecified() -
unsetServiceToken
public void unsetServiceToken() -
getSourceVirtualGuestId
-
setSourceVirtualGuestId
-
isSourceVirtualGuestIdSpecified
public boolean isSourceVirtualGuestIdSpecified() -
unsetSourceVirtualGuestId
public void unsetSourceVirtualGuestId() -
getSshKeys
-
isSshKeysSpecified
public boolean isSshKeysSpecified() -
unsetSshKeys
public void unsetSshKeys() -
getStepId
-
setStepId
-
isStepIdSpecified
public boolean isStepIdSpecified() -
unsetStepId
public void unsetStepId() -
getStorageGroups
-
isStorageGroupsSpecified
public boolean isStorageGroupsSpecified() -
unsetStorageGroups
public void unsetStorageGroups() -
getTaxCacheHash
-
setTaxCacheHash
-
isTaxCacheHashSpecified
public boolean isTaxCacheHashSpecified() -
unsetTaxCacheHash
public void unsetTaxCacheHash() -
getTaxCompletedFlag
-
setTaxCompletedFlag
-
isTaxCompletedFlagSpecified
public boolean isTaxCompletedFlagSpecified() -
unsetTaxCompletedFlag
public void unsetTaxCompletedFlag() -
getTechIncubatorItemPrice
-
setTechIncubatorItemPrice
-
isTechIncubatorItemPriceSpecified
public boolean isTechIncubatorItemPriceSpecified() -
unsetTechIncubatorItemPrice
public void unsetTechIncubatorItemPrice() -
getTotalRecurringTax
-
setTotalRecurringTax
-
isTotalRecurringTaxSpecified
public boolean isTotalRecurringTaxSpecified() -
unsetTotalRecurringTax
public void unsetTotalRecurringTax() -
getTotalSetupTax
-
setTotalSetupTax
-
isTotalSetupTaxSpecified
public boolean isTotalSetupTaxSpecified() -
unsetTotalSetupTax
public void unsetTotalSetupTax() -
getUsagePrices
-
isUsagePricesSpecified
public boolean isUsagePricesSpecified() -
unsetUsagePrices
public void unsetUsagePrices() -
getUseHourlyPricing
-
setUseHourlyPricing
-
isUseHourlyPricingSpecified
public boolean isUseHourlyPricingSpecified() -
unsetUseHourlyPricing
public void unsetUseHourlyPricing() -
getVirtualGuests
-
isVirtualGuestsSpecified
public boolean isVirtualGuestsSpecified() -
unsetVirtualGuests
public void unsetVirtualGuests()
-