Class Request
java.lang.Object
com.softlayer.api.Type
com.softlayer.api.service.Entity
com.softlayer.api.service.network.firewall.update.Request
@ApiType("SoftLayer_Network_Firewall_Update_Request") public class Request extends Entity
The SoftLayer_Network_Firewall_Update_Request data type contains information relating to a SoftLayer network firewall update request. Use the [[SoftLayer Network Component Firewall]] service to view current rules. Use the [[SoftLayer Network Firewall Template]] service to pull SoftLayer recommended rule set templates.
-
Nested Class Summary
Nested Classes Modifier and Type Class Description static classRequest.Maskstatic interfaceRequest.ServiceThe SoftLayer_Network_Firewall_Update_Request service can be used to create SoftLayer network component firewall rules update requests.static interfaceRequest.ServiceAsync -
Field Summary
Fields Modifier and Type Field Description protected GregorianCalendarapplyDateTimestamp of when the rules from the update request were applied to the firewall.protected booleanapplyDateSpecifiedprotected InterfaceauthorizingUserThe user that authorized this firewall update request.protected LongauthorizingUserIdThe unique identifier of the user that authorized the update request.protected booleanauthorizingUserIdSpecifiedprotected StringauthorizingUserTypeThe type of user that authorized the update request [EMP or USR].protected booleanauthorizingUserTypeSpecifiedprotected BooleanbypassFlagFlag indicating whether the request is for a rule bypass configuration [0 or 1].protected booleanbypassFlagSpecifiedprotected GregorianCalendarcreateDateTimestamp of the creation of the record.protected booleancreateDateSpecifiedprotected LongfirewallContextAccessControlListIdThe unique identifier of the firewall access control list that the rule set is destined for.protected booleanfirewallContextAccessControlListIdSpecifiedprotected GuestguestThe downstream virtual server that the rule set will be applied to.protected HardwarehardwareThe downstream server that the rule set will be applied to.protected LonghardwareIdThe unique identifier of the server that the rule set is destined to protect.protected booleanhardwareIdSpecifiedprotected LongidThe unique identifier of the firewall update request.protected booleanidSpecifiedprotected FirewallnetworkComponentFirewallThe network component firewall that the rule set will be applied to.protected LongnetworkComponentFirewallIdThe unique identifier of the network component firewall that the rule set is destined for.protected booleannetworkComponentFirewallIdSpecifiedprotected LongruleCountA count of the group of rules contained within the update request.protected List<Rule>rulesThe group of rules contained within the update request. -
Constructor Summary
Constructors Constructor Description Request() -
Method Summary
-
Field Details
-
authorizingUser
The user that authorized this firewall update request. -
guest
The downstream virtual server that the rule set will be applied to. -
hardware
The downstream server that the rule set will be applied to. -
networkComponentFirewall
The network component firewall that the rule set will be applied to. -
rules
The group of rules contained within the update request. -
applyDate
Timestamp of when the rules from the update request were applied to the firewall. -
applyDateSpecified
protected boolean applyDateSpecified -
authorizingUserId
The unique identifier of the user that authorized the update request. -
authorizingUserIdSpecified
protected boolean authorizingUserIdSpecified -
authorizingUserType
The type of user that authorized the update request [EMP or USR]. -
authorizingUserTypeSpecified
protected boolean authorizingUserTypeSpecified -
bypassFlag
Flag indicating whether the request is for a rule bypass configuration [0 or 1]. -
bypassFlagSpecified
protected boolean bypassFlagSpecified -
createDate
Timestamp of the creation of the record. -
createDateSpecified
protected boolean createDateSpecified -
firewallContextAccessControlListId
The unique identifier of the firewall access control list that the rule set is destined for. -
firewallContextAccessControlListIdSpecified
protected boolean firewallContextAccessControlListIdSpecified -
hardwareId
The unique identifier of the server that the rule set is destined to protect. -
hardwareIdSpecified
protected boolean hardwareIdSpecified -
id
The unique identifier of the firewall update request. -
idSpecified
protected boolean idSpecified -
networkComponentFirewallId
The unique identifier of the network component firewall that the rule set is destined for. -
networkComponentFirewallIdSpecified
protected boolean networkComponentFirewallIdSpecified -
ruleCount
A count of the group of rules contained within the update request.
-
-
Constructor Details
-
Request
public Request()
-
-
Method Details
-
getAuthorizingUser
-
setAuthorizingUser
-
getGuest
-
setGuest
-
getHardware
-
setHardware
-
getNetworkComponentFirewall
-
setNetworkComponentFirewall
-
getRules
-
getApplyDate
-
setApplyDate
-
isApplyDateSpecified
public boolean isApplyDateSpecified() -
unsetApplyDate
public void unsetApplyDate() -
getAuthorizingUserId
-
setAuthorizingUserId
-
isAuthorizingUserIdSpecified
public boolean isAuthorizingUserIdSpecified() -
unsetAuthorizingUserId
public void unsetAuthorizingUserId() -
getAuthorizingUserType
-
setAuthorizingUserType
-
isAuthorizingUserTypeSpecified
public boolean isAuthorizingUserTypeSpecified() -
unsetAuthorizingUserType
public void unsetAuthorizingUserType() -
getBypassFlag
-
setBypassFlag
-
isBypassFlagSpecified
public boolean isBypassFlagSpecified() -
unsetBypassFlag
public void unsetBypassFlag() -
getCreateDate
-
setCreateDate
-
isCreateDateSpecified
public boolean isCreateDateSpecified() -
unsetCreateDate
public void unsetCreateDate() -
getFirewallContextAccessControlListId
-
setFirewallContextAccessControlListId
-
isFirewallContextAccessControlListIdSpecified
public boolean isFirewallContextAccessControlListIdSpecified() -
unsetFirewallContextAccessControlListId
public void unsetFirewallContextAccessControlListId() -
getHardwareId
-
setHardwareId
-
isHardwareIdSpecified
public boolean isHardwareIdSpecified() -
unsetHardwareId
public void unsetHardwareId() -
getId
-
setId
-
isIdSpecified
public boolean isIdSpecified() -
unsetId
public void unsetId() -
getNetworkComponentFirewallId
-
setNetworkComponentFirewallId
-
isNetworkComponentFirewallIdSpecified
public boolean isNetworkComponentFirewallIdSpecified() -
unsetNetworkComponentFirewallId
public void unsetNetworkComponentFirewallId() -
getRuleCount
-
setRuleCount
-
asService
-
service
-
service
-