Class Event
java.lang.Object
com.softlayer.api.Type
com.softlayer.api.service.Entity
com.softlayer.api.service.network.storage.Event
@ApiType("SoftLayer_Network_Storage_Event") public class Event extends Entity
Storage volumes can create various events to keep track of what has occurred to the volume. Events provide an audit trail that can be used to verify that various tasks have occurred, such as snapshots to be created by a schedule or remote replication synchronization.
- See Also:
- SoftLayer_Network_Storage_Event
-
Nested Class Summary
Nested Classes Modifier and Type Class Description static classEvent.Mask -
Field Summary
Fields Modifier and Type Field Description protected GregorianCalendarcreateDateThe date an event was created.protected booleancreateDateSpecifiedprotected StringmessageThe message text for an event.protected booleanmessageSpecifiedprotected SchedulescheduleA schedule that is associated with an event.protected LongscheduleIdAn identifier for the schedule which is associated with an event.protected booleanscheduleIdSpecifiedprotected TypetypeA Storage volume's event type.protected LongtypeIdAn identifier for the type of an event.protected booleantypeIdSpecifiedprotected StoragevolumeThe associated volume for an event.protected LongvolumeIdThe volume id which an event is associated with.protected booleanvolumeIdSpecifiedFields inherited from class com.softlayer.api.Type
unknownProperties -
Constructor Summary
Constructors Constructor Description Event() -
Method Summary
Modifier and Type Method Description GregorianCalendargetCreateDate()StringgetMessage()SchedulegetSchedule()LonggetScheduleId()TypegetType()LonggetTypeId()StoragegetVolume()LonggetVolumeId()booleanisCreateDateSpecified()booleanisMessageSpecified()booleanisScheduleIdSpecified()booleanisTypeIdSpecified()booleanisVolumeIdSpecified()voidsetCreateDate(GregorianCalendar createDate)voidsetMessage(String message)voidsetSchedule(Schedule schedule)voidsetScheduleId(Long scheduleId)voidsetType(Type type)voidsetTypeId(Long typeId)voidsetVolume(Storage volume)voidsetVolumeId(Long volumeId)voidunsetCreateDate()voidunsetMessage()voidunsetScheduleId()voidunsetTypeId()voidunsetVolumeId()Methods inherited from class com.softlayer.api.Type
getUnknownProperties, setUnknownProperties
-
Field Details
-
schedule
A schedule that is associated with an event. Not all events will have a schedule. -
type
A Storage volume's event type. The type provides a standardized definition for an event. -
volume
The associated volume for an event. -
createDate
The date an event was created. -
createDateSpecified
protected boolean createDateSpecified -
message
The message text for an event. -
messageSpecified
protected boolean messageSpecified -
scheduleId
An identifier for the schedule which is associated with an event. -
scheduleIdSpecified
protected boolean scheduleIdSpecified -
typeId
An identifier for the type of an event. -
typeIdSpecified
protected boolean typeIdSpecified -
volumeId
The volume id which an event is associated with. -
volumeIdSpecified
protected boolean volumeIdSpecified
-
-
Constructor Details
-
Event
public Event()
-
-
Method Details
-
getSchedule
-
setSchedule
-
getType
-
setType
-
getVolume
-
setVolume
-
getCreateDate
-
setCreateDate
-
isCreateDateSpecified
public boolean isCreateDateSpecified() -
unsetCreateDate
public void unsetCreateDate() -
getMessage
-
setMessage
-
isMessageSpecified
public boolean isMessageSpecified() -
unsetMessage
public void unsetMessage() -
getScheduleId
-
setScheduleId
-
isScheduleIdSpecified
public boolean isScheduleIdSpecified() -
unsetScheduleId
public void unsetScheduleId() -
getTypeId
-
setTypeId
-
isTypeIdSpecified
public boolean isTypeIdSpecified() -
unsetTypeId
public void unsetTypeId() -
getVolumeId
-
setVolumeId
-
isVolumeIdSpecified
public boolean isVolumeIdSpecified() -
unsetVolumeId
public void unsetVolumeId()
-